/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyTuple__nlLlqVveYUlcdyx2e2bPTw tyTuple__nlLlqVveYUlcdyx2e2bPTw;
typedef struct tyTuple__9cqHuynYNPU9avbszh3XtBAg tyTuple__9cqHuynYNPU9avbszh3XtBAg;
typedef struct tyTuple__flePlH29a9c9cGo1Wdll1KDOQ tyTuple__flePlH29a9c9cGo1Wdll1KDOQ;
typedef struct tyTuple__HFn8JzZZeLZ9aKrFg4S9a7HA tyTuple__HFn8JzZZeLZ9aKrFg4S9a7HA;
typedef struct tyTuple__Fb1Z8PVtzpSjrvQ67oA88w tyTuple__Fb1Z8PVtzpSjrvQ67oA88w;
typedef struct tyTuple__QVkyTCL0msoEdWvhK6TYrw tyTuple__QVkyTCL0msoEdWvhK6TYrw;
typedef struct tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyTuple__nlLlqVveYUlcdyx2e2bPTw {
NimStringDesc* Field0;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NI Field5;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
struct tyTuple__9cqHuynYNPU9avbszh3XtBAg {
NimStringDesc* Field0;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag Field1;
};
struct tyTuple__flePlH29a9c9cGo1Wdll1KDOQ {
NimStringDesc* Field0;
NimStringDesc* Field1;
NCSTRING Field2;
};
typedef NU16 tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA;
struct tyTuple__HFn8JzZZeLZ9aKrFg4S9a7HA {
NimStringDesc* Field0;
tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA Field1;
};
typedef NU8 tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA;
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyTuple__Fb1Z8PVtzpSjrvQ67oA88w {
NimStringDesc* Field0;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw Field1;
};
typedef NU8 tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA;
struct tyTuple__QVkyTCL0msoEdWvhK6TYrw {
NimStringDesc* Field0;
tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA Field1;
tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA Field2;
};
struct tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ {
NimStringDesc* rdoccmd;
NimStringDesc* docCmd;
NimStringDesc* code;
NI index;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__45fPtFhY4FavRaYwDhRfuA)(NimStringDesc** s, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__sCg9bHpRxLXpSphc63mtWdw)(NimStringDesc** s, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__wRMAZHpaipmaQ037ptRATQ)(NimStringDesc** s, NI x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__2NPdL9cn8CBwngwsy2yb9bcg)(NimStringDesc** s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__ARWLtdz6aJCA2LIYS9cFiGQ)(NimStringDesc** s, NCSTRING x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__1G4urwoNQVZWpvb9cOSxyDg)(NimStringDesc** s, tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__doMKFdUqCnGTD5AcDAmwhg)(tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__a1NjIrFmhV6Q9aR4YbBJQ5g)(NimStringDesc** s, tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__bNErf7GhjMrVOemPdPJ2MQ)(NimStringDesc** s, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__VkbNubvSrpK6VayQ9aRjUvA)(NimStringDesc** s, tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA x);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__Eys2fLM61EBlquSM8n9cIsw)(NimStringDesc** s, NI x);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_2, "0", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_3, "(", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_4, ", ", 2);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_5, ",", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_6, ")", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_7, "nil", 3);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_8, "{", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_9, "}", 1);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_10, "rdoccmd", 7);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_11, ": ", 2);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_12, "docCmd", 6);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_13, "code", 4);
STRING_LITERAL(TM__n49a9aYp5BrbXv9a6OCpJYm0g_14, "index", 5);

/* section: NIM_merge_PROCS */
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___M2d4UEGH9cZOvte6rEhvUTQ)(NU64 x) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!(x == 0ULL)) goto LA3_;
		result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_2));
	}
	goto LA1_;
	LA3_: ;
	{
		NI i;
		NU64 n;
		NI half;
		result = mnewString(((NI) 60));
		i = ((NI) 0);
		n = x;
		{
			while (1) {
				NU64 nn;
				if (!!((n == 0ULL))) goto LA7;
				nn = (NU64)((NU64)(n) / (NU64)(10ULL));
				result->data[i] = ((NIM_CHAR) ((NU64)((NU64)((NU64)((NU64)(n) - (NU64)((NU64)((NU64)(10ULL) * (NU64)(nn))))) + (NU64)(48ULL))));
				i += ((NI) 1);
				n = nn;
			} LA7: ;
		}
		result = setLengthStr(result, ((NI) (i)));
		half = (NI)(i / ((NI) 2));
		{
			NI t;
			NI colontmp_;
			NI res;
			t = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = (NI)(half - ((NI) 1));
			res = ((NI) 0);
			{
				while (1) {
					NIM_CHAR T11_;
					if (!(res <= colontmp_)) goto LA10;
					t = res;
					T11_ = (NIM_CHAR)0;
					T11_ = result->data[t];
					result->data[t] = result->data[(NI)((NI)(i - t) - ((NI) 1))];
					result->data[(NI)((NI)(i - t) - ((NI) 1))] = T11_;
					res += ((NI) 1);
				} LA10: ;
			}
		}
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___HBZb4pgGTJ0NuRxlEYFytw)(tyTuple__nlLlqVveYUlcdyx2e2bPTw x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__sCg9bHpRxLXpSphc63mtWdw((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field2);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA15_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field3);
	{
		if (!(((NI) 0) < count)) goto LA19_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA19_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field4);
	{
		if (!(((NI) 0) < count)) goto LA23_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA23_: ;
	count += ((NI) 1);
	addQuoted__wRMAZHpaipmaQ037ptRATQ((&result), x.Field5);
	{
		if (!(count == ((NI) 1))) goto LA27_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA27_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___XSFzZuEhhtAqOvJ5uRr9cuA)(tyTuple__9cqHuynYNPU9avbszh3XtBAg x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__2NPdL9cn8CBwngwsy2yb9bcg((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___uRqZ9b9aRtL1gygwVfSa9bmlQ)(tyTuple__flePlH29a9c9cGo1Wdll1KDOQ x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	count += ((NI) 1);
	{
		if (!(x.Field2 == 0)) goto LA15_;
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_7));
	}
	goto LA13_;
	LA15_: ;
	{
		addQuoted__ARWLtdz6aJCA2LIYS9cFiGQ((&result), x.Field2);
	}
	LA13_: ;
	{
		if (!(count == ((NI) 1))) goto LA20_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA20_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, collectionToString__doMKFdUqCnGTD5AcDAmwhg)(tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA x, NimStringDesc* prefix, NimStringDesc* separator, NimStringDesc* suffix) {
	NimStringDesc* result;
	NIM_BOOL firstElement;
	result = (NimStringDesc*)0;
	result = copyString(prefix);
	firstElement = NIM_TRUE;
	{
		tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA value;
		NI i;
		value = (tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i <= ((NI) 8))) goto LA3;
				{
					if (!((x &((NU16)1<<((NU)(((tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA) (i)))&15U)))!=0)) goto LA6_;
					value = ((tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA) (i));
					{
						if (!firstElement) goto LA10_;
						firstElement = NIM_FALSE;
					}
					goto LA8_;
					LA10_: ;
					{
						result = resizeString(result, (separator ? separator->Sup.len : 0) + 0);
appendString(result, separator);
					}
					LA8_: ;
					addQuoted__a1NjIrFmhV6Q9aR4YbBJQ5g((&result), value);
				}
				LA6_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = resizeString(result, (suffix ? suffix->Sup.len : 0) + 0);
appendString(result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___rwI9b63GTi28OPn2o8TnuVg)(tySet_tyEnum_FilePermission__uTVeDpjCH6aWw9c74YkAskA x) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = collectionToString__doMKFdUqCnGTD5AcDAmwhg(x, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_8), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4), ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_9));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___VhyooW9cjC7wNKZM71oRg9cg)(tyTuple__HFn8JzZZeLZ9aKrFg4S9a7HA x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__1G4urwoNQVZWpvb9cOSxyDg((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___HZ7mfC6lJSSHM4bdhgCYTg)(tyTuple__Fb1Z8PVtzpSjrvQ67oA88w x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__bNErf7GhjMrVOemPdPJ2MQ((&result), x.Field1);
	{
		if (!(count == ((NI) 1))) goto LA11_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA11_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___NDGD2HOmz0EkwXFFCD1T6w)(tyTuple__QVkyTCL0msoEdWvhK6TYrw x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__VkbNubvSrpK6VayQ9aRjUvA((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__VkbNubvSrpK6VayQ9aRjUvA((&result), x.Field2);
	{
		if (!(count == ((NI) 1))) goto LA15_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA15_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___IgedJtiWLIr01rtDe6Fo8Q)(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	result = resizeString(result, 7);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_10));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_11));
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.rdoccmd);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	result = resizeString(result, 6);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_12));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_11));
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.docCmd);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	result = resizeString(result, 4);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_13));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_11));
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.code);
	{
		if (!(((NI) 0) < count)) goto LA15_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA15_: ;
	result = resizeString(result, 5);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_14));
	result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_11));
	count += ((NI) 1);
	addQuoted__Eys2fLM61EBlquSM8n9cIsw((&result), x.index);
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___TxnkcKaQe5poR9bunjJ8j7A)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg x) {
	NimStringDesc* result;
	NI count;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_3));
	count = ((NI) 0);
	{
		if (!(((NI) 0) < count)) goto LA3_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA3_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field0);
	{
		if (!(((NI) 0) < count)) goto LA7_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA7_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field1);
	{
		if (!(((NI) 0) < count)) goto LA11_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_4));
	}
	LA11_: ;
	count += ((NI) 1);
	addQuoted__45fPtFhY4FavRaYwDhRfuA((&result), x.Field2);
	{
		if (!(count == ((NI) 1))) goto LA15_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_5));
	}
	LA15_: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__n49a9aYp5BrbXv9a6OCpJYm0g_6));
	return result;
}
