/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <stdio.h>
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw {
NIM_BOOL enabled;
FILE* f;
NimStringDesc* buf;
NimStringDesc* filename;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* syms;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg;
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__cb1k9citqyT9a9brBSJAz8pkg)(NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, doWrite__1nU29cZKUVlth4bckzRe6Tw)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, write__y2dplmr7ar8o7Yykk7MOlA)(FILE* f, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, writeRope__FwuzOBq6SLlanVUstm8q9cA)(FILE* f, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0);
N_LIB_PRIVATE N_NIMCALL(void, write__PArlm09bKklm2BLsCg6YtaA)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, close__fU6ZlJAtQ9bre04EDZLdGsA_3)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(void, reset__wWlgiv42bMjPaZIPtEb67w)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** obj);
N_LIB_PRIVATE N_NIMCALL(void, reset__oB9cU60GMAKcBJZRXAVlNxA)(NimStringDesc** obj);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__9cEuXfAnHp9bnWFK409cMtsEw_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__XBeRj4rw9bUuE7CB3DS1rgg_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
STRING_LITERAL(TM__QVKrxgdkvZgAHGFrhgVOcA_3, "ndi.nim(44, 14) `f.f != nil` ", 29);
STRING_LITERAL(TM__QVKrxgdkvZgAHGFrhgVOcA_4, "\011", 1);
STRING_LITERAL(TM__QVKrxgdkvZgAHGFrhgVOcA_5, "\012", 1);

/* section: NIM_merge_PROCS */
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, open__jmWVcl5Qp9atJWCEkvq1SfA)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils(filename);
	(*f).enabled = !(T1_);
	{
		if (!(*f).enabled) goto LA4_;
		unsureAsgnRef((void**) (&(*f).filename), copyString(filename));
		unsureAsgnRef((void**) (&(*f).buf), rawNewString(((NI) 20)));
	}
	LA4_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(void, writeLine__45Em82MGXqv9biomV0DEbSgio)(FILE* f, NimStringDesc** x, NI xLen_0) {
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < xLen_0)) goto LA3;
				i = (&x[i_2]);
				write__PArlm09bKklm2BLsCg6YtaA(f, (*i));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	write__PArlm09bKklm2BLsCg6YtaA(f, ((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_5));
}
N_LIB_PRIVATE N_NIMCALL(void, doWrite__1nU29cZKUVlth4bckzRe6Tw)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyArray__Re75IspeoxXy2oCZHwcRrA T1_;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T2_;
	unsureAsgnRef((void**) (&(*f).buf), setLengthStr((*f).buf, ((NI) 0)));
	addInt__mftMOxbyu0h4yByfs3sqjA((&(*f).buf), ((NI64) (((NI) ((*s).info.line)))));
	unsureAsgnRef((void**) (&(*f).buf), resizeString((*f).buf, 1));
appendString((*f).buf, ((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_4));
	addInt__mftMOxbyu0h4yByfs3sqjA((&(*f).buf), ((NI64) (((NI) ((*s).info.col)))));
	nimZeroMem((void*)T1_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T1_[0] = copyString((*(*s).name).s);
	T1_[1] = copyString(((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_4));
	write__y2dplmr7ar8o7Yykk7MOlA((*f).f, T1_, 2);
	writeRope__FwuzOBq6SLlanVUstm8q9cA((*f).f, (*s).loc.r);
	nimZeroMem((void*)T2_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_4));
	T2_[1] = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, (*s).info.fileIndex);
	T2_[2] = copyString(((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_4));
	T2_[3] = copyString((*f).buf);
	writeLine__45Em82MGXqv9biomV0DEbSgio((*f).f, T2_, 4);
}
N_LIB_PRIVATE N_NIMCALL(void, close__yy9bzEsQhd9bXopz79cWnxXdw)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		if (!(*f).enabled) goto LA3_;
		(*f).f = open__cb1k9citqyT9a9brBSJAz8pkg((*f).filename, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 1), ((NI) 8000));
		{
			NimStringDesc* T9_;
			if (!!(!(((*f).f == ((FILE*) NIM_NIL))))) goto LA7_;
			T9_ = (NimStringDesc*)0;
			T9_ = rawNewString(((*f).filename ? (*f).filename->Sup.len : 0) + 29);
appendString(T9_, ((NimStringDesc*) &TM__QVKrxgdkvZgAHGFrhgVOcA_3));
appendString(T9_, (*f).filename);
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(T9_);
		}
		LA7_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** s;
			NI i;
			NI L;
			NI T11_;
			s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
			i = ((NI) 0);
			T11_ = ((*f).syms ? (*f).syms->Sup.len : 0);
			L = T11_;
			{
				while (1) {
					if (!(i < L)) goto LA13;
					s = &(*f).syms->data[i];
					doWrite__1nU29cZKUVlth4bckzRe6Tw(f, (*s), conf);
					i += ((NI) 1);
				} LA13: ;
			}
		}
		close__fU6ZlJAtQ9bre04EDZLdGsA_3((*f).f);
		reset__wWlgiv42bMjPaZIPtEb67w((&(*f).syms));
		reset__oB9cU60GMAKcBJZRXAVlNxA((&(*f).filename));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_ndiDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[5];
static TNimNode TM__QVKrxgdkvZgAHGFrhgVOcA_0[6];

/* section: NIM_merge_TYPE_INIT3 */
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.size = sizeof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw);
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.align = NIM_ALIGNOF(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw);
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.kind = 18;
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.base = 0;
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.flags = 2;
TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[0] = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[1];
TM__QVKrxgdkvZgAHGFrhgVOcA_0[1].kind = 1;
TM__QVKrxgdkvZgAHGFrhgVOcA_0[1].offset = offsetof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw, enabled);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[1].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[1].name = "enabled";
TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[1] = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[2];
TM__QVKrxgdkvZgAHGFrhgVOcA_0[2].kind = 1;
TM__QVKrxgdkvZgAHGFrhgVOcA_0[2].offset = offsetof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw, f);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[2].typ = (&NTI__XBeRj4rw9bUuE7CB3DS1rgg_);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[2].name = "f";
TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[2] = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[3];
TM__QVKrxgdkvZgAHGFrhgVOcA_0[3].kind = 1;
TM__QVKrxgdkvZgAHGFrhgVOcA_0[3].offset = offsetof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw, buf);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[3].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[3].name = "buf";
TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[3] = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[4];
TM__QVKrxgdkvZgAHGFrhgVOcA_0[4].kind = 1;
TM__QVKrxgdkvZgAHGFrhgVOcA_0[4].offset = offsetof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw, filename);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[4].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[4].name = "filename";
TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[4] = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[5];
TM__QVKrxgdkvZgAHGFrhgVOcA_0[5].kind = 1;
TM__QVKrxgdkvZgAHGFrhgVOcA_0[5].offset = offsetof(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw, syms);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[5].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__QVKrxgdkvZgAHGFrhgVOcA_0[5].name = "syms";
TM__QVKrxgdkvZgAHGFrhgVOcA_0[0].len = 5; TM__QVKrxgdkvZgAHGFrhgVOcA_0[0].kind = 2; TM__QVKrxgdkvZgAHGFrhgVOcA_0[0].sons = &TM__QVKrxgdkvZgAHGFrhgVOcA_2_5[0];
NTI__9cEuXfAnHp9bnWFK409cMtsEw_.node = &TM__QVKrxgdkvZgAHGFrhgVOcA_0[0];
}

