/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ;
typedef struct tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg;
typedef struct RootObj RootObj;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ;
typedef struct tySequence__Ih0V9cYug0VPJyBBGvgEH7Q tySequence__Ih0V9cYug0VPJyBBGvgEH7Q;
typedef struct tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg;
typedef struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg {
  RootObj Sup;
NI bufpos;
NimStringDesc* buf;
tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* input;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars;
};
typedef NU8 tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw;
typedef NU8 tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA;
typedef NU8 tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew;
struct tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ {
  tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg Sup;
NimStringDesc* a;
tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw tok;
tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA kind;
tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew err;
tySequence__Ih0V9cYug0VPJyBBGvgEH7Q* state;
NimStringDesc* filename;
NIM_BOOL rawStringLiterals;
};
typedef NU8 tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw {
  tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA Sup;
};
struct tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg {
  tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw Sup;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NimStringDesc* tyArray__FkG8aLMyiZfDjueUwWl3WA[14];
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__Ih0V9cYug0VPJyBBGvgEH7Q {
  TGenericSeq Sup;
  tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_NIMCALL(void, Marker_tySequence__Ih0V9cYug0VPJyBBGvgEH7Q)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, open__P89aGatd6bDNJ0Ak5E9cQgWw)(tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* L, tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* input, NI bufLen, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw, getTok__9cGllg9a4hN9cmfjsUw6zu39bQ)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, skip__FPdQ9beZqb3bJ7eVHJww6Qg_2)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NI, handleCR__sLQC1Z9cokufE3lZEw9b42Cw)(tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(NI, handleLF__sLQC1Z9cokufE3lZEw9b42Cw_3)(tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(void, parseNumber__FPdQ9beZqb3bJ7eVHJww6Qg_3)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw, parseString__9cGllg9a4hN9cmfjsUw6zu39bQ_2)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NI, parseEscapedUTF16__MMwgsOXZK0fQw6h7UQcVsQ)(NCSTRING buf, NI* pos);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleHexChar__Avai9b5a9bb83l1HPqx75AfA)(NIM_CHAR c, NI* x);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nuctoUTF8)(NI32 c);
N_LIB_PRIVATE N_NIMCALL(void, parseName__FPdQ9beZqb3bJ7eVHJww6Qg_4)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ, pop__wGIX8i2tVhp4gFSPlGuf2gsystem)(tySequence__Ih0V9cYug0VPJyBBGvgEH7Q** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, next__FPdQ9beZqb3bJ7eVHJww6Qg)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__PyuSdojUZWOAnzN7dInq1Q)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, errorMsgExpected__wyJNOK33UcOVCdJ9aSuAbOw)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my, NimStringDesc* e);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
static N_INLINE(NI, getLine__cAlRX82MU9aihWfxn79b1A6wparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
static N_INLINE(NI, getColumn__cAlRX82MU9aihWfxn79b1A6w_2parsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NI, getColNumber__KUMaHICF9bUPO7tt6hrBs3g)(tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* L, NI pos);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, NimStringDesc* msg) __attribute__((noreturn));

/* section: NIM_merge_DATA */
extern TNimType NTI__MAw8rJZtJ279bVV3TWMtXSg_;
N_LIB_PRIVATE TNimType NTI__KWIQnzXEOUqdWsnCUL9atyQ_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__Q9c4KaNqJU4PbXaGht0C7iw_;
N_LIB_PRIVATE TNimType NTI__0zjE9c54eTrq224F5wMcaFA_;
N_LIB_PRIVATE TNimType NTI__G9cw5MrJXJrcpID5JXaplew_;
N_LIB_PRIVATE TNimType NTI__Na0rM2Zdr3RpxeNeXbvLrQ_;
N_LIB_PRIVATE TNimType NTI__Ih0V9cYug0VPJyBBGvgEH7Q_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__nIinruGrC8EPIfjL3PuTvA_15 = {
0x00, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_16, "0.", 2);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__nIinruGrC8EPIfjL3PuTvA_17 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x20, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_18, "null", 4);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_19, "true", 4);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_20, "false", 5);
extern TNimType NTI__yoNlBGx0D2tRizIdhQuENw_;
N_LIB_PRIVATE TNimType NTI__XTejXaID1NT7KS9byQm3Jxg_;
N_LIB_PRIVATE TNimType NTI__PyuSdojUZWOAnzN7dInq1Q_;
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_21, "$1($2, $3) Error: $4", 20);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_22, " expected", 9);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_23, "invalid token", 13);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_24, "EOF", 3);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_25, "string literal", 14);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_26, "int literal", 11);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_27, "float literal", 13);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_28, "{", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_29, "}", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_30, "[", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_31, "]", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_32, ":", 1);
STRING_LITERAL(TM__nIinruGrC8EPIfjL3PuTvA_33, ",", 1);
N_LIB_PRIVATE NIM_CONST tyArray__FkG8aLMyiZfDjueUwWl3WA tokToStr__JGKyaHusNBrTLCQ7XiBnyw = {((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_23),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_24),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_25),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_26),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_27),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_19),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_20),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_18),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_28),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_29),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_30),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_31),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_32),
((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_33)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__Ih0V9cYug0VPJyBBGvgEH7Q)(void* p, NI op) {
	tySequence__Ih0V9cYug0VPJyBBGvgEH7Q* a;
	NI T1_;
	a = (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(void, open__caSf5pJv2JnMMpxc9bAhdpA)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my, tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* input, NimStringDesc* filename, NIM_BOOL rawStringLiterals) {
	tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T1_;
	T1_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
	T1_ = &my->Sup;
	open__P89aGatd6bDNJ0Ak5E9cQgWw(T1_, input, ((NI) 8192), TM__nIinruGrC8EPIfjL3PuTvA_15);
	unsureAsgnRef((void**) (&(*my).filename), copyString(filename));
	unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) newSeq((&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_), 1));
	(*my).state->data[0] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 1);
	(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
	unsureAsgnRef((void**) (&(*my).a), ((NimStringDesc*) NIM_NIL));
	(*my).rawStringLiterals = rawStringLiterals;
}
N_LIB_PRIVATE N_NIMCALL(void, skip__FPdQ9beZqb3bJ7eVHJww6Qg_2)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		while (1) {
			switch (((NU8)((*my).Sup.buf->data[pos]))) {
			case 47:
			{
				{
					if (!((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(47))) goto LA6_;
					pos += ((NI) 2);
					{
						while (1) {
							switch (((NU8)((*my).Sup.buf->data[pos]))) {
							case 0:
							{
								goto LA8;
							}
							break;
							case 13:
							{
								tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T12_;
								T12_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
								T12_ = &my->Sup;
								pos = handleCR__sLQC1Z9cokufE3lZEw9b42Cw(T12_, pos);
								goto LA8;
							}
							break;
							case 10:
							{
								tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T14_;
								T14_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
								T14_ = &my->Sup;
								pos = handleLF__sLQC1Z9cokufE3lZEw9b42Cw_3(T14_, pos);
								goto LA8;
							}
							break;
							default:
							{
								pos += ((NI) 1);
							}
							break;
							}
						}
					} LA8: ;
				}
				goto LA4_;
				LA6_: ;
				{
					if (!((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(42))) goto LA17_;
					pos += ((NI) 2);
					{
						while (1) {
							switch (((NU8)((*my).Sup.buf->data[pos]))) {
							case 0:
							{
								(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 8);
								goto LA19;
							}
							break;
							case 13:
							{
								tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T23_;
								T23_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
								T23_ = &my->Sup;
								pos = handleCR__sLQC1Z9cokufE3lZEw9b42Cw(T23_, pos);
							}
							break;
							case 10:
							{
								tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T25_;
								T25_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
								T25_ = &my->Sup;
								pos = handleLF__sLQC1Z9cokufE3lZEw9b42Cw_3(T25_, pos);
							}
							break;
							case 42:
							{
								pos += ((NI) 1);
								{
									if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(47))) goto LA29_;
									pos += ((NI) 1);
									goto LA19;
								}
								LA29_: ;
							}
							break;
							default:
							{
								pos += ((NI) 1);
							}
							break;
							}
						}
					} LA19: ;
				}
				goto LA4_;
				LA17_: ;
				{
					goto LA1;
				}
				LA4_: ;
			}
			break;
			case 32:
			case 9:
			{
				pos += ((NI) 1);
			}
			break;
			case 13:
			{
				tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T35_;
				T35_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
				T35_ = &my->Sup;
				pos = handleCR__sLQC1Z9cokufE3lZEw9b42Cw(T35_, pos);
			}
			break;
			case 10:
			{
				tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T37_;
				T37_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
				T37_ = &my->Sup;
				pos = handleLF__sLQC1Z9cokufE3lZEw9b42Cw_3(T37_, pos);
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	(*my).Sup.bufpos = pos;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseNumber__FPdQ9beZqb3bJ7eVHJww6Qg_3)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(45))) goto LA3_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 45));
		pos += ((NI) 1);
	}
	LA3_: ;
	{
		if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(46))) goto LA7_;
		unsureAsgnRef((void**) (&(*my).a), resizeString((*my).a, 2));
appendString((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_16));
		pos += ((NI) 1);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA11;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA11: ;
		}
		{
			if (!((NU8)((*my).Sup.buf->data[pos]) == (NU8)(46))) goto LA14_;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 46));
			pos += ((NI) 1);
		}
		LA14_: ;
	}
	LA5_: ;
	{
		while (1) {
			if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA17;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
			pos += ((NI) 1);
		} LA17: ;
	}
	{
		if (!(((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(69)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(101)))) goto LA20_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
		pos += ((NI) 1);
		{
			if (!(((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(43)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(45)))) goto LA24_;
			unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
			pos += ((NI) 1);
		}
		LA24_: ;
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)))) goto LA27;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA27: ;
		}
	}
	LA20_: ;
	(*my).Sup.bufpos = pos;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleHexChar__Avai9b5a9bb83l1HPqx75AfA)(NIM_CHAR c, NI* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	switch (((NU8)(c))) {
	case 48 ... 57:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)(((NU8)(c)) - ((NI) 48)));
	}
	break;
	case 97 ... 102:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)((NI)(((NU8)(c)) - ((NI) 97)) + ((NI) 10)));
	}
	break;
	case 65 ... 70:
	{
		(*x) = (NI)((NI)((NU64)((*x)) << (NU64)(((NI) 4))) | (NI)((NI)(((NU8)(c)) - ((NI) 65)) + ((NI) 10)));
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, parseEscapedUTF16__MMwgsOXZK0fQw6h7UQcVsQ)(NCSTRING buf, NI* pos) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI _;
		NI res;
		_ = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= ((NI) 3))) goto LA3;
				_ = res;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = handleHexChar__Avai9b5a9bb83l1HPqx75AfA(buf[(*pos)], (&result));
					if (!T6_) goto LA7_;
					(*pos) += ((NI) 1);
				}
				goto LA4_;
				LA7_: ;
				{
					result = ((NI) -1);
					goto BeforeRet_;
				}
				LA4_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw, parseString__9cGllg9a4hN9cmfjsUw6zu39bQ_2)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw result;
	NI pos;
	result = (tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw)0;
	result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 2);
	pos = (NI)((*my).Sup.bufpos + ((NI) 1));
	{
		if (!(*my).rawStringLiterals) goto LA3_;
		unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 34));
	}
	LA3_: ;
	{
		while (1) {
			switch (((NU8)((*my).Sup.buf->data[pos]))) {
			case 0:
			{
				(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 7);
				result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 0);
				goto LA5;
			}
			break;
			case 34:
			{
				{
					if (!(*my).rawStringLiterals) goto LA11_;
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 34));
				}
				LA11_: ;
				pos += ((NI) 1);
				goto LA5;
			}
			break;
			case 92:
			{
				{
					if (!(*my).rawStringLiterals) goto LA16_;
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 92));
				}
				LA16_: ;
				switch (((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]))) {
				case 92:
				case 34:
				case 39:
				case 47:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[(NI)(pos + ((NI) 1))]));
					pos += ((NI) 2);
				}
				break;
				case 98:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 8));
					pos += ((NI) 2);
				}
				break;
				case 102:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 12));
					pos += ((NI) 2);
				}
				break;
				case 110:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 10));
					pos += ((NI) 2);
				}
				break;
				case 114:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 13));
					pos += ((NI) 2);
				}
				break;
				case 116:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 9));
					pos += ((NI) 2);
				}
				break;
				case 118:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 11));
					pos += ((NI) 2);
				}
				break;
				case 117:
				{
					NI pos2;
					NI r;
					{
						if (!(*my).rawStringLiterals) goto LA28_;
						unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 117));
					}
					LA28_: ;
					pos += ((NI) 2);
					pos2 = pos;
					r = parseEscapedUTF16__MMwgsOXZK0fQw6h7UQcVsQ(nimToCStringConv((*my).Sup.buf), (&pos));
					{
						if (!(r < ((NI) 0))) goto LA32_;
						(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 1);
						goto LA5;
					}
					LA32_: ;
					{
						NI s;
						if (!((NI)(r & ((NI) 64512)) == ((NI) 55296))) goto LA36_;
						{
							NIM_BOOL T40_;
							T40_ = (NIM_BOOL)0;
							T40_ = !(((NU8)((*my).Sup.buf->data[pos]) == (NU8)(92)));
							if (T40_) goto LA41_;
							T40_ = !(((NU8)((*my).Sup.buf->data[(NI)(pos + ((NI) 1))]) == (NU8)(117)));
							LA41_: ;
							if (!T40_) goto LA42_;
							(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 1);
							goto LA5;
						}
						LA42_: ;
						pos += ((NI) 2);
						s = parseEscapedUTF16__MMwgsOXZK0fQw6h7UQcVsQ(nimToCStringConv((*my).Sup.buf), (&pos));
						{
							NIM_BOOL T46_;
							T46_ = (NIM_BOOL)0;
							T46_ = ((NI)(s & ((NI) 64512)) == ((NI) 56320));
							if (!(T46_)) goto LA47_;
							T46_ = (((NI) 0) < s);
							LA47_: ;
							if (!T46_) goto LA48_;
							r = (NI)(((NI) 65536) + (NI)((NI)((NU64)((NI)(r - ((NI) 55296))) << (NU64)(((NI) 10))) | (NI)(s - ((NI) 56320))));
						}
						goto LA44_;
						LA48_: ;
						{
							(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 1);
							goto LA5;
						}
						LA44_: ;
					}
					LA36_: ;
					{
						NI length;
						if (!(*my).rawStringLiterals) goto LA53_;
						length = (NI)(pos - pos2);
						{
							NI i;
							NI res;
							i = (NI)0;
							res = ((NI) 1);
							{
								while (1) {
									if (!(res <= length)) goto LA57;
									i = res;
									{
										if (!(((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(57)) || ((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(70)) || ((NU8)((*my).Sup.buf->data[pos2])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos2])) <= ((NU8)(102)))) goto LA60_;
										unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos2]));
										pos2 += ((NI) 1);
									}
									goto LA58_;
									LA60_: ;
									{
										goto LA55;
									}
									LA58_: ;
									res += ((NI) 1);
								} LA57: ;
							}
						} LA55: ;
					}
					goto LA51_;
					LA53_: ;
					{
						NimStringDesc* T64_;
						T64_ = (NimStringDesc*)0;
						T64_ = nuctoUTF8(((NI32) (r)));
						unsureAsgnRef((void**) (&(*my).a), resizeString((*my).a, (T64_ ? T64_->Sup.len : 0) + 0));
appendString((*my).a, T64_);
					}
					LA51_: ;
				}
				break;
				default:
				{
					unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
					pos += ((NI) 1);
				}
				break;
				}
			}
			break;
			case 13:
			{
				tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T67_;
				T67_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
				T67_ = &my->Sup;
				pos = handleCR__sLQC1Z9cokufE3lZEw9b42Cw(T67_, pos);
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 13));
			}
			break;
			case 10:
			{
				tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T69_;
				T69_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
				T69_ = &my->Sup;
				pos = handleLF__sLQC1Z9cokufE3lZEw9b42Cw_3(T69_, pos);
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, 10));
			}
			break;
			default:
			{
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			}
			break;
			}
		}
	} LA5: ;
	(*my).Sup.bufpos = pos;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, parseName__FPdQ9beZqb3bJ7eVHJww6Qg_4)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI pos;
	pos = (*my).Sup.bufpos;
	{
		if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(122)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(90)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(95)))) goto LA3_;
		{
			while (1) {
				if (!(((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(97)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(122)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(65)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(90)) || ((NU8)((*my).Sup.buf->data[pos])) >= ((NU8)(48)) && ((NU8)((*my).Sup.buf->data[pos])) <= ((NU8)(57)) || ((NU8)((*my).Sup.buf->data[pos])) == ((NU8)(95)))) goto LA6;
				unsureAsgnRef((void**) (&(*my).a), addChar((*my).a, (*my).Sup.buf->data[pos]));
				pos += ((NI) 1);
			} LA6: ;
		}
	}
	LA3_: ;
	(*my).Sup.bufpos = pos;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw, getTok__9cGllg9a4hN9cmfjsUw6zu39bQ)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw result;
	result = (tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw)0;
	unsureAsgnRef((void**) (&(*my).a), setLengthStr((*my).a, ((NI) 0)));
	skip__FPdQ9beZqb3bJ7eVHJww6Qg_2(my);
	switch (((NU8)((*my).Sup.buf->data[(*my).Sup.bufpos]))) {
	case 45:
	case 46:
	case 48 ... 57:
	{
		parseNumber__FPdQ9beZqb3bJ7eVHJww6Qg_3(my);
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ((*my).a, TM__nIinruGrC8EPIfjL3PuTvA_17);
			if (!T4_) goto LA5_;
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 4);
		}
		goto LA2_;
		LA5_: ;
		{
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 3);
		}
		LA2_: ;
	}
	break;
	case 34:
	{
		result = parseString__9cGllg9a4hN9cmfjsUw6zu39bQ_2(my);
	}
	break;
	case 91:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 10);
	}
	break;
	case 123:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 8);
	}
	break;
	case 93:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 11);
	}
	break;
	case 125:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 9);
	}
	break;
	case 44:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 13);
	}
	break;
	case 58:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 12);
	}
	break;
	case 0:
	{
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 1);
	}
	break;
	case 97 ... 122:
	case 65 ... 90:
	case 95:
	{
		parseName__FPdQ9beZqb3bJ7eVHJww6Qg_4(my);
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_18))) goto LA17_;
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_19))) goto LA18_;
		if (eqStrings((*my).a, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_20))) goto LA19_;
		goto LA20_;
		LA17_: ;
		{
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 7);
		}
		goto LA21_;
		LA18_: ;
		{
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 5);
		}
		goto LA21_;
		LA19_: ;
		{
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 6);
		}
		goto LA21_;
		LA20_: ;
		{
			result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 0);
		}
		LA21_: ;
	}
	break;
	default:
	{
		(*my).Sup.bufpos += ((NI) 1);
		result = ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 0);
	}
	break;
	}
	(*my).tok = result;
	return result;
}
static N_INLINE(tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ, pop__wGIX8i2tVhp4gFSPlGuf2gsystem)(tySequence__Ih0V9cYug0VPJyBBGvgEH7Q** s) {
	tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ result;
	NI L;
	NI T1_;
	result = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) setLengthSeqV2(&((*s))->Sup, (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, next__FPdQ9beZqb3bJ7eVHJww6Qg)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw tk;
	NI i;
	NI T1_;
	tk = getTok__9cGllg9a4hN9cmfjsUw6zu39bQ(my);
	T1_ = ((*my).state ? (*my).state->Sup.len : 0);
	i = (NI)(T1_ - ((NI) 1));
	switch ((*my).state->data[i]) {
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 0):
	{
		{
			if (!(tk == ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 1))) goto LA5_;
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1);
		}
		goto LA3_;
		LA5_: ;
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 9);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 1):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 2):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 3):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 4):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 5):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 6):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 7):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 0);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) (tk));
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 10):
		{
			NI T11_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T11_ = (*my).state->Sup.len++;
			(*my).state->data[T11_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 3);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 8):
		{
			NI T13_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T13_ = (*my).state->Sup.len++;
			(*my).state->data[T13_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 2);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 1):
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 9);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 2):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 2):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 3):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 4):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 5):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 6):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 7):
		{
			NI T18_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T18_ = (*my).state->Sup.len++;
			(*my).state->data[T18_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 6);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) (tk));
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 10):
		{
			NI T20_;
			NI T21_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T20_ = (*my).state->Sup.len++;
			(*my).state->data[T20_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 6);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T21_ = (*my).state->Sup.len++;
			(*my).state->data[T21_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 3);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 8):
		{
			NI T23_;
			NI T24_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T23_ = (*my).state->Sup.len++;
			(*my).state->data[T23_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 6);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T24_ = (*my).state->Sup.len++;
			(*my).state->data[T24_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 2);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 9):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T26_;
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9);
			T26_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T26_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T26_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 6);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 3):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 2):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 3):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 4):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 5):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 6):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 7):
		{
			NI T30_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T30_ = (*my).state->Sup.len++;
			(*my).state->data[T30_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 4);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) (tk));
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 10):
		{
			NI T32_;
			NI T33_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T32_ = (*my).state->Sup.len++;
			(*my).state->data[T32_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 4);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T33_ = (*my).state->Sup.len++;
			(*my).state->data[T33_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 3);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 8):
		{
			NI T35_;
			NI T36_;
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T35_ = (*my).state->Sup.len++;
			(*my).state->data[T35_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 4);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T36_ = (*my).state->Sup.len++;
			(*my).state->data[T36_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 2);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 11):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T38_;
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11);
			T38_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T38_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T38_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 5);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 4):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 13):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T42_;
			T42_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T42_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T42_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(my);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 11):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T44_;
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T45_;
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11);
			T44_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T44_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T44_);
			T45_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T45_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T45_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 5);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 5):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 13):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T49_;
			T49_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T49_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T49_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(my);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 9):
		{
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T51_;
			tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ T52_;
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9);
			T51_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T51_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T51_);
			T52_ = (tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ)0;
			T52_ = pop__wGIX8i2tVhp4gFSPlGuf2gsystem((&(*my).state));
			(void)(T52_);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 6);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 6):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 12):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 7);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(my);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 3);
		}
		break;
		}
	}
	break;
	case ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 7):
	{
		switch (tk) {
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 2):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 3):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 4):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 5):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 6):
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 7):
		{
			(*my).state->data[i] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 5);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) (tk));
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 10):
		{
			NI T60_;
			(*my).state->data[i] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 5);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T60_ = (*my).state->Sup.len++;
			(*my).state->data[T60_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 3);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10);
		}
		break;
		case ((tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw) 8):
		{
			NI T62_;
			(*my).state->data[i] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 5);
			unsureAsgnRef((void**) (&(*my).state), (tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*) incrSeqV3((TGenericSeq*)((*my).state), (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_)));
			T62_ = (*my).state->Sup.len++;
			(*my).state->data[T62_] = ((tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ) 2);
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8);
		}
		break;
		default:
		{
			(*my).kind = ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 0);
			(*my).err = ((tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew) 10);
		}
		break;
		}
	}
	break;
	}
}
static N_NIMCALL(void, Marker_tyRef__PyuSdojUZWOAnzN7dInq1Q)(void* p, NI op) {
	tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg* a;
	a = (tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(NI, getLine__cAlRX82MU9aihWfxn79b1A6wparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI result;
	result = (NI)0;
	result = (*my).Sup.lineNumber;
	return result;
}
static N_INLINE(NI, getColumn__cAlRX82MU9aihWfxn79b1A6w_2parsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI result;
	result = (NI)0;
	result = getColNumber__KUMaHICF9bUPO7tt6hrBs3g((&(*my).Sup), (*my).Sup.bufpos);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, errorMsgExpected__wyJNOK33UcOVCdJ9aSuAbOw)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my, NimStringDesc* e) {
	NimStringDesc* result;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T1_;
	NI T2_;
	NI T3_;
	NimStringDesc* T4_;
	result = (NimStringDesc*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T1_[0] = copyString((*my).filename);
	T2_ = (NI)0;
	T2_ = getLine__cAlRX82MU9aihWfxn79b1A6wparsejson(my);
	T1_[1] = nimIntToStr(T2_);
	T3_ = (NI)0;
	T3_ = getColumn__cAlRX82MU9aihWfxn79b1A6w_2parsejson(my);
	T1_[2] = nimIntToStr(T3_);
	T4_ = (NimStringDesc*)0;
	T4_ = rawNewString((e ? e->Sup.len : 0) + 9);
appendString(T4_, e);
appendString(T4_, ((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_22));
	T1_[3] = T4_;
	result = nsuFormatOpenArray(((NimStringDesc*) &TM__nIinruGrC8EPIfjL3PuTvA_21), T1_, 4);
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, NimStringDesc* msg) {
	tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg* T1_;
	T1_ = (tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg*)0;
	T1_ = (tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg*) newObj((&NTI__PyuSdojUZWOAnzN7dInq1Q_), sizeof(tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTI__XTejXaID1NT7KS9byQm3Jxg_);
	(*T1_).Sup.Sup.Sup.name = "JsonParsingError";
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.message), errorMsgExpected__wyJNOK33UcOVCdJ9aSuAbOw(p, msg));
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "JsonParsingError", "raiseParseErr", "parsejson.nim", 522);
}
N_LIB_PRIVATE N_NIMCALL(void, eat__mMX9c3cw7Tuh0xvz23drvSg)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw tok) {
	{
		tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw T5_;
		if (!((*p).tok == tok)) goto LA3_;
		T5_ = (tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw)0;
		T5_ = getTok__9cGllg9a4hN9cmfjsUw6zu39bQ(p);
		(void)(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), tokToStr__JGKyaHusNBrTLCQ7XiBnyw[(tok)- 0]);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, stdlib_parsejsonDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_2_7[7];
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_3_14[14];
NI TM__nIinruGrC8EPIfjL3PuTvA_5;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_4[14] = {
"tkError", 
"tkEof", 
"tkString", 
"tkInt", 
"tkFloat", 
"tkTrue", 
"tkFalse", 
"tkNull", 
"tkCurlyLe", 
"tkCurlyRi", 
"tkBracketLe", 
"tkBracketRi", 
"tkColon", 
"tkComma"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_6_12[12];
NI TM__nIinruGrC8EPIfjL3PuTvA_8;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_7[12] = {
"jsonError", 
"jsonEof", 
"jsonString", 
"jsonInt", 
"jsonFloat", 
"jsonTrue", 
"jsonFalse", 
"jsonNull", 
"jsonObjectStart", 
"jsonObjectEnd", 
"jsonArrayStart", 
"jsonArrayEnd"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_9_11[11];
NI TM__nIinruGrC8EPIfjL3PuTvA_11;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_10[11] = {
"errNone", 
"errInvalidToken", 
"errStringExpected", 
"errColonExpected", 
"errCommaExpected", 
"errBracketRiExpected", 
"errCurlyRiExpected", 
"errQuoteExpected", 
"errEOC_Expected", 
"errEofExpected", 
"errExprExpected"};
static TNimNode* TM__nIinruGrC8EPIfjL3PuTvA_12_8[8];
NI TM__nIinruGrC8EPIfjL3PuTvA_14;
static char* NIM_CONST TM__nIinruGrC8EPIfjL3PuTvA_13[8] = {
"stateEof", 
"stateStart", 
"stateObject", 
"stateArray", 
"stateExpectArrayComma", 
"stateExpectObjectComma", 
"stateExpectColon", 
"stateExpectValue"};
static TNimNode TM__nIinruGrC8EPIfjL3PuTvA_0[58];

/* section: NIM_merge_TYPE_INIT3 */
NTI__KWIQnzXEOUqdWsnCUL9atyQ_.size = sizeof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ);
NTI__KWIQnzXEOUqdWsnCUL9atyQ_.align = NIM_ALIGNOF(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ);
NTI__KWIQnzXEOUqdWsnCUL9atyQ_.kind = 17;
NTI__KWIQnzXEOUqdWsnCUL9atyQ_.base = (&NTI__MAw8rJZtJ279bVV3TWMtXSg_);
TM__nIinruGrC8EPIfjL3PuTvA_2_7[0] = &TM__nIinruGrC8EPIfjL3PuTvA_0[1];
TM__nIinruGrC8EPIfjL3PuTvA_0[1].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[1].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, a);
TM__nIinruGrC8EPIfjL3PuTvA_0[1].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[1].name = "a";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[1] = &TM__nIinruGrC8EPIfjL3PuTvA_0[2];
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.size = sizeof(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw);
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.align = NIM_ALIGNOF(tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw);
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.kind = 14;
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.base = 0;
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_5 = 0; TM__nIinruGrC8EPIfjL3PuTvA_5 < 14; TM__nIinruGrC8EPIfjL3PuTvA_5++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].offset = TM__nIinruGrC8EPIfjL3PuTvA_5;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3].name = TM__nIinruGrC8EPIfjL3PuTvA_4[TM__nIinruGrC8EPIfjL3PuTvA_5];
TM__nIinruGrC8EPIfjL3PuTvA_3_14[TM__nIinruGrC8EPIfjL3PuTvA_5] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_5+3];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[17].len = 14; TM__nIinruGrC8EPIfjL3PuTvA_0[17].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[17].sons = &TM__nIinruGrC8EPIfjL3PuTvA_3_14[0];
NTI__Q9c4KaNqJU4PbXaGht0C7iw_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[17];
TM__nIinruGrC8EPIfjL3PuTvA_0[2].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[2].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, tok);
TM__nIinruGrC8EPIfjL3PuTvA_0[2].typ = (&NTI__Q9c4KaNqJU4PbXaGht0C7iw_);
TM__nIinruGrC8EPIfjL3PuTvA_0[2].name = "tok";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[2] = &TM__nIinruGrC8EPIfjL3PuTvA_0[18];
NTI__0zjE9c54eTrq224F5wMcaFA_.size = sizeof(tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA);
NTI__0zjE9c54eTrq224F5wMcaFA_.align = NIM_ALIGNOF(tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA);
NTI__0zjE9c54eTrq224F5wMcaFA_.kind = 14;
NTI__0zjE9c54eTrq224F5wMcaFA_.base = 0;
NTI__0zjE9c54eTrq224F5wMcaFA_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_8 = 0; TM__nIinruGrC8EPIfjL3PuTvA_8 < 12; TM__nIinruGrC8EPIfjL3PuTvA_8++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].offset = TM__nIinruGrC8EPIfjL3PuTvA_8;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19].name = TM__nIinruGrC8EPIfjL3PuTvA_7[TM__nIinruGrC8EPIfjL3PuTvA_8];
TM__nIinruGrC8EPIfjL3PuTvA_6_12[TM__nIinruGrC8EPIfjL3PuTvA_8] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_8+19];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[31].len = 12; TM__nIinruGrC8EPIfjL3PuTvA_0[31].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[31].sons = &TM__nIinruGrC8EPIfjL3PuTvA_6_12[0];
NTI__0zjE9c54eTrq224F5wMcaFA_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[31];
TM__nIinruGrC8EPIfjL3PuTvA_0[18].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[18].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, kind);
TM__nIinruGrC8EPIfjL3PuTvA_0[18].typ = (&NTI__0zjE9c54eTrq224F5wMcaFA_);
TM__nIinruGrC8EPIfjL3PuTvA_0[18].name = "kind";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[3] = &TM__nIinruGrC8EPIfjL3PuTvA_0[32];
NTI__G9cw5MrJXJrcpID5JXaplew_.size = sizeof(tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew);
NTI__G9cw5MrJXJrcpID5JXaplew_.align = NIM_ALIGNOF(tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew);
NTI__G9cw5MrJXJrcpID5JXaplew_.kind = 14;
NTI__G9cw5MrJXJrcpID5JXaplew_.base = 0;
NTI__G9cw5MrJXJrcpID5JXaplew_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_11 = 0; TM__nIinruGrC8EPIfjL3PuTvA_11 < 11; TM__nIinruGrC8EPIfjL3PuTvA_11++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].offset = TM__nIinruGrC8EPIfjL3PuTvA_11;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33].name = TM__nIinruGrC8EPIfjL3PuTvA_10[TM__nIinruGrC8EPIfjL3PuTvA_11];
TM__nIinruGrC8EPIfjL3PuTvA_9_11[TM__nIinruGrC8EPIfjL3PuTvA_11] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_11+33];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[44].len = 11; TM__nIinruGrC8EPIfjL3PuTvA_0[44].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[44].sons = &TM__nIinruGrC8EPIfjL3PuTvA_9_11[0];
NTI__G9cw5MrJXJrcpID5JXaplew_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[44];
TM__nIinruGrC8EPIfjL3PuTvA_0[32].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[32].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, err);
TM__nIinruGrC8EPIfjL3PuTvA_0[32].typ = (&NTI__G9cw5MrJXJrcpID5JXaplew_);
TM__nIinruGrC8EPIfjL3PuTvA_0[32].name = "err";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[4] = &TM__nIinruGrC8EPIfjL3PuTvA_0[45];
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.size = sizeof(tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ);
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.align = NIM_ALIGNOF(tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ);
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.kind = 14;
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.base = 0;
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.flags = 3;
for (TM__nIinruGrC8EPIfjL3PuTvA_14 = 0; TM__nIinruGrC8EPIfjL3PuTvA_14 < 8; TM__nIinruGrC8EPIfjL3PuTvA_14++) {
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].offset = TM__nIinruGrC8EPIfjL3PuTvA_14;
TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46].name = TM__nIinruGrC8EPIfjL3PuTvA_13[TM__nIinruGrC8EPIfjL3PuTvA_14];
TM__nIinruGrC8EPIfjL3PuTvA_12_8[TM__nIinruGrC8EPIfjL3PuTvA_14] = &TM__nIinruGrC8EPIfjL3PuTvA_0[TM__nIinruGrC8EPIfjL3PuTvA_14+46];
}
TM__nIinruGrC8EPIfjL3PuTvA_0[54].len = 8; TM__nIinruGrC8EPIfjL3PuTvA_0[54].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[54].sons = &TM__nIinruGrC8EPIfjL3PuTvA_12_8[0];
NTI__Na0rM2Zdr3RpxeNeXbvLrQ_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[54];
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.size = sizeof(tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*);
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.align = NIM_ALIGNOF(tySequence__Ih0V9cYug0VPJyBBGvgEH7Q*);
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.kind = 24;
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.base = (&NTI__Na0rM2Zdr3RpxeNeXbvLrQ_);
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.flags = 2;
NTI__Ih0V9cYug0VPJyBBGvgEH7Q_.marker = Marker_tySequence__Ih0V9cYug0VPJyBBGvgEH7Q;
TM__nIinruGrC8EPIfjL3PuTvA_0[45].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[45].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, state);
TM__nIinruGrC8EPIfjL3PuTvA_0[45].typ = (&NTI__Ih0V9cYug0VPJyBBGvgEH7Q_);
TM__nIinruGrC8EPIfjL3PuTvA_0[45].name = "state";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[5] = &TM__nIinruGrC8EPIfjL3PuTvA_0[55];
TM__nIinruGrC8EPIfjL3PuTvA_0[55].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[55].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, filename);
TM__nIinruGrC8EPIfjL3PuTvA_0[55].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__nIinruGrC8EPIfjL3PuTvA_0[55].name = "filename";
TM__nIinruGrC8EPIfjL3PuTvA_2_7[6] = &TM__nIinruGrC8EPIfjL3PuTvA_0[56];
TM__nIinruGrC8EPIfjL3PuTvA_0[56].kind = 1;
TM__nIinruGrC8EPIfjL3PuTvA_0[56].offset = offsetof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ, rawStringLiterals);
TM__nIinruGrC8EPIfjL3PuTvA_0[56].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__nIinruGrC8EPIfjL3PuTvA_0[56].name = "rawStringLiterals";
TM__nIinruGrC8EPIfjL3PuTvA_0[0].len = 7; TM__nIinruGrC8EPIfjL3PuTvA_0[0].kind = 2; TM__nIinruGrC8EPIfjL3PuTvA_0[0].sons = &TM__nIinruGrC8EPIfjL3PuTvA_2_7[0];
NTI__KWIQnzXEOUqdWsnCUL9atyQ_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[0];
NTI__XTejXaID1NT7KS9byQm3Jxg_.size = sizeof(tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg);
NTI__XTejXaID1NT7KS9byQm3Jxg_.align = NIM_ALIGNOF(tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg);
NTI__XTejXaID1NT7KS9byQm3Jxg_.kind = 17;
NTI__XTejXaID1NT7KS9byQm3Jxg_.base = (&NTI__yoNlBGx0D2tRizIdhQuENw_);
TM__nIinruGrC8EPIfjL3PuTvA_0[57].len = 0; TM__nIinruGrC8EPIfjL3PuTvA_0[57].kind = 2;
NTI__XTejXaID1NT7KS9byQm3Jxg_.node = &TM__nIinruGrC8EPIfjL3PuTvA_0[57];
NTI__PyuSdojUZWOAnzN7dInq1Q_.size = sizeof(tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg*);
NTI__PyuSdojUZWOAnzN7dInq1Q_.align = NIM_ALIGNOF(tyObject_JsonParsingError__XTejXaID1NT7KS9byQm3Jxg*);
NTI__PyuSdojUZWOAnzN7dInq1Q_.kind = 22;
NTI__PyuSdojUZWOAnzN7dInq1Q_.base = (&NTI__XTejXaID1NT7KS9byQm3Jxg_);
NTI__PyuSdojUZWOAnzN7dInq1Q_.marker = Marker_tyRef__PyuSdojUZWOAnzN7dInq1Q;
}

