/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg tySequence__WwUFq9cJ2xKRlsAWVEHyPRg;
typedef struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ;
typedef struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ tySequence__XUL1TrMU0tgXmaMFCIYgFQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg;

/* section: NIM_merge_TYPES */
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
typedef NU32 tyArray__JlnxiR65D9cjJpwi6uBZRtA[2];
typedef NU8 tyArray__w5VB8h5K8DB3oWrO5U2wqg[64];
struct tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw {
tyArray__FleBT9cC2nxhgiXmSYYnEKA state;
tyArray__JlnxiR65D9cjJpwi6uBZRtA count;
tyArray__w5VB8h5K8DB3oWrO5U2wqg buffer;
};
typedef NU8 tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g;
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ {
tySequence__XUL1TrMU0tgXmaMFCIYgFQ* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg {
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field0;
NI Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg {
  TGenericSeq Sup;
  tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ {
  TGenericSeq Sup;
  tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
static N_INLINE(NI, rawGet__8eLPyJNN6hcR50ctxeSkDgtables)(tyObject_Table__G1v8c16HePOldLeucwe05Q t, NI key, NI* hc);
static N_INLINE(NI, hash__aWv89bCLOibANstPF9bHQoyQhashes)(NI x);
static N_INLINE(NI, hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes)(NU64 x);
static N_INLINE(NU64, hiXorLo__wWqo9alrSZddOyokrApfNaQhashes)(NU64 a, NU64 b);
static N_INLINE(NU64, hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes)(NU64 a, NU64 b);
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode);
static N_INLINE(NI, nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables)(NI h, NI maxHash);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(void, md5Init__aFJbJ6Fb5boL1UBjNazO4A)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c);
N_LIB_PRIVATE N_NIMCALL(void, hashType__X3duBun3y5IEGlsZHDYFtg)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, md5Update__3dyWcdKqKqoei9csU09cRuCA)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NCSTRING input, NI len);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, hashSym__4UomljBfnHYVnNSgF8li7A)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, base__PfgI9ap7WOnsRfFV4znQ27w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___LVdKEnlSa6KY6NiwOwD18A)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NIM_CHAR ch);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___kV0SIDmAwVTn8YOHtzApRw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, hashTypeSym__4UomljBfnHYVnNSgF8li7A_2)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, hashTree__Wc3X9c0TJjrObB74wKpwEQw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___0IHf40yKCedwAJraBJsClw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NI64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, md5Final__CQoglTaDBxWEuKEO9ah9bXuQ)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NU8* digest);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vM9aGuvtd2MaMcJSPmyUs0g)(tyObject_Table__G1v8c16HePOldLeucwe05Q* t, NI key, tyArray__qtqsWM5aXmcpMIVmvq3kAA val);
N_LIB_PRIVATE N_NIMCALL(void, hashBodyTree__NOmlbN0VgYYQShzDKZbiJg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___ApHAXPiMhq6D4O2XoBiVyA)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyArray__qtqsWM5aXmcpMIVmvq3kAA s);
N_LIB_PRIVATE N_NIMCALL(void, symBodyDigest__CuOAIgIy9afVyEqS9a6M9bEMA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
N_LIB_PRIVATE N_NIMCALL(void, hashVarSymBody__p4B4aiqKxlwguHMWYHcfTw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, hashNonProc__mSn9a9aX0NBzWqerwPW0qRww)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
N_LIB_PRIVATE N_NIMCALL(void, ampeq___yo33QkDko0oZ9akrdXEMhLg)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NF f);
N_LIB_PRIVATE N_NIMCALL(void, hashProc__mSn9a9aX0NBzWqerwPW0qRww_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___0A9bslyIJ49bWrftLGh13rvg)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__jOz9cq69cLtimtiCsRyrmEBA)(tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___4cYKitaHx6RQ9azRtQsZp6w)(NimStringDesc* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__KOisMGxcPhz6CcSmxgwEQQ)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(void, inc__WbyI1m6UOEsGT1YIEaB7UA)(tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, NI val);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_2, "\376", 1);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_3, ":anon", 5);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_4, ".", 1);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_5, "sighashes.nim(147, 18) `t.sym.loc.r != nil` ", 44);
extern TNimType NTI__WwUFq9cJ2xKRlsAWVEHyPRg_;
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_6, "\377", 1);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_7, ".empty", 6);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_8, ".varisptr", 9);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_9, "iterator ", 9);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_10, "proc ", 5);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_11, ".varargs", 8);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_12, "not nil", 7);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_13, "nil", 3);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_14, ".dispatcher", 11);
STRING_LITERAL(TM__e0lkmDV64LUjE3ua6F9agUw_15, "_", 1);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(NU64, hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes)(NU64 a, NU64 b) {
	NU64 result;
	NU64 aH;
	NU64 aL;
	NU64 bH;
	NU64 bL;
	NU64 rHH;
	NU64 rHL;
	NU64 rLH;
	NU64 rLL;
	NU64 t;
	NU64 c;
	NU64 lo;
	NU64 T6_;
	NU64 hi;
{	result = (NU64)0;
	aH = (NU64)((NU64)(a) >> (NU64)(((NI) 32)));
	aL = (NU64)(a & 4294967295ULL);
	bH = (NU64)((NU64)(b) >> (NU64)(((NI) 32)));
	bL = (NU64)(b & 4294967295ULL);
	rHH = (NU64)((NU64)(aH) * (NU64)(bH));
	rHL = (NU64)((NU64)(aH) * (NU64)(bL));
	rLH = (NU64)((NU64)(aL) * (NU64)(bH));
	rLL = (NU64)((NU64)(aL) * (NU64)(bL));
	t = (NU64)((NU64)(rLL) + (NU64)((NU64)((NU64)(rHL) << (NU64)(((NI) 32)))));
	{
		if (!((NU64)(t) < (NU64)(rLL))) goto LA3_;
		c = 1ULL;
	}
	goto LA1_;
	LA3_: ;
	{
		c = 0ULL;
	}
	LA1_: ;
	lo = (NU64)((NU64)(t) + (NU64)((NU64)((NU64)(rLH) << (NU64)(((NI) 32)))));
	T6_ = (NU64)0;
	{
		if (!((NU64)(lo) < (NU64)(t))) goto LA9_;
		T6_ = 1ULL;
	}
	goto LA7_;
	LA9_: ;
	{
		T6_ = 0ULL;
	}
	LA7_: ;
	c += T6_;
	hi = (NU64)((NU64)((NU64)((NU64)((NU64)((NU64)(rHH) + (NU64)((NU64)((NU64)(rHL) >> (NU64)(((NI) 32)))))) + (NU64)((NU64)((NU64)(rLH) >> (NU64)(((NI) 32)))))) + (NU64)(c));
	result = (NU64)(hi ^ lo);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLo__wWqo9alrSZddOyokrApfNaQhashes)(NU64 a, NU64 b) {
	NU64 result;
	result = (NU64)0;
	result = hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes(a, b);
	return result;
}
static N_INLINE(NI, hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes)(NU64 x) {
	NI result;
	NU64 T1_;
	NU64 T2_;
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__wWqo9alrSZddOyokrApfNaQhashes(11562461410679940143ULL, (NU64)(x ^ 16646288086500911323ULL));
	T2_ = (NU64)0;
	T2_ = hiXorLo__wWqo9alrSZddOyokrApfNaQhashes(T1_, 16952864883938283885ULL);
	result = ((NI) (T2_));
	return result;
}
static N_INLINE(NI, hash__aWv89bCLOibANstPF9bHQoyQhashes)(NI x) {
	NI result;
	result = (NI)0;
	result = hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes(((NU64) (x)));
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(NI, nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
static N_INLINE(NI, rawGet__8eLPyJNN6hcR50ctxeSkDgtables)(tyObject_Table__G1v8c16HePOldLeucwe05Q t, NI key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__aWv89bCLOibANstPF9bHQoyQhashes(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__5Qpmu5QqwDY0esVXn6wf7wtables(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = (t.data->data[h].Field1 == key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NimStringDesc* s) {
	md5Update__3dyWcdKqKqoei9csU09cRuCA(c, nimToCStringConv(s), (s ? s->Sup.len : 0));
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, hashSym__4UomljBfnHYVnNSgF8li7A)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4));
		LA4_: ;
		if (!T3_) goto LA5_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_3));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
		it = s;
		{
			while (1) {
				if (!!((it == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9;
				ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*it).name).s);
				ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_4));
				it = (*it).owner;
			} LA9: ;
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___LVdKEnlSa6KY6NiwOwD18A)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NIM_CHAR ch) {
	md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) ((&ch))), ((NI) 1));
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI L;
	NI T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) setLengthSeqV2(&((*s))->Sup, (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___kV0SIDmAwVTn8YOHtzApRw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r) {
	{
		NimStringDesc* l;
		l = (NimStringDesc*)0;
		{
			tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* stack;
			if (!!((r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA4_;
			stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) newSeq((&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), 1);
			asgnRef((void**) (&stack->data[0]), r);
			{
				while (1) {
					NI T8_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* it;
					T8_ = (stack ? stack->Sup.len : 0);
					if (!(((NI) 0) < T8_)) goto LA7;
					it = pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem((&stack));
					{
						while (1) {
							NI T11_;
							if (!!(((*it).left == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA10;
							stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) incrSeqV3((TGenericSeq*)(stack), (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_));
							T11_ = stack->Sup.len++;
							asgnRef((void**) (&stack->data[T11_]), (*it).right);
							it = (*it).left;
						} LA10: ;
					}
					l = (*it).data;
					md5Update__3dyWcdKqKqoei9csU09cRuCA(c, nimToCStringConv(l), (l ? l->Sup.len : 0));
				} LA7: ;
			}
		}
		LA4_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, hashTypeSym__4UomljBfnHYVnNSgF8li7A_2)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4));
		LA4_: ;
		if (!T3_) goto LA5_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_3));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
		it = s;
		{
			while (1) {
				if (!!((it == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9;
				{
					NIM_BOOL T12_;
					NIM_BOOL T13_;
					T12_ = (NIM_BOOL)0;
					T13_ = (NIM_BOOL)0;
					T13_ = (((*it).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0);
					if (!(T13_)) goto LA14_;
					T13_ = ((520192 &((NU32)1<<((NU)((*it).kind)&31U)))!=0);
					LA14_: ;
					T12_ = T13_;
					if (!(T12_)) goto LA15_;
					T12_ = !(((*it).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					LA15_: ;
					if (!T12_) goto LA16_;
					hashType__X3duBun3y5IEGlsZHDYFtg(c, (*it).typ, 1);
				}
				LA16_: ;
				ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*it).name).s);
				ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_4));
				it = (*it).owner;
			} LA9: ;
		}
	}
	LA1_: ;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, hashTree__Wc3X9c0TJjrObB74wKpwEQw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags) {
	tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw k;
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_6));
		goto BeforeRet_;
	}
	LA3_: ;
	k = (*n).kind;
	ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) (k)));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*n)._kind_5.ident).s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		hashSym__4UomljBfnHYVnNSgF8li7A(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = ((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 6))&7U)))!=0);
			if (!(T10_)) goto LA11_;
			T10_ = !(((*(*n)._kind_4.sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA11_: ;
			if (!T10_) goto LA12_;
			hashType__X3duBun3y5IEGlsZHDYFtg(c, (*(*n)._kind_4.sym).typ, flags);
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		NI64 v;
		v = (*n)._kind_1.intVal;
		md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) ((&v))), ((NI) 8));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		NF v_2;
		v_2 = (*n)._kind_2.floatVal;
		md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) ((&v_2))), ((NI) 8));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*n)._kind_3.strVal);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					hashTree__Wc3X9c0TJjrObB74wKpwEQw(c, (*n)._kind_6.sons->data[i], flags);
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___0IHf40yKCedwAJraBJsClw)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NI64 i) {
	md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) ((&i))), ((NI) 8));
}
N_LIB_PRIVATE N_NIMCALL(void, hashType__X3duBun3y5IEGlsZHDYFtg)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags) {
{	{
		if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_2));
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i], flags);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	{
		{
			if (!((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 5))&7U)))!=0)) goto LA12_;
			{
				if (!!(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
				hashSym__4UomljBfnHYVnNSgF8li7A(c, (*t).sym);
			}
			LA16_: ;
			{
				NIM_BOOL T20_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
				T20_ = (NIM_BOOL)0;
				T20_ = ((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
				if (T20_) goto LA21_;
				T20_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 8))&63U)))!=0);
				LA21_: ;
				if (!T20_) goto LA22_;
				T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T24_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
				hashType__X3duBun3y5IEGlsZHDYFtg(c, T24_, flags);
			}
			LA22_: ;
		}
		goto LA10_;
		LA12_: ;
		{
			NIM_BOOL T26_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T30_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 1))&7U)))!=0);
			if (T26_) goto LA27_;
			T26_ = ((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			LA27_: ;
			if (!T26_) goto LA28_;
			T30_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T30_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			hashType__X3duBun3y5IEGlsZHDYFtg(c, T30_, flags);
		}
		goto LA10_;
		LA28_: ;
		{
			hashSym__4UomljBfnHYVnNSgF8li7A(c, (*t).sym);
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T35_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* normalizedType;
			T35_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T35_ = base__PfgI9ap7WOnsRfFV4znQ27w(t);
			if (!(((*(*T35_).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0)) goto LA36_;
			normalizedType = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(t);
			{
				NI i_3;
				NI colontmp__2;
				NI T39_;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				T39_ = (NI)0;
				T39_ = len__5mJADrRYkP3r9auuiuDZN9cQast(normalizedType);
				colontmp__2 = (NI)(T39_ - ((NI) 1));
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA41;
						i_3 = i_4;
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_3], flags);
						i_4 += ((NI) 1);
					} LA41: ;
				}
			}
		}
		goto LA33_;
		LA36_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
			T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T43_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			hashType__X3duBun3y5IEGlsZHDYFtg(c, T43_, flags);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
		T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T45_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		hashType__X3duBun3y5IEGlsZHDYFtg(c, T45_, flags);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T51_;
		{
			if (!((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 4))&7U)))!=0)) goto LA49_;
			ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		}
		LA49_: ;
		T51_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T51_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		hashType__X3duBun3y5IEGlsZHDYFtg(c, T51_, flags);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T55_)) goto LA56_;
			T55_ = !(((192 & (*(*t).sym).flags) == 0));
			LA56_: ;
			if (!T55_) goto LA57_;
			hashSym__4UomljBfnHYVnNSgF8li7A(c, (*t).sym);
		}
		LA57_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inst;
			if (!!(((*t).typeInst == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA62_;
			inst = (*t).typeInst;
			asgnRef((void**) (&(*t).typeInst), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			{
				NI i_5;
				NI colontmp__3;
				NI T65_;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				T65_ = (NI)0;
				T65_ = len__5mJADrRYkP3r9auuiuDZN9cQast(inst);
				colontmp__3 = (NI)(T65_ - ((NI) 1));
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA67;
						i_5 = i_6;
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*inst).sons->data[i_5], flags);
						i_6 += ((NI) 1);
					} LA67: ;
				}
			}
			asgnRef((void**) (&(*t).typeInst), inst);
			goto BeforeRet_;
		}
		LA62_: ;
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		{
			if (!!(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA70_;
			{
				if (!!(((262144 & (*(*t).sym).flags) == 0))) goto LA74_;
				{
					if (!!(!(((*(*t).sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))))) goto LA78_;
					failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_5));
				}
				LA78_: ;
				ampeq___kV0SIDmAwVTn8YOHtzApRw(c, (*(*t).sym).loc.r);
			}
			goto LA72_;
			LA74_: ;
			{
				if (!((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 2))&7U)))!=0)) goto LA81_;
				hashTypeSym__4UomljBfnHYVnNSgF8li7A_2(c, (*t).sym);
			}
			goto LA72_;
			LA81_: ;
			{
				hashSym__4UomljBfnHYVnNSgF8li7A(c, (*t).sym);
			}
			LA72_: ;
			{
				if (!!(((IL64(77309411328) & (*(*t).sym).flags) == 0))) goto LA86_;
				{
					NI T90_;
					tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw oldFlags;
					T90_ = (NI)0;
					T90_ = len__P89cqdlERShb9alU3iC0yj8wast((*t).n);
					if (!(((NI) 0) < T90_)) goto LA91_;
					oldFlags = (*(*t).sym).flags;
					(*(*t).sym).flags = ((*(*t).sym).flags & ~ IL64(77309411328));
					hashTree__Wc3X9c0TJjrObB74wKpwEQw(c, (*t).n, (flags | 64));
					(*(*t).sym).flags = oldFlags;
				}
				goto LA88_;
				LA91_: ;
				{
					ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_7));
				}
				LA88_: ;
			}
			LA86_: ;
		}
		goto LA68_;
		LA70_: ;
		{
			ampeq___0IHf40yKCedwAJraBJsClw(c, ((NI64) ((*t).Sup.id)));
		}
		LA68_: ;
		{
			NIM_BOOL T97_;
			NI T98_;
			T97_ = (NIM_BOOL)0;
			T98_ = (NI)0;
			T98_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			T97_ = (((NI) 0) < T98_);
			if (!(T97_)) goto LA99_;
			T97_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA99_: ;
			if (!T97_) goto LA100_;
			hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[((NI) 0)], flags);
		}
		LA100_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T103_;
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		T103_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T103_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		hashType__X3duBun3y5IEGlsZHDYFtg(c, T103_, flags);
		{
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0)) goto LA106_;
			ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_8));
		}
		LA106_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		hashTree__Wc3X9c0TJjrObB74wKpwEQw(c, (*t).n, 0);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		{
			NIM_BOOL T112_;
			T112_ = (NIM_BOOL)0;
			T112_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T112_)) goto LA113_;
			T112_ = !(((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 1))&7U)))!=0));
			LA113_: ;
			if (!T112_) goto LA114_;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast((*t).n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA118;
						i_7 = i_8;
						ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*(*(*(*t).n)._kind_6.sons->data[i_7])._kind_4.sym).name).s);
						ampeq___LVdKEnlSa6KY6NiwOwD18A(c, 58);
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_7], (flags | 8));
						ampeq___LVdKEnlSa6KY6NiwOwD18A(c, 44);
						i_8 += ((NI) 1);
					} LA118: ;
				}
			}
		}
		goto LA110_;
		LA114_: ;
		{
			{
				NI i_9;
				NI colontmp__5;
				NI i_10;
				i_9 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
				i_10 = ((NI) 0);
				{
					while (1) {
						if (!(i_10 < colontmp__5)) goto LA122;
						i_9 = i_10;
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_9], (flags | 8));
						i_10 += ((NI) 1);
					} LA122: ;
				}
			}
		}
		LA110_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	{
		{
			if (!!(((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 3))&7U)))!=0))) goto LA126_;
			ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
			hashTree__Wc3X9c0TJjrObB74wKpwEQw(c, (*t).n, 0);
		}
		LA126_: ;
		hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[((NI) 0)], flags);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		hashTree__Wc3X9c0TJjrObB74wKpwEQw(c, (*t).n, 0);
		hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[((NI) 0)], flags);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		NimStringDesc* T130_;
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		T130_ = (NimStringDesc*)0;
		{
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA133_;
			T130_ = copyString(((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_9));
		}
		goto LA131_;
		LA133_: ;
		{
			T130_ = copyString(((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_10));
		}
		LA131_: ;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, T130_);
		{
			NIM_BOOL T138_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
			T138_ = (NIM_BOOL)0;
			T138_ = ((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 0))&7U)))!=0);
			if (!(T138_)) goto LA139_;
			T138_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA139_: ;
			if (!T138_) goto LA140_;
			params = (*t).n;
			{
				NI i_11;
				NI colontmp__6;
				NI i_12;
				i_11 = (NI)0;
				colontmp__6 = (NI)0;
				colontmp__6 = len__P89cqdlERShb9alU3iC0yj8wast(params);
				i_12 = ((NI) 1);
				{
					while (1) {
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
						if (!(i_12 < colontmp__6)) goto LA144;
						i_11 = i_12;
						param = (*(*params)._kind_6.sons->data[i_11])._kind_4.sym;
						ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*param).name).s);
						ampeq___LVdKEnlSa6KY6NiwOwD18A(c, 58);
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*param).typ, flags);
						ampeq___LVdKEnlSa6KY6NiwOwD18A(c, 44);
						i_12 += ((NI) 1);
					} LA144: ;
				}
			}
			hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[((NI) 0)], flags);
		}
		goto LA136_;
		LA140_: ;
		{
			{
				NI i_13;
				NI colontmp__7;
				NI i_14;
				i_13 = (NI)0;
				colontmp__7 = (NI)0;
				colontmp__7 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
				i_14 = ((NI) 0);
				{
					while (1) {
						if (!(i_14 < colontmp__7)) goto LA148;
						i_13 = i_14;
						hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_13], flags);
						i_14 += ((NI) 1);
					} LA148: ;
				}
			}
		}
		LA136_: ;
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).callConv)));
		{
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0))&63U)))!=0)) goto LA151_;
			ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_11));
		}
		LA151_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		{
			NI i_15;
			NI colontmp__8;
			NI i_16;
			i_15 = (NI)0;
			colontmp__8 = (NI)0;
			colontmp__8 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_16 = ((NI) 0);
			{
				while (1) {
					if (!(i_16 < colontmp__8)) goto LA156;
					i_15 = i_16;
					hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_15], (flags & ~ 8));
					i_16 += ((NI) 1);
				} LA156: ;
			}
		}
	}
	break;
	default:
	{
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*t).kind)));
		{
			NI i_17;
			NI colontmp__9;
			NI i_18;
			i_17 = (NI)0;
			colontmp__9 = (NI)0;
			colontmp__9 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_18 = ((NI) 0);
			{
				while (1) {
					if (!(i_18 < colontmp__9)) goto LA160;
					i_17 = i_18;
					hashType__X3duBun3y5IEGlsZHDYFtg(c, (*t).sons->data[i_17], flags);
					i_18 += ((NI) 1);
				} LA160: ;
			}
		}
	}
	break;
	}
	{
		NIM_BOOL T163_;
		T163_ = (NIM_BOOL)0;
		T163_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
		if (!(T163_)) goto LA164_;
		T163_ = !(((flags &((NU8)1<<((NU)(((tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g) 1))&7U)))!=0));
		LA164_: ;
		if (!T163_) goto LA165_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_12));
	}
	LA165_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___ApHAXPiMhq6D4O2XoBiVyA)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyArray__qtqsWM5aXmcpMIVmvq3kAA s) {
	md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) (s)), ((NI) 16));
}
N_LIB_PRIVATE N_NIMCALL(void, hashNonProc__mSn9a9aX0NBzWqerwPW0qRww)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw c;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
	nimZeroMem((void*)Result, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	nimZeroMem((void*)(&c), sizeof(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw));
	md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
	hashSym__4UomljBfnHYVnNSgF8li7A((&c), s);
	it = s;
	{
		while (1) {
			if (!!((it == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), (*(*it).name).s);
			ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_4));
			it = (*it).owner;
		} LA2: ;
	}
	{
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3))) goto LA5_;
		ampeq___0IHf40yKCedwAJraBJsClw((&c), ((NI64) ((*s).position)));
	}
	LA5_: ;
	md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
}
N_LIB_PRIVATE N_NIMCALL(void, hashVarSymBody__p4B4aiqKxlwguHMWYHcfTw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0))) goto LA3_;
		ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*s).kind)));
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*s).name).s);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__qtqsWM5aXmcpMIVmvq3kAA T6_;
		nimZeroMem((void*)T6_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashNonProc__mSn9a9aX0NBzWqerwPW0qRww(s, T6_);
		ampeq___ApHAXPiMhq6D4O2XoBiVyA(c, T6_);
		{
			NIM_BOOL T9_;
			NI T13_;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T9_)) goto LA10_;
			T9_ = ((*(*s).ast).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35));
			LA10_: ;
			if (!T9_) goto LA11_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast((*s).ast);
			hashBodyTree__NOmlbN0VgYYQShzDKZbiJg(graph, c, (*(*s).ast)._kind_6.sons->data[(NI)(T13_ - ((NI) 1))]);
		}
		goto LA7_;
		LA11_: ;
		{
			hashBodyTree__NOmlbN0VgYYQShzDKZbiJg(graph, c, (*s).ast);
		}
		LA7_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, ampeq___yo33QkDko0oZ9akrdXEMhLg)(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, NF f) {
	md5Update__3dyWcdKqKqoei9csU09cRuCA(c, ((NCSTRING) ((&f))), ((NI) 8));
}
N_LIB_PRIVATE N_NIMCALL(void, hashBodyTree__NOmlbN0VgYYQShzDKZbiJg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_13));
		goto BeforeRet_;
	}
	LA3_: ;
	ampeq___LVdKEnlSa6KY6NiwOwD18A(c, ((NIM_CHAR) ((*n).kind)));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*(*n)._kind_5.ident).s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			tyArray__qtqsWM5aXmcpMIVmvq3kAA T12_;
			if (!((520192 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA10_;
			nimZeroMem((void*)T12_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
			symBodyDigest__CuOAIgIy9afVyEqS9a6M9bEMA(graph, (*n)._kind_4.sym, T12_);
			ampeq___ApHAXPiMhq6D4O2XoBiVyA(c, T12_);
		}
		goto LA8_;
		LA10_: ;
		{
			if (!((2101000 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0)) goto LA14_;
			hashVarSymBody__p4B4aiqKxlwguHMWYHcfTw(graph, c, (*n)._kind_4.sym);
		}
		goto LA8_;
		LA14_: ;
		{
			tyArray__qtqsWM5aXmcpMIVmvq3kAA T17_;
			nimZeroMem((void*)T17_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
			hashNonProc__mSn9a9aX0NBzWqerwPW0qRww((*n)._kind_4.sym, T17_);
			ampeq___ApHAXPiMhq6D4O2XoBiVyA(c, T17_);
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		ampeq___0IHf40yKCedwAJraBJsClw(c, (*n)._kind_1.intVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		ampeq___yo33QkDko0oZ9akrdXEMhLg(c, (*n)._kind_2.floatVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q(c, (*n)._kind_3.strVal);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA25;
					i = i_2;
					hashBodyTree__NOmlbN0VgYYQShzDKZbiJg(graph, c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA25: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, symBodyDigest__CuOAIgIy9afVyEqS9a6M9bEMA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	NI hcX60gensym88_;
	NI indexX60gensym88_;
	NIM_BOOL hasKeyX60gensym88_;
	tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw c;
{	nimZeroMem((void*)Result, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hcX60gensym88_ = (NI)0;
	indexX60gensym88_ = rawGet__8eLPyJNN6hcR50ctxeSkDgtables((*graph).symBodyHashes, (*sym).Sup.id, (&hcX60gensym88_));
	hasKeyX60gensym88_ = (((NI) 0) <= indexX60gensym88_);
	{
		NU8* value;
		if (!hasKeyX60gensym88_) goto LA3_;
		value = (*graph).symBodyHashes.data->data[indexX60gensym88_].Field2;
		nimCopyMem((void*)Result, (NIM_CONST void*)value, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&c), sizeof(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw));
	md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
	hashType__X3duBun3y5IEGlsZHDYFtg((&c), (*sym).typ, 1);
	ampeq___LVdKEnlSa6KY6NiwOwD18A((&c), ((NIM_CHAR) ((*sym).kind)));
	md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
	X5BX5Deq___vM9aGuvtd2MaMcJSPmyUs0g((&(*graph).symBodyHashes), (*sym).Sup.id, Result);
	{
		if (!!(((*sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA7_;
		md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
		md5Update__3dyWcdKqKqoei9csU09cRuCA((&c), ((NCSTRING) (Result)), ((NI) 16));
		hashBodyTree__NOmlbN0VgYYQShzDKZbiJg(graph, (&c), (*(*sym).ast)._kind_6.sons->data[((NI) 6)]);
		md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
		X5BX5Deq___vM9aGuvtd2MaMcJSPmyUs0g((&(*graph).symBodyHashes), (*sym).Sup.id, Result);
	}
	LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, hashType__UdooXLclXL8uld7qLI5JRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw c;
	nimZeroMem((void*)Result, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	nimZeroMem((void*)(&c), sizeof(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw));
	md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
	hashType__X3duBun3y5IEGlsZHDYFtg((&c), t, (flags | 4));
	md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
}
N_LIB_PRIVATE N_NIMCALL(void, hashProc__mSn9a9aX0NBzWqerwPW0qRww_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw c;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p;
	nimZeroMem((void*)Result, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	nimZeroMem((void*)(&c), sizeof(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw));
	md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
	hashType__X3duBun3y5IEGlsZHDYFtg((&c), (*s).typ, 1);
	m = s;
	{
		while (1) {
			if (!!(((*m).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA2;
			m = (*m).owner;
		} LA2: ;
	}
	p = (*m).owner;
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), (*(*p).name).s);
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_4));
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), (*(*m).name).s);
	{
		if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 29))&63U)))!=0)) goto LA5_;
		ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_14));
	}
	LA5_: ;
	md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
}
N_LIB_PRIVATE N_NIMCALL(void, sigHash__mSn9a9aX0NBzWqerwPW0qRww_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		hashProc__mSn9a9aX0NBzWqerwPW0qRww_3(s, Result);
	}
	goto LA1_;
	LA5_: ;
	{
		hashNonProc__mSn9a9aX0NBzWqerwPW0qRww(s, Result);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, hashOwner__mSn9a9aX0NBzWqerwPW0qRww_4)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result) {
	tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw c;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p;
	nimZeroMem((void*)Result, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	nimZeroMem((void*)(&c), sizeof(tyObject_MD5Context__oMciKUdSdCaIeMtcxbiPOw));
	md5Init__aFJbJ6Fb5boL1UBjNazO4A((&c));
	m = s;
	{
		while (1) {
			if (!!(((*m).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA2;
			m = (*m).owner;
		} LA2: ;
	}
	p = (*m).owner;
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), (*(*p).name).s);
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), ((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_4));
	ampeq___zUEnLo9crqCXlwcsJP9bPZ0Q((&c), (*(*m).name).s);
	md5Final__CQoglTaDBxWEuKEO9ah9bXuQ((&c), Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, idOrSig__sKAFwdXn9cKHxc9cdaovk69cA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* currentModule, tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* sigCollisions) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
		NimStringDesc* T7_;
		NI counter;
		T3_ = (NIM_BOOL)0;
		T3_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashProc__mSn9a9aX0NBzWqerwPW0qRww_3(s, sig);
		T7_ = (NimStringDesc*)0;
		T7_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T7_);
		counter = getOrDefault__jOz9cq69cLtimtiCsRyrmEBA((*sigCollisions), sig, ((NI) 0));
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			if (!!((counter == ((NI) 0)))) goto LA10_;
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(counter + ((NI) 1)))));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_15), T12_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T13_);
		}
		LA10_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			if (!((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5))) goto LA16_;
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = rope__yShmEg9cffWxI7s5XzEKBow(currentModule);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T18_);
		}
		LA16_: ;
		inc__WbyI1m6UOEsGT1YIEaB7UA(sigCollisions, sig, ((NI) 1));
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig_2;
		NimStringDesc* T20_;
		NI counter_2;
		nimZeroMem((void*)sig_2, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashNonProc__mSn9a9aX0NBzWqerwPW0qRww(s, sig_2);
		T20_ = (NimStringDesc*)0;
		T20_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig_2);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T20_);
		counter_2 = getOrDefault__jOz9cq69cLtimtiCsRyrmEBA((*sigCollisions), sig_2, ((NI) 0));
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			if (!!((counter_2 == ((NI) 0)))) goto LA23_;
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(counter_2 + ((NI) 1)))));
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__e0lkmDV64LUjE3ua6F9agUw_15), T25_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T26_);
		}
		LA23_: ;
		inc__WbyI1m6UOEsGT1YIEaB7UA(sigCollisions, sig_2, ((NI) 1));
	}
	LA1_: ;
	return result;
}
