/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg;
typedef struct RootObj RootObj;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_NIMCALL_PTR(void, tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ) (void);
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* cmd, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, void* ClE_0);
void* ClE_0;
} tyProc__34NX3arOx349cB4sFiTD3uA;
struct tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg {
NIM_BOOL suggestMode;
NIM_BOOL supportsStdinFile;
tyProc__34NX3arOx349cB4sFiTD3uA processCmdLine;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA;
struct tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg {
  RootObj Sup;
NI pos;
NIM_BOOL inShortState;
NIM_BOOL allowWhitespaceAfterColon;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cmds;
NI idx;
tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA kind;
NimStringDesc* key;
NimStringDesc* val;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef N_CLOSURE_PTR(void, TM__6xNBOpPeN0DsJ34t7RoSng_13) (tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* cmd, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, void* ClE_0);
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, GC_disableMarkAndSweep__amVlU9ajqZ06ujoesRBHcDg_3)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, TM__6xNBOpPeN0DsJ34t7RoSng_2)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimRegisterGlobalMarker)(tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ markerProc);
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*, newConfigRef__YbeeoJLQnRQK2F8DAaXI8w)(void);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, handleCmdLine__I9aitIr13Z1B6wHv5vzMf2w)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, processCmdLine__0ODH9apAuQHiVD2VRBWaB5Q)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* cmd, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initOptParser__C9a079cuyRqhvKudWkyCzvXQ)(NimStringDesc* cmdline, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal, NIM_BOOL allowWhitespaceAfterColon, tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, nponext)(tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addCmdPrefix__wEj87UK9bqDpzf8XE3AkG9aA)(NimStringDesc** result, tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nospquoteShell)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processArgument__MHrYBQtd7a5cMBE9clMgEKg)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p, NI* argsCount, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__dV5jwz9cYCLeNjAX40tnQHw)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(void, initDefinesProg__59abjgA38liT9axvqVqzqA1A)(tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg* self, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NI, paramCount__LYkRnwMk6UXTCs9c59cPvZsQ)(void);
N_LIB_PRIVATE N_NIMCALL(void, writeCommandLineUsage__t8RT1Qk4s0rBX8YbKQ0DBQ_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, processCmdLineAndProjectPath__Cg1dOQGwciny9ad7gh4258w)(tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg* self, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ*, newModuleGraph__i9b4NK8jPhAUAsvbtMitNLw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, loadConfigsAndRunMainCommand__3aAEaOd6nhtgmlwjBQ2GcQ)(tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg* self, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(void, mainCommand__ikP0vuP6oxqlYdG7q9cY7sA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, GC_getStatistics__wZiNbtaUL82bHwwHPZjV9cQ)(void);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__ea9bsNo9cwchKzwCi7UjcP7g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(NimStringDesc*, findNodeJs__dT9cGd8fI0ylss24ld7sh9bQnodejs)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findExe__9cov9c3aI19bfbEIyMe9bNCSEA)(NimStringDesc* exe, NIM_BOOL followSymlinks, NimStringDesc** extensions, NI extensionsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, execExternalProgram__WKaD677f7aLTxInYSr0wMw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* cmd, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(void, openDefaultBrowser__lhAiGWV9cJtbG6lYE4tGA3A)(NimStringDesc* url);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___l9cjIIY6CNqmzrJ1PC9apeYg)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw*, newIdentCache__C9aDMlmEchTc9anNE0BtBTYg)(void);
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__PlZXt6qHCDDk29c9ac4IuLGA)(NI8 x);
static N_INLINE(void, initStackBottomWith)(void* locals);
N_LIB_PRIVATE N_NOINLINE(void, nimGC_setStackBottom)(void* theStackBottom);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_ioDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, systemDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, systemInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_strutilsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_posixDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_timesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_timesInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_osDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_osInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_strtabsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_setsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_ropesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_ropesInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_tablesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_lineinfosDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_platformDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_prefixmatchesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_terminalDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_terminalInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_optionsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_streamsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_osprocDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_lexbaseDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_parsejsonDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_jsonDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_extccompDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_wordrecgDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_parseoptDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_incrementalDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_identsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_astDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_llstreamDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_nimlexbaseDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_lexerDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_parserDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_rendererDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_syntaxesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_intsetsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_typesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_btreesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_md5DatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_modulegraphsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_vmdefDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_semdataDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_semtypinstDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_sigmatchDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_reorderDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_guardsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_varpartitionsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_transfDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_vmDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_patternsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_semDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_ndiDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_cgendataDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_dfaDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_semparallelDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_cgenDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_scriptconfigDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_nimconfDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_passauxDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_dependsDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_sourcemapDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_sourcemapInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_jsgenDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, docutils_rstastDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, docutils_rstDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, docutils_highliteDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, docutils_rstgenDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_cgiInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_docgenDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_docgen2DatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_mainDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, compiler_cmdlinehelperDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, NimMainModule)(void);

/* section: NIM_merge_DATA */
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__oQuE3daAnIJJmmxLCZ80bA_;
extern TNimType NTI__l9cyoK9aLLTUH7LBRIbLqETg_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__6xNBOpPeN0DsJ34t7RoSng_3 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_4, " ", 1);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_5, "-", 1);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_7, "run", 3);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_8, "e", 1);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_9, "r", 1);
static NIM_CONST tyArray__24KAM9afIUgUaqBaEBB6r9bg TM__6xNBOpPeN0DsJ34t7RoSng_6 = {((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_7),
((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_8),
((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_9)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_10, "arguments can only be given if the \'--run\' option is selected", 61);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_12, "/home/runner/work/nightlies/nightlies/nim/compiler/nim.nim", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6xNBOpPeN0DsJ34t7RoSng_11 = {((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_12),
((NI) 68),
((NI) 16)}
;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_14, "nim_compiler", 12);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_15, "nodejs", 6);
extern NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA ExeExts__ONrgkgAZ9bh6KVTWl4XeOSw;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_16, "node", 4);
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_17, "nim.nim(98, 22) `false` ", 24);
extern TNimType NTI__4OBsgZ9cscH2JLUE5Wcz01g_;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_18, "\'$1 cannot handle arguments", 27);
extern TNimType NTI__VH3ghgQVwLSg3krOAoXigw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6xNBOpPeN0DsJ34t7RoSng_19 = {((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_12),
((NI) 103),
((NI) 18)}
;
STRING_LITERAL(TM__6xNBOpPeN0DsJ34t7RoSng_20, "\'$1 cannot handle --run", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__6xNBOpPeN0DsJ34t7RoSng_21 = {((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_12),
((NI) 107),
((NI) 16)}
;

/* section: NIM_merge_VARS */
N_LIB_PRIVATE tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf__lKXhfYq5erKa0KS4nncpUA;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, TM__6xNBOpPeN0DsJ34t7RoSng_2)(void) {
	nimGCvisit((void*)conf__lKXhfYq5erKa0KS4nncpUA, 0);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__CWgb1wQSxTCKtdHVU5pCYQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCmdLine__0ODH9apAuQHiVD2VRBWaB5Q)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* cmd, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg p;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T1_;
	NI argsCount;
	nimZeroMem((void*)(&p), sizeof(tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg));
	p.Sup.m_type = (&NTI__l9cyoK9aLLTUH7LBRIbLqETg_);
	T1_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
	T1_ = NIM_NIL;
	initOptParser__C9a079cuyRqhvKudWkyCzvXQ(cmd, TM__6xNBOpPeN0DsJ34t7RoSng_3, T1_, NIM_TRUE, (&p));
	argsCount = ((NI) 0);
	asgnRef((void**) (&(*config).commandLine), setLengthStr((*config).commandLine, ((NI) 0)));
	{
		while (1) {
			nponext((&p));
			switch (p.kind) {
			case ((tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA) 0):
			{
				goto LA2;
			}
			break;
			case ((tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA) 2):
			case ((tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA) 3):
			{
				NimStringDesc* T6_;
				asgnRef((void**) (&(*config).commandLine), resizeString((*config).commandLine, 1));
appendString((*config).commandLine, ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_4));
				addCmdPrefix__wEj87UK9bqDpzf8XE3AkG9aA((&(*config).commandLine), p.kind);
				T6_ = (NimStringDesc*)0;
				T6_ = nospquoteShell(p.key);
				asgnRef((void**) (&(*config).commandLine), resizeString((*config).commandLine, (T6_ ? T6_->Sup.len : 0) + 0));
appendString((*config).commandLine, T6_);
				{
					NimStringDesc* T11_;
					if (!(((NI) 0) < (p.val ? p.val->Sup.len : 0))) goto LA9_;
					asgnRef((void**) (&(*config).commandLine), addChar((*config).commandLine, 58));
					T11_ = (NimStringDesc*)0;
					T11_ = nospquoteShell(p.val);
					asgnRef((void**) (&(*config).commandLine), resizeString((*config).commandLine, (T11_ ? T11_->Sup.len : 0) + 0));
appendString((*config).commandLine, T11_);
				}
				LA9_: ;
				{
					if (!((p.key ? p.key->Sup.len : 0) == 0)) goto LA14_;
					p.key = copyString(((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_5));
					{
						NIM_BOOL T18_;
						T18_ = (NIM_BOOL)0;
						T18_ = processArgument__MHrYBQtd7a5cMBE9clMgEKg(pass, (&p), (&argsCount), config);
						if (!T18_) goto LA19_;
						goto LA2;
					}
					LA19_: ;
				}
				goto LA12_;
				LA14_: ;
				{
					processSwitch__dV5jwz9cYCLeNjAX40tnQHw(pass, (&p), config);
				}
				LA12_: ;
			}
			break;
			case ((tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA) 1):
			{
				NimStringDesc* T23_;
				asgnRef((void**) (&(*config).commandLine), resizeString((*config).commandLine, 1));
appendString((*config).commandLine, ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_4));
				T23_ = (NimStringDesc*)0;
				T23_ = nospquoteShell(p.key);
				asgnRef((void**) (&(*config).commandLine), resizeString((*config).commandLine, (T23_ ? T23_->Sup.len : 0) + 0));
appendString((*config).commandLine, T23_);
				{
					NIM_BOOL T26_;
					T26_ = (NIM_BOOL)0;
					T26_ = processArgument__MHrYBQtd7a5cMBE9clMgEKg(pass, (&p), (&argsCount), config);
					if (!T26_) goto LA27_;
					goto LA2;
				}
				LA27_: ;
			}
			break;
			}
		}
	} LA2: ;
	{
		if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 1))) goto LA31_;
		{
			NIM_BOOL T35_;
			NIM_BOOL T36_;
			NimStringDesc* T39_;
			NIM_BOOL T40_;
			T35_ = (NIM_BOOL)0;
			T36_ = (NIM_BOOL)0;
			T36_ = ((4100 & (*config).globalOptions) == 0);
			if (!(T36_)) goto LA37_;
			T36_ = (((NI) 0) < ((*config).arguments ? (*config).arguments->Sup.len : 0));
			LA37_: ;
			T35_ = T36_;
			if (!(T35_)) goto LA38_;
			T39_ = (NimStringDesc*)0;
			T39_ = nsuNormalize((*config).command);
			T40_ = (NIM_BOOL)0;
			T40_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem(TM__6xNBOpPeN0DsJ34t7RoSng_6, 3, T39_);
			T35_ = !(T40_);
			LA38_: ;
			if (!T35_) goto LA41_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew(config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_10), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__6xNBOpPeN0DsJ34t7RoSng_11, NIM_FALSE);
		}
		LA41_: ;
	}
	LA31_: ;
}
static N_INLINE(NimStringDesc*, findNodeJs__dT9cGd8fI0ylss24ld7sh9bQnodejs)(void) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = findExe__9cov9c3aI19bfbEIyMe9bNCSEA(((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_15), NIM_TRUE, ExeExts__ONrgkgAZ9bh6KVTWl4XeOSw, 1);
	{
		if (!((result ? result->Sup.len : 0) == 0)) goto LA3_;
		result = findExe__9cov9c3aI19bfbEIyMe9bNCSEA(((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_16), NIM_TRUE, ExeExts__ONrgkgAZ9bh6KVTWl4XeOSw, 1);
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, handleCmdLine__I9aitIr13Z1B6wHv5vzMf2w)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg* self;
	tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg* T1_;
	tyProc__34NX3arOx349cB4sFiTD3uA T2_;
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
{	T1_ = (tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg*)0;
	T1_ = (tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg*) newObj((&NTI__oQuE3daAnIJJmmxLCZ80bA_), sizeof(tyObject_NimProgcolonObjectType___bzPe2PlnnyJH4wKrjRuvwg));
	(*T1_).supportsStdinFile = NIM_TRUE;
	nimZeroMem((void*)(&T2_), sizeof(tyProc__34NX3arOx349cB4sFiTD3uA));
	T2_.ClP_0 = ((TM__6xNBOpPeN0DsJ34t7RoSng_13) (processCmdLine__0ODH9apAuQHiVD2VRBWaB5Q)); T2_.ClE_0 = NIM_NIL;
	asgnRef((void**) (&(*T1_).processCmdLine.ClE_0), T2_.ClE_0);
	(*T1_).processCmdLine.ClP_0 = T2_.ClP_0;
	self = T1_;
	initDefinesProg__59abjgA38liT9axvqVqzqA1A(self, conf, ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_14));
	{
		NI T5_;
		T5_ = (NI)0;
		T5_ = paramCount__LYkRnwMk6UXTCs9c59cPvZsQ();
		if (!(T5_ == ((NI) 0))) goto LA6_;
		writeCommandLineUsage__t8RT1Qk4s0rBX8YbKQ0DBQ_2(conf);
		goto BeforeRet_;
	}
	LA6_: ;
	processCmdLineAndProjectPath__Cg1dOQGwciny9ad7gh4258w(self, conf);
	graph = newModuleGraph__i9b4NK8jPhAUAsvbtMitNLw(cache, conf);
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = loadConfigsAndRunMainCommand__3aAEaOd6nhtgmlwjBQ2GcQ(self, cache, conf, graph);
		if (!!(T10_)) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	mainCommand__ikP0vuP6oxqlYdG7q9cY7sA(graph);
	{
		NIM_BOOL T15_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T18_;
		T15_ = (NIM_BOOL)0;
		T15_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2(conf, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 77));
		if (!T15_) goto LA16_;
		nimZeroMem((void*)T18_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T18_[0] = GC_getStatistics__wZiNbtaUL82bHwwHPZjV9cQ();
		echoBinSafe(T18_, 1);
	}
	LA16_: ;
	{
		if (!!(((*conf).errorCounter == ((NI) 0)))) goto LA21_;
		goto BeforeRet_;
	}
	LA21_: ;
	{
		NimStringDesc* output;
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 12))&63U)))!=0)) goto LA25_;
		output = absOutFile__ea9bsNo9cwchKzwCi7UjcP7g(conf);
		switch ((*conf).cmd) {
		case ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 21):
		{
			NimStringDesc* cmdPrefix;
			NimStringDesc* T38_;
			NimStringDesc* T39_;
			cmdPrefix = ((NimStringDesc*) NIM_NIL);
			switch ((*conf).backend) {
			case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1):
			case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2):
			case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4):
			{
			}
			break;
			case ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3):
			{
				NimStringDesc* T30_;
				NimStringDesc* T31_;
				T30_ = (NimStringDesc*)0;
				T31_ = (NimStringDesc*)0;
				T31_ = findNodeJs__dT9cGd8fI0ylss24ld7sh9bQnodejs();
				T30_ = rawNewString((T31_ ? T31_->Sup.len : 0) + 1);
appendString(T30_, T31_);
appendString(T30_, ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_4));
				cmdPrefix = T30_;
			}
			break;
			default:
			{
				{
					NimStringDesc* T37_;
					if (!NIM_TRUE) goto LA35_;
					T37_ = (NimStringDesc*)0;
					T37_ = rawNewString((reprEnum((NI)(*conf).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_)) ? reprEnum((NI)(*conf).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_))->Sup.len : 0) + 24);
appendString(T37_, ((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_17));
appendString(T37_, reprEnum((NI)(*conf).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_)));
					failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(T37_);
				}
				LA35_: ;
			}
			break;
			}
			T38_ = (NimStringDesc*)0;
			T39_ = (NimStringDesc*)0;
			T39_ = nospquoteShell(output);
			T38_ = rawNewString((cmdPrefix ? cmdPrefix->Sup.len : 0) + (T39_ ? T39_->Sup.len : 0) + ((*conf).arguments ? (*conf).arguments->Sup.len : 0) + 1);
appendString(T38_, cmdPrefix);
appendString(T38_, T39_);
appendChar(T38_, 32);
appendString(T38_, (*conf).arguments);
			execExternalProgram__WKaD677f7aLTxInYSr0wMw(conf, T38_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 71));
		}
		break;
		case ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8):
		case ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 16):
		{
			NimStringDesc* T47_;
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T45_;
				NimStringDesc* T46_;
				if (!(((NI) 0) < ((*conf).arguments ? (*conf).arguments->Sup.len : 0))) goto LA43_;
				nimZeroMem((void*)T45_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T45_[0] = reprEnum((NI)(*conf).cmd, (&NTI__VH3ghgQVwLSg3krOAoXigw_));
				T46_ = (NimStringDesc*)0;
				T46_ = nsuFormatOpenArray(((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_18), T45_, 1);
				liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T46_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__6xNBOpPeN0DsJ34t7RoSng_19, NIM_FALSE);
			}
			LA43_: ;
			T47_ = (NimStringDesc*)0;
			T47_ = dollar___l9cjIIY6CNqmzrJ1PC9apeYg(output);
			openDefaultBrowser__lhAiGWV9cJtbG6lYE4tGA3A(T47_);
		}
		break;
		default:
		{
			tyArray__nHXaesL0DJZHyVS07ARPRA T49_;
			NimStringDesc* T50_;
			nimZeroMem((void*)T49_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T49_[0] = reprEnum((NI)(*conf).cmd, (&NTI__VH3ghgQVwLSg3krOAoXigw_));
			T50_ = (NimStringDesc*)0;
			T50_ = nsuFormatOpenArray(((NimStringDesc*) &TM__6xNBOpPeN0DsJ34t7RoSng_20), T49_, 1);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T50_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__6xNBOpPeN0DsJ34t7RoSng_21, NIM_FALSE);
		}
		break;
		}
	}
	LA25_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, initStackBottomWith)(void* locals) {
	nimGC_setStackBottom(locals);
}

N_LIB_PRIVATE void PreMainInner(void) {
	stdlib_timesInit000();
	stdlib_osInit000();
	compiler_ropesInit000();
	stdlib_terminalInit000();
	compiler_sourcemapInit000();
	stdlib_cgiInit000();
}

N_LIB_PRIVATE int cmdCount;
N_LIB_PRIVATE char** cmdLine;
N_LIB_PRIVATE char** gEnv;
N_LIB_PRIVATE void PreMain(void) {
	void (*volatile inner)(void);
	inner = PreMainInner;
	stdlib_ioDatInit000();
	systemDatInit000();
	initStackBottomWith((void *)&inner);
	systemInit000();
	stdlib_strutilsDatInit000();
	stdlib_posixDatInit000();
	stdlib_timesDatInit000();
	stdlib_osDatInit000();
	stdlib_strtabsDatInit000();
	stdlib_setsDatInit000();
	compiler_ropesDatInit000();
	stdlib_tablesDatInit000();
	compiler_lineinfosDatInit000();
	compiler_platformDatInit000();
	compiler_prefixmatchesDatInit000();
	stdlib_terminalDatInit000();
	compiler_optionsDatInit000();
	stdlib_streamsDatInit000();
	stdlib_osprocDatInit000();
	stdlib_lexbaseDatInit000();
	stdlib_parsejsonDatInit000();
	stdlib_jsonDatInit000();
	compiler_extccompDatInit000();
	compiler_wordrecgDatInit000();
	stdlib_parseoptDatInit000();
	compiler_incrementalDatInit000();
	compiler_identsDatInit000();
	compiler_astDatInit000();
	compiler_llstreamDatInit000();
	compiler_nimlexbaseDatInit000();
	compiler_lexerDatInit000();
	compiler_parserDatInit000();
	compiler_rendererDatInit000();
	compiler_syntaxesDatInit000();
	stdlib_intsetsDatInit000();
	compiler_typesDatInit000();
	compiler_btreesDatInit000();
	stdlib_md5DatInit000();
	compiler_modulegraphsDatInit000();
	compiler_vmdefDatInit000();
	compiler_semdataDatInit000();
	compiler_semtypinstDatInit000();
	compiler_sigmatchDatInit000();
	compiler_reorderDatInit000();
	compiler_guardsDatInit000();
	compiler_varpartitionsDatInit000();
	compiler_transfDatInit000();
	compiler_vmDatInit000();
	compiler_patternsDatInit000();
	compiler_semDatInit000();
	compiler_ndiDatInit000();
	compiler_cgendataDatInit000();
	compiler_dfaDatInit000();
	compiler_semparallelDatInit000();
	compiler_cgenDatInit000();
	compiler_scriptconfigDatInit000();
	compiler_nimconfDatInit000();
	compiler_passauxDatInit000();
	compiler_dependsDatInit000();
	compiler_sourcemapDatInit000();
	compiler_jsgenDatInit000();
	docutils_rstastDatInit000();
	docutils_rstDatInit000();
	docutils_highliteDatInit000();
	docutils_rstgenDatInit000();
	compiler_docgenDatInit000();
	compiler_docgen2DatInit000();
	compiler_mainDatInit000();
	compiler_cmdlinehelperDatInit000();
	(*inner)();
}

N_LIB_PRIVATE N_CDECL(void, NimMainInner)(void) {
	NimMainModule();
}

N_CDECL(void, NimMain)(void) {
	void (*volatile inner)(void);
	PreMain();
	inner = NimMainInner;
	initStackBottomWith((void *)&inner);
	(*inner)();
}

int main(int argc, char** args, char** env) {
	cmdLine = args;
	cmdCount = argc;
	gEnv = env;
	NimMain();
	return nim_program_result;
}

N_LIB_PRIVATE N_NIMCALL(void, NimMainModule)(void) {
{
	tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* T1_;

	nimRegisterGlobalMarker(TM__6xNBOpPeN0DsJ34t7RoSng_2);

	GC_disableMarkAndSweep__amVlU9ajqZ06ujoesRBHcDg_3();
	asgnRef((void**) (&conf__lKXhfYq5erKa0KS4nncpUA), newConfigRef__YbeeoJLQnRQK2F8DAaXI8w());
	T1_ = (tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw*)0;
	T1_ = newIdentCache__C9aDMlmEchTc9anNE0BtBTYg();
	handleCmdLine__I9aitIr13Z1B6wHv5vzMf2w(T1_, conf__lKXhfYq5erKa0KS4nncpUA);
	msgQuit__PlZXt6qHCDDk29c9ac4IuLGA(((NI8) ((((NI) 0) < (*conf__lKXhfYq5erKa0KS4nncpUA).errorCounter))));
}
}

