/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__5L3fCt9bX0gyEcO30ervPLw tyTuple__5L3fCt9bX0gyEcO30ervPLw;
typedef struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyTuple__UpiOGlu5Ux6DLM73wSrdpg;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg;
struct tyTuple__5L3fCt9bX0gyEcO30ervPLw {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg Field12;
};
typedef tyTuple__5L3fCt9bX0gyEcO30ervPLw tyArray__geAxQ09aiJ4i2plLZEkYDpg[31];
typedef NU8 tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg;
struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg {
NimStringDesc* Field0;
NI Field1;
tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyArray__8d8P9caia9cszVjIJKsQGMQA[25];
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ, nameToOS__iaKZ3jKfqDIiIRvch1tYwg)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag, nameToCPU__xntkVpXHPIZMT9cuNDXtepg)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__08masX9a9bS9a9b87wx8moDG9aQ)(tyObject_Target__9abOl5DLX8suLujOaHSvGzw* t, tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ o, tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag c);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__9abOl5DLX8suLujOaHSvGzw_;
N_LIB_PRIVATE TNimType NTI__XYDt7D1G3qcClFyZy1Ky9ag_;
N_LIB_PRIVATE TNimType NTI__s7Mlr1t66SUqP6BKJMXLaQ_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_9, "DOS", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_10, "..", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_11, "$1.dll", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_12, "/", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_13, ".obj", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_14, "\015\012", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_15, ";", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_16, "\\", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_17, ".bat", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_18, ".", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_19, ".exe", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_20, "Windows", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_21, "OS2", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_22, "Linux", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_23, "lib$1.so", 8);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_24, ".o", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_25, "\012", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_26, ":", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_27, ".sh", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_28, "MorphOS", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_29, "SkyOS", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_30, "Solaris", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_31, "Irix", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_32, "NetBSD", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_33, "FreeBSD", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_34, "OpenBSD", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_35, "DragonFly", 9);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_36, "AIX", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_37, "PalmOS", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_38, "QNX", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_39, "Amiga", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_40, "$1.library", 10);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_41, "Atari", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_42, ".tpp", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_43, "Netware", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_44, "$1.nlm", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_45, ".nlm", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_46, "MacOS", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_47, "::", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_48, "$1Lib", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_49, "\015", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_50, ",", 1);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_51, "MacOSX", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_52, "lib$1.dylib", 11);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_53, "iOS", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_54, "Haiku", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_55, "Android", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_56, "VxWorks", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_57, ".vxe", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_58, "Genode", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_59, "$1.lib.so", 9);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_60, "JS", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_61, "NimVM", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_62, "Standalone", 10);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_63, "NintendoSwitch", 14);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_64, ".elf", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_65, "FreeRTOS", 8);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_66, "Any", 3);
N_LIB_PRIVATE NIM_CONST tyArray__geAxQ09aiJ4i2plLZEkYDpg OS__Jx0qy9c9bSo4fGkMxUfUaAaw = {{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_9),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_11),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_13),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_14),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_15),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_16),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_17),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_19),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
2}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_20),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_11),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_13),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_14),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_15),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_16),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_17),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_19),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
2}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_21),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_11),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_13),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_14),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_15),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_16),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_17),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_19),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
2}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_22),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_28),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_29),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_30),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_31),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_32),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_33),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_34),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_35),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_36),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_37),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
1}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_38),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_39),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_40),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
1}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_41),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_11),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_42),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
1}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_43),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_44),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_14),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_45),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
2}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_46),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_47),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_48),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_49),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_50),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
2}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_51),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_52),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
13}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_53),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_54),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
13}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_55),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_56),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_15),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_16),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_57),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
13}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_58),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_59),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
9}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_60),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
0}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_61),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
0}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_62),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
0}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_63),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_64),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
5}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_65),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
4}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_66),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_10),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_23),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_24),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_25),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_26),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_12),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_27),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
((NimStringDesc*) NIM_NIL),
((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_18),
0}
}
;
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_67, "windows", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_68, "i386", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_69, "m68k", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_70, "alpha", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_71, "powerpc", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_72, "powerpc64", 9);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_73, "powerpc64el", 11);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_74, "sparc", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_75, "vm", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_76, "hppa", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_77, "ia64", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_78, "amd64", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_79, "mips", 4);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_80, "mipsel", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_81, "arm", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_82, "arm64", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_83, "js", 2);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_84, "nimvm", 5);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_85, "avr", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_86, "msp430", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_87, "sparc64", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_88, "mips64", 6);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_89, "mips64el", 8);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_90, "riscv64", 7);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_91, "esp", 3);
STRING_LITERAL(TM__LEa0rTUoGHqcCT74IoUuTg_92, "wasm32", 6);
N_LIB_PRIVATE NIM_CONST tyArray__8d8P9caia9cszVjIJKsQGMQA CPU__uYXopJX8pM87pQDCtmgWfQ = {{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_68),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_69),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_70),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_71),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_72),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_73),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_74),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_75),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_76),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_77),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_78),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_79),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_80),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_81),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_82),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_83),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_84),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_85),
((NI) 16),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 32),
((NI) 16)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_86),
((NI) 16),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 32),
((NI) 16)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_87),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_88),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 1),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_89),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_90),
((NI) 64),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 64)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_91),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
,
{((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_92),
((NI) 32),
((tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg) 0),
((NI) 64),
((NI) 32)}
}
;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ, nameToOS__iaKZ3jKfqDIiIRvch1tYwg)(NimStringDesc* name) {
	tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ result;
{	result = (tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ)0;
	{
		tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ i;
		NI res;
		i = (tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= ((NI) 31))) goto LA3;
				i = ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) (res));
				{
					NI T6_;
					T6_ = (NI)0;
					T6_ = nsuCmpIgnoreStyle(name, OS__Jx0qy9c9bSo4fGkMxUfUaAaw[(i)- 1].Field0);
					if (!(T6_ == ((NI) 0))) goto LA7_;
					result = i;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 0);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag, nameToCPU__xntkVpXHPIZMT9cuNDXtepg)(NimStringDesc* name) {
	tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag result;
{	result = (tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag)0;
	{
		tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag i;
		NI res;
		i = (tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= ((NI) 25))) goto LA3;
				i = ((tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag) (res));
				{
					NI T6_;
					T6_ = (NI)0;
					T6_ = nsuCmpIgnoreStyle(name, CPU__uYXopJX8pM87pQDCtmgWfQ[(i)- 1].Field0);
					if (!(T6_ == ((NI) 0))) goto LA7_;
					result = i;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag) 0);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setTarget__08masX9a9bS9a9b87wx8moDG9aQ)(tyObject_Target__9abOl5DLX8suLujOaHSvGzw* t, tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ o, tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag c) {
	(*t).targetCPU = c;
	(*t).targetOS = o;
	(*t).intSize = (NI)(CPU__uYXopJX8pM87pQDCtmgWfQ[(c)- 1].Field1 / ((NI) 8));
	(*t).floatSize = (NI)(CPU__uYXopJX8pM87pQDCtmgWfQ[(c)- 1].Field3 / ((NI) 8));
	(*t).ptrSize = (NI)(CPU__uYXopJX8pM87pQDCtmgWfQ[(c)- 1].Field4 / ((NI) 8));
	unsureAsgnRef((void**) (&(*t).tnl), copyString(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[(o)- 1].Field5));
}
N_LIB_PRIVATE N_NIMCALL(void, setTargetFromSystem__c0dhUDe82ayzPjzLru8rUA)(tyObject_Target__9abOl5DLX8suLujOaHSvGzw* t) {
	(*t).hostOS = nameToOS__iaKZ3jKfqDIiIRvch1tYwg(((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_67));
	(*t).hostCPU = nameToCPU__xntkVpXHPIZMT9cuNDXtepg(((NimStringDesc*) &TM__LEa0rTUoGHqcCT74IoUuTg_68));
	setTarget__08masX9a9bS9a9b87wx8moDG9aQ(t, (*t).hostOS, (*t).hostCPU);
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listOSnames__WnkSGhffTY6oNw2hLBbKUQ)(void) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* result;
	result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
	{
		tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ i;
		NI res;
		i = (tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ)0;
		res = ((NI) 1);
		{
			while (1) {
				NI T4_;
				NimStringDesc* T5_;
				if (!(res <= ((NI) 31))) goto LA3;
				i = ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) (res));
				result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
				T4_ = result->Sup.len++;
				T5_ = (NimStringDesc*)0;
				T5_ = result->data[T4_]; result->data[T4_] = copyStringRC1(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[(i)- 1].Field0);
				if (T5_) nimGCunrefNoCycle(T5_);
				res += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listCPUnames__WnkSGhffTY6oNw2hLBbKUQ_2)(void) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* result;
	result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
	{
		tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag i;
		NI res;
		i = (tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag)0;
		res = ((NI) 1);
		{
			while (1) {
				NI T4_;
				NimStringDesc* T5_;
				if (!(res <= ((NI) 25))) goto LA3;
				i = ((tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag) (res));
				result = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
				T4_ = result->Sup.len++;
				T5_ = (NimStringDesc*)0;
				T5_ = result->data[T4_]; result->data[T4_] = copyStringRC1(CPU__uYXopJX8pM87pQDCtmgWfQ[(i)- 1].Field0);
				if (T5_) nimGCunrefNoCycle(T5_);
				res += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_platformDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__LEa0rTUoGHqcCT74IoUuTg_2_8[8];
static TNimNode* TM__LEa0rTUoGHqcCT74IoUuTg_3_26[26];
NI TM__LEa0rTUoGHqcCT74IoUuTg_5;
static char* NIM_CONST TM__LEa0rTUoGHqcCT74IoUuTg_4[26] = {
"cpuNone", 
"cpuI386", 
"cpuM68k", 
"cpuAlpha", 
"cpuPowerpc", 
"cpuPowerpc64", 
"cpuPowerpc64el", 
"cpuSparc", 
"cpuVm", 
"cpuHppa", 
"cpuIa64", 
"cpuAmd64", 
"cpuMips", 
"cpuMipsel", 
"cpuArm", 
"cpuArm64", 
"cpuJS", 
"cpuNimVM", 
"cpuAVR", 
"cpuMSP430", 
"cpuSparc64", 
"cpuMips64", 
"cpuMips64el", 
"cpuRiscV64", 
"cpuEsp", 
"cpuWasm32"};
static TNimNode* TM__LEa0rTUoGHqcCT74IoUuTg_6_32[32];
NI TM__LEa0rTUoGHqcCT74IoUuTg_8;
static char* NIM_CONST TM__LEa0rTUoGHqcCT74IoUuTg_7[32] = {
"osNone", 
"osDos", 
"osWindows", 
"osOs2", 
"osLinux", 
"osMorphos", 
"osSkyos", 
"osSolaris", 
"osIrix", 
"osNetbsd", 
"osFreebsd", 
"osOpenbsd", 
"osDragonfly", 
"osAix", 
"osPalmos", 
"osQnx", 
"osAmiga", 
"osAtari", 
"osNetware", 
"osMacos", 
"osMacosx", 
"osIos", 
"osHaiku", 
"osAndroid", 
"osVxWorks", 
"osGenode", 
"osJS", 
"osNimVM", 
"osStandalone", 
"osNintendoSwitch", 
"osFreeRTOS", 
"osAny"};
static TNimNode TM__LEa0rTUoGHqcCT74IoUuTg_0[69];

/* section: NIM_merge_TYPE_INIT3 */
NTI__9abOl5DLX8suLujOaHSvGzw_.size = sizeof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw);
NTI__9abOl5DLX8suLujOaHSvGzw_.align = NIM_ALIGNOF(tyObject_Target__9abOl5DLX8suLujOaHSvGzw);
NTI__9abOl5DLX8suLujOaHSvGzw_.kind = 18;
NTI__9abOl5DLX8suLujOaHSvGzw_.base = 0;
NTI__9abOl5DLX8suLujOaHSvGzw_.flags = 2;
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[0] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[1];
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.size = sizeof(tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag);
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.align = NIM_ALIGNOF(tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag);
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.kind = 14;
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.base = 0;
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.flags = 3;
for (TM__LEa0rTUoGHqcCT74IoUuTg_5 = 0; TM__LEa0rTUoGHqcCT74IoUuTg_5 < 26; TM__LEa0rTUoGHqcCT74IoUuTg_5++) {
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_5+2].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_5+2].offset = TM__LEa0rTUoGHqcCT74IoUuTg_5;
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_5+2].name = TM__LEa0rTUoGHqcCT74IoUuTg_4[TM__LEa0rTUoGHqcCT74IoUuTg_5];
TM__LEa0rTUoGHqcCT74IoUuTg_3_26[TM__LEa0rTUoGHqcCT74IoUuTg_5] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_5+2];
}
TM__LEa0rTUoGHqcCT74IoUuTg_0[28].len = 26; TM__LEa0rTUoGHqcCT74IoUuTg_0[28].kind = 2; TM__LEa0rTUoGHqcCT74IoUuTg_0[28].sons = &TM__LEa0rTUoGHqcCT74IoUuTg_3_26[0];
NTI__XYDt7D1G3qcClFyZy1Ky9ag_.node = &TM__LEa0rTUoGHqcCT74IoUuTg_0[28];
TM__LEa0rTUoGHqcCT74IoUuTg_0[1].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[1].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, targetCPU);
TM__LEa0rTUoGHqcCT74IoUuTg_0[1].typ = (&NTI__XYDt7D1G3qcClFyZy1Ky9ag_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[1].name = "targetCPU";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[1] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[29];
TM__LEa0rTUoGHqcCT74IoUuTg_0[29].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[29].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, hostCPU);
TM__LEa0rTUoGHqcCT74IoUuTg_0[29].typ = (&NTI__XYDt7D1G3qcClFyZy1Ky9ag_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[29].name = "hostCPU";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[2] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[30];
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.size = sizeof(tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ);
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.align = NIM_ALIGNOF(tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ);
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.kind = 14;
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.base = 0;
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.flags = 3;
for (TM__LEa0rTUoGHqcCT74IoUuTg_8 = 0; TM__LEa0rTUoGHqcCT74IoUuTg_8 < 32; TM__LEa0rTUoGHqcCT74IoUuTg_8++) {
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_8+31].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_8+31].offset = TM__LEa0rTUoGHqcCT74IoUuTg_8;
TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_8+31].name = TM__LEa0rTUoGHqcCT74IoUuTg_7[TM__LEa0rTUoGHqcCT74IoUuTg_8];
TM__LEa0rTUoGHqcCT74IoUuTg_6_32[TM__LEa0rTUoGHqcCT74IoUuTg_8] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[TM__LEa0rTUoGHqcCT74IoUuTg_8+31];
}
TM__LEa0rTUoGHqcCT74IoUuTg_0[63].len = 32; TM__LEa0rTUoGHqcCT74IoUuTg_0[63].kind = 2; TM__LEa0rTUoGHqcCT74IoUuTg_0[63].sons = &TM__LEa0rTUoGHqcCT74IoUuTg_6_32[0];
NTI__s7Mlr1t66SUqP6BKJMXLaQ_.node = &TM__LEa0rTUoGHqcCT74IoUuTg_0[63];
TM__LEa0rTUoGHqcCT74IoUuTg_0[30].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[30].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, targetOS);
TM__LEa0rTUoGHqcCT74IoUuTg_0[30].typ = (&NTI__s7Mlr1t66SUqP6BKJMXLaQ_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[30].name = "targetOS";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[3] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[64];
TM__LEa0rTUoGHqcCT74IoUuTg_0[64].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[64].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, hostOS);
TM__LEa0rTUoGHqcCT74IoUuTg_0[64].typ = (&NTI__s7Mlr1t66SUqP6BKJMXLaQ_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[64].name = "hostOS";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[4] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[65];
TM__LEa0rTUoGHqcCT74IoUuTg_0[65].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[65].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, intSize);
TM__LEa0rTUoGHqcCT74IoUuTg_0[65].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[65].name = "intSize";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[5] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[66];
TM__LEa0rTUoGHqcCT74IoUuTg_0[66].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[66].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, floatSize);
TM__LEa0rTUoGHqcCT74IoUuTg_0[66].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[66].name = "floatSize";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[6] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[67];
TM__LEa0rTUoGHqcCT74IoUuTg_0[67].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[67].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, ptrSize);
TM__LEa0rTUoGHqcCT74IoUuTg_0[67].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[67].name = "ptrSize";
TM__LEa0rTUoGHqcCT74IoUuTg_2_8[7] = &TM__LEa0rTUoGHqcCT74IoUuTg_0[68];
TM__LEa0rTUoGHqcCT74IoUuTg_0[68].kind = 1;
TM__LEa0rTUoGHqcCT74IoUuTg_0[68].offset = offsetof(tyObject_Target__9abOl5DLX8suLujOaHSvGzw, tnl);
TM__LEa0rTUoGHqcCT74IoUuTg_0[68].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__LEa0rTUoGHqcCT74IoUuTg_0[68].name = "tnl";
TM__LEa0rTUoGHqcCT74IoUuTg_0[0].len = 8; TM__LEa0rTUoGHqcCT74IoUuTg_0[0].kind = 2; TM__LEa0rTUoGHqcCT74IoUuTg_0[0].sons = &TM__LEa0rTUoGHqcCT74IoUuTg_2_8[0];
NTI__9abOl5DLX8suLujOaHSvGzw_.node = &TM__LEa0rTUoGHqcCT74IoUuTg_0[0];
}

