/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g;
typedef struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg tyArray__vRMVBJdMPxNRfDfsYvXF0A[4];
typedef NimStringDesc* tyArray__z9cqFgHiS9ahHOXLmNWEBvBg[84];
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw {
  tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA Sup;
};
struct tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g {
  tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw Sup;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ {
  tyObject_ValueError__yoNlBGx0D2tRizIdhQuENw Sup;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__tNFrR3kRuS1FSwuiLGoSSA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Zi9cGbCWofbtABoHJ5RbLNQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initTable__14glhEbpv2WXsBQ7EIe6aQ)(NI initialSize, tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_NIMCALL(void, Marker_tyRef__4EUwpnAlpBobir11lyz7Dw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
static N_NIMCALL(void, Marker_tyRef__q2mvqo4oBiq6VrjsaIw7rg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NI, hash__DlYP6SiFE58o4AvueiY0Eg)(tyTuple__47w2DboNEPf69aPgubZdd7Q x);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__kV7r8HWT0SqOYW2k2ukC6A_;
N_LIB_PRIVATE TNimType NTI__WGx4rAexNXnczy1Avn646Q_;
extern TNimType NTI__M4na42GvebBMnI5wV9cYMxg_;
extern TNimType NTI__kDPg4wXyR8DDyA0MeEjIsw_;
extern TNimType NTI__sVg18TP9cLifHyygRe9cro9aA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__fBf8Teueoz9aAkO5cXaxrpA_;
N_LIB_PRIVATE TNimType NTI__JQkdt474rFdq9cehApnhFhw_;
N_LIB_PRIVATE TNimType NTI__z822nu9bFF1AlQnLrHjdwpA_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__tNFrR3kRuS1FSwuiLGoSSA_;
extern TNimType NTI__Ab4q9c36aMR4mtkEOIBzdzA_;
N_LIB_PRIVATE TNimType NTI__GE3hAakXKOEpch4ap3zXAw_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
N_LIB_PRIVATE TNimType NTI__Zi9cGbCWofbtABoHJ5RbLNQ_;
N_LIB_PRIVATE TNimType NTI__6kx5ul0BSa9aHxHPGwkvVHg_;
N_LIB_PRIVATE TNimType NTI__aW7oi9a49ccVPeB9ca8RVoz8g_;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg = {((NU16) 0), ((NI16) -1), ((NI32) -1)}
;
N_LIB_PRIVATE NIM_CONST tyArray__vRMVBJdMPxNRfDfsYvXF0A NotesVerbosity__DnFX9bU018gdYu1P77fbdxQ = {{
0xff, 0xff, 0x7f, 0xae, 0xbf, 0xf8, 0x83, 0x83,
0x38}
,
{
0xff, 0xff, 0x7f, 0xae, 0xbf, 0xff, 0xa7, 0x9f,
0x38}
,
{
0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff,
0xbe}
,
{
0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
0xff}
}
;
N_LIB_PRIVATE TNimType NTI__29cbg2fC1z5iM1PAI28kR5w_;
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_15, "unknown error", 13);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_16, "internal error: $1", 18);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_17, "illformed AST: $1", 17);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_18, "cannot open \'$1\'", 16);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_19, "\'$1\' expected", 13);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_20, "grid table is not implemented", 29);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_21, "general parse error", 19);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_22, "new section expected", 20);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_23, "invalid directive: \'$1\'", 23);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_24, "Cannot prove that \'$1\' is initialized.", 38);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_25, "$1", 2);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_26, "octal escape sequences do not exist; leading zero is ignored", 60);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_27, "\'$1\' is never read", 18);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_28, "\'$1\' might not have been initialized", 36);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_29, "config file \'$1\' is deprecated", 30);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_30, "\'l\' should not be used as an identifier; may look like \'1\' (one"
")", 64);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_31, "unknown magic \'$1\' might crash the compiler", 43);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_32, "redefinition of label \'$1\'", 26);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_33, "unknown substitution \'$1\'", 25);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_34, "language \'$1\' not supported", 27);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_35, "field \'$1\' not supported", 24);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_36, "comment \'$1\' ignored", 20);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_37, "\'$1\' has no type. Typeless parameters are deprecated; only allo"
"wed for \'template\'", 81);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_38, "use {.base.} for base methods; baseless methods are deprecated", 62);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_39, "write to foreign heap", 21);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_40, "unsafe code: \'$1\'", 17);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_41, "imported and not used: \'$1\'", 27);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_42, "inherit from a more precise exception type like ValueError, IOE"
"rror or OSError. If these don\'t suit, inherit from CatchableErro"
"r or Defect.", 139);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_43, "each identifier is a tuple", 26);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_44, "setLen can potentially expand the sequence, but the element typ"
"e \'$1\' doesn\'t have a valid default value", 104);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_45, "The \'$1\' type doesn\'t have a valid default value", 48);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_46, "Cannot prove that \'$1\' is initialized. This will become a compi"
"le time error in the future.", 91);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_47, "cannot prove that field \'$1\' is accessible", 42);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_48, "cannot prove index \'$1\' is valid", 32);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_49, "unreachable else, all cases are already covered", 47);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_50, "unreachable code after \'return\' statement or \'{.noReturn.}\' pro"
"c", 64);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_51, "not GC-safe: \'$1\'", 17);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_52, "use explicit initialization of \'$1\' for clarity", 47);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_53, "\'$1\' uses GC\'ed memory", 22);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_54, "usage of a type with a destructor in a non destructible context"
". This will become a compile time error in the future.", 117);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_55, "Special variable \'result\' is shadowed.", 38);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_56, "Number of spaces around \'$#\' is not consistent", 46);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_57, "Potential object case transition, instantiate new object instea"
"d", 64);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_58, "observable stores to \'$1\'", 25);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_59, "operation successful: $#", 24);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_60, "${loc} lines; ${sec}s; $mem; $build build; proj: $project; out:"
" $output", 71);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_61, "CC: $1", 6);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_62, "line too long", 13);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_63, "\'$1\' is declared but not used", 29);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_64, "conversion to base object is not needed", 39);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_65, "conversion from $1 to itself is pointless", 41);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_66, "expression evaluates always to \'$1\'", 35);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_67, "quit() called", 13);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_68, "generated code listing:", 23);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_69, "end of listing", 14);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_70, "used config file \'$1\'", 21);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_71, "added path: \'$1\'", 16);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_72, "condition is always true: \'$1\'", 30);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_73, "condition is always false: \'$1\'", 31);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_74, "global variable declared here", 29);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_75, "expanded macro: $1", 18);
N_LIB_PRIVATE NIM_CONST tyArray__z9cqFgHiS9ahHOXLmNWEBvBg MsgKindToStr__toc2ERobyllo49aZhx0umtQ = {((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_15),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_16),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_17),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_18),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_19),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_20),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_21),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_22),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_23),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_24),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_18),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_26),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_27),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_28),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_29),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_30),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_31),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_32),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_33),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_34),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_35),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_36),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_37),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_38),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_39),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_40),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_41),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_42),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_43),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_44),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_45),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_46),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_47),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_48),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_49),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_50),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_51),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_52),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_53),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_54),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_55),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_56),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_57),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_58),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_59),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_60),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_61),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_62),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_63),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_64),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_65),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_66),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_67),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_68),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_69),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_70),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_71),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_72),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_73),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_74),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_75),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25),
((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_25)}
;
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_76, "https://nim-lang.github.io/Nim", 30);
STRING_LITERAL(TM__fug3IAAsDRtODxWPJjHlFg_77, "/", 1);
extern TNimType NTI__yoNlBGx0D2tRizIdhQuENw_;
N_LIB_PRIVATE TNimType NTI__IxbcvonC7TQkv166Uvdu1g_;
N_LIB_PRIVATE TNimType NTI__4EUwpnAlpBobir11lyz7Dw_;
N_LIB_PRIVATE TNimType NTI__cDtWY9cE7zf8BAC5QcEZZkQ_;
N_LIB_PRIVATE TNimType NTI__q2mvqo4oBiq6VrjsaIw7rg_;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__tNFrR3kRuS1FSwuiLGoSSA)(void* p, NI op) {
	tySequence__tNFrR3kRuS1FSwuiLGoSSA* a;
	NI T1_;
	a = (tySequence__tNFrR3kRuS1FSwuiLGoSSA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__Zi9cGbCWofbtABoHJ5RbLNQ)(void* p, NI op) {
	tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* a;
	NI T1_;
	a = (tySequence__Zi9cGbCWofbtABoHJ5RbLNQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].fullPath, op);
	nimGCvisit((void*)a->data[T1_].projPath, op);
	nimGCvisit((void*)a->data[T1_].shortName, op);
	nimGCvisit((void*)a->data[T1_].quotedName, op);
	nimGCvisit((void*)a->data[T1_].quotedFullName, op);
	nimGCvisit((void*)a->data[T1_].lines, op);
	nimGCvisit((void*)a->data[T1_].dirtyFile, op);
	nimGCvisit((void*)a->data[T1_].hash, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initMsgConfig__opN9bUFJa9bxNOrOzIvqpkfg)(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A* Result) {
	(*Result).trackPos.line = 0;
	(*Result).trackPos.col = 0;
	(*Result).trackPos.fileIndex = 0;
	(*Result).trackPosAttached = 0;
	unsureAsgnRef((void**)&(*Result).msgContext, NIM_NIL);
	(*Result).lastError.line = 0;
	(*Result).lastError.col = 0;
	(*Result).lastError.fileIndex = 0;
	unsureAsgnRef((void**)&(*Result).filenameToIndexTbl.data, NIM_NIL);
	(*Result).filenameToIndexTbl.counter = 0;
	unsureAsgnRef((void**)&(*Result).fileInfos, NIM_NIL);
	(*Result).systemFileIdx = 0;
	unsureAsgnRef((void**) (&(*Result).msgContext), NIM_NIL);
	(*Result).lastError = unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
	initTable__14glhEbpv2WXsBQ7EIe6aQ(((NI) 32), (&(*Result).filenameToIndexTbl));
	unsureAsgnRef((void**) (&(*Result).fileInfos), NIM_NIL);
	(*Result).errorOutputs = 3;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, createDocLink__pWiLD3R2s41obcTDlPhj9cA)(NimStringDesc* urlSuffix) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_76));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (urlSuffix ? urlSuffix->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(urlSuffix->data[((NI) 0)]) == (NU8)(47));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = resizeString(result, (urlSuffix ? urlSuffix->Sup.len : 0) + 0);
appendString(result, urlSuffix);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T8_;
		T8_ = (NimStringDesc*)0;
		T8_ = rawNewString((urlSuffix ? urlSuffix->Sup.len : 0) + 1);
appendString(T8_, ((NimStringDesc*) &TM__fug3IAAsDRtODxWPJjHlFg_77));
appendString(T8_, urlSuffix);
		result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
	}
	LA1_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__4EUwpnAlpBobir11lyz7Dw)(void* p, NI op) {
	tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g* a;
	a = (tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ)(NimStringDesc* msg) {
	tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g* T1_;
	NimStringDesc* T2_;
	T1_ = (tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g*)0;
	T1_ = (tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g*) newObj((&NTI__4EUwpnAlpBobir11lyz7Dw_), sizeof(tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTI__IxbcvonC7TQkv166Uvdu1g_);
	(*T1_).Sup.Sup.Sup.name = "ERecoverableError";
	T2_ = (NimStringDesc*)0;
	T2_ = (*T1_).Sup.Sup.Sup.message; (*T1_).Sup.Sup.Sup.message = copyStringRC1(msg);
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*T1_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
	raiseExceptionEx((Exception*)T1_, "ERecoverableError", "raiseRecoverableError", "lineinfos.nim", 242);
}
static N_NIMCALL(void, Marker_tyRef__q2mvqo4oBiq6VrjsaIw7rg)(void* p, NI op) {
	tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ* a;
	a = (tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ*)p;
	nimGCvisit((void*)(*a).Sup.Sup.Sup.parent, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.message, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.trace, op);
	nimGCvisit((void*)(*a).Sup.Sup.Sup.up, op);
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__SGf1i29beSa89acqisuwMuyg)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i) {
	NI result;
	tyTuple__47w2DboNEPf69aPgubZdd7Q T1_;
	result = (NI)0;
	T1_.Field0 = ((NI) (i.line));
	T1_.Field1 = ((NI) (i.col));
	T1_.Field2 = ((NI) (i.fileIndex));
	result = hash__DlYP6SiFE58o4AvueiY0Eg(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_lineinfosDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_2_8[8];
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_3_3[3];
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_4_2[2];
NI TM__fug3IAAsDRtODxWPJjHlFg_6;
static char* NIM_CONST TM__fug3IAAsDRtODxWPJjHlFg_5[2] = {
"eStdOut", 
"eStdErr"};
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_7_2[2];
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_8_9[9];
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_9_84[84];
NI TM__fug3IAAsDRtODxWPJjHlFg_11;
static char* NIM_CONST TM__fug3IAAsDRtODxWPJjHlFg_10[84] = {
"errUnknown", 
"errInternal", 
"errIllFormedAstX", 
"errCannotOpenFile", 
"errXExpected", 
"errGridTableNotImplemented", 
"errGeneralParseError", 
"errNewSectionExpected", 
"errInvalidDirectiveX", 
"errProveInit", 
"errGenerated", 
"errUser", 
"CannotOpenFile", 
"OctalEscape", 
"XIsNeverRead", 
"XmightNotBeenInit", 
"Deprecated", 
"ConfigDeprecated", 
"SmallLshouldNotBeUsed", 
"UnknownMagic", 
"RedefinitionOfLabel", 
"UnknownSubstitutionX", 
"LanguageXNotSupported", 
"FieldXNotSupported", 
"CommentXIgnored", 
"TypelessParam", 
"UseBase", 
"WriteToForeignHeap", 
"UnsafeCode", 
"UnusedImport", 
"InheritFromException", 
"EachIdentIsTuple", 
"UnsafeSetLen", 
"UnsafeDefault", 
"ProveInit", 
"ProveField", 
"ProveIndex", 
"UnreachableElse", 
"UnreachableCode", 
"IndexCheck", 
"GcUnsafe", 
"GcUnsafe2", 
"Uninit", 
"GcMem", 
"Destructor", 
"LockLevel", 
"ResultShadowed", 
"Spacing", 
"CaseTransition", 
"CycleCreated", 
"ObservableStores", 
"User", 
"Success", 
"SuccessX", 
"CC", 
"LineTooLong", 
"XDeclaredButNotUsed", 
"XCannotRaiseY", 
"ConvToBaseNotNeeded", 
"ConvFromXtoItselfNotNeeded", 
"ExprAlwaysX", 
"QuitCalled", 
"Processing", 
"CodeBegin", 
"CodeEnd", 
"Conf", 
"Path", 
"CondTrue", 
"CondFalse", 
"Name", 
"Pattern", 
"Exec", 
"Link", 
"Dependency", 
"Source", 
"Performance", 
"StackTrace", 
"GCStats", 
"GlobalVar", 
"ExpandMacro", 
"User", 
"UserRaw", 
"ExtendedContext", 
"MsgOrigin"};
static TNimNode* TM__fug3IAAsDRtODxWPJjHlFg_12_84[84];
NI TM__fug3IAAsDRtODxWPJjHlFg_14;
static char* NIM_CONST TM__fug3IAAsDRtODxWPJjHlFg_13[84] = {
"errUnknown", 
"errInternal", 
"errIllFormedAstX", 
"errCannotOpenFile", 
"errXExpected", 
"errGridTableNotImplemented", 
"errGeneralParseError", 
"errNewSectionExpected", 
"errInvalidDirectiveX", 
"errProveInit", 
"errGenerated", 
"errUser", 
"CannotOpenFile", 
"OctalEscape", 
"XIsNeverRead", 
"XmightNotBeenInit", 
"Deprecated", 
"ConfigDeprecated", 
"SmallLshouldNotBeUsed", 
"UnknownMagic", 
"RedefinitionOfLabel", 
"UnknownSubstitutionX", 
"LanguageXNotSupported", 
"FieldXNotSupported", 
"CommentXIgnored", 
"TypelessParam", 
"UseBase", 
"WriteToForeignHeap", 
"UnsafeCode", 
"UnusedImport", 
"InheritFromException", 
"EachIdentIsTuple", 
"UnsafeSetLen", 
"UnsafeDefault", 
"ProveInit", 
"ProveField", 
"ProveIndex", 
"UnreachableElse", 
"UnreachableCode", 
"IndexCheck", 
"GcUnsafe", 
"GcUnsafe2", 
"Uninit", 
"GcMem", 
"Destructor", 
"LockLevel", 
"ResultShadowed", 
"Spacing", 
"CaseTransition", 
"CycleCreated", 
"ObservableStores", 
"User", 
"Success", 
"SuccessX", 
"CC", 
"LineTooLong", 
"XDeclaredButNotUsed", 
"XCannotRaiseY", 
"ConvToBaseNotNeeded", 
"ConvFromXtoItselfNotNeeded", 
"ExprAlwaysX", 
"QuitCalled", 
"Processing", 
"CodeBegin", 
"CodeEnd", 
"Conf", 
"Path", 
"CondTrue", 
"CondFalse", 
"Name", 
"Pattern", 
"Exec", 
"Link", 
"Dependency", 
"Source", 
"Performance", 
"StackTrace", 
"GCStats", 
"GlobalVar", 
"ExpandMacro", 
"User", 
"UserRaw", 
"ExtendedContext", 
"MsgOrigin"};
static TNimNode TM__fug3IAAsDRtODxWPJjHlFg_0[203];

/* section: NIM_merge_TYPE_INIT3 */
NTI__kV7r8HWT0SqOYW2k2ukC6A_.size = sizeof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A);
NTI__kV7r8HWT0SqOYW2k2ukC6A_.align = NIM_ALIGNOF(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A);
NTI__kV7r8HWT0SqOYW2k2ukC6A_.kind = 18;
NTI__kV7r8HWT0SqOYW2k2ukC6A_.base = 0;
NTI__kV7r8HWT0SqOYW2k2ukC6A_.flags = 2;
TM__fug3IAAsDRtODxWPJjHlFg_2_8[0] = &TM__fug3IAAsDRtODxWPJjHlFg_0[1];
NTI__WGx4rAexNXnczy1Avn646Q_.size = sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q);
NTI__WGx4rAexNXnczy1Avn646Q_.align = NIM_ALIGNOF(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q);
NTI__WGx4rAexNXnczy1Avn646Q_.kind = 18;
NTI__WGx4rAexNXnczy1Avn646Q_.base = 0;
NTI__WGx4rAexNXnczy1Avn646Q_.flags = 3;
TM__fug3IAAsDRtODxWPJjHlFg_3_3[0] = &TM__fug3IAAsDRtODxWPJjHlFg_0[3];
TM__fug3IAAsDRtODxWPJjHlFg_0[3].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[3].offset = offsetof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, line);
TM__fug3IAAsDRtODxWPJjHlFg_0[3].typ = (&NTI__M4na42GvebBMnI5wV9cYMxg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[3].name = "line";
TM__fug3IAAsDRtODxWPJjHlFg_3_3[1] = &TM__fug3IAAsDRtODxWPJjHlFg_0[4];
TM__fug3IAAsDRtODxWPJjHlFg_0[4].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[4].offset = offsetof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, col);
TM__fug3IAAsDRtODxWPJjHlFg_0[4].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__fug3IAAsDRtODxWPJjHlFg_0[4].name = "col";
TM__fug3IAAsDRtODxWPJjHlFg_3_3[2] = &TM__fug3IAAsDRtODxWPJjHlFg_0[5];
TM__fug3IAAsDRtODxWPJjHlFg_0[5].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[5].offset = offsetof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, fileIndex);
TM__fug3IAAsDRtODxWPJjHlFg_0[5].typ = (&NTI__sVg18TP9cLifHyygRe9cro9aA_);
TM__fug3IAAsDRtODxWPJjHlFg_0[5].name = "fileIndex";
TM__fug3IAAsDRtODxWPJjHlFg_0[2].len = 3; TM__fug3IAAsDRtODxWPJjHlFg_0[2].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[2].sons = &TM__fug3IAAsDRtODxWPJjHlFg_3_3[0];
NTI__WGx4rAexNXnczy1Avn646Q_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[2];
TM__fug3IAAsDRtODxWPJjHlFg_0[1].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[1].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, trackPos);
TM__fug3IAAsDRtODxWPJjHlFg_0[1].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__fug3IAAsDRtODxWPJjHlFg_0[1].name = "trackPos";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[1] = &TM__fug3IAAsDRtODxWPJjHlFg_0[6];
TM__fug3IAAsDRtODxWPJjHlFg_0[6].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[6].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, trackPosAttached);
TM__fug3IAAsDRtODxWPJjHlFg_0[6].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[6].name = "trackPosAttached";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[2] = &TM__fug3IAAsDRtODxWPJjHlFg_0[7];
NTI__fBf8Teueoz9aAkO5cXaxrpA_.size = sizeof(tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA);
NTI__fBf8Teueoz9aAkO5cXaxrpA_.align = NIM_ALIGNOF(tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA);
NTI__fBf8Teueoz9aAkO5cXaxrpA_.kind = 14;
NTI__fBf8Teueoz9aAkO5cXaxrpA_.base = 0;
NTI__fBf8Teueoz9aAkO5cXaxrpA_.flags = 3;
for (TM__fug3IAAsDRtODxWPJjHlFg_6 = 0; TM__fug3IAAsDRtODxWPJjHlFg_6 < 2; TM__fug3IAAsDRtODxWPJjHlFg_6++) {
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_6+8].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_6+8].offset = TM__fug3IAAsDRtODxWPJjHlFg_6;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_6+8].name = TM__fug3IAAsDRtODxWPJjHlFg_5[TM__fug3IAAsDRtODxWPJjHlFg_6];
TM__fug3IAAsDRtODxWPJjHlFg_4_2[TM__fug3IAAsDRtODxWPJjHlFg_6] = &TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_6+8];
}
TM__fug3IAAsDRtODxWPJjHlFg_0[10].len = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[10].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[10].sons = &TM__fug3IAAsDRtODxWPJjHlFg_4_2[0];
NTI__fBf8Teueoz9aAkO5cXaxrpA_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[10];
NTI__JQkdt474rFdq9cehApnhFhw_.size = sizeof(tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA);
NTI__JQkdt474rFdq9cehApnhFhw_.align = NIM_ALIGNOF(tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA);
NTI__JQkdt474rFdq9cehApnhFhw_.kind = 19;
NTI__JQkdt474rFdq9cehApnhFhw_.base = (&NTI__fBf8Teueoz9aAkO5cXaxrpA_);
NTI__JQkdt474rFdq9cehApnhFhw_.flags = 3;
TM__fug3IAAsDRtODxWPJjHlFg_0[11].len = 0; TM__fug3IAAsDRtODxWPJjHlFg_0[11].kind = 0;
NTI__JQkdt474rFdq9cehApnhFhw_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[11];
TM__fug3IAAsDRtODxWPJjHlFg_0[7].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[7].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, errorOutputs);
TM__fug3IAAsDRtODxWPJjHlFg_0[7].typ = (&NTI__JQkdt474rFdq9cehApnhFhw_);
TM__fug3IAAsDRtODxWPJjHlFg_0[7].name = "errorOutputs";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[3] = &TM__fug3IAAsDRtODxWPJjHlFg_0[12];
NTI__z822nu9bFF1AlQnLrHjdwpA_.size = sizeof(tyTuple__z822nu9bFF1AlQnLrHjdwpA);
NTI__z822nu9bFF1AlQnLrHjdwpA_.align = NIM_ALIGNOF(tyTuple__z822nu9bFF1AlQnLrHjdwpA);
NTI__z822nu9bFF1AlQnLrHjdwpA_.kind = 18;
NTI__z822nu9bFF1AlQnLrHjdwpA_.base = 0;
NTI__z822nu9bFF1AlQnLrHjdwpA_.flags = 2;
TM__fug3IAAsDRtODxWPJjHlFg_7_2[0] = &TM__fug3IAAsDRtODxWPJjHlFg_0[14];
TM__fug3IAAsDRtODxWPJjHlFg_0[14].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[14].offset = offsetof(tyTuple__z822nu9bFF1AlQnLrHjdwpA, Field0);
TM__fug3IAAsDRtODxWPJjHlFg_0[14].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__fug3IAAsDRtODxWPJjHlFg_0[14].name = "Field0";
TM__fug3IAAsDRtODxWPJjHlFg_7_2[1] = &TM__fug3IAAsDRtODxWPJjHlFg_0[15];
TM__fug3IAAsDRtODxWPJjHlFg_0[15].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[15].offset = offsetof(tyTuple__z822nu9bFF1AlQnLrHjdwpA, Field1);
TM__fug3IAAsDRtODxWPJjHlFg_0[15].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[15].name = "Field1";
TM__fug3IAAsDRtODxWPJjHlFg_0[13].len = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[13].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[13].sons = &TM__fug3IAAsDRtODxWPJjHlFg_7_2[0];
NTI__z822nu9bFF1AlQnLrHjdwpA_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[13];
NTI__tNFrR3kRuS1FSwuiLGoSSA_.size = sizeof(tySequence__tNFrR3kRuS1FSwuiLGoSSA*);
NTI__tNFrR3kRuS1FSwuiLGoSSA_.align = NIM_ALIGNOF(tySequence__tNFrR3kRuS1FSwuiLGoSSA*);
NTI__tNFrR3kRuS1FSwuiLGoSSA_.kind = 24;
NTI__tNFrR3kRuS1FSwuiLGoSSA_.base = (&NTI__z822nu9bFF1AlQnLrHjdwpA_);
NTI__tNFrR3kRuS1FSwuiLGoSSA_.flags = 2;
NTI__tNFrR3kRuS1FSwuiLGoSSA_.marker = Marker_tySequence__tNFrR3kRuS1FSwuiLGoSSA;
TM__fug3IAAsDRtODxWPJjHlFg_0[12].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[12].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, msgContext);
TM__fug3IAAsDRtODxWPJjHlFg_0[12].typ = (&NTI__tNFrR3kRuS1FSwuiLGoSSA_);
TM__fug3IAAsDRtODxWPJjHlFg_0[12].name = "msgContext";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[4] = &TM__fug3IAAsDRtODxWPJjHlFg_0[16];
TM__fug3IAAsDRtODxWPJjHlFg_0[16].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[16].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, lastError);
TM__fug3IAAsDRtODxWPJjHlFg_0[16].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__fug3IAAsDRtODxWPJjHlFg_0[16].name = "lastError";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[5] = &TM__fug3IAAsDRtODxWPJjHlFg_0[17];
TM__fug3IAAsDRtODxWPJjHlFg_0[17].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[17].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, filenameToIndexTbl);
TM__fug3IAAsDRtODxWPJjHlFg_0[17].typ = (&NTI__Ab4q9c36aMR4mtkEOIBzdzA_);
TM__fug3IAAsDRtODxWPJjHlFg_0[17].name = "filenameToIndexTbl";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[6] = &TM__fug3IAAsDRtODxWPJjHlFg_0[18];
NTI__GE3hAakXKOEpch4ap3zXAw_.size = sizeof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw);
NTI__GE3hAakXKOEpch4ap3zXAw_.align = NIM_ALIGNOF(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw);
NTI__GE3hAakXKOEpch4ap3zXAw_.kind = 18;
NTI__GE3hAakXKOEpch4ap3zXAw_.base = 0;
NTI__GE3hAakXKOEpch4ap3zXAw_.flags = 2;
TM__fug3IAAsDRtODxWPJjHlFg_8_9[0] = &TM__fug3IAAsDRtODxWPJjHlFg_0[20];
TM__fug3IAAsDRtODxWPJjHlFg_0[20].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[20].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, fullPath);
TM__fug3IAAsDRtODxWPJjHlFg_0[20].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[20].name = "fullPath";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[1] = &TM__fug3IAAsDRtODxWPJjHlFg_0[21];
TM__fug3IAAsDRtODxWPJjHlFg_0[21].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[21].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, projPath);
TM__fug3IAAsDRtODxWPJjHlFg_0[21].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[21].name = "projPath";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[2] = &TM__fug3IAAsDRtODxWPJjHlFg_0[22];
TM__fug3IAAsDRtODxWPJjHlFg_0[22].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[22].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, shortName);
TM__fug3IAAsDRtODxWPJjHlFg_0[22].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[22].name = "shortName";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[3] = &TM__fug3IAAsDRtODxWPJjHlFg_0[23];
TM__fug3IAAsDRtODxWPJjHlFg_0[23].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[23].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, quotedName);
TM__fug3IAAsDRtODxWPJjHlFg_0[23].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[23].name = "quotedName";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[4] = &TM__fug3IAAsDRtODxWPJjHlFg_0[24];
TM__fug3IAAsDRtODxWPJjHlFg_0[24].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[24].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, quotedFullName);
TM__fug3IAAsDRtODxWPJjHlFg_0[24].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[24].name = "quotedFullName";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[5] = &TM__fug3IAAsDRtODxWPJjHlFg_0[25];
TM__fug3IAAsDRtODxWPJjHlFg_0[25].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[25].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, lines);
TM__fug3IAAsDRtODxWPJjHlFg_0[25].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[25].name = "lines";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[6] = &TM__fug3IAAsDRtODxWPJjHlFg_0[26];
TM__fug3IAAsDRtODxWPJjHlFg_0[26].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[26].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, dirtyFile);
TM__fug3IAAsDRtODxWPJjHlFg_0[26].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[26].name = "dirtyFile";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[7] = &TM__fug3IAAsDRtODxWPJjHlFg_0[27];
TM__fug3IAAsDRtODxWPJjHlFg_0[27].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[27].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, hash);
TM__fug3IAAsDRtODxWPJjHlFg_0[27].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__fug3IAAsDRtODxWPJjHlFg_0[27].name = "hash";
TM__fug3IAAsDRtODxWPJjHlFg_8_9[8] = &TM__fug3IAAsDRtODxWPJjHlFg_0[28];
TM__fug3IAAsDRtODxWPJjHlFg_0[28].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[28].offset = offsetof(tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw, dirty);
TM__fug3IAAsDRtODxWPJjHlFg_0[28].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[28].name = "dirty";
TM__fug3IAAsDRtODxWPJjHlFg_0[19].len = 9; TM__fug3IAAsDRtODxWPJjHlFg_0[19].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[19].sons = &TM__fug3IAAsDRtODxWPJjHlFg_8_9[0];
NTI__GE3hAakXKOEpch4ap3zXAw_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[19];
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.size = sizeof(tySequence__Zi9cGbCWofbtABoHJ5RbLNQ*);
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.align = NIM_ALIGNOF(tySequence__Zi9cGbCWofbtABoHJ5RbLNQ*);
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.kind = 24;
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.base = (&NTI__GE3hAakXKOEpch4ap3zXAw_);
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.flags = 2;
NTI__Zi9cGbCWofbtABoHJ5RbLNQ_.marker = Marker_tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
TM__fug3IAAsDRtODxWPJjHlFg_0[18].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[18].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, fileInfos);
TM__fug3IAAsDRtODxWPJjHlFg_0[18].typ = (&NTI__Zi9cGbCWofbtABoHJ5RbLNQ_);
TM__fug3IAAsDRtODxWPJjHlFg_0[18].name = "fileInfos";
TM__fug3IAAsDRtODxWPJjHlFg_2_8[7] = &TM__fug3IAAsDRtODxWPJjHlFg_0[29];
TM__fug3IAAsDRtODxWPJjHlFg_0[29].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[29].offset = offsetof(tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A, systemFileIdx);
TM__fug3IAAsDRtODxWPJjHlFg_0[29].typ = (&NTI__sVg18TP9cLifHyygRe9cro9aA_);
TM__fug3IAAsDRtODxWPJjHlFg_0[29].name = "systemFileIdx";
TM__fug3IAAsDRtODxWPJjHlFg_0[0].len = 8; TM__fug3IAAsDRtODxWPJjHlFg_0[0].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[0].sons = &TM__fug3IAAsDRtODxWPJjHlFg_2_8[0];
NTI__kV7r8HWT0SqOYW2k2ukC6A_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[0];
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.size = sizeof(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w);
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.align = NIM_ALIGNOF(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w);
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.kind = 14;
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.base = 0;
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.flags = 3;
for (TM__fug3IAAsDRtODxWPJjHlFg_11 = 0; TM__fug3IAAsDRtODxWPJjHlFg_11 < 84; TM__fug3IAAsDRtODxWPJjHlFg_11++) {
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_11+30].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_11+30].offset = TM__fug3IAAsDRtODxWPJjHlFg_11;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_11+30].name = TM__fug3IAAsDRtODxWPJjHlFg_10[TM__fug3IAAsDRtODxWPJjHlFg_11];
TM__fug3IAAsDRtODxWPJjHlFg_9_84[TM__fug3IAAsDRtODxWPJjHlFg_11] = &TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_11+30];
}
TM__fug3IAAsDRtODxWPJjHlFg_0[114].len = 84; TM__fug3IAAsDRtODxWPJjHlFg_0[114].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[114].sons = &TM__fug3IAAsDRtODxWPJjHlFg_9_84[0];
NTI__6kx5ul0BSa9aHxHPGwkvVHg_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[114];
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.size = sizeof(tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg);
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.align = NIM_ALIGNOF(tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg);
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.kind = 19;
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.base = (&NTI__6kx5ul0BSa9aHxHPGwkvVHg_);
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.flags = 3;
TM__fug3IAAsDRtODxWPJjHlFg_0[115].len = 12; TM__fug3IAAsDRtODxWPJjHlFg_0[115].kind = 0;
NTI__aW7oi9a49ccVPeB9ca8RVoz8g_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[115];
NTI__29cbg2fC1z5iM1PAI28kR5w_.size = sizeof(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w);
NTI__29cbg2fC1z5iM1PAI28kR5w_.align = NIM_ALIGNOF(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w);
NTI__29cbg2fC1z5iM1PAI28kR5w_.kind = 14;
NTI__29cbg2fC1z5iM1PAI28kR5w_.base = 0;
NTI__29cbg2fC1z5iM1PAI28kR5w_.flags = 3;
for (TM__fug3IAAsDRtODxWPJjHlFg_14 = 0; TM__fug3IAAsDRtODxWPJjHlFg_14 < 84; TM__fug3IAAsDRtODxWPJjHlFg_14++) {
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_14+116].kind = 1;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_14+116].offset = TM__fug3IAAsDRtODxWPJjHlFg_14;
TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_14+116].name = TM__fug3IAAsDRtODxWPJjHlFg_13[TM__fug3IAAsDRtODxWPJjHlFg_14];
TM__fug3IAAsDRtODxWPJjHlFg_12_84[TM__fug3IAAsDRtODxWPJjHlFg_14] = &TM__fug3IAAsDRtODxWPJjHlFg_0[TM__fug3IAAsDRtODxWPJjHlFg_14+116];
}
TM__fug3IAAsDRtODxWPJjHlFg_0[200].len = 84; TM__fug3IAAsDRtODxWPJjHlFg_0[200].kind = 2; TM__fug3IAAsDRtODxWPJjHlFg_0[200].sons = &TM__fug3IAAsDRtODxWPJjHlFg_12_84[0];
NTI__29cbg2fC1z5iM1PAI28kR5w_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[200];
NTI__IxbcvonC7TQkv166Uvdu1g_.size = sizeof(tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g);
NTI__IxbcvonC7TQkv166Uvdu1g_.align = NIM_ALIGNOF(tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g);
NTI__IxbcvonC7TQkv166Uvdu1g_.kind = 17;
NTI__IxbcvonC7TQkv166Uvdu1g_.base = (&NTI__yoNlBGx0D2tRizIdhQuENw_);
TM__fug3IAAsDRtODxWPJjHlFg_0[201].len = 0; TM__fug3IAAsDRtODxWPJjHlFg_0[201].kind = 2;
NTI__IxbcvonC7TQkv166Uvdu1g_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[201];
NTI__4EUwpnAlpBobir11lyz7Dw_.size = sizeof(tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g*);
NTI__4EUwpnAlpBobir11lyz7Dw_.align = NIM_ALIGNOF(tyObject_ERecoverableError__IxbcvonC7TQkv166Uvdu1g*);
NTI__4EUwpnAlpBobir11lyz7Dw_.kind = 22;
NTI__4EUwpnAlpBobir11lyz7Dw_.base = (&NTI__IxbcvonC7TQkv166Uvdu1g_);
NTI__4EUwpnAlpBobir11lyz7Dw_.marker = Marker_tyRef__4EUwpnAlpBobir11lyz7Dw;
NTI__cDtWY9cE7zf8BAC5QcEZZkQ_.size = sizeof(tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ);
NTI__cDtWY9cE7zf8BAC5QcEZZkQ_.align = NIM_ALIGNOF(tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ);
NTI__cDtWY9cE7zf8BAC5QcEZZkQ_.kind = 17;
NTI__cDtWY9cE7zf8BAC5QcEZZkQ_.base = (&NTI__yoNlBGx0D2tRizIdhQuENw_);
TM__fug3IAAsDRtODxWPJjHlFg_0[202].len = 0; TM__fug3IAAsDRtODxWPJjHlFg_0[202].kind = 2;
NTI__cDtWY9cE7zf8BAC5QcEZZkQ_.node = &TM__fug3IAAsDRtODxWPJjHlFg_0[202];
NTI__q2mvqo4oBiq6VrjsaIw7rg_.size = sizeof(tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ*);
NTI__q2mvqo4oBiq6VrjsaIw7rg_.align = NIM_ALIGNOF(tyObject_ESuggestDone__cDtWY9cE7zf8BAC5QcEZZkQ*);
NTI__q2mvqo4oBiq6VrjsaIw7rg_.kind = 22;
NTI__q2mvqo4oBiq6VrjsaIw7rg_.base = (&NTI__cDtWY9cE7zf8BAC5QcEZZkQ_);
NTI__q2mvqo4oBiq6VrjsaIw7rg_.marker = Marker_tyRef__q2mvqo4oBiq6VrjsaIw7rg;
}

