/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct TNimType TNimType;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A;
typedef struct RootObj RootObj;
typedef struct TNimNode TNimNode;
typedef struct tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg;
typedef struct tySequence__b7kA8pLABz0wMAUNGYo6Wg tySequence__b7kA8pLABz0wMAUNGYo6Wg;
typedef struct tyObject_Table__i55W8RrwGKsG9cl0sAKxgkQ tyObject_Table__i55W8RrwGKsG9cl0sAKxgkQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_Table__9bHTqygodsMdJIfIXO86mVg tyObject_Table__9bHTqygodsMdJIfIXO86mVg;
typedef struct tySequence__Pi9a31vXpln9bINd05AMU7KQ tySequence__Pi9a31vXpln9bINd05AMU7KQ;
typedef struct tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw;
typedef struct tySequence__n1XPc9anZlEQHQuS14lnGwg tySequence__n1XPc9anZlEQHQuS14lnGwg;
typedef struct tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg;
typedef struct tySequence__MlAD6nAPq9bHKla9cWiIZP0g tySequence__MlAD6nAPq9bHKla9cWiIZP0g;
typedef struct tySequence__oLpBKXzW3hF9aCVMo5EymfQ tySequence__oLpBKXzW3hF9aCVMo5EymfQ;
typedef struct tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg;
typedef struct tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg;
typedef struct tySequence__sawZST1Esj3o7EY9ayWwGPw tySequence__sawZST1Esj3o7EY9ayWwGPw;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg;
typedef struct tySequence__0W45b4tBLx0JWnu0NjAmVQ tySequence__0W45b4tBLx0JWnu0NjAmVQ;
typedef struct tyTuple__FK7aTjjzjZq5t6qUNlGUDA tyTuple__FK7aTjjzjZq5t6qUNlGUDA;
typedef struct tyTuple__a1MVSYzFHR69aYce0XHk20g tyTuple__a1MVSYzFHR69aYce0XHk20g;
typedef struct tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyTuple__jq7X5k7hWG0tdTZTDkiyGQ;
typedef struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg tySequence__WwUFq9cJ2xKRlsAWVEHyPRg;
typedef struct tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA;
typedef struct tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TocEntry__z7kal23LlR1mL50YJIPMCw tyObject_TocEntry__z7kal23LlR1mL50YJIPMCw;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyTuple__awOivLjlO76sGdHY7nQUjQ tyTuple__awOivLjlO76sGdHY7nQUjQ;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyObject_TRenderTok__FnEE3o2nWtqdjoC0wa2wgA tyObject_TRenderTok__FnEE3o2nWtqdjoC0wa2wgA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf1;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw;
typedef NU8 tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw;
typedef struct {
N_NIMCALL_PTR(NimStringDesc*, ClP_0) (NimStringDesc* filename, void* ClE_0);
void* ClE_0;
} tyProc__oFHfEKFsiYTMAy9a42cSiKw;
typedef NU8 tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* filename, NI line, NI col, tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ msgKind, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__BnbLegyGxTOhIgncw6Jqfg;
typedef NimStringDesc* tyArray__C9cQfUOxfT2Mk6yT19cPu9aIA[5];
struct tyObject_Table__i55W8RrwGKsG9cl0sAKxgkQ {
tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
void* ClE_0;
} tyProc__XtNNqpdSSaHFEnbiw4OQrw;
struct tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg {
  RootObj Sup;
tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw target;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* config;
NI splitAfter;
NI listingCounter;
tySequence__b7kA8pLABz0wMAUNGYo6Wg* tocPart;
NIM_BOOL hasToc;
NimStringDesc* theIndex;
tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw options;
tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
tyProc__BnbLegyGxTOhIgncw6Jqfg msgHandler;
NimStringDesc* outDir;
NimStringDesc* destFile;
NimStringDesc* filename;
tyArray__C9cQfUOxfT2Mk6yT19cPu9aIA meta;
NimStringDesc* currentSection;
tyObject_Table__i55W8RrwGKsG9cl0sAKxgkQ seenIndexTerms;
NI id;
tyProc__XtNNqpdSSaHFEnbiw4OQrw onTestSnippet;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__bQohEW4Jw1ENvElOMs9bxmQ[26];
struct tyObject_Table__9bHTqygodsMdJIfIXO86mVg {
tySequence__Pi9a31vXpln9bINd05AMU7KQ* data;
NI counter;
};
typedef tyObject_Table__9bHTqygodsMdJIfIXO86mVg tyArray__TmA6vhsDrA5kGEbtiSS2wg[26];
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw {
tySequence__n1XPc9anZlEQHQuS14lnGwg* data;
NI counter;
NI first;
NI last;
};
struct tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ {
  tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* modDesc;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* modDeprecationMsg;
tyArray__bQohEW4Jw1ENvElOMs9bxmQ toc;
tyArray__bQohEW4Jw1ENvElOMs9bxmQ toc2;
tyArray__bQohEW4Jw1ENvElOMs9bxmQ section;
tyArray__TmA6vhsDrA5kGEbtiSS2wg tocTable;
NimStringDesc* indexValFilename;
NimStringDesc* analytics;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* seenSymbols;
tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* jArray;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA types;
NIM_BOOL isPureRst;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
NI exampleCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg emitted;
NimStringDesc* thisDir;
tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw exampleGroups;
NIM_BOOL wroteSupportFiles;
};
struct tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ {
NimStringDesc* rdoccmd;
NimStringDesc* docCmd;
NimStringDesc* code;
NI index;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tyArray__o8KQyTFgNQGvsJZYtdEsgA[8192];
struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw {
tyArray__o8KQyTFgNQGvsJZYtdEsgA buckets;
NI wordCounter;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idAnon;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idDelegator;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* emptyIdent;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ;
struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg {
  RootObj Sup;
NI counter;
tySequence__xv3aaFd3JCw8NbmALHiezQ* data;
tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ mode;
};
typedef NU8 tyEnum_JsonNodeKind__RUngo7nCHe6O8aBGIcrhtg;
struct tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg {
tySequence__MlAD6nAPq9bHKla9cWiIZP0g* data;
NI counter;
NI first;
NI last;
};
struct tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q {
NIM_BOOL isUnquoted;
tyEnum_JsonNodeKind__RUngo7nCHe6O8aBGIcrhtg kind;
union{
struct {NimStringDesc* str;
} _kind_1;
struct {NI64 num;
} _kind_2;
struct {NF fnum;
} _kind_3;
struct {NIM_BOOL bval;
} _kind_4;
struct {tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg fields;
} _kind_6;
struct {tySequence__oLpBKXzW3hF9aCVMo5EymfQ* elems;
} _kind_7;
};
};
struct tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw {
  RootObj Sup;
NI colonstate_;
tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ d1;
NimStringDesc* outp2;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
typedef NimStringDesc* tyArray__yt5VDPNtUGx9cBkOVakHwdQ[6];
typedef N_CLOSURE_PTR(NimStringDesc*, TM__5fUAZGW8WPeit3fZaQyNXA_24) (NimStringDesc* cmd);
typedef NU8 tySet_tyEnum_ProcessOption__bnU6W8LhTMnT4JaSWtGlSA;
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
NimStringDesc* Field0;
NI Field1;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf1;
NimStringDesc* file22;
};
typedef struct {
N_NIMCALL_PTR(NimStringDesc*, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__LCMSFwcIs5O0HdDmqpX05g;
typedef N_CLOSURE_PTR(NimStringDesc*, TM__5fUAZGW8WPeit3fZaQyNXA_32) (void);
typedef N_CLOSURE_PTR(NimStringDesc*, TM__5fUAZGW8WPeit3fZaQyNXA_33) (void);
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
NimStringDesc* Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog;
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__mrugoXXRZUEeG9bEXo9auBKw[2];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__qTjAvTvKF9anytN1At69aJMQ[1];
struct tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf1;
};
typedef NU8 tyEnum_RstNodeKind__Q1jM9a8f0MKlvbLZpipB3qg;
struct tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg {
tyEnum_RstNodeKind__Q1jM9a8f0MKlvbLZpipB3qg kind;
NimStringDesc* text;
NI level;
tySequence__sawZST1Esj3o7EY9ayWwGPw* sons;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ;
typedef NU8 tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA;
typedef NU8 tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw[21];
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__cypz0nHJsd9cnKgpO7fP5hQ[1];
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__JiWwrsTRC6xqNlGcBthSVA[1];
struct tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg {
NI indent;
NI lineLen;
NI col;
NI pos;
NI idx;
tySequence__0W45b4tBLx0JWnu0NjAmVQ* tokens;
NimStringDesc* buf;
NI pendingNL;
NI pendingWhitespace;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* comStack;
tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw flags;
NIM_BOOL inGenericParams;
NIM_BOOL checkAnon;
NI inPragma;
NI32 fid;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* mangler;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__wqYjTJU9ab2ZgEFMaQc3vNA[3];
typedef NU8 tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NimStringDesc* tyArray__haiLFy0nBviVTKFGuwztzQ[5];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__duFhZXIIlrbrM62cWjNekg[5];
typedef NimStringDesc* tyArray__jcN9bpO9aCR09cTLP9bY4PaJVQ[11];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__ovcl1w9aI1ZmKzg6fGNtM9bQ[11];
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__f7nG5LD47BH5K9c6mASit3g[4];
struct tyTuple__FK7aTjjzjZq5t6qUNlGUDA {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ* Field3;
};
typedef NimStringDesc* tyArray__ICDQ54qlGBxp1TLqclKASg[14];
typedef NimStringDesc* tyArray__29by1HzZaB30irI9cPdBy9cNw[14];
struct tyTuple__a1MVSYzFHR69aYce0XHk20g {
NI Field0;
NimStringDesc* Field1;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field2;
};
typedef NU8 tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg;
typedef NimStringDesc* tyArray__17w6ns39bmjfAZ429aQpCFUA[9];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__Eng719aVJBoE9cgJDyPOaffg[9];
typedef NimStringDesc* tyArray__ucDUDWdKfioXQrN9bCbG29bg[12];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__2bUjanmTGweqyhItSNsJQA[12];
struct tyTuple__jq7X5k7hWG0tdTZTDkiyGQ {
NimStringDesc* Field0;
tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* Field1;
};
typedef tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyArray__nFPyKpuH1zPi4VuXhWbFAg[1];
typedef tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyArray__rhtWm6uYOU6da9bZDT6ryDA[4];
typedef tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyArray__fG4HAsOMuyKnlovN4zCUaA[3];
typedef tyTuple__jq7X5k7hWG0tdTZTDkiyGQ tyArray__rnBfBeuXQMeTae3dUyC1Bw[2];
typedef NU8 tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg;
struct tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf1;
};
struct tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ {
  RootObj Sup;
NI colonstate_;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_TocEntry__z7kal23LlR1mL50YJIPMCw {
tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* n;
NimStringDesc* refname;
NimStringDesc* header;
};
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
NI Field0;
NimStringDesc* Field1;
NI Field2;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
NimStringDesc* Field0;
NimStringDesc* Field1;
NIM_BOOL Field2;
};
struct tyTuple__awOivLjlO76sGdHY7nQUjQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* Field3;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyObject_TRenderTok__FnEE3o2nWtqdjoC0wa2wgA {
tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ kind;
NI16 length;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg {
  TGenericSeq Sup;
  tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__b7kA8pLABz0wMAUNGYo6Wg {
  TGenericSeq Sup;
  tyObject_TocEntry__z7kal23LlR1mL50YJIPMCw data[SEQ_DECL_SIZE];
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  TGenericSeq Sup;
  tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE];
};
struct tySequence__Pi9a31vXpln9bINd05AMU7KQ {
  TGenericSeq Sup;
  tyTuple__a1MVSYzFHR69aYce0XHk20g data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__n1XPc9anZlEQHQuS14lnGwg {
  TGenericSeq Sup;
  tyTuple__FK7aTjjzjZq5t6qUNlGUDA data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  TGenericSeq Sup;
  tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__MlAD6nAPq9bHKla9cWiIZP0g {
  TGenericSeq Sup;
  tyTuple__awOivLjlO76sGdHY7nQUjQ data[SEQ_DECL_SIZE];
};
struct tySequence__oLpBKXzW3hF9aCVMo5EymfQ {
  TGenericSeq Sup;
  tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__sawZST1Esj3o7EY9ayWwGPw {
  TGenericSeq Sup;
  tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__0W45b4tBLx0JWnu0NjAmVQ {
  TGenericSeq Sup;
  tyObject_TRenderTok__FnEE3o2nWtqdjoC0wa2wgA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__XbQ9cZpzVfEPm68TZ4kxJow)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___QVqo5OOQAdrjFqBsPctklw)(NimStringDesc* base, NimStringDesc* f);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, parseFile__HSBHiITVPKlv327uAC12yw)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*, newDocumentor__4NQNwjts5pclqjg2wHmDug)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* outExt, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__V3MI5pMOk7mgnWO9c9b9czAZQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_NIMCALL(void, Marker_tyRef__12SjKZyLpJKBYPLZVcoGLA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__ZoZ1pRtzmEiOBBpTrqMZHA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, initRstGenerator__yb79cZGnzSmPK9bVz9c4Yy9aMg)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* g, tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw target, tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* config, NimStringDesc* filename, tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw options, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile, tyProc__BnbLegyGxTOhIgncw6Jqfg msgHandler);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__x9aMrspyzTek6VHYWJiGQ8w)(NimStringDesc* sX60gensym33_, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__Jsd6LfkMRIXL9b0vzcHVYOA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___gEyhbzZ1UcxyenWRLJRXNQ)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__hcPI9cq6aFLznoPn1i5OoAA)(NimStringDesc* filenameX60gensym33_, NI lineX60gensym33_, NI colX60gensym33_, tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ msgKindX60gensym33_, NimStringDesc* argX60gensym33_, void* ClE_0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__NPagzbOMpGo9aqJmfnDrITg)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOrDefault__2a0cbxcfpWcXtK45m9bR5Kg)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg*, nstnewStringTable)(tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ mode);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, newJArray__nXwnFPu9beTnGPwglrr7ztA_3)(void);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___P6saueTqDtsV5sp5vaoeKw)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* gen, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
static N_NIMCALL(void, Marker_tyRef__ihldeoD3pGN083UxUgAFWg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, objectInit)(void* dest, TNimType* typ);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___0U8YTiSB6NvFwgvyimFN2Q)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__z7B4FbwzX3Y0L1EA2lLGXw)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__D6Pj9c29aCLEJP9beOWa08HYA)(NimStringDesc* filename, NimStringDesc* content);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, interpSnippetCmd__nRa1UefxxmpBifgdHly9a0A)(NimStringDesc* cmd, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nospquoteShell)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, execCmdEx__130zQ9a9cS3YNDwoh0G9at3bw)(NimStringDesc* command, tySet_tyEnum_ProcessOption__bnU6W8LhTMnT4JaSWtGlSA options, tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* env, NimStringDesc* workingDir, NimStringDesc* input, tyTuple__XOVT24GHXwqiEj5GCsEGCA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile2__lg7fst4NMqq6lfa07YO7Rg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NimStringDesc* ext, NIM_BOOL guessTarget);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
static N_INLINE(NIM_BOOL, isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, absOutFile__ea9bsNo9cwchKzwCi7UjcP7g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile__wyg2NQihYStyX9aXfJMkKlg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, presentationPath__a9cVWkngyzzlrLvtxpnRSvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* file, NIM_BOOL isTitle);
static N_NIMCALL(void, Marker_tyRef__c2g79crEiD9bqYYWD2mguKAA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___l9cjIIY6CNqmzrJ1PC9apeYg)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getRelativePathFromConfigPath__lECD7EhJa9a9cW0kLsTWY4bQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* f);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, nimbleDir__09b7vShk9aU7cpTGhH179cQ5g)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimbleFile__ez7MSoVdvcTOZlBJgbu5Sg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path);
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeTo__zjjWvxBunys9bbBJHoqyLyQ)(NimStringDesc* fullPath, NimStringDesc* baseFilename, NIM_CHAR sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosexpandFilename)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, nossplitPath)(NimStringDesc* path, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nativeToUnixPath__solXjq9b9ca3yY9cmjx52n9a8Q)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__KoQU28HwEVx1pDp3hXeOpg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog docFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, findPragma__0mDn9a9aralwZhM9cLc7HEF9aA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw which);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genDeprecationMsg__CsFui9bBKN4zbV9c9cdppnsLA)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* frmt, NimStringDesc** varnames, NI varnamesLen_0, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** varvalues, NI varvaluesLen_0);
N_LIB_PRIVATE N_NIMCALL(void, add__yG4AKzsBRS1W4MANDlXQeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NI, getVarIdx__MkK6vdaNQ6XNXG2RGNC9a9aw)(NimStringDesc** varnames, NI varnamesLen_0, NimStringDesc* id);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__2yh9cer0ymNRHlOOg8P7IuA)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getConfigVar__nT6pi8CimjduqrsM6Cc8mQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UQrwMIIitnm9cEflSXdCkPg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___A9aKFJUF6ZjJQfrcPHJigOQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escape__MqjZ9c9b479ayFgA5h9aAscAFA)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genComment__1NsSIzkKMtq49acu82VJUxg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__9bVWgX0SWmhEi3eHlrcMD8g)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* n, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg*, parseRst__U0R9a9aB9ccn8lJ7U1XqFb10Q)(NimStringDesc* text, NimStringDesc* filename, NI line, NI column, NIM_BOOL* hasToc, tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw rstOptions, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_NIMCALL(void, Marker_tyRef__QWqhrbgPD84P9aNEkDLWGug)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg*, rstParse__UvKI39cksmpU0237JQw9cBYA)(NimStringDesc* text, NimStringDesc* filename, NI line, NI column, NIM_BOOL* hasToc, tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw options, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile, tyProc__BnbLegyGxTOhIgncw6Jqfg msgHandler);
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__XF1IuAEczMm2Z2kiQicPTw)(NimStringDesc* sX60gensym29_, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__ks78Qmor9cBt3TlwQgS4cTg)(NimStringDesc* filenameX60gensym29_, NI lineX60gensym29_, NI colX60gensym29_, tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ msgKindX60gensym29_, NimStringDesc* argX60gensym29_, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentEffect__pcvClInajR04YlyHZGrbzA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw effectType, NI idx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, effectSpec__bT2fsf3zXYRpjYdeea19aAA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw effectType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeI__L1Xluv2iZ8cHbWec9bBiiaw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentWriteEffect__IPIc9bSzbkNTXg0Vxi6qL3A)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flag, NimStringDesc* pragmaName);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentNewEffect__iKOR2aWWACOqq4zd7hmg7w)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genItem__FFKq9cqnaX9c3oo9a5AloSpuQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k, tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog docFlags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__2S18TVv8561n8da19ah7VxQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getName__X4ox39cm9bzH8GS36cF3gOsQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI splitAfter);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, esc__Tgq9c7oEp9c4LGF7SoXGTh8w)(tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw target, NimStringDesc* s, NI splitAfter);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderDefinitionName__l9ckhTtdY2uD8Mjq9cwreZDA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL noQuotes);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPlainDocstring__w0RLWJSCLHZKQXisk15Reg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__KTaDQnNH9ae4Bf008FpUeJw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getRoutineBody__vTJBniW3ZS5dVMOR2Z9aeWg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA, getAllRunnableExamplesImpl__0Dh1R1yxkJQZk4chz78Tcg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** dest, tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA state);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecComment__CsFui9bBKN4zbV9c9cdppnsLA_2)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecCommentAux__CsFui9bBKN4zbV9c9cdppnsLA_3)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRunnableExamples__CZaoTkWCFI9acor4BmYF3Yw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__QOfHld1n7oz11NnxsBYS9cw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 info);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, extractRunnableExamplesSource__CT0AYtMqaaWjtLZ9cUvHsiw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, writeExample__r3AKACONID3L7AuURMfLmw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex, NimStringDesc* rdoccmd);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, exampleOutputDir__hwg9aq9cMZugC9arDWh9bne3Yw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, renderModule__PMQ9adArlSkkG8lng7soccA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* infile, NimStringDesc* outfile, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags, NI32 fid, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__RwllE9aq05N1XhihGDBODsw)(tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___ZGs5MV3ViG3GBfnvvT9c9ctw)(tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw* t, NimStringDesc* key, tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ* val);
static N_INLINE(NI, len__9cIAgXWUH5Nk24xwUJ9bNbtQtables)(tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw t);
N_LIB_PRIVATE N_NIMCALL(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ**, X5BX5D___XsqiT9czg3Cv3zY9cWLZy9aFA)(tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8ehuHmXS8omgqFrdYMsPBg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2Opo6JkHmCRmDA87qcGfvg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, renderNimCode__iKaVLSux2ljcS3wu8Q8ylw)(NimStringDesc** result, NimStringDesc* code, NIM_BOOL isLatex);
N_LIB_PRIVATE N_NIMCALL(void, initTokRender__fvDS5PTYUI6zuDDOhODswg)(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg* r, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(void, getNextTok__F3VjMm1n9aNzNovLrk02g5g)(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg* r, tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ* kind, NimStringDesc** literal);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCallable__SUIy9a9bqpDkoM66A6tppSaA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuStrip)(NimStringDesc* s, NIM_BOOL leading, NIM_BOOL trailing, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderPlainSymbolName__0mm4u02iK86TVZPOApjzQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, complexName__9cXtMWiiMWGlqAPzr9aEWCzQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* baseName);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderParamTypes__le9bedpmveKS6qhiVCc9c7cg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, encodeUrl__hfOKCSlSHEBA7MAnVFj2bA)(NimStringDesc* s, NIM_BOOL usePlus);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__KOisMGxcPhz6CcSmxgwEQQ)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newUniquePlainSymbol__SMnsxF7PtS1Zx9aDjvvC7rw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NimStringDesc* original);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__MJcQaUOmoJidpolnPcz9aSQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procLink);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___C7jQ1fH79bR8HRQrbJjFKDg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2eu2gmgXiDUZkBgTVqD7pg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___cCI1wZSoDB14achJW7ZFSQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dkLAWa1dMAcGEAyfUZ59bRA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___DuvwOyJJ9b2gpVM9cV7DCFSQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4MBgNtJLOyqbjfGytl2OTw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___336bx9aXX7GZckfWQE5Jy3g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___IbsmsXdtDOH7pLpzh9cmAOA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9cGelOO9b6sliTnobJf6XAsg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___aNorSJCSJyyDo7w0s6eynA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BYRFs7dwiqyMIzbsx9cDq8Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TavFv5xK0dxxJCk9b4v34zg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9aAWQyBOqadJYgBT29bzliAw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zpFS2Xy9cmoAoqCFSUQj1gg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getTokSym__c63Q9b9bWYYRP36QgDsG9cNDQ)(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Nz9cwOtMmcX2gklRogKhyEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YGYo0XYmypYw3N26AYh7ug)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(NI, getnimblePkgId__h22KSexh3g61XkIPdO8SNA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, externalDep__P9b6ldiOs1C1cjAHSU4Jlpg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___e8Z4ajz6IErIB0a6mpq4Wg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___eqn09cqDPu9csxGUOSa2untg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QXMcmOst45ThYFLo9cOKDiQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YGa4o1aenD9cjoU03CAgtqQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___rZ5o6ziDKz4d3bfaN54Dgg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___b2PLtFwpZkVmYhHWvW4i1Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ctY4Nx9aQFC9bl9c2wbRLoFYA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___M2d4UEGH9cZOvte6rEhvUTQ)(NU64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CtS8L8cOLTsSuQ10mtHsvw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, attachToType__2z9at9cKP7a6GoM6O9ba1zd7g)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, whichType__P6VVhFoRXYNTxCtafqu9bmg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableContains__qQqj4cZyGcSQKBqbLx4Alg)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__59a2OAWg9c9azGlf9aSfMJTaLA)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* htmlFile, NimStringDesc* id, NimStringDesc* term, NimStringDesc* linkTitle, NimStringDesc* linkDesc);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, docstringSummary__kPnzAIKnun4jRp3dcGAV8Q)(NimStringDesc* rstText);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(void, nsuDelete)(NimStringDesc** s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindCharSet)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, mgetOrPut__0qPqS0Ahbl9crTMtdrZk6CQ)(tyObject_Table__9bHTqygodsMdJIfIXO86mVg* t, NimStringDesc* key, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* val);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__tyTgUybFIoow4CX2l5beug)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__SUIy9a9bqpDkoM66A6tppSaA_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__Eq9c0D6KgDDYSrjqwmAUuRg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xsFAphqq4CRpmuZ79bXVLrA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prettyLink__wqjxtEP9aQIQkUTKzbjpNkQ)(NimStringDesc* file);
N_LIB_PRIVATE N_NIMCALL(void, exportSym__qYoJMTaZpxeCNRoEoCKzkw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, originatingModule__lIu8wX6Beq6dBJgESOFFjg_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ypCukdfzc26AjS7pGJ5Q9cw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__eA6azHzJ9cvJzUy6fY2ILpA)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NIM_BOOL useWarning, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__6UjzL2rSgVAuceHWxn9c01Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d);
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(NI, nosexecShellCmd)(NimStringDesc* command);
N_LIB_PRIVATE N_NIMCALL(void, quit__q8QKbUwWyOe9b9a1QNJQr71A)(NimStringDesc* errormsg, NI errorcode) __attribute__((noreturn));
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___IgedJtiWLIr01rtDe6Fo8Q)(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOutFile__dxphY5tqCcKvikJIbUMu5Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__lXmEBiWEMeUQB9cTe0c6XoQ)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NI* j, NI lvl, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(void, genSection__PEsLviLPpF9bX8MsjBavO4Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, NIM_BOOL groupedToc);
N_LIB_PRIVATE N_NIMCALL(NI, len__dx37O9cdYBT1LvwGglU9akrw)(tyObject_Table__9bHTqygodsMdJIfIXO86mVg t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, X5BX5D___sd3f1kRPAXhIuKDwkllg9cQ)(tyObject_Table__9bHTqygodsMdJIfIXO86mVg* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___1d2waHISqAkJMu7hkyCpZg)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDateStr__ye3QcrLEUbQh0AniHZYCHg_2)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getClockStr__ye3QcrLEUbQh0AniHZYCHg_3)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, relLink__PAa9bhm2IGZzoGk9cubfh9a6w)(NimStringDesc* outDir, NimStringDesc* destFile, NimStringDesc* linkto);
N_LIB_PRIVATE N_NIMCALL(void, writeRope__FwuzOBq6SLlanVUstm8q9cA)(FILE* f, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__lnHFCgpMa7a239cx3L7ar0g)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NimStringDesc* outfile);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRope__LLRRC42xWBSkxzV9bsPu7lA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* head, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___hGkBbU4pIQDXq4yGHJbKBQ)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__oltK69akg0xLqkR2ITKbomg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringDesc* source, NimStringDesc* dest);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, interp__a0DsESj69cWZcRAWqDjErOw)(NimStringDesc* path, NimStringDesc* nimr);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDocHacksJs__uOPHHO9bNZaiu8yCOVxjnyA)(NimStringDesc* nimr, NimStringDesc* nim, NIM_BOOL forceRebuild);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noslastPathPart)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__6UjzL2rSgVAuceHWxn9c01Q_2)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d);
N_LIB_PRIVATE N_NIMCALL(void, writeIndexFile__XQaohh8v9brpMTzazPqfP6g)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* g, NimStringDesc* outfile);
N_LIB_PRIVATE N_NIMCALL(void, add__3iwzPz66TEml47u8LtfIQg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* j);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___ufBNJwWgb20cY5Bv3NMT7A)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* a, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* b);
N_LIB_PRIVATE N_NIMCALL(void, add__8FFZVkexaQ73y9aREGlrY9bQ)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* father, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* child);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___HoVDUa0lAOcINNYBrrSTiA)(tyTuple__jq7X5k7hWG0tdTZTDkiyGQ* keyVals, NI keyValsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___19ag6cl4fMjxytc9arHmLIbw_3)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, genJsonItem__6Yvyha9boYC58GWZQItGmBg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___mZ66tEveFIQokq3arf8Klw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___NSr46Qz23yGk4m9csPSbQBQ)(NI n);
static N_INLINE(void, X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* obj, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vlnBr1uIbtu0ntnZh6Askg)(tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg* t, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, newJObject__nXwnFPu9beTnGPwglrr7ztA_2)(void);
static N_INLINE(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, X5BX5D___277k8m8OstpfbY4dHQex6wjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q**, X5BX5D___l9atGRY9bA25fn4p5uueZfUQ)(tyObject_OrderedTable__ZZvSdVkA2s2sIyifu4cpkg* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, generateJson__aCcnJCcOFu8Y1ZdiDOUa6Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL includeComments);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPackageName__ez7MSoVdvcTOZlBJgbu5Sg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, write__PArlm09bKklm2BLsCg6YtaA)(FILE* f, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___79aIqF5QC8ZRJgu2hlv9bdjw)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__gq12VLhVO0NBzUTnGgz4nw)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(void, close__fU6ZlJAtQ9bre04EDZLdGsA_3)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mergeIndexes__gnBYZcMG5WPYB3f83P6f9ag)(NimStringDesc* dir);
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__Zb29b9be2mdWzzb1jYhPz69aw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NimStringDesc* outExt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, readFile__4PGnM9bWmsH0Nu7dnr3XzgA)(NimStringDesc* filename);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_NIMCALL(void, Marker_tyRef__SNRao7b4hOZKnbHC8HR0gg)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pretty__6ucoq7dFiVhOGmHlWNWbTg)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node, NI indent);
static N_NIMCALL(void, Marker_tyRef__sHJ3bK9btAJ66R8tJi9bFYHg)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA_2)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, generateTags__MfiAsDFdBFUXqSzZDl4T9bg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genTagsItem__tmOrGY09ab3EZGuwH5pi26w)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);

/* section: NIM_merge_DATA */
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__bjZ39beKZKuX6eBUmfaMw0A_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
N_LIB_PRIVATE TNimType NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_;
extern TNimType NTI__yF9cB1II0vYb2F0YKmIiArg_;
N_LIB_PRIVATE TNimType NTI__aItnR9bvqDIftcasLwUztVQ_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__bQohEW4Jw1ENvElOMs9bxmQ_;
extern TNimType NTI__9bHTqygodsMdJIfIXO86mVg_;
N_LIB_PRIVATE TNimType NTI__TmA6vhsDrA5kGEbtiSS2wg_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTI__n9cmoMXcDs47wYDFGEXuCfw_;
extern TNimType NTI__zfzzuQ8txrdZAYK0WGWpHg_;
extern TNimType NTI__f07aOS3dr28kGa5wcE29aFA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__lnkYNZP9asc88UfiEGjLrbA_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
N_LIB_PRIVATE TNimType NTI__fmIjjJC59a002tPvpD7yKSQ_;
N_LIB_PRIVATE TNimType NTI__12SjKZyLpJKBYPLZVcoGLA_;
extern TNimType NTI__82OdS5RTON4FvDz04E3cFw_;
N_LIB_PRIVATE TNimType NTI__ZoZ1pRtzmEiOBBpTrqMZHA_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_6, "/home/runner/work/nightlies/nightlies/nim/compiler/docgen.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_5 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 138),
((NI) 17)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_7, "doc.googleAnalytics", 19);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_8, "<script>\012  (function(i,s,o,g,r,a,m){i[\'GoogleAnalyticsObject\']="
"r;i[r]=i[r]||function(){\012  (i[r].q=i[r].q||[]).push(arguments)},"
"i[r].l=1*new Date();a=s.createElement(o),\012  m=s.getElementsByTag"
"Name(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)\012  })"
"(window,document,\'script\',\'//www.google-analytics.com/analytics."
"js\',\'ga\');\012\012  ga(\'create\', \'$1\', \'auto\');\012  ga(\'send\', \'pageview"
"\');\012\012</script>\012    ", 402);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_9, "doc.googleAnalytics", 19);
N_LIB_PRIVATE TNimType NTI__o58RO4LYcVDmmDyTJ0uhVw_;
N_LIB_PRIVATE TNimType NTI__ihldeoD3pGN083UxUgAFWg_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_11, "skip", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_12, "_snippet_", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_13, ".nim", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_14, "import \"$1\"\012", 12);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_15, "\\", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_16, "/", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_17, "nim ", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_18, "$nim ", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_19, "$1", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_20, "$options", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_21, "nim", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_22, "backend", 7);
extern TNimType NTI__4OBsgZ9cscH2JLUE5Wcz01g_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_23, "options", 7);
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_25 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 228),
((NI) 16)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_26, "snippet failed: cmd: \'$1\' status: $2 expected: $3 output: $4", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_27 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 231),
((NI) 18)}
;
N_LIB_PRIVATE TNimType NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_;
N_LIB_PRIVATE TNimType NTI__c2g79crEiD9bqYYWD2mguKAA_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_29, "@default", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_30, "@pkg", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_31, "@path", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_34, "\'$1\' failed", 11);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_36, "conf.docRoot.isAbsolute", 23);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__5fUAZGW8WPeit3fZaQyNXA_35 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_36)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_37, "; conf.docRoot: ", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_38 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 85),
((NI) 8)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_40, "conf.docRoot.dirExists", 22);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__5fUAZGW8WPeit3fZaQyNXA_39 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_41 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 86),
((NI) 8)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_42, "..", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_43, "_._", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_44, "docgen.nim(97, 3) `not result.isEmpty` ", 39);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_45, "docgen.nim(98, 3) `not isAbsolute(result.string)` ", 50);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_46, "html", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_47, "$", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_48, "Invalid format string; too many $s: ", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_49 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 270),
((NI) 20)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_50, "unknown substition variable: ", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_51 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 281),
((NI) 24)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_52, "expected closing \'}\'", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_53 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 289),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_54 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 295),
((NI) 24)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_55, "doc.deprecationmsg", 18);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_57, "label", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_58, "message", 7);
static NIM_CONST tyArray__Re75IspeoxXy2oCZHwcRrA TM__5fUAZGW8WPeit3fZaQyNXA_56 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_57),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_58)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_59, "docgen.nim(776, 14) `false` ", 28);
N_LIB_PRIVATE TNimType NTI__4EIPlYmwmzq4foglAJUuOg_;
N_LIB_PRIVATE TNimType NTI__QWqhrbgPD84P9aNEkDLWGug_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_61, "ref ", 4);
extern TNimType NTI__ycbpMCRV6Cd2eBh3X9biEiw_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_62, "writes", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_63, "new", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_64, "escapes", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_65, "`", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_66, "##", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_67, "docgen.nim(598, 14) `result.len == 2` ", 38);
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__5fUAZGW8WPeit3fZaQyNXA_68 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
0x00, 0x06, 0x00, 0x00, 0xc0, 0x00, 0x08, 0x40,
0x20, 0x60, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_69, "runnableExamples invalid", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_70 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 489),
((NI) 40)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_71, "string litteral expected", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_72 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 493),
((NI) 44)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_73, "(", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_74, ", ", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_75, ")", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_76, "autogenerated by docgen\012loc: $1\012rdoccmd: $2", 43);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_77, "runnableExamples", 16);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_78, "_examples", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_79, "import r\"$1\"\012", 13);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_80, "Example:", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_81, " cmd: ", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_82, "doc.listing_start", 17);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_83, "langNim", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_84, "doc.listing_end", 15);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__5fUAZGW8WPeit3fZaQyNXA_85 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_86, ".m", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_87, ".e", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_88, ".i", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_89, ".t", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_90, ".c", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_91, ",", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_92, "_", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_93, "doc.item.seesrc", 15);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_94, "git.url", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_95, "devel", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_96, "version-$1-$2", 13);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_98, "1", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_99, "4", 1);
static NIM_CONST tyArray__Re75IspeoxXy2oCZHwcRrA TM__5fUAZGW8WPeit3fZaQyNXA_97 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_98),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_99)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_100, "git.commit", 10);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_101, "git.devel", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_103, "path", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_104, "line", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_105, "url", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_106, "commit", 6);
static NIM_CONST tyArray__haiLFy0nBviVTKFGuwztzQ TM__5fUAZGW8WPeit3fZaQyNXA_102 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_103),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_104),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_105),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_106),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_95)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_107, "doc.item", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_109, "name", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_110, "header", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_111, "desc", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_112, "itemID", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_113, "header_plain", 12);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_114, "itemSym", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_115, "itemSymOrID", 11);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_116, "itemSymEnc", 10);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_117, "itemSymOrIDEnc", 14);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_118, "seeSrc", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_119, "deprecationMsg", 14);
static NIM_CONST tyArray__jcN9bpO9aCR09cTLP9bY4PaJVQ TM__5fUAZGW8WPeit3fZaQyNXA_108 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_110),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_111),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_112),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_113),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_114),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_115),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_116),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_117),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_118),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_119)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_120, "\342\200\246", 3);
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__5fUAZGW8WPeit3fZaQyNXA_121 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x50, 0x00, 0x04,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_122, "doc.item.toc", 12);
static NIM_CONST tyArray__24KAM9afIUgUaqBaEBB6r9bg TM__5fUAZGW8WPeit3fZaQyNXA_123 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_113),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_117)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_124, "doc.item.tocTable", 17);
static NIM_CONST tyArray__sMpvt1sOxOJ3LFGulnbeMQ TM__5fUAZGW8WPeit3fZaQyNXA_125 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_113),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_115),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_117)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_126, ",<wbr>", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_127, ": ", 2);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_128, "false", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_129, "$1_group$2_examples.nim", 23);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_130, "# autogenerated by docgen\012# source: $1\012# rdoccmd: $2\012$3", 55);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_131, "$nim $backend -r --warning:UnusedImport:off --path:$path --nimc"
"ache:$nimcache $rdoccmd $docCmd $file", 100);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_132, "nimcache", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_133, "file", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_134, "rdoccmd", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_135, "docCmd", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_136, "[runnableExamples] failed: generated file: \'$1\' group: \'$2\' cmd"
": $3", 67);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_137, "runnableExamples: ", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_138 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 483),
((NI) 16)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_139, "Imports", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_140, "Types", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_141, "Vars", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_142, "Lets", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_143, "Consts", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_144, "Procs", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_145, "Funcs", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_146, "Methods", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_147, "Iterators", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_148, "Converters", 10);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_149, "Macros", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_150, "Templates", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_151, "Exports", 7);
N_LIB_PRIVATE NIM_CONST tyArray__29by1HzZaB30irI9cPdBy9cNw sectionNames__9bFbR0UW0hviZzxnBeyotPA = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_139),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_140),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_141),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_142),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_143),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_141),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_144),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_145),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_146),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_147),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_148),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_149),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_150),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_151)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_152, "doc.section", 11);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_154, "sectionid", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_155, "sectionTitle", 12);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_156, "sectionTitleID", 14);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_157, "content", 7);
static NIM_CONST tyArray__sMpvt1sOxOJ3LFGulnbeMQ TM__5fUAZGW8WPeit3fZaQyNXA_153 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_154),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_155),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_156),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_158, "doc.section.toc2", 16);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_160, "plainName", 9);
static NIM_CONST tyArray__haiLFy0nBviVTKFGuwztzQ TM__5fUAZGW8WPeit3fZaQyNXA_159 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_154),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_155),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_156),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_160)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_161, "doc.section.toc", 15);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_162, "doc.toc", 7);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__5fUAZGW8WPeit3fZaQyNXA_163 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_164, "doc.body_toc_groupsection", 25);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_165, "doc.body_toc_group", 18);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_166, "doc.body_toc", 12);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_167, "doc.body_no_toc", 15);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_169, "title", 5);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_170, "tableofcontents", 15);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_171, "moduledesc", 10);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_172, "date", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_173, "time", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_174, "theindexhref", 12);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_175, "body_toc_groupsection", 21);
static NIM_CONST tyArray__17w6ns39bmjfAZ429aQpCFUA TM__5fUAZGW8WPeit3fZaQyNXA_168 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_169),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_170),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_171),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_172),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_173),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_119),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_174),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_175)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_176, "theindex.html", 13);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_177, "doc.file", 8);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_179, "nimdoccss", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_180, "dochackjs", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_181, "author", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_182, "version", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_183, "analytics", 9);
static NIM_CONST tyArray__ucDUDWdKfioXQrN9bCbG29bg TM__5fUAZGW8WPeit3fZaQyNXA_178 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_179),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_180),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_169),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_170),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_171),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_172),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_173),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_181),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_182),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_183),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_119)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_184, "nimdoc.out.css", 14);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_185, "dochack.js", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_186 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1280),
((NI) 16)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_187, "$nimr/doc/nimdoc.css", 20);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_188, "nimdoc.out.css", 14);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_189, ".idx", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_190, "comment", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_191, "type", 4);
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_192, "col", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_193, "description", 11);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_194, "code", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_195, "signature", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_196, "return", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_197, "arguments", 9);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_198, "default", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_199, "pragmas", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_200, "genericParams", 13);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_201, "types", 5);
extern TNimType NTI__WwUFq9cJ2xKRlsAWVEHyPRg_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_202, "orig", 4);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_203, "nimble", 6);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_204, "moduleDescription", 17);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_205, "entries", 7);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_206, "unable to open file \"", 21);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_207, "\" for writing", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_208 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1308),
((NI) 16)}
;
static NIM_CONST tyArray__jcN9bpO9aCR09cTLP9bY4PaJVQ TM__5fUAZGW8WPeit3fZaQyNXA_209 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_179),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_180),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_169),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_170),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_171),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_172),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_173),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_157),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_181),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_182),
((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_183)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_210, "Index", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_211 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1409),
((NI) 14)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_212, "txt", 3);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_213, "tex", 3);
N_LIB_PRIVATE TNimType NTI__jwayR6zaxkEYAMp3GS09bOA_;
N_LIB_PRIVATE TNimType NTI__SNRao7b4hOZKnbHC8HR0gg_;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_215, "the \':test:\' attribute is not supported by this backend", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_216 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1355),
((NI) 14)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_217, "json", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_218 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1368),
((NI) 16)}
;
N_LIB_PRIVATE TNimType NTI__pwUZDPkEs6xKitbL0Cjk9cQ_;
N_LIB_PRIVATE TNimType NTI__sHJ3bK9btAJ66R8tJi9bFYHg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_220 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1376),
((NI) 14)}
;
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_221, "\012", 1);
STRING_LITERAL(TM__5fUAZGW8WPeit3fZaQyNXA_222, "tags", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_223 = {((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_6),
((NI) 1389),
((NI) 16)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__XbQ9cZpzVfEPm68TZ4kxJow)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 33))&63U)))!=0)) goto LA3_;
		asgnRef((void**) (&(*conf).outDir), slash___QVqo5OOQAdrjFqBsPctklw((*conf).outDir, (*conf).outFile));
	}
	LA3_: ;
}
static N_NIMCALL(void, Marker_tyRef__V3MI5pMOk7mgnWO9c9b9czAZQ)(void* p, NI op) {
	tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A* a;
	a = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
static N_NIMCALL(void, Marker_tyRef__12SjKZyLpJKBYPLZVcoGLA)(void* p, NI op) {
	tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ* a;
	a = (tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*)p;
	nimGCvisit((void*)(*a).rdoccmd, op);
	nimGCvisit((void*)(*a).docCmd, op);
	nimGCvisit((void*)(*a).code, op);
}
static N_NIMCALL(void, Marker_tyRef__ZoZ1pRtzmEiOBBpTrqMZHA)(void* p, NI op) {
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* a;
	NI T1_;
	NI T2_;
	NI T3_;
	NI T4_;
	NI T5_;
	NI T6_;
	a = (tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*)p;
	nimGCvisit((void*)(*a).Sup.config, op);
	nimGCvisit((void*)(*a).Sup.tocPart, op);
	nimGCvisit((void*)(*a).Sup.theIndex, op);
	nimGCvisit((void*)(*a).Sup.findFile.ClE_0, op);
	nimGCvisit((void*)(*a).Sup.msgHandler.ClE_0, op);
	nimGCvisit((void*)(*a).Sup.outDir, op);
	nimGCvisit((void*)(*a).Sup.destFile, op);
	nimGCvisit((void*)(*a).Sup.filename, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 5; T1_++) {
	nimGCvisit((void*)(*a).Sup.meta[T1_], op);
	}
	nimGCvisit((void*)(*a).Sup.currentSection, op);
	nimGCvisit((void*)(*a).Sup.seenIndexTerms.data, op);
	nimGCvisit((void*)(*a).Sup.onTestSnippet.ClE_0, op);
	nimGCvisit((void*)(*a).modDesc, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).modDeprecationMsg, op);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 26; T2_++) {
	nimGCvisit((void*)(*a).toc[T2_], op);
	}
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 26; T3_++) {
	nimGCvisit((void*)(*a).toc2[T3_], op);
	}
	T4_ = (NI)0;
	for (T4_ = 0; T4_ < 26; T4_++) {
	nimGCvisit((void*)(*a).section[T4_], op);
	}
	T5_ = (NI)0;
	for (T5_ = 0; T5_ < 26; T5_++) {
	nimGCvisit((void*)(*a).tocTable[T5_].data, op);
	}
	nimGCvisit((void*)(*a).indexValFilename, op);
	nimGCvisit((void*)(*a).analytics, op);
	nimGCvisit((void*)(*a).seenSymbols, op);
	nimGCvisit((void*)(*a).jArray, op);
	nimGCvisit((void*)(*a).types.data, op);
	nimGCvisit((void*)(*a).conf, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).emitted.head, op);
	nimGCvisit((void*)(*a).emitted.data, op);
	T6_ = (NI)0;
	nimGCvisit((void*)(*a).thisDir, op);
	nimGCvisit((void*)(*a).exampleGroups.data, op);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__x9aMrspyzTek6VHYWJiGQ8w)(NimStringDesc* sX60gensym33_, void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A* colonenvP_;
	result = (NimStringDesc*)0;
	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*) ClE_0;
	result = findFile__Jsd6LfkMRIXL9b0vzcHVYOA((*colonenvP_).conf1, sX60gensym33_, NIM_FALSE);
	{
		NimStringDesc* T5_;
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nosgetCurrentDir();
		result = slash___gEyhbzZ1UcxyenWRLJRXNQ(T5_, sX60gensym33_);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nosfileExists(result);
			if (!!(T8_)) goto LA9_;
			result = ((NimStringDesc*) NIM_NIL);
		}
		LA9_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NI line, NI col) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
	NI32 T1_;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA(conf, filename);
	result = newLineInfo__NPagzbOMpGo9aqJmfnDrITg(T1_, line, col);
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__hcPI9cq6aFLznoPn1i5OoAA)(NimStringDesc* filenameX60gensym33_, NI lineX60gensym33_, NI colX60gensym33_, tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ msgKindX60gensym33_, NimStringDesc* argX60gensym33_, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A* colonenvP_;
	tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kX60gensym33_;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T11_;
	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*) ClE_0;
	kX60gensym33_ = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
	switch (msgKindX60gensym33_) {
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 0):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 1):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 2):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 5);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 3):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 7);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 4):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 6);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 5):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 8);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 6):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 20);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 7):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 21);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 8):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 22);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 9):
	{
		kX60gensym33_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 23);
	}
	break;
	}
	T11_ = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs((*colonenvP_).conf1, filenameX60gensym33_, lineX60gensym33_, colX60gensym33_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, T11_, kX60gensym33_, argX60gensym33_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_5, NIM_FALSE);
}
static N_NIMCALL(void, Marker_tyRef__ihldeoD3pGN083UxUgAFWg)(void* p, NI op) {
	tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw* a;
	NI T1_;
	NI T2_;
	NI T3_;
	NI T4_;
	NI T5_;
	NI T6_;
	a = (tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*)p;
	nimGCvisit((void*)(*a).d1.Sup.config, op);
	nimGCvisit((void*)(*a).d1.Sup.tocPart, op);
	nimGCvisit((void*)(*a).d1.Sup.theIndex, op);
	nimGCvisit((void*)(*a).d1.Sup.findFile.ClE_0, op);
	nimGCvisit((void*)(*a).d1.Sup.msgHandler.ClE_0, op);
	nimGCvisit((void*)(*a).d1.Sup.outDir, op);
	nimGCvisit((void*)(*a).d1.Sup.destFile, op);
	nimGCvisit((void*)(*a).d1.Sup.filename, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 5; T1_++) {
	nimGCvisit((void*)(*a).d1.Sup.meta[T1_], op);
	}
	nimGCvisit((void*)(*a).d1.Sup.currentSection, op);
	nimGCvisit((void*)(*a).d1.Sup.seenIndexTerms.data, op);
	nimGCvisit((void*)(*a).d1.Sup.onTestSnippet.ClE_0, op);
	nimGCvisit((void*)(*a).d1.modDesc, op);
	nimGCvisit((void*)(*a).d1.module, op);
	nimGCvisit((void*)(*a).d1.modDeprecationMsg, op);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 26; T2_++) {
	nimGCvisit((void*)(*a).d1.toc[T2_], op);
	}
	T3_ = (NI)0;
	for (T3_ = 0; T3_ < 26; T3_++) {
	nimGCvisit((void*)(*a).d1.toc2[T3_], op);
	}
	T4_ = (NI)0;
	for (T4_ = 0; T4_ < 26; T4_++) {
	nimGCvisit((void*)(*a).d1.section[T4_], op);
	}
	T5_ = (NI)0;
	for (T5_ = 0; T5_ < 26; T5_++) {
	nimGCvisit((void*)(*a).d1.tocTable[T5_].data, op);
	}
	nimGCvisit((void*)(*a).d1.indexValFilename, op);
	nimGCvisit((void*)(*a).d1.analytics, op);
	nimGCvisit((void*)(*a).d1.seenSymbols, op);
	nimGCvisit((void*)(*a).d1.jArray, op);
	nimGCvisit((void*)(*a).d1.types.data, op);
	nimGCvisit((void*)(*a).d1.conf, op);
	nimGCvisit((void*)(*a).d1.cache, op);
	nimGCvisit((void*)(*a).d1.emitted.head, op);
	nimGCvisit((void*)(*a).d1.emitted.data, op);
	T6_ = (NI)0;
	nimGCvisit((void*)(*a).d1.thisDir, op);
	nimGCvisit((void*)(*a).d1.exampleGroups.data, op);
	nimGCvisit((void*)(*a).outp2, op);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, interpSnippetCmd__nRa1UefxxmpBifgdHly9a0A)(NimStringDesc* cmd, void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw* colonenvP_;
	NimStringDesc* T10_;
	tyArray__yt5VDPNtUGx9cBkOVakHwdQ T11_;
	NimStringDesc* T12_;
	result = (NimStringDesc*)0;
	colonenvP_ = (tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*) ClE_0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T7_;
		NimStringDesc* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(cmd, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_17));
		if (!T3_) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T7_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 4), ((NI) 1));
		T8_ = (NimStringDesc*)0;
		T8_ = X5BX5D___ogYTOKbgqbjPfyC123US1gsystem(cmd, T7_);
		T6_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 5);
appendString(T6_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_18));
appendString(T6_, T8_);
		result = T6_;
	}
	goto LA1_;
	LA4_: ;
	{
		result = copyString(cmd);
	}
	LA1_: ;
	T10_ = (NimStringDesc*)0;
	T10_ = nsuReplaceStr(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_19), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_20));
	nimZeroMem((void*)T11_, sizeof(tyArray__yt5VDPNtUGx9cBkOVakHwdQ));
	T11_[0] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_21));
	T12_ = (NimStringDesc*)0;
	T12_ = nosgetAppFilename();
	T11_[1] = nospquoteShell(T12_);
	T11_[2] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_22));
	T11_[3] = reprEnum((NI)(*(*colonenvP_).d1.conf).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_));
	T11_[4] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_23));
	T11_[5] = nospquoteShell((*colonenvP_).outp2);
	result = nsuFormatOpenArray(T10_, T11_, 6);
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___P6saueTqDtsV5sp5vaoeKw)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* gen, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A* colonenvP_;
	tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw* colonenv_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T21_;
	NimStringDesc* importStmt;
	NimStringDesc* T28_;
	NimStringDesc* cmd_2;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T29_;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA T30_;
	NimStringDesc* output;
	NI gotten;
{	colonenvP_ = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*) ClE_0;
	colonenv_ = (tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*)0;
	colonenv_ = (tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*) newObj((&NTI__ihldeoD3pGN083UxUgAFWg_), sizeof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw));
	objectInit(colonenv_, (&NTI__o58RO4LYcVDmmDyTJ0uhVw_));
	{
		if (!eqStrings((*(*colonenvP_).conf1).docCmd, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_11))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*gen).id += ((NI) 1);
	genericAssign((void*)(&(*colonenv_).d1), (void*)(&(*(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*) ((&(*gen))))), (&NTI__aItnR9bvqDIftcasLwUztVQ_));
	(*colonenv_).outp2 = (NimStringDesc*)0;
	{
		NimStringDesc* nameOnly;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T9_;
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		NimStringDesc* T13_;
		if (!((filename ? filename->Sup.len : 0) == ((NI) 0))) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*colonenv_).d1.Sup.filename, (&T9_));
		nameOnly = T9_.Field1;
		T10_ = (NimStringDesc*)0;
		T10_ = getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2((*colonenvP_).conf1);
		T11_ = (NimStringDesc*)0;
		T11_ = slash___0U8YTiSB6NvFwgvyimFN2Q(T10_, nameOnly);
		T12_ = (NimStringDesc*)0;
		T13_ = (NimStringDesc*)0;
		T13_ = nimIntToStr((*colonenv_).d1.Sup.id);
		T12_ = rawNewString((nameOnly ? nameOnly->Sup.len : 0) + (T13_ ? T13_->Sup.len : 0) + 13);
appendString(T12_, nameOnly);
appendString(T12_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_12));
appendString(T12_, T13_);
appendString(T12_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_13));
		asgnRef((void**) (&(*colonenv_).outp2), slash___QVqo5OOQAdrjFqBsPctklw(T11_, T12_));
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL T15_;
		NimStringDesc* T18_;
		T15_ = (NIM_BOOL)0;
		T15_ = nosisAbsolute(filename);
		if (!T15_) goto LA16_;
		T18_ = (NimStringDesc*)0;
		T18_ = (*colonenv_).outp2; (*colonenv_).outp2 = copyStringRC1(filename);
		if (T18_) nimGCunrefNoCycle(T18_);
	}
	goto LA5_;
	LA16_: ;
	{
		NimStringDesc* nameOnly_2;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T20_;
		nimZeroMem((void*)(&T20_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*colonenv_).d1.Sup.filename, (&T20_));
		nameOnly_2 = T20_.Field1;
		asgnRef((void**) (&(*colonenv_).outp2), slash___QVqo5OOQAdrjFqBsPctklw(nameOnly_2, filename));
	}
	LA5_: ;
	nimZeroMem((void*)(&T21_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw((*colonenv_).outp2, (&T21_));
	noscreateDir(T21_.Field0);
	{
		if (!(*colonenv_).d1.isPureRst) goto LA24_;
		importStmt = ((NimStringDesc*) NIM_NIL);
	}
	goto LA22_;
	LA24_: ;
	{
		tyArray__nHXaesL0DJZHyVS07ARPRA T27_;
		nimZeroMem((void*)T27_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T27_[0] = nsuReplaceStr((*colonenv_).d1.Sup.filename, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_15), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_16));
		importStmt = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_14), T27_, 1);
	}
	LA22_: ;
	T28_ = (NimStringDesc*)0;
	T28_ = rawNewString((importStmt ? importStmt->Sup.len : 0) + (content ? content->Sup.len : 0) + 0);
appendString(T28_, importStmt);
appendString(T28_, content);
	writeFile__D6Pj9c29aCLEJP9beOWa08HYA((*colonenv_).outp2, T28_);
	nimZeroMem((void*)(&T29_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T29_.ClP_0 = interpSnippetCmd__nRa1UefxxmpBifgdHly9a0A; T29_.ClE_0 = colonenv_;
	cmd_2 = T29_.ClE_0? T29_.ClP_0(cmd, T29_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_24)(T29_.ClP_0))(cmd);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 71), cmd_2, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_25, NIM_FALSE);
	nimZeroMem((void*)(&T30_), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
	execCmdEx__130zQ9a9cS3YNDwoh0G9at3bw(cmd_2, 10, ((tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg*) NIM_NIL), ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) NIM_NIL), (&T30_));
	output = (NimStringDesc*)0;
	output = T30_.Field0;
	gotten = (NI)0;
	gotten = T30_.Field1;
	{
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T35_;
		NimStringDesc* T36_;
		if (!!((gotten == status))) goto LA33_;
		nimZeroMem((void*)T35_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T35_[0] = copyString(cmd_2);
		T35_[1] = nimIntToStr(gotten);
		T35_[2] = nimIntToStr(status);
		T35_[3] = copyString(output);
		T36_ = (NimStringDesc*)0;
		T36_ = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_26), T35_, 4);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T36_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_27, NIM_FALSE);
	}
	LA33_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOutFile2__lg7fst4NMqq6lfa07YO7Rg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NimStringDesc* ext, NIM_BOOL guessTarget) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* d;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = guessTarget;
		LA4_: ;
		if (!T3_) goto LA5_;
		d = (*conf).outDir;
		noscreateDir(d);
		T7_ = (NimStringDesc*)0;
		T7_ = noschangeFileExt(filename, ext);
		result = slash___QVqo5OOQAdrjFqBsPctklw(d, T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils((*conf).outFile);
		if (!!(T9_)) goto LA10_;
		result = absOutFile__ea9bsNo9cwchKzwCi7UjcP7g(conf);
	}
	goto LA1_;
	LA10_: ;
	{
		result = getOutFile__wyg2NQihYStyX9aXfJMkKlg(conf, filename, ext);
	}
	LA1_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__c2g79crEiD9bqYYWD2mguKAA)(void* p, NI op) {
	tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg* a;
	a = (tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*)p;
	nimGCvisit((void*)(*a).conf1, op);
	nimGCvisit((void*)(*a).file22, op);
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, nimbleDir__09b7vShk9aU7cpTGhH179cQ5g)(void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg* colonenvP_;
	NimStringDesc* T1_;
	result = (NimStringDesc*)0;
	colonenvP_ = (tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*) ClE_0;
	T1_ = (NimStringDesc*)0;
	T1_ = getNimbleFile__ez7MSoVdvcTOZlBJgbu5Sg_2((*colonenvP_).conf1, (*colonenvP_).file22);
	result = nosparentDir(T1_);
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, presentationPath__a9cVWkngyzzlrLvtxpnRSvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* file, NIM_BOOL isTitle) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg* colonenv_;
	result = (NimStringDesc*)0;
	colonenv_ = (tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*)0;
	colonenv_ = (tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*) newObj((&NTI__c2g79crEiD9bqYYWD2mguKAA_), sizeof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg));
	(*colonenv_).Sup.m_type = (&NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	asgnRef((void**) (&(*colonenv_).file22), dollar___l9cjIIY6CNqmzrJ1PC9apeYg(file));
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_29))) goto LA1_;
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_30))) goto LA2_;
	if (eqStrings((*(*colonenv_).conf1).docRoot, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_31))) goto LA3_;
	goto LA4_;
	LA1_: ;
	{
		NimStringDesc* dir;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T7_;
		result = getRelativePathFromConfigPath__lECD7EhJa9a9cW0kLsTWY4bQ((*colonenv_).conf1, file);
		nimZeroMem((void*)(&T7_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T7_.ClP_0 = nimbleDir__09b7vShk9aU7cpTGhH179cQ5g; T7_.ClE_0 = colonenv_;
		dir = T7_.ClE_0? T7_.ClP_0(T7_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_32)(T7_.ClP_0))();
		{
			NIM_BOOL T10_;
			NimStringDesc* result2;
			T10_ = (NIM_BOOL)0;
			T10_ = isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils(dir);
			if (!!(T10_)) goto LA11_;
			result2 = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, dir, 47);
			{
				NIM_BOOL T15_;
				NIM_BOOL T16_;
				NIM_BOOL T18_;
				T15_ = (NIM_BOOL)0;
				T16_ = (NIM_BOOL)0;
				T16_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(result2);
				T15_ = !(T16_);
				if (!(T15_)) goto LA17_;
				T18_ = (NIM_BOOL)0;
				T18_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(result);
				if (T18_) goto LA19_;
				T18_ = ((result2 ? result2->Sup.len : 0) < (result ? result->Sup.len : 0));
				LA19_: ;
				T15_ = T18_;
				LA17_: ;
				if (!T15_) goto LA20_;
				result = copyString(result2);
			}
			LA20_: ;
		}
		LA11_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(result);
			if (!T24_) goto LA25_;
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA25_: ;
	}
	goto LA5_;
	LA2_: ;
	{
		NimStringDesc* dir_2;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T28_;
		nimZeroMem((void*)(&T28_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T28_.ClP_0 = nimbleDir__09b7vShk9aU7cpTGhH179cQ5g; T28_.ClE_0 = colonenv_;
		dir_2 = T28_.ClE_0? T28_.ClP_0(T28_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_33)(T28_.ClP_0))();
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils(dir_2);
			if (!T31_) goto LA32_;
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		goto LA29_;
		LA32_: ;
		{
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, dir_2, 47);
		}
		LA29_: ;
	}
	goto LA5_;
	LA3_: ;
	{
		result = getRelativePathFromConfigPath__lECD7EhJa9a9cW0kLsTWY4bQ((*colonenv_).conf1, file);
		{
			NIM_BOOL T38_;
			T38_ = (NIM_BOOL)0;
			T38_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(result);
			if (!T38_) goto LA39_;
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA39_: ;
	}
	goto LA5_;
	LA4_: ;
	{
		{
			NimStringDesc* T66_;
			if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA44_;
			{
				NIM_BOOL T48_;
				NimStringDesc* arg2X60gensym4_;
				T48_ = (NIM_BOOL)0;
				T48_ = nosisAbsolute((*(*colonenv_).conf1).docRoot);
				if (!!(T48_)) goto LA49_;
				arg2X60gensym4_ = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_34), TM__5fUAZGW8WPeit3fZaQyNXA_35, 1);
				{
					NimStringDesc* T55_;
					if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA53_;
					T55_ = (NimStringDesc*)0;
					T55_ = rawNewString(((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0) + 16);
appendString(T55_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_37));
appendString(T55_, (*(*colonenv_).conf1).docRoot);
					arg2X60gensym4_ = resizeString(arg2X60gensym4_, (T55_ ? T55_->Sup.len : 0) + 0);
appendString(arg2X60gensym4_, T55_);
				}
				LA53_: ;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), arg2X60gensym4_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_38, NIM_FALSE);
			}
			LA49_: ;
			{
				NIM_BOOL T58_;
				NimStringDesc* arg2X60gensym7_;
				T58_ = (NIM_BOOL)0;
				T58_ = nosdirExists((*(*colonenv_).conf1).docRoot);
				if (!!(T58_)) goto LA59_;
				arg2X60gensym7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_34), TM__5fUAZGW8WPeit3fZaQyNXA_39, 1);
				{
					NimStringDesc* T65_;
					if (!(((NI) 0) < ((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0))) goto LA63_;
					T65_ = (NimStringDesc*)0;
					T65_ = rawNewString(((*(*colonenv_).conf1).docRoot ? (*(*colonenv_).conf1).docRoot->Sup.len : 0) + 16);
appendString(T65_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_37));
appendString(T65_, (*(*colonenv_).conf1).docRoot);
					arg2X60gensym7_ = resizeString(arg2X60gensym7_, (T65_ ? T65_->Sup.len : 0) + 0);
appendString(arg2X60gensym7_, T65_);
				}
				LA63_: ;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), arg2X60gensym7_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_41, NIM_FALSE);
			}
			LA59_: ;
			T66_ = (NimStringDesc*)0;
			T66_ = nosexpandFilename((*(*colonenv_).conf1).docRoot);
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, T66_, 47);
		}
		goto LA42_;
		LA44_: ;
		{
			result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(file, (*(*colonenv_).conf1).projectPath, 47);
		}
		LA42_: ;
	}
	LA5_: ;
	{
		NIM_BOOL T70_;
		tyTuple__UV3llMMYFckfui8YMBuUZA T73_;
		T70_ = (NIM_BOOL)0;
		T70_ = nosisAbsolute(result);
		if (!T70_) goto LA71_;
		nimZeroMem((void*)(&T73_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nossplitPath(file, (&T73_));
		result = copyString(T73_.Field1);
	}
	LA71_: ;
	{
		if (!isTitle) goto LA76_;
		result = nativeToUnixPath__solXjq9b9ca3yY9cmjx52n9a8Q(result);
	}
	goto LA74_;
	LA76_: ;
	{
		result = nsuReplaceStr(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_42), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_43));
	}
	LA74_: ;
	{
		NIM_BOOL T81_;
		T81_ = (NIM_BOOL)0;
		T81_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(result);
		if (!!(!(T81_))) goto LA82_;
		failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_44));
	}
	LA82_: ;
	{
		NIM_BOOL T86_;
		T86_ = (NIM_BOOL)0;
		T86_ = nosisAbsolute(result);
		if (!!(!(T86_))) goto LA87_;
		failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_45));
	}
	LA87_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*, newDocumentor__4NQNwjts5pclqjg2wHmDug)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* outExt, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* result;
	tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A* colonenv_;
	NimStringDesc* T1_;
	tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T2_;
	tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw T3_;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T9_;
	tyProc__BnbLegyGxTOhIgncw6Jqfg T10_;
	tyProc__XtNNqpdSSaHFEnbiw4OQrw T18_;
	NimStringDesc* T19_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T20_;
	NimStringDesc* T21_;
	result = (tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*)0;
	colonenv_ = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*)0;
	colonenv_ = (tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*) newObj((&NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_), sizeof(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A));
	(*colonenv_).Sup.m_type = (&NTI__bjZ39beKZKuX6eBUmfaMw0A_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	result = (tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*) newObj((&NTI__ZoZ1pRtzmEiOBBpTrqMZHA_), sizeof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ));
	(*result).Sup.Sup.m_type = (&NTI__aItnR9bvqDIftcasLwUztVQ_);
	asgnRef((void**) (&(*result).module), module);
	asgnRef((void**) (&(*result).conf), (*colonenv_).conf1);
	asgnRef((void**) (&(*result).cache), cache);
	T1_ = (NimStringDesc*)0;
	T1_ = (*result).Sup.outDir; (*result).Sup.outDir = copyStringRC1((*(*colonenv_).conf1).outDir);
	if (T1_) nimGCunrefNoCycle(T1_);
	T2_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
	T2_ = &result->Sup;
	T3_ = (tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw)0;
	{
		if (!!(((*(*colonenv_).conf1).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA6_;
		T3_ = ((tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw) 0);
	}
	goto LA4_;
	LA6_: ;
	{
		T3_ = ((tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw) 1);
	}
	LA4_: ;
	nimZeroMem((void*)(&T9_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T9_.ClP_0 = docgenFindFile__x9aMrspyzTek6VHYWJiGQ8w; T9_.ClE_0 = colonenv_;
	nimZeroMem((void*)(&T10_), sizeof(tyProc__BnbLegyGxTOhIgncw6Jqfg));
	T10_.ClP_0 = compilerMsgHandler__hcPI9cq6aFLznoPn1i5OoAA; T10_.ClE_0 = colonenv_;
	initRstGenerator__yb79cZGnzSmPK9bVz9c4Yy9aMg(T2_, T3_, (*(*colonenv_).conf1).configVars, filename, 12, T9_, T10_);
	{
		NIM_BOOL T13_;
		tyArray__nHXaesL0DJZHyVS07ARPRA T16_;
		T13_ = (NIM_BOOL)0;
		T13_ = nsthasKey((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_7));
		if (!T13_) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T16_[0] = getOrDefault__2a0cbxcfpWcXtK45m9bR5Kg((*(*colonenv_).conf1).configVars, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_9), ((NimStringDesc*) NIM_NIL));
		asgnRef((void**) (&(*result).analytics), nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_8), T16_, 1));
	}
	goto LA11_;
	LA14_: ;
	{
		asgnRef((void**) (&(*result).analytics), ((NimStringDesc*) NIM_NIL));
	}
	LA11_: ;
	asgnRef((void**) (&(*result).seenSymbols), nstnewStringTable(((tyEnum_StringTableMode__G9c4wVDFIzf0xHmQvxso9a9cQ) 1)));
	(*result).Sup.id = ((NI) 100);
	asgnRef((void**) (&(*result).jArray), newJArray__nXwnFPu9beTnGPwglrr7ztA_3());
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&(*result).types));
	nimZeroMem((void*)(&T18_), sizeof(tyProc__XtNNqpdSSaHFEnbiw4OQrw));
	T18_.ClP_0 = colonanonymous___P6saueTqDtsV5sp5vaoeKw; T18_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*result).Sup.onTestSnippet.ClE_0), T18_.ClE_0);
	(*result).Sup.onTestSnippet.ClP_0 = T18_.ClP_0;
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).emitted));
	T19_ = (NimStringDesc*)0;
	T19_ = presentationPath__a9cVWkngyzzlrLvtxpnRSvg((*colonenv_).conf1, filename, NIM_FALSE);
	asgnRef((void**) (&(*result).Sup.destFile), getOutFile2__lg7fst4NMqq6lfa07YO7Rg((*colonenv_).conf1, T19_, outExt, NIM_FALSE));
	nimZeroMem((void*)(&T20_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw((*result).Sup.destFile, (&T20_));
	T21_ = (NimStringDesc*)0;
	T21_ = (*result).thisDir; (*result).thisDir = copyStringRC1(T20_.Field0);
	if (T21_) nimGCunrefNoCycle(T21_);
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getVarIdx__MkK6vdaNQ6XNXG2RGNC9a9aw)(NimStringDesc** varnames, NI varnamesLen_0, NimStringDesc* id) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (varnamesLen_0-1);
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA3;
				i = res;
				{
					NI T6_;
					T6_ = (NI)0;
					T6_ = nsuCmpIgnoreStyle(varnames[i], id);
					if (!(T6_ == ((NI) 0))) goto LA7_;
					result = i;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* frmt, NimStringDesc** varnames, NI varnamesLen_0, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** varvalues, NI varvaluesLen_0) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI i;
	NI num;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	i = ((NI) 0);
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	num = ((NI) 0);
	{
		while (1) {
			NI start;
			if (!(i < (frmt ? frmt->Sup.len : 0))) goto LA2;
			{
				if (!((NU8)(frmt->data[i]) == (NU8)(36))) goto LA5_;
				i += ((NI) 1);
				switch (((NU8)(frmt->data[i]))) {
				case 35:
				{
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, varvalues[num]);
					num += ((NI) 1);
					i += ((NI) 1);
				}
				break;
				case 36:
				{
					add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_47));
					i += ((NI) 1);
				}
				break;
				case 48 ... 57:
				{
					NI j;
					j = ((NI) 0);
					{
						while (1) {
							j = (NI)((NI)((NI)(j * ((NI) 10)) + ((NU8)(frmt->data[i]))) - ((NI) 48));
							i += ((NI) 1);
							{
								NIM_BOOL T14_;
								T14_ = (NIM_BOOL)0;
								T14_ = ((NI)((NI)((frmt ? frmt->Sup.len : 0) + ((NI) 0)) - ((NI) 1)) < i);
								if (T14_) goto LA15_;
								T14_ = !((((NU8)(frmt->data[i])) >= ((NU8)(48)) && ((NU8)(frmt->data[i])) <= ((NU8)(57))));
								LA15_: ;
								if (!T14_) goto LA16_;
								goto LA10;
							}
							LA16_: ;
						}
					} LA10: ;
					{
						NimStringDesc* T22_;
						if (!((NI)((varvaluesLen_0-1) + ((NI) 1)) < j)) goto LA20_;
						T22_ = (NimStringDesc*)0;
						T22_ = rawNewString((frmt ? frmt->Sup.len : 0) + 36);
appendString(T22_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_48));
appendString(T22_, frmt);
						liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_49, NIM_FALSE);
					}
					LA20_: ;
					num = j;
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, varvalues[(NI)(j - ((NI) 1))]);
				}
				break;
				case 65 ... 90:
				case 97 ... 122:
				case 128 ... 255:
				{
					NimStringDesc* id;
					NI idx;
					id = ((NimStringDesc*) NIM_NIL);
					{
						while (1) {
							id = addChar(id, frmt->data[i]);
							i += ((NI) 1);
							{
								if (!!((((NU8)(frmt->data[i])) >= ((NU8)(65)) && ((NU8)(frmt->data[i])) <= ((NU8)(90)) || ((NU8)(frmt->data[i])) == ((NU8)(95)) || ((NU8)(frmt->data[i])) >= ((NU8)(97)) && ((NU8)(frmt->data[i])) <= ((NU8)(122)) || ((NU8)(frmt->data[i])) >= ((NU8)(128)) && ((NU8)(frmt->data[i])) <= ((NU8)(255))))) goto LA28_;
								goto LA24;
							}
							LA28_: ;
						}
					} LA24: ;
					idx = getVarIdx__MkK6vdaNQ6XNXG2RGNC9a9aw(varnames, varnamesLen_0, id);
					{
						if (!(((NI) 0) <= idx)) goto LA32_;
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, varvalues[idx]);
					}
					goto LA30_;
					LA32_: ;
					{
						NimStringDesc* T35_;
						T35_ = (NimStringDesc*)0;
						T35_ = rawNewString((id ? id->Sup.len : 0) + 29);
appendString(T35_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_50));
appendString(T35_, id);
						liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T35_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_51, NIM_FALSE);
					}
					LA30_: ;
				}
				break;
				case 123:
				{
					NimStringDesc* id_2;
					NI idx_2;
					id_2 = ((NimStringDesc*) NIM_NIL);
					i += ((NI) 1);
					{
						while (1) {
							NIM_BOOL T39_;
							T39_ = (NIM_BOOL)0;
							T39_ = (i < (frmt ? frmt->Sup.len : 0));
							if (!(T39_)) goto LA40_;
							T39_ = !(((NU8)(frmt->data[i]) == (NU8)(125)));
							LA40_: ;
							if (!T39_) goto LA38;
							id_2 = addChar(id_2, frmt->data[i]);
							i += ((NI) 1);
						} LA38: ;
					}
					{
						if (!((frmt ? frmt->Sup.len : 0) <= i)) goto LA43_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_52), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_53, NIM_FALSE);
					}
					goto LA41_;
					LA43_: ;
					{
						i += ((NI) 1);
					}
					LA41_: ;
					idx_2 = getVarIdx__MkK6vdaNQ6XNXG2RGNC9a9aw(varnames, varnamesLen_0, id_2);
					{
						if (!(((NI) 0) <= idx_2)) goto LA48_;
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, varvalues[idx_2]);
					}
					goto LA46_;
					LA48_: ;
					{
						NimStringDesc* T51_;
						T51_ = (NimStringDesc*)0;
						T51_ = rawNewString((id_2 ? id_2->Sup.len : 0) + 29);
appendString(T51_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_50));
appendString(T51_, id_2);
						liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T51_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_54, NIM_FALSE);
					}
					LA46_: ;
				}
				break;
				default:
				{
					add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_47));
				}
				break;
				}
			}
			LA5_: ;
			start = i;
			{
				while (1) {
					if (!(i < (frmt ? frmt->Sup.len : 0))) goto LA54;
					{
						if (!!(((NU8)(frmt->data[i]) == (NU8)(36)))) goto LA57_;
						i += ((NI) 1);
					}
					goto LA55_;
					LA57_: ;
					{
						goto LA53;
					}
					LA55_: ;
				} LA54: ;
			} LA53: ;
			{
				NimStringDesc* T64_;
				if (!(start <= (NI)(i - ((NI) 1)))) goto LA62_;
				T64_ = (NimStringDesc*)0;
				T64_ = substr__2yh9cer0ymNRHlOOg8P7IuA(frmt, start, (NI)(i - ((NI) 1)));
				add__yG4AKzsBRS1W4MANDlXQeg(&result, T64_);
			}
			LA62_: ;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genDeprecationMsg__CsFui9bBKN4zbV9c9cdppnsLA)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI T5_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (NI)0;
	T5_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
	switch (T5_) {
	case ((NI) 0):
	{
		NimStringDesc* T7_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T9_;
		T7_ = (NimStringDesc*)0;
		T7_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_55), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		nimZeroMem((void*)T9_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T8_[0] = percent___UQrwMIIitnm9cEflSXdCkPg(T9_, 0);
		T8_[1] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		result = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T7_, TM__5fUAZGW8WPeit3fZaQyNXA_56, 2, T8_, 2);
	}
	break;
	case ((NI) 2):
	{
		{
			NimStringDesc* T15_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T17_;
			NimStringDesc* T18_;
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*n)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA13_;
			T15_ = (NimStringDesc*)0;
			T15_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_55), ((NimStringDesc*) NIM_NIL));
			nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			nimZeroMem((void*)T17_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T16_[0] = percent___A9aKFJUF6ZjJQfrcPHJigOQ(T17_, 0);
			T18_ = (NimStringDesc*)0;
			T18_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
			T16_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T18_);
			result = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T15_, TM__5fUAZGW8WPeit3fZaQyNXA_56, 2, T16_, 2);
		}
		LA13_: ;
	}
	break;
	default:
	{
		{
			if (!NIM_TRUE) goto LA22_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_59));
		}
		LA22_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__QWqhrbgPD84P9aNEkDLWGug)(void* p, NI op) {
	tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg* a;
	a = (tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
N_LIB_PRIVATE N_CLOSURE(NimStringDesc*, docgenFindFile__XF1IuAEczMm2Z2kiQicPTw)(NimStringDesc* sX60gensym29_, void* ClE_0) {
	NimStringDesc* result;
	tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg* colonenvP_;
	result = (NimStringDesc*)0;
	colonenvP_ = (tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*) ClE_0;
	result = findFile__Jsd6LfkMRIXL9b0vzcHVYOA((*colonenvP_).conf1, sX60gensym29_, NIM_FALSE);
	{
		NimStringDesc* T5_;
		if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nosgetCurrentDir();
		result = slash___gEyhbzZ1UcxyenWRLJRXNQ(T5_, sX60gensym29_);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nosfileExists(result);
			if (!!(T8_)) goto LA9_;
			result = ((NimStringDesc*) NIM_NIL);
		}
		LA9_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__ks78Qmor9cBt3TlwQgS4cTg)(NimStringDesc* filenameX60gensym29_, NI lineX60gensym29_, NI colX60gensym29_, tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ msgKindX60gensym29_, NimStringDesc* argX60gensym29_, void* ClE_0) {
	tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg* colonenvP_;
	tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w kX60gensym29_;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T11_;
	colonenvP_ = (tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*) ClE_0;
	kX60gensym29_ = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
	switch (msgKindX60gensym29_) {
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 0):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 1):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 2):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 5);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 3):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 7);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 4):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 6);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 5):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 8);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 6):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 20);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 7):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 21);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 8):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 22);
	}
	break;
	case ((tyEnum_MsgKind__iviJnHlj9acPYlnNRbd9bhkQ) 9):
	{
		kX60gensym29_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 23);
	}
	break;
	}
	T11_ = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs((*colonenvP_).conf1, filenameX60gensym29_, lineX60gensym29_, colX60gensym29_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, T11_, kX60gensym29_, argX60gensym29_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_5, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg*, parseRst__U0R9a9aB9ccn8lJ7U1XqFb10Q)(NimStringDesc* text, NimStringDesc* filename, NI line, NI column, NIM_BOOL* hasToc, tySet_tyEnum_RstParseOption__fiZmsylYkyh6nEciRZcPsw rstOptions, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* result;
	tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg* colonenv_;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T1_;
	tyProc__BnbLegyGxTOhIgncw6Jqfg T2_;
	result = (tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg*)0;
	colonenv_ = (tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*)0;
	colonenv_ = (tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*) newObj((&NTI__QWqhrbgPD84P9aNEkDLWGug_), sizeof(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg));
	(*colonenv_).Sup.m_type = (&NTI__4EIPlYmwmzq4foglAJUuOg_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	nimZeroMem((void*)(&T1_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T1_.ClP_0 = docgenFindFile__XF1IuAEczMm2Z2kiQicPTw; T1_.ClE_0 = colonenv_;
	nimZeroMem((void*)(&T2_), sizeof(tyProc__BnbLegyGxTOhIgncw6Jqfg));
	T2_.ClP_0 = compilerMsgHandler__ks78Qmor9cBt3TlwQgS4cTg; T2_.ClE_0 = colonenv_;
	result = rstParse__UvKI39cksmpU0237JQw9cBYA(text, filename, line, column, hasToc, rstOptions, T1_, T2_);
	return result;
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genComment__1NsSIzkKMtq49acu82VJUxg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NimStringDesc* comment;
		tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T5_;
		NimStringDesc* T6_;
		NI T7_;
		NI T8_;
		NIM_BOOL dummy;
		tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* T9_;
		if (!(((NI) 0) < ((*n).comment ? (*n).comment->Sup.len : 0))) goto LA3_;
		comment = (*n).comment;
		T5_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
		T5_ = &d->Sup;
		T6_ = (NimStringDesc*)0;
		T6_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*d).conf, (*n).info.fileIndex);
		T7_ = (NI)0;
		T7_ = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs((*n).info);
		T8_ = (NI)0;
		T8_ = toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs((*n).info);
		dummy = (NIM_BOOL)0;
		T9_ = (tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg*)0;
		T9_ = parseRst__U0R9a9aB9ccn8lJ7U1XqFb10Q(comment, T6_, T7_, T8_, (&dummy), (*d).Sup.options, (*d).conf);
		renderRstToOut__9bVWgX0SWmhEi3eHlrcMD8g(T5_, T9_, (&result));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentEffect__pcvClInajR04YlyHZGrbzA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw effectType, NI idx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	spec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(x, effectType);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* actual;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* real;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects;
		NI T10_;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T20_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T21_;
		if (!(spec == 0)) goto LA3_;
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		actual = (*(*(*s).typ).n)._kind_6.sons->data[((NI) 0)];
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(actual);
			if (!!((T7_ == ((NI) 5)))) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
		real = (*actual)._kind_6.sons->data[idx];
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(real);
		effects = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*n).info, T10_);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(real);
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* t;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T19_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					t = typeToString__QlvraUan7WbHowhAbvDvdA((*(*real)._kind_6.sons->data[i]).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					{
						NIM_BOOL T16_;
						T16_ = (NIM_BOOL)0;
						T16_ = nsuStartsWith(t, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_61));
						if (!T16_) goto LA17_;
						t = substr__iGg0RIKceRvsmvq8FUHOEw(t, ((NI) 4));
					}
					LA17_: ;
					T19_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
					T19_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, t);
					asgnRef((void**) (&(*effects)._kind_6.sons->data[i]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T19_, (*n).info));
					asgnRef((void**) (&(*(*effects)._kind_6.sons->data[i]).typ), (*(*real)._kind_6.sons->data[i]).typ);
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
		nimZeroMem((void*)T20_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T21_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T21_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, reprEnum((NI)effectType, (&NTI__ycbpMCRV6Cd2eBh3X9biEiw_)));
		T20_[0] = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T21_, (*n).info);
		T20_[1] = effects;
		result = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34), (*n).info, T20_, 2);
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentWriteEffect__IPIc9bSzbkNTXg0Vxi6qL3A)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flag, NimStringDesc* pragmaName) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	params = (*(*s).typ).n;
	effects = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*(*params)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
					if (!(T6_)) goto LA7_;
					T6_ = (((*(*(*params)._kind_6.sons->data[i])._kind_4.sym).flags &((NU64)1<<((NU)(flag)&63U)))!=0);
					LA7_: ;
					if (!T6_) goto LA8_;
					add__P8dDSotTW25BkfbyspojGg(effects, (*params)._kind_6.sons->data[i]);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI T12_;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T15_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T16_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(effects);
		if (!(((NI) 0) < T12_)) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T16_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T16_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, pragmaName);
		T15_[0] = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T16_, (*n).info);
		T15_[1] = effects;
		result = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34), (*n).info, T15_, 2);
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, documentNewEffect__iKOR2aWWACOqq4zd7hmg7w)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T5_;
		if (!(((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T5_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_63));
		result = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T5_, (*n).info);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p1;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p3;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p4;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p5;
{	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	pragmas = (*n)._kind_6.sons->data[((NI) 4)];
	p1 = documentEffect__pcvClInajR04YlyHZGrbzA(cache, n, pragmas, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170), ((NI) 0));
	p2 = documentEffect__pcvClInajR04YlyHZGrbzA(cache, n, pragmas, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175), ((NI) 3));
	p3 = documentWriteEffect__IPIc9bSzbkNTXg0Vxi6qL3A(cache, n, ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_62));
	p4 = documentNewEffect__iKOR2aWWACOqq4zd7hmg7w(cache, n);
	p5 = documentWriteEffect__IPIc9bSzbkNTXg0Vxi6qL3A(cache, n, ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 19), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_64));
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T10_ = !((p1 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (T10_) goto LA11_;
		T10_ = !((p2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA11_: ;
		T9_ = T10_;
		if (T9_) goto LA12_;
		T9_ = !((p3 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA12_: ;
		T8_ = T9_;
		if (T8_) goto LA13_;
		T8_ = !((p4 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA13_: ;
		T7_ = T8_;
		if (T7_) goto LA14_;
		T7_ = !((p5 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA14_: ;
		if (!T7_) goto LA15_;
		{
			if (!((*pragmas).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA19_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90), (*n).info));
		}
		LA19_: ;
		{
			if (!!((p1 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA23_;
			add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p1);
		}
		LA23_: ;
		{
			if (!!((p2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA27_;
			add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p2);
		}
		LA27_: ;
		{
			if (!!((p3 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA31_;
			add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p3);
		}
		LA31_: ;
		{
			if (!!((p4 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA35_;
			add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p4);
		}
		LA35_: ;
		{
			if (!!((p5 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA39_;
			add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p5);
		}
		LA39_: ;
	}
	LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__2S18TVv8561n8da19ah7VxQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31))) goto LA3_;
		{
			NIM_BOOL T7_;
			NI T8_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* v;
			NIM_BOOL T12_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T7_ = (T8_ == ((NI) 2));
			if (!(T7_)) goto LA9_;
			T7_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
			LA9_: ;
			if (!T7_) goto LA10_;
			v = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*v).Sup.id == ((NI) 72));
			if (T12_) goto LA13_;
			T12_ = ((*v).Sup.id == ((NI) 73));
			LA13_: ;
			result = T12_;
		}
		LA10_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA15_;
		{
			if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 34))&63U)))!=0)) goto LA19_;
			result = ((20 & (*(*n)._kind_4.sym).flags) == 0);
		}
		goto LA17_;
		LA19_: ;
		{
			result = ((22 & (*(*n)._kind_4.sym).flags) == 2);
		}
		LA17_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = result;
			if (!(T24_)) goto LA25_;
			T24_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*d).emitted), (*(*n)._kind_4.sym).Sup.id);
			LA25_: ;
			if (!T24_) goto LA26_;
			result = NIM_FALSE;
		}
		LA26_: ;
	}
	goto LA1_;
	LA15_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA29_;
		result = isVisible__2S18TVv8561n8da19ah7VxQ(d, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA1_;
	LA29_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getName__X4ox39cm9bzH8GS36cF3gOsQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI splitAfter) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		result = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, (*n)._kind_6.sons->data[((NI) 1)], splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		result = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, (*n)._kind_6.sons->data[((NI) 0)], splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		NimStringDesc* T4_;
		T4_ = (NimStringDesc*)0;
		T4_ = renderDefinitionName__l9ckhTtdY2uD8Mjq9cwreZDA((*n)._kind_4.sym, NIM_FALSE);
		result = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, T4_, splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		result = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, (*(*n)._kind_5.ident).s, splitAfter);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		NimStringDesc* T11_;
		result = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_65), ((NI) -1));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T10_;
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					T10_ = (NimStringDesc*)0;
					T10_ = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, (*n)._kind_6.sons->data[i], splitAfter);
					result = resizeString(result, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(result, T10_);
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		T11_ = (NimStringDesc*)0;
		T11_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_65), ((NI) -1));
		result = resizeString(result, (T11_ ? T11_->Sup.len : 0) + 0);
appendString(result, T11_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	{
		result = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, (*n)._kind_6.sons->data[((NI) 0)], splitAfter);
	}
	break;
	default:
	{
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPlainDocstring__w0RLWJSCLHZKQXisk15Reg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
{	result = (NimStringDesc*)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = nsuStartsWith((*n).comment, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_66));
		if (!T6_) goto LA7_;
		result = copyString((*n).comment);
	}
	goto LA1_;
	LA7_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					result = getPlainDocstring__w0RLWJSCLHZKQXisk15Reg((*n)._kind_6.sons->data[i]);
					{
						if (!(((NI) 0) < (result ? result->Sup.len : 0))) goto LA15_;
						goto BeforeRet_;
					}
					LA15_: ;
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getRoutineBody__vTJBniW3ZS5dVMOR2Z9aeWg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = (*n)._kind_6.sons->data[((NI) 6)];
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (((NI) 7) < T8_);
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA9_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 7)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA9_: ;
		if (!T3_) goto LA10_;
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!!((T14_ == ((NI) 2)))) goto LA15_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_67));
		}
		LA15_: ;
		result = (*result)._kind_6.sons->data[((NI) 1)];
	}
	LA10_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecCommentAux__CsFui9bBKN4zbV9c9cdppnsLA_3)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T5_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (NimStringDesc*)0;
	T5_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T5_);
	{
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
		{
			if (!((TM__5fUAZGW8WPeit3fZaQyNXA_68[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0)) goto LA12_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						result = genRecCommentAux__CsFui9bBKN4zbV9c9cdppnsLA_3(d, (*n)._kind_6.sons->data[i]);
						{
							if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA19_;
							goto BeforeRet_;
						}
						LA19_: ;
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		LA12_: ;
	}
	goto LA6_;
	LA8_: ;
	{
		asgnRef((void**) (&(*n).comment), ((NimStringDesc*) NIM_NIL));
	}
	LA6_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecComment__CsFui9bBKN4zbV9c9cdppnsLA_2)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T5_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (NimStringDesc*)0;
	T5_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T5_);
	{
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81))) goto LA12_;
			result = genRecCommentAux__CsFui9bBKN4zbV9c9cdppnsLA_3(d, (*n)._kind_6.sons->data[((NI) 6)]);
		}
		goto LA10_;
		LA12_: ;
		{
			result = genRecCommentAux__CsFui9bBKN4zbV9c9cdppnsLA_3(d, n);
		}
		LA10_: ;
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_73));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (((NI) (info.line)))));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_74));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(((NI) (info.col)) + ((NI) 1)))));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_75));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, exampleOutputDir__hwg9aq9cMZugC9arDWh9bne3Yw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2((*d).conf);
	result = slash___0U8YTiSB6NvFwgvyimFN2Q(T1_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_77));
	return result;
}
static N_INLINE(NI, len__9cIAgXWUH5Nk24xwUJ9bNbtQtables)(tyObject_OrderedTable__82OdS5RTON4FvDz04E3cFw t) {
	NI result;
	result = (NI)0;
	result = t.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeExample__r3AKACONID3L7AuURMfLmw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex, NimStringDesc* rdoccmd) {
	NimStringDesc* outputDir;
	NimStringDesc* outp;
	NimStringDesc* T5_;
	NimStringDesc* T6_;
	NimStringDesc* T7_;
	NimStringDesc* T8_;
	tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ** T17_;
	NimStringDesc* T18_;
{	{
		if (!(((NI) 0) < (*(*d).conf).errorCounter)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	outputDir = exampleOutputDir__hwg9aq9cMZugC9arDWh9bne3Yw(d);
	noscreateDir(outputDir);
	(*d).exampleCounter += ((NI) 1);
	T5_ = (NimStringDesc*)0;
	T6_ = (NimStringDesc*)0;
	T6_ = noschangeFileExt((*d).Sup.filename, ((NimStringDesc*) NIM_NIL));
	T7_ = (NimStringDesc*)0;
	T7_ = nimIntToStr((*d).exampleCounter);
	T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + (T7_ ? T7_->Sup.len : 0) + 13);
appendString(T5_, T6_);
appendString(T5_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_78));
appendString(T5_, T7_);
appendString(T5_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_13));
	T8_ = (NimStringDesc*)0;
	T8_ = nosextractFilename(T5_);
	outp = slash___QVqo5OOQAdrjFqBsPctklw(outputDir, T8_);
	renderModule__PMQ9adArlSkkG8lng7soccA(ex, (*d).Sup.filename, outp, 0, ((NI32) -1), (*d).conf);
	{
		NIM_BOOL T11_;
		tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ* T14_;
		NimStringDesc* T15_;
		NimStringDesc* T16_;
		T11_ = (NIM_BOOL)0;
		T11_ = contains__RwllE9aq05N1XhihGDBODsw((*d).exampleGroups, rdoccmd);
		if (!!(T11_)) goto LA12_;
		T14_ = (tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*)0;
		T14_ = (tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*) newObj((&NTI__12SjKZyLpJKBYPLZVcoGLA_), sizeof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ));
		T15_ = (NimStringDesc*)0;
		T15_ = (*T14_).rdoccmd; (*T14_).rdoccmd = copyStringRC1(rdoccmd);
		if (T15_) nimGCunrefNoCycle(T15_);
		T16_ = (NimStringDesc*)0;
		T16_ = (*T14_).docCmd; (*T14_).docCmd = copyStringRC1((*(*d).conf).docCmd);
		if (T16_) nimGCunrefNoCycle(T16_);
		(*T14_).index = len__9cIAgXWUH5Nk24xwUJ9bNbtQtables((*d).exampleGroups);
		X5BX5Deq___ZGs5MV3ViG3GBfnvvT9c9ctw((&(*d).exampleGroups), rdoccmd, T14_);
	}
	LA12_: ;
	T17_ = (tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ**)0;
	T17_ = X5BX5D___XsqiT9czg3Cv3zY9cWLZy9aFA((&(*d).exampleGroups), rdoccmd);
	T18_ = (NimStringDesc*)0;
	T18_ = nsuFormatSingleElem(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_79), outp);
	asgnRef((void**) (&(*(*T17_)).code), resizeString((*(*T17_)).code, (T18_ ? T18_->Sup.len : 0) + 0));
appendString((*(*T17_)).code, T18_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__QOfHld1n7oz11NnxsBYS9cw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringDesc* rdoccmd;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* docComment;
	tyArray__cypz0nHJsd9cnKgpO7fP5hQ T18_;
	NimStringDesc* loc;
	tyArray__Re75IspeoxXy2oCZHwcRrA T19_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* runnableExamples;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T20_;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T21_;
	NimStringDesc* ret;
	NimStringDesc* colontmp__3;
	NimStringDesc* colontmp__4;
	rdoccmd = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T4_ < ((NI) 2));
		if (T3_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (((NI) 3) < T6_);
		LA5_: ;
		if (!T3_) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*d).conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_69), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_70, NIM_FALSE);
	}
	LA7_: ;
	{
		NI T11_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n1;
		T11_ = (NI)0;
		T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T11_ == ((NI) 3))) goto LA12_;
		n1 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*n1).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*n1).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)))) goto LA16_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*d).conf, (*n1).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_71), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__5fUAZGW8WPeit3fZaQyNXA_72, NIM_FALSE);
		}
		LA16_: ;
		rdoccmd = copyString((*n1)._kind_3.strVal);
	}
	LA12_: ;
	nimZeroMem((void*)T18_, sizeof(tyArray__cypz0nHJsd9cnKgpO7fP5hQ));
	docComment = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125), T18_, 0);
	loc = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs((*d).conf, (*n).info);
	nimZeroMem((void*)T19_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T19_[0] = copyString(loc);
	T19_[1] = copyString(rdoccmd);
	asgnRef((void**) (&(*docComment).comment), nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_76), T19_, 2));
	nimZeroMem((void*)T20_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T20_[0] = docComment;
	nimZeroMem((void*)T21_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T21_[0] = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*d).Sup.filename);
	T20_[1] = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116), T21_, 1);
	runnableExamples = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T20_, 2);
	(*runnableExamples).info = (*n).info;
	ret = extractRunnableExamplesSource__CT0AYtMqaaWjtLZ9cUvHsiw((*d).conf, n);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp_;
		a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		{
			NI i;
			NI colontmp__2;
			NI i_2;
			i = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp_);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA25;
					i = i_2;
					a = (*colontmp_)._kind_6.sons->data[i];
					add__P8dDSotTW25BkfbyspojGg(runnableExamples, a);
					i_2 += ((NI) 1);
				} LA25: ;
			}
		}
	}
	writeExample__r3AKACONID3L7AuURMfLmw(d, runnableExamples, rdoccmd);
	colontmp__3 = copyString(rdoccmd);
	colontmp__4 = copyString(ret);
	unsureAsgnRef((void**) (&(*Result).Field0), copyString(colontmp__3));
	unsureAsgnRef((void**) (&(*Result).Field1), copyString(colontmp__4));
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA, getAllRunnableExamplesImpl__0Dh1R1yxkJQZk4chz78Tcg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** dest, tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA state) {
	tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA result;
{	result = (tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
			if (!((5 &((NU8)1<<((NU)(state)&7U)))!=0)) goto LA4_;
			T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T6_ = genRecComment__CsFui9bBKN4zbV9c9cdppnsLA_2(d, n);
			add__IM4kcMNkkOLJtqdEqSxR8A(dest, T6_);
			result = ((tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA) 1);
			goto BeforeRet_;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			NI T14_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
			tyTuple__UV3llMMYFckfui8YMBuUZA T20_;
			NimStringDesc* rdoccmd;
			NimStringDesc* code;
			NimStringDesc* msg;
			NimStringDesc* id;
			NimStringDesc* T35_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T36_;
			NimStringDesc* T37_;
			NimStringDesc* dest2;
			NimStringDesc* T38_;
			NimStringDesc* T39_;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = isRunnableExamples__CZaoTkWCFI9acor4BmYF3Yw_3((*n)._kind_6.sons->data[((NI) 0)]);
			if (!(T12_)) goto LA13_;
			T14_ = (NI)0;
			T14_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T12_ = (((NI) 2) <= T14_);
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA15_;
			T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T16_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			T11_ = ((*T16_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
			LA15_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA17_;
			T10_ = ((7 &((NU8)1<<((NU)(state)&7U)))!=0);
			LA17_: ;
			if (!T10_) goto LA18_;
			nimZeroMem((void*)(&T20_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			prepareExample__QOfHld1n7oz11NnxsBYS9cw(d, n, (&T20_));
			rdoccmd = (NimStringDesc*)0;
			rdoccmd = T20_.Field0;
			code = (NimStringDesc*)0;
			code = T20_.Field1;
			msg = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_80));
			{
				NimStringDesc* T25_;
				if (!(((NI) 0) < (rdoccmd ? rdoccmd->Sup.len : 0))) goto LA23_;
				T25_ = (NimStringDesc*)0;
				T25_ = rawNewString((rdoccmd ? rdoccmd->Sup.len : 0) + 6);
appendString(T25_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_81));
appendString(T25_, rdoccmd);
				msg = resizeString(msg, (T25_ ? T25_->Sup.len : 0) + 0);
appendString(msg, T25_);
			}
			LA23_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T30_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
				if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA28_;
				nimZeroMem((void*)T30_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T30_[0] = rope__yShmEg9cffWxI7s5XzEKBow(msg);
				T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T31_ = percent___8ehuHmXS8omgqFrdYMsPBg(T30_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(dest, T31_);
			}
			goto LA26_;
			LA28_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T33_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
				nimZeroMem((void*)T33_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T33_[0] = rope__yShmEg9cffWxI7s5XzEKBow(msg);
				T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T34_ = percent___2Opo6JkHmCRmDA87qcGfvg(T33_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(dest, T34_);
			}
			LA26_: ;
			(*d).Sup.listingCounter += ((NI) 1);
			id = nimIntToStr((*d).Sup.listingCounter);
			T35_ = (NimStringDesc*)0;
			T35_ = getOrDefault__2a0cbxcfpWcXtK45m9bR5Kg((*d).Sup.config, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_82), ((NimStringDesc*) NIM_NIL));
			nimZeroMem((void*)T36_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T36_[0] = copyString(id);
			T36_[1] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_83));
			T37_ = (NimStringDesc*)0;
			T37_ = nsuFormatOpenArray(T35_, T36_, 2);
			add__yG4AKzsBRS1W4MANDlXQeg(dest, T37_);
			dest2 = ((NimStringDesc*) NIM_NIL);
			renderNimCode__iKaVLSux2ljcS3wu8Q8ylw((&dest2), code, ((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)));
			add__yG4AKzsBRS1W4MANDlXQeg(dest, dest2);
			T38_ = (NimStringDesc*)0;
			T38_ = getOrDefault__2a0cbxcfpWcXtK45m9bR5Kg((*d).Sup.config, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_84), ((NimStringDesc*) NIM_NIL));
			T39_ = (NimStringDesc*)0;
			T39_ = nsuFormatSingleElem(T38_, id);
			add__yG4AKzsBRS1W4MANDlXQeg(dest, T39_);
			result = ((tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA) 2);
			goto BeforeRet_;
		}
		LA18_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	result = ((tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA) 3);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__KTaDQnNH9ae4Bf008FpUeJw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** dest) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA state;
	NimStringDesc* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
{	n_2 = n;
	state = ((tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA) 0);
	T1_ = (NimStringDesc*)0;
	T1_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n_2);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	add__IM4kcMNkkOLJtqdEqSxR8A(dest, T2_);
	switch ((*n_2).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		n_2 = getRoutineBody__vTJBniW3ZS5dVMOR2Z9aeWg(n_2);
		switch ((*n_2).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
		{
			state = getAllRunnableExamplesImpl__0Dh1R1yxkJQZk4chz78Tcg(d, n_2, dest, state);
		}
		break;
		default:
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n_2);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						state = getAllRunnableExamplesImpl__0Dh1R1yxkJQZk4chz78Tcg(d, (*n_2)._kind_6.sons->data[i], dest, state);
						{
							if (!(state == ((tyEnum_RunnableState__ReeHgNC8fI9bdgH6uVZ2ZTA) 3))) goto LA11_;
							goto BeforeRet_;
						}
						LA11_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		break;
		}
	}
	break;
	default:
	{
		state = getAllRunnableExamplesImpl__0Dh1R1yxkJQZk4chz78Tcg(d, n_2, dest, state);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCallable__SUIy9a9bqpDkoM66A6tppSaA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = NIM_TRUE;
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, complexName__9cXtMWiiMWGlqAPzr9aEWCzQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* baseName) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = copyString(baseName);
	switch (k) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
	{
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_86));
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_87));
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_88));
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_89));
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
	{
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_90));
	}
	break;
	default:
	{
	}
	break;
	}
	{
		NIM_BOOL T10_;
		NI T11_;
		NimStringDesc* params;
		T10_ = (NIM_BOOL)0;
		T11_ = (NI)0;
		T11_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		T10_ = (((NI) 3) < T11_);
		if (!(T10_)) goto LA12_;
		T10_ = ((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76));
		LA12_: ;
		if (!T10_) goto LA13_;
		params = renderParamTypes__le9bedpmveKS6qhiVCc9c7cg((*n)._kind_6.sons->data[((NI) 3)], ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_91));
		{
			if (!(((NI) 0) < (params ? params->Sup.len : 0))) goto LA17_;
			result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_91));
			result = resizeString(result, (params ? params->Sup.len : 0) + 0);
appendString(result, params);
		}
		LA17_: ;
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, newUniquePlainSymbol__SMnsxF7PtS1Zx9aDjvvC7rw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NimStringDesc* original) {
	NimStringDesc* result;
	NI count;
{	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey((*d).seenSymbols, original);
		if (!!(T3_)) goto LA4_;
		result = copyString(original);
		nstPut((*d).seenSymbols, original, ((NimStringDesc*) NIM_NIL));
		goto BeforeRet_;
	}
	LA4_: ;
	count = ((NI) 2);
	{
		while (1) {
			NimStringDesc* T8_;
			NimStringDesc* T9_;
			T8_ = (NimStringDesc*)0;
			T9_ = (NimStringDesc*)0;
			T9_ = nimIntToStr(count);
			T8_ = rawNewString((original ? original->Sup.len : 0) + (T9_ ? T9_->Sup.len : 0) + 1);
appendString(T8_, original);
appendString(T8_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_92));
appendString(T8_, T9_);
			result = T8_;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = nsthasKey((*d).seenSymbols, result);
				if (!!(T12_)) goto LA13_;
				nstPut((*d).seenSymbols, result, ((NimStringDesc*) NIM_NIL));
				goto LA6;
			}
			LA13_: ;
			count += ((NI) 1);
		}
	} LA6: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*module).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
	if (!(T1_)) goto LA2_;
	T3_ = (NI)0;
	T3_ = getnimblePkgId__h22KSexh3g61XkIPdO8SNA(module);
	T1_ = (T3_ == (*conf).mainPackageId);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, externalDep__P9b6ldiOs1C1cjAHSU4Jlpg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* full;
		NimStringDesc* tmp;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 33))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = (((NI) 0) < ((*(*d).conf).docRoot ? (*(*d).conf).docRoot->Sup.len : 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		full = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*d).conf, ((NI32) ((*module).position)));
		T7_ = (NimStringDesc*)0;
		T7_ = presentationPath__a9cVWkngyzzlrLvtxpnRSvg((*d).conf, full, NIM_FALSE);
		tmp = getOutFile2__lg7fst4NMqq6lfa07YO7Rg((*d).conf, T7_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46), !((((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)));
		result = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(tmp, (*d).thisDir, 47);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T9_;
		T9_ = (NimStringDesc*)0;
		T9_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*d).conf, ((NI32) ((*module).position)));
		result = nosextractFilename(T9_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__MJcQaUOmoJidpolnPcz9aSQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procLink) {
	tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg r;
	NimStringDesc* literal;
	tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ kind;
	NI tokenPos;
	NI procTokenPos;
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg));
	literal = ((NimStringDesc*) NIM_NIL);
	initTokRender__fvDS5PTYUI6zuDDOhODswg((&r), n, renderFlags);
	kind = ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 1);
	tokenPos = ((NI) 0);
	procTokenPos = ((NI) 0);
	{
		while (1) {
			getNextTok__F3VjMm1n9aNzNovLrk02g5g((&r), (&kind), (&literal));
			tokenPos += ((NI) 1);
			switch (kind) {
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 1):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 110):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
					NimStringDesc* T10_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA7_;
					nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T10_ = (NimStringDesc*)0;
					T10_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T9_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T10_);
					T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T11_ = percent___C7jQ1fH79bR8HRQrbJjFKDg(T9_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T11_);
				}
				goto LA5_;
				LA7_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
					NimStringDesc* T14_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
					nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T14_ = (NimStringDesc*)0;
					T14_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T13_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T14_);
					T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T15_ = percent___2eu2gmgXiDUZkBgTVqD7pg(T13_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T15_);
				}
				LA5_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 3) ... ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 68):
			{
				{
					if (!(kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 51) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 41) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 38) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 40) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 59) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 30) || kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 15))) goto LA19_;
					procTokenPos = tokenPos;
				}
				LA19_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA23_;
					nimZeroMem((void*)T25_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T25_[0] = rope__yShmEg9cffWxI7s5XzEKBow(literal);
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = percent___cCI1wZSoDB14achJW7ZFSQ(T25_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T26_);
				}
				goto LA21_;
				LA23_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T28_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
					nimZeroMem((void*)T28_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T28_[0] = rope__yShmEg9cffWxI7s5XzEKBow(literal);
					T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T29_ = percent___dkLAWa1dMAcGEAyfUZ59bRA(T28_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T29_);
				}
				LA21_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 109):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T35_;
					NimStringDesc* T36_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA33_;
					nimZeroMem((void*)T35_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T36_ = (NimStringDesc*)0;
					T36_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T35_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T36_);
					T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T37_ = percent___DuvwOyJJ9b2gpVM9cV7DCFSQ(T35_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T37_);
				}
				goto LA31_;
				LA33_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T39_;
					NimStringDesc* T40_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
					nimZeroMem((void*)T39_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T40_ = (NimStringDesc*)0;
					T40_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T39_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T40_);
					T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T41_ = percent___4MBgNtJLOyqbjfGytl2OTw(T39_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T41_);
				}
				LA31_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 83) ... ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 85):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T47_;
					NimStringDesc* T48_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA45_;
					nimZeroMem((void*)T47_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T48_ = (NimStringDesc*)0;
					T48_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T47_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T48_);
					T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T49_ = percent___336bx9aXX7GZckfWQE5Jy3g(T47_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T49_);
				}
				goto LA43_;
				LA45_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T51_;
					NimStringDesc* T52_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
					nimZeroMem((void*)T51_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T52_ = (NimStringDesc*)0;
					T52_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T51_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T52_);
					T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T53_ = percent___IbsmsXdtDOH7pLpzh9cmAOA(T51_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T53_);
				}
				LA43_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 88):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T59_;
					NimStringDesc* T60_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA57_;
					nimZeroMem((void*)T59_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T60_ = (NimStringDesc*)0;
					T60_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T59_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T60_);
					T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T61_ = percent___9cGelOO9b6sliTnobJf6XAsg(T59_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T61_);
				}
				goto LA55_;
				LA57_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T63_;
					NimStringDesc* T64_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
					nimZeroMem((void*)T63_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T64_ = (NimStringDesc*)0;
					T64_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T63_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T64_);
					T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T65_ = percent___aNorSJCSJyyDo7w0s6eynA(T63_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T65_);
				}
				LA55_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 69) ... ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 78):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T71_;
					NimStringDesc* T72_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA69_;
					nimZeroMem((void*)T71_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T72_ = (NimStringDesc*)0;
					T72_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T71_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T72_);
					T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T73_ = percent___BYRFs7dwiqyMIzbsx9cDq8Q(T71_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T73_);
				}
				goto LA67_;
				LA69_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T75_;
					NimStringDesc* T76_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
					nimZeroMem((void*)T75_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T76_ = (NimStringDesc*)0;
					T76_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T75_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T76_);
					T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T77_ = percent___TavFv5xK0dxxJCk9b4v34zg(T75_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T77_);
				}
				LA67_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 79) ... ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 82):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T83_;
					NimStringDesc* T84_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA81_;
					nimZeroMem((void*)T83_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T84_ = (NimStringDesc*)0;
					T84_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T83_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T84_);
					T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T85_ = percent___9aAWQyBOqadJYgBT29bzliAw(T83_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T85_);
				}
				goto LA79_;
				LA81_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T87_;
					NimStringDesc* T88_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T89_;
					nimZeroMem((void*)T87_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T88_ = (NimStringDesc*)0;
					T88_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T87_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T88_);
					T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T89_ = percent___zpFS2Xy9cmoAoqCFSUQj1gg(T87_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T89_);
				}
				LA79_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 2):
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
				s = getTokSym__c63Q9b9bWYYRP36QgDsG9cNDQ((&r));
				{
					NIM_BOOL T93_;
					T93_ = (NIM_BOOL)0;
					T93_ = (procTokenPos == (NI)(tokenPos - ((NI) 2)));
					if (!(T93_)) goto LA94_;
					T93_ = !((procLink == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
					LA94_: ;
					if (!T93_) goto LA95_;
					{
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T101_;
						NimStringDesc* T102_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA99_;
						nimZeroMem((void*)T101_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T102_ = (NimStringDesc*)0;
						T102_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T101_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T102_);
						T101_[1] = procLink;
						T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T103_ = percent___Nz9cwOtMmcX2gklRogKhyEA(T101_, 2);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T103_);
					}
					goto LA97_;
					LA99_: ;
					{
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T105_;
						NimStringDesc* T106_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
						nimZeroMem((void*)T105_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T106_ = (NimStringDesc*)0;
						T106_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T105_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T106_);
						T105_[1] = procLink;
						T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T107_ = percent___YGYo0XYmypYw3N26AYh7ug(T105_, 2);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T107_);
					}
					LA97_: ;
				}
				goto LA91_;
				LA95_: ;
				{
					NIM_BOOL T109_;
					NIM_BOOL T110_;
					NIM_BOOL T111_;
					NIM_BOOL T112_;
					NIM_BOOL T113_;
					NimStringDesc* external;
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T121_;
					NimStringDesc* T122_;
					NimStringDesc* T123_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T124_;
					T109_ = (NIM_BOOL)0;
					T110_ = (NIM_BOOL)0;
					T111_ = (NIM_BOOL)0;
					T112_ = (NIM_BOOL)0;
					T113_ = (NIM_BOOL)0;
					T113_ = !((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T113_)) goto LA114_;
					T113_ = ((1920 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					LA114_: ;
					T112_ = T113_;
					if (!(T112_)) goto LA115_;
					T112_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0);
					LA115_: ;
					T111_ = T112_;
					if (!(T111_)) goto LA116_;
					T111_ = !(((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					LA116_: ;
					T110_ = T111_;
					if (!(T110_)) goto LA117_;
					T110_ = belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA((*d).conf, (*s).owner);
					LA117_: ;
					T109_ = T110_;
					if (!(T109_)) goto LA118_;
					T109_ = ((*d).Sup.target == ((tyEnum_OutputTarget__lDlBg9cTod71s9abpUj82lsw) 0));
					LA118_: ;
					if (!T109_) goto LA119_;
					external = externalDep__P9b6ldiOs1C1cjAHSU4Jlpg(d, (*s).owner);
					nimZeroMem((void*)T121_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T122_ = (NimStringDesc*)0;
					T122_ = noschangeFileExt(external, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
					T121_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T122_);
					T121_[1] = rope__yShmEg9cffWxI7s5XzEKBow(literal);
					T123_ = (NimStringDesc*)0;
					T123_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T121_[2] = rope__yShmEg9cffWxI7s5XzEKBow(T123_);
					T124_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T124_ = percent___e8Z4ajz6IErIB0a6mpq4Wg(T121_, 3);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T124_);
				}
				goto LA91_;
				LA119_: ;
				{
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T130_;
						NimStringDesc* T131_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T132_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA128_;
						nimZeroMem((void*)T130_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T131_ = (NimStringDesc*)0;
						T131_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T130_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T131_);
						T132_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T132_ = percent___eqn09cqDPu9csxGUOSa2untg(T130_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T132_);
					}
					goto LA126_;
					LA128_: ;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T134_;
						NimStringDesc* T135_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T136_;
						nimZeroMem((void*)T134_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T135_ = (NimStringDesc*)0;
						T135_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T134_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T135_);
						T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T136_ = percent___YGYo0XYmypYw3N26AYh7ug(T134_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T136_);
					}
					LA126_: ;
				}
				LA91_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 112):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 0):
			{
				add__yG4AKzsBRS1W4MANDlXQeg(result, literal);
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 97):
			{
				{
					if (!((renderFlags &((NU16)1<<((NU)(((tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw) 8))&15U)))!=0)) goto LA141_;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T147_;
						NimStringDesc* T148_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T149_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA145_;
						nimZeroMem((void*)T147_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T148_ = (NimStringDesc*)0;
						T148_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T147_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T148_);
						T149_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T149_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T147_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T149_);
					}
					goto LA143_;
					LA145_: ;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T151_;
						NimStringDesc* T152_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T153_;
						nimZeroMem((void*)T151_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T152_ = (NimStringDesc*)0;
						T152_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T151_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T152_);
						T153_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T153_ = percent___YGa4o1aenD9cjoU03CAgtqQ(T151_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T153_);
					}
					LA143_: ;
				}
				goto LA139_;
				LA141_: ;
				{
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T159_;
						NimStringDesc* T160_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T161_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA157_;
						nimZeroMem((void*)T159_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T160_ = (NimStringDesc*)0;
						T160_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T159_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T160_);
						T161_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T161_ = percent___rZ5o6ziDKz4d3bfaN54Dgg(T159_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T161_);
					}
					goto LA155_;
					LA157_: ;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T163_;
						NimStringDesc* T164_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T165_;
						nimZeroMem((void*)T163_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T164_ = (NimStringDesc*)0;
						T164_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T163_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T164_);
						T165_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T165_ = percent___YGa4o1aenD9cjoU03CAgtqQ(T163_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T165_);
					}
					LA155_: ;
				}
				LA139_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 98):
			{
				{
					if (!((renderFlags &((NU16)1<<((NU)(((tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw) 8))&15U)))!=0)) goto LA169_;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T175_;
						NimStringDesc* T176_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T177_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA173_;
						nimZeroMem((void*)T175_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T176_ = (NimStringDesc*)0;
						T176_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T175_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T176_);
						T177_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T177_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T175_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T177_);
					}
					goto LA171_;
					LA173_: ;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T179_;
						NimStringDesc* T180_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T181_;
						nimZeroMem((void*)T179_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T180_ = (NimStringDesc*)0;
						T180_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T179_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T180_);
						T181_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T181_ = percent___YGa4o1aenD9cjoU03CAgtqQ(T179_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T181_);
					}
					LA171_: ;
				}
				goto LA167_;
				LA169_: ;
				{
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T187_;
						NimStringDesc* T188_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T189_;
						if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA185_;
						nimZeroMem((void*)T187_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T188_ = (NimStringDesc*)0;
						T188_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T187_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T188_);
						T189_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T189_ = percent___b2PLtFwpZkVmYhHWvW4i1Q(T187_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T189_);
					}
					goto LA183_;
					LA185_: ;
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T191_;
						NimStringDesc* T192_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T193_;
						nimZeroMem((void*)T191_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T192_ = (NimStringDesc*)0;
						T192_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
						T191_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T192_);
						T193_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T193_ = percent___YGa4o1aenD9cjoU03CAgtqQ(T191_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(result, T193_);
					}
					LA183_: ;
				}
				LA167_: ;
			}
			break;
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 89):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 90):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 91):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 92):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 93):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 94):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 95):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 96):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 99):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 100):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 101):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 102):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 103):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 105):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 106):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 107):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 111):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 104):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 86):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 87):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 113):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 114):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 115):
			case ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 108):
			{
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T199_;
					NimStringDesc* T200_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T201_;
					if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA197_;
					nimZeroMem((void*)T199_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T200_ = (NimStringDesc*)0;
					T200_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T199_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T200_);
					T201_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T201_ = percent___ctY4Nx9aQFC9bl9c2wbRLoFYA(T199_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T201_);
				}
				goto LA195_;
				LA197_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T203_;
					NimStringDesc* T204_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T205_;
					nimZeroMem((void*)T203_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T204_ = (NimStringDesc*)0;
					T204_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, literal, ((NI) -1));
					T203_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T204_);
					T205_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T205_ = percent___YGa4o1aenD9cjoU03CAgtqQ(T203_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(result, T205_);
				}
				LA195_: ;
			}
			break;
			}
		}
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, whichType__P6VVhFoRXYNTxCtafqu9bmg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = strTableContains__qQqj4cZyGcSQKBqbLx4Alg((*d).types, (*n)._kind_4.sym);
			if (!T7_) goto LA8_;
			result = (*n)._kind_4.sym;
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					x = whichType__P6VVhFoRXYNTxCtafqu9bmg(d, (*n)._kind_6.sons->data[i]);
					{
						if (!!((x == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
						result = x;
						goto BeforeRet_;
					}
					LA16_: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, attachToType__2z9at9cKP7a6GoM6O9ba1zd7g)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	params = (*(*p).ast)._kind_6.sons->data[((NI) 3)];
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
		if (!(((NI) 1) < T3_)) goto LA4_;
		result = whichType__P6VVhFoRXYNTxCtafqu9bmg(d, (*params)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
	}
	LA4_: ;
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
		if (!(((NI) 0) < T12_)) goto LA13_;
		result = whichType__P6VVhFoRXYNTxCtafqu9bmg(d, (*params)._kind_6.sons->data[((NI) 0)]);
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA17_;
			goto BeforeRet_;
		}
		LA17_: ;
	}
	LA13_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
		i_2 = ((NI) 2);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA21;
				i = i_2;
				result = whichType__P6VVhFoRXYNTxCtafqu9bmg(d, (*params)._kind_6.sons->data[i]);
				{
					if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA24_;
					goto BeforeRet_;
				}
				LA24_: ;
				i_2 += ((NI) 1);
			} LA21: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, docstringSummary__kPnzAIKnun4jRp3dcGAV8Q)(NimStringDesc* rstText) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NI pos;
	NI last;
{	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = substr__iGg0RIKceRvsmvq8FUHOEw(rstText, ((NI) 2));
	result = nsuStrip(T1_, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_85);
	pos = nsuFindChar(result, 10, ((NI) 0), ((NI) 0));
	{
		if (!(((NI) 0) < pos)) goto LA4_;
		nsuDelete((&result), pos, (NI)((result ? result->Sup.len : 0) - ((NI) 1)));
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_120));
	}
	LA4_: ;
	{
		if (!(pos < ((NI) 100))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	pos = nsuFindCharSet(result, TM__5fUAZGW8WPeit3fZaQyNXA_121, ((NI) 0), ((NI) 0));
	last = (NI)((result ? result->Sup.len : 0) - ((NI) 1));
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((NI) 0) < pos);
		if (!(T12_)) goto LA13_;
		T12_ = (pos < last);
		LA13_: ;
		if (!T12_) goto LA14_;
		nsuDelete((&result), pos, last);
		result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_120));
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genItem__FFKq9cqnaX9c3oo9a5AloSpuQ)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k, tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog docFlags) {
	NimStringDesc* name;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nameRope;
	NimStringDesc* plainDocstring;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* literal;
	NimStringDesc* plainName;
	tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ kind;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* comm;
	tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg r;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaNode;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* plainNameRope;
	NimStringDesc* T26_;
	NimStringDesc* T27_;
	NimStringDesc* cleanPlainSymbol;
	NimStringDesc* complexSymbol;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* plainSymbolRope;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* plainSymbolEncRope;
	NimStringDesc* T28_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* itemIDRope;
	NimStringDesc* symbolOrId;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* symbolOrIdRope;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* symbolOrIdEncRope;
	NimStringDesc* T29_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* deprecationMsgRope;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* seeSrcRope;
	NimStringDesc* docItemSeeSrc;
	NimStringDesc* T58_;
	tyArray__ovcl1w9aI1ZmKzg6fGNtM9bQ T59_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
	NimStringDesc* external;
	NimStringDesc* T61_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* attype;
	NimStringDesc* T94_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T95_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T97_;
	NimStringDesc* T98_;
	tyArray__f7nG5LD47BH5K9c6mASit3g T99_;
	NimStringDesc* T100_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
	NimStringDesc* linkTitle;
	NimStringDesc* T102_;
	NimStringDesc* T103_;
	NimStringDesc* T104_;
	tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T115_;
	NimStringDesc* T116_;
	NimStringDesc* T117_;
{	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((docFlags == ((tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog) 1)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isVisible__2S18TVv8561n8da19ah7VxQ(d, nameNode);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	name = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, nameNode, ((NI) -1));
	nameRope = rope__yShmEg9cffWxI7s5XzEKBow(name);
	plainDocstring = getPlainDocstring__w0RLWJSCLHZKQXisk15Reg(n);
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	literal = ((NimStringDesc*) NIM_NIL);
	plainName = ((NimStringDesc*) NIM_NIL);
	kind = ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 1);
	comm = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159))) goto LA10_;
		getAllRunnableExamples__KTaDQnNH9ae4Bf008FpUeJw(d, n, &comm);
	}
	goto LA8_;
	LA10_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = genRecComment__CsFui9bBKN4zbV9c9cdppnsLA_2(d, n);
		add__IM4kcMNkkOLJtqdEqSxR8A(&comm, T13_);
	}
	LA8_: ;
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg));
	initTokRender__fvDS5PTYUI6zuDDOhODswg((&r), n, 94);
	{
		while (1) {
			getNextTok__F3VjMm1n9aNzNovLrk02g5g((&r), (&kind), (&literal));
			{
				if (!(kind == ((tyEnum_TokType__5VVBIL7Ozj1cc9akK23jAGQ) 1))) goto LA18_;
				goto LA14;
			}
			LA18_: ;
			plainName = resizeString(plainName, (literal ? literal->Sup.len : 0) + 0);
appendString(plainName, literal);
		}
	} LA14: ;
	pragmaNode = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		NIM_BOOL T22_;
		T22_ = (NIM_BOOL)0;
		T22_ = isCallable__SUIy9a9bqpDkoM66A6tppSaA(n);
		if (!(T22_)) goto LA23_;
		T22_ = !(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		LA23_: ;
		if (!T22_) goto LA24_;
		pragmaNode = findPragma__0mDn9a9aralwZhM9cLc7HEF9aA((*n)._kind_6.sons->data[((NI) 4)], ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 134));
	}
	LA24_: ;
	(*d).Sup.id += ((NI) 1);
	T26_ = (NimStringDesc*)0;
	T26_ = nsuStrip(plainName, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_85);
	T27_ = (NimStringDesc*)0;
	T27_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA(T26_);
	plainNameRope = rope__yShmEg9cffWxI7s5XzEKBow(T27_);
	cleanPlainSymbol = renderPlainSymbolName__0mm4u02iK86TVZPOApjzQA(nameNode);
	complexSymbol = complexName__9cXtMWiiMWGlqAPzr9aEWCzQ(k, n, cleanPlainSymbol);
	plainSymbolRope = rope__yShmEg9cffWxI7s5XzEKBow(cleanPlainSymbol);
	T28_ = (NimStringDesc*)0;
	T28_ = encodeUrl__hfOKCSlSHEBA7MAnVFj2bA(cleanPlainSymbol, NIM_TRUE);
	plainSymbolEncRope = rope__yShmEg9cffWxI7s5XzEKBow(T28_);
	itemIDRope = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*d).Sup.id)));
	symbolOrId = newUniquePlainSymbol__SMnsxF7PtS1Zx9aDjvvC7rw(d, complexSymbol);
	symbolOrIdRope = rope__yShmEg9cffWxI7s5XzEKBow(symbolOrId);
	T29_ = (NimStringDesc*)0;
	T29_ = encodeUrl__hfOKCSlSHEBA7MAnVFj2bA(symbolOrId, NIM_TRUE);
	symbolOrIdEncRope = rope__yShmEg9cffWxI7s5XzEKBow(T29_);
	deprecationMsgRope = genDeprecationMsg__CsFui9bBKN4zbV9c9cdppnsLA(d, pragmaNode);
	nodeToHighlightedHtml__MJcQaUOmoJidpolnPcz9aSQ(d, n, &result, 142, symbolOrIdEncRope);
	seeSrcRope = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	docItemSeeSrc = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_93), ((NimStringDesc*) NIM_NIL));
	{
		NimStringDesc* path;
		NimStringDesc* T34_;
		NimStringDesc* T35_;
		NimStringDesc* gitUrl;
		if (!(((NI) 0) < (docItemSeeSrc ? docItemSeeSrc->Sup.len : 0))) goto LA32_;
		T34_ = (NimStringDesc*)0;
		T34_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*d).conf, (*n).info.fileIndex);
		T35_ = (NimStringDesc*)0;
		T35_ = nosgetCurrentDir();
		path = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(T34_, T35_, 47);
		gitUrl = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_94), ((NimStringDesc*) NIM_NIL));
		{
			NimStringDesc* defaultBranch;
			NimStringDesc* commit;
			NimStringDesc* develBranch;
			if (!(((NI) 0) < (gitUrl ? gitUrl->Sup.len : 0))) goto LA38_;
			{
				if (!NIM_FALSE) goto LA42_;
				defaultBranch = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_95));
			}
			goto LA40_;
			LA42_: ;
			{
				defaultBranch = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_96), TM__5fUAZGW8WPeit3fZaQyNXA_97, 2);
			}
			LA40_: ;
			commit = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_100), defaultBranch);
			develBranch = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_101), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_95));
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T49_;
				tyArray__duFhZXIIlrbrM62cWjNekg T50_;
				NimStringDesc* T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
				if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA47_;
				nimZeroMem((void*)T49_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				nimZeroMem((void*)T50_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
				T50_[0] = rope__yShmEg9cffWxI7s5XzEKBow(path);
				T51_ = (NimStringDesc*)0;
				T51_ = dollar___M2d4UEGH9cZOvte6rEhvUTQ(((NU64) ((*n).info.line)));
				T50_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T51_);
				T50_[2] = rope__yShmEg9cffWxI7s5XzEKBow(gitUrl);
				T50_[3] = rope__yShmEg9cffWxI7s5XzEKBow(commit);
				T50_[4] = rope__yShmEg9cffWxI7s5XzEKBow(develBranch);
				T49_[0] = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, docItemSeeSrc, TM__5fUAZGW8WPeit3fZaQyNXA_102, 5, T50_, 5);
				T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T52_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T49_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(&seeSrcRope, T52_);
			}
			goto LA45_;
			LA47_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T54_;
				tyArray__duFhZXIIlrbrM62cWjNekg T55_;
				NimStringDesc* T56_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
				nimZeroMem((void*)T54_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				nimZeroMem((void*)T55_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
				T55_[0] = rope__yShmEg9cffWxI7s5XzEKBow(path);
				T56_ = (NimStringDesc*)0;
				T56_ = dollar___M2d4UEGH9cZOvte6rEhvUTQ(((NU64) ((*n).info.line)));
				T55_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T56_);
				T55_[2] = rope__yShmEg9cffWxI7s5XzEKBow(gitUrl);
				T55_[3] = rope__yShmEg9cffWxI7s5XzEKBow(commit);
				T55_[4] = rope__yShmEg9cffWxI7s5XzEKBow(develBranch);
				T54_[0] = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, docItemSeeSrc, TM__5fUAZGW8WPeit3fZaQyNXA_102, 5, T55_, 5);
				T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T57_ = percent___CtS8L8cOLTsSuQ10mtHsvw(T54_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(&seeSrcRope, T57_);
			}
			LA45_: ;
		}
		LA38_: ;
	}
	LA32_: ;
	T58_ = (NimStringDesc*)0;
	T58_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_107), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T59_, sizeof(tyArray__ovcl1w9aI1ZmKzg6fGNtM9bQ));
	T59_[0] = nameRope;
	T59_[1] = result;
	T59_[2] = comm;
	T59_[3] = itemIDRope;
	T59_[4] = plainNameRope;
	T59_[5] = plainSymbolRope;
	T59_[6] = symbolOrIdRope;
	T59_[7] = plainSymbolEncRope;
	T59_[8] = symbolOrIdEncRope;
	T59_[9] = seeSrcRope;
	T59_[10] = deprecationMsgRope;
	T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T60_ = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T58_, TM__5fUAZGW8WPeit3fZaQyNXA_108, 11, T59_, 11);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(k)- 0], T60_);
	T61_ = (NimStringDesc*)0;
	T61_ = relativeTo__zjjWvxBunys9bbBJHoqyLyQ((*d).Sup.destFile, (*(*d).conf).outDir, 47);
	external = noschangeFileExt(T61_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
	attype = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T64_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* att;
		T64_ = (NIM_BOOL)0;
		T64_ = ((520192 &((NU32)1<<((NU)(k)&31U)))!=0);
		if (!(T64_)) goto LA65_;
		T64_ = ((*nameNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA65_: ;
		if (!T64_) goto LA66_;
		att = attachToType__2z9at9cKP7a6GoM6O9ba1zd7g(d, (*nameNode)._kind_4.sym);
		{
			NimStringDesc* T72_;
			if (!!((att == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA70_;
			T72_ = (NimStringDesc*)0;
			T72_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, (*(*att).name).s, ((NI) -1));
			attype = rope__yShmEg9cffWxI7s5XzEKBow(T72_);
		}
		LA70_: ;
	}
	goto LA62_;
	LA66_: ;
	{
		NIM_BOOL T74_;
		NIM_BOOL T75_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* etyp;
		T74_ = (NIM_BOOL)0;
		T75_ = (NIM_BOOL)0;
		T75_ = (k == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		if (!(T75_)) goto LA76_;
		T75_ = ((*nameNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA76_: ;
		T74_ = T75_;
		if (!(T74_)) goto LA77_;
		T74_ = ((*(*(*nameNode)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14) || (*(*(*nameNode)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
		LA77_: ;
		if (!T74_) goto LA78_;
		etyp = (*(*nameNode)._kind_4.sym).typ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
			e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*etyp).n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA83;
						i = i_2;
						e = (*(*etyp).n)._kind_6.sons->data[i];
						{
							NimStringDesc* plain;
							NimStringDesc* symbolOrId_2;
							tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T89_;
							NimStringDesc* T90_;
							NimStringDesc* T91_;
							NimStringDesc* T92_;
							NimStringDesc* T93_;
							{
								if (!!(((*(*e)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20)))) goto LA87_;
								goto LA84;
							}
							LA87_: ;
							plain = renderPlainSymbolName__0mm4u02iK86TVZPOApjzQA(e);
							symbolOrId_2 = newUniquePlainSymbol__SMnsxF7PtS1Zx9aDjvvC7rw(d, plain);
							T89_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
							T89_ = &d->Sup;
							T90_ = (NimStringDesc*)0;
							T90_ = rawNewString(((*(*(*nameNode)._kind_4.sym).name).s ? (*(*(*nameNode)._kind_4.sym).name).s->Sup.len : 0) + (plain ? plain->Sup.len : 0) + 1);
appendString(T90_, (*(*(*nameNode)._kind_4.sym).name).s);
appendChar(T90_, 46);
appendString(T90_, plain);
							T91_ = (NimStringDesc*)0;
							T91_ = getPlainDocstring__w0RLWJSCLHZKQXisk15Reg(e);
							T92_ = (NimStringDesc*)0;
							T92_ = docstringSummary__kPnzAIKnun4jRp3dcGAV8Q(T91_);
							T93_ = (NimStringDesc*)0;
							T93_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA(T92_);
							setIndexTerm__59a2OAWg9c9azGlf9aSfMJTaLA(T89_, external, symbolOrId_2, plain, T90_, T93_);
						} LA84: ;
						i_2 += ((NI) 1);
					} LA83: ;
				}
			}
		}
	}
	goto LA62_;
	LA78_: ;
	LA62_: ;
	T94_ = (NimStringDesc*)0;
	T94_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_122), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T95_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T95_[0] = nameRope;
	T95_[1] = plainNameRope;
	T95_[2] = symbolOrIdEncRope;
	T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T96_ = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T94_, TM__5fUAZGW8WPeit3fZaQyNXA_123, 3, T95_, 3);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).toc[(k)- 0], T96_);
	T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T97_ = mgetOrPut__0qPqS0Ahbl9crTMtdrZk6CQ((&(*d).tocTable[(k)- 0]), cleanPlainSymbol, ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	T98_ = (NimStringDesc*)0;
	T98_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_124), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T99_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T99_[0] = nameRope;
	T99_[1] = plainNameRope;
	T100_ = (NimStringDesc*)0;
	T100_ = nsuReplaceStr(symbolOrId, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_91), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_126));
	T99_[2] = rope__yShmEg9cffWxI7s5XzEKBow(T100_);
	T99_[3] = symbolOrIdEncRope;
	T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T101_ = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T98_, TM__5fUAZGW8WPeit3fZaQyNXA_125, 4, T99_, 4);
	add__IM4kcMNkkOLJtqdEqSxR8A(T97_, T101_);
	T102_ = (NimStringDesc*)0;
	T103_ = (NimStringDesc*)0;
	T103_ = nosextractFilename((*d).Sup.filename);
	T104_ = (NimStringDesc*)0;
	T104_ = noschangeFileExt(T103_, ((NimStringDesc*) NIM_NIL));
	T102_ = rawNewString((T104_ ? T104_->Sup.len : 0) + 2);
appendString(T102_, T104_);
appendString(T102_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_127));
	linkTitle = T102_;
	{
		NIM_BOOL T107_;
		NimStringDesc* T110_;
		NimStringDesc* T111_;
		T107_ = (NIM_BOOL)0;
		T107_ = isCallable__SUIy9a9bqpDkoM66A6tppSaA(n);
		if (!T107_) goto LA108_;
		T110_ = (NimStringDesc*)0;
		T110_ = nsuStrip(plainName, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_85);
		T111_ = (NimStringDesc*)0;
		T111_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA(T110_);
		linkTitle = resizeString(linkTitle, (T111_ ? T111_->Sup.len : 0) + 0);
appendString(linkTitle, T111_);
	}
	goto LA105_;
	LA108_: ;
	{
		NimStringDesc* T113_;
		NimStringDesc* T114_;
		T113_ = (NimStringDesc*)0;
		T113_ = nsuStrip(complexSymbol, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_85);
		T114_ = (NimStringDesc*)0;
		T114_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA(T113_);
		linkTitle = resizeString(linkTitle, (T114_ ? T114_->Sup.len : 0) + 0);
appendString(linkTitle, T114_);
	}
	LA105_: ;
	T115_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
	T115_ = &d->Sup;
	T116_ = (NimStringDesc*)0;
	T116_ = docstringSummary__kPnzAIKnun4jRp3dcGAV8Q(plainDocstring);
	T117_ = (NimStringDesc*)0;
	T117_ = escape__MqjZ9c9b479ayFgA5h9aAscAFA(T116_);
	setIndexTerm__59a2OAWg9c9azGlf9aSfMJTaLA(T115_, external, symbolOrId, name, linkTitle, T117_);
	{
		NIM_BOOL T120_;
		T120_ = (NIM_BOOL)0;
		T120_ = (k == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		if (!(T120_)) goto LA121_;
		T120_ = ((*nameNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA121_: ;
		if (!T120_) goto LA122_;
		strTableAdd__tyTgUybFIoow4CX2l5beug((&(*d).types), (*nameNode)._kind_4.sym);
	}
	LA122_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__SUIy9a9bqpDkoM66A6tppSaA_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
	if (!(T1_)) goto LA2_;
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreStyle((*(*n)._kind_5.ident).s, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_128));
	T1_ = (T3_ == ((NI) 0));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__Eq9c0D6KgDDYSrjqwmAUuRg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sep;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dir;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T4_ = (T6_ == ((NI) 3));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*it)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
		LA7_: ;
		if (!T3_) goto LA8_;
		sep = (*it)._kind_6.sons->data[((NI) 0)];
		dir = (*it)._kind_6.sons->data[((NI) 1)];
		a = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29), (*it).info);
		add__P8dDSotTW25BkfbyspojGg(a, sep);
		add__P8dDSotTW25BkfbyspojGg(a, dir);
		add__P8dDSotTW25BkfbyspojGg(a, sep);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp_;
			x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			colontmp_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			colontmp_ = (*it)._kind_6.sons->data[((NI) 2)];
			{
				NI i;
				NI colontmp__2;
				NI i_2;
				i = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp_);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp__2)) goto LA13;
						i = i_2;
						x = (*colontmp_)._kind_6.sons->data[i];
						asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 2)]), x);
						traceDeps__Eq9c0D6KgDDYSrjqwmAUuRg(d, a);
						i_2 += ((NI) 1);
					} LA13: ;
				}
			}
		}
	}
	goto LA1_;
	LA8_: ;
	{
		NIM_BOOL T15_;
		NimStringDesc* external;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T15_)) goto LA16_;
		T15_ = belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA((*d).conf, (*it)._kind_4.sym);
		LA16_: ;
		if (!T15_) goto LA17_;
		external = externalDep__P9b6ldiOs1C1cjAHSU4Jlpg(d, (*it)._kind_4.sym);
		{
			if (!!(((*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))- 0] == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA21_;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))- 0], ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_74));
		}
		LA21_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T27_;
			NimStringDesc* T28_;
			NimStringDesc* T29_;
			NimStringDesc* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA25_;
			nimZeroMem((void*)T27_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T28_ = (NimStringDesc*)0;
			T28_ = prettyLink__wqjxtEP9aQIQkUTKzbjpNkQ(external);
			T29_ = (NimStringDesc*)0;
			T29_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, T28_, ((NI) -1));
			T27_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T29_);
			T30_ = (NimStringDesc*)0;
			T30_ = noschangeFileExt(external, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
			T27_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T30_);
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = percent___xsFAphqq4CRpmuZ79bXVLrA(T27_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))- 0], T31_);
		}
		goto LA23_;
		LA25_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T33_;
			NimStringDesc* T34_;
			NimStringDesc* T35_;
			NimStringDesc* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			nimZeroMem((void*)T33_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T34_ = (NimStringDesc*)0;
			T34_ = prettyLink__wqjxtEP9aQIQkUTKzbjpNkQ(external);
			T35_ = (NimStringDesc*)0;
			T35_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, T34_, ((NI) -1));
			T33_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T35_);
			T36_ = (NimStringDesc*)0;
			T36_ = noschangeFileExt(external, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
			T33_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T36_);
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T33_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))- 0], T37_);
		}
		LA23_: ;
	}
	goto LA1_;
	LA17_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exportSym__qYoJMTaZpxeCNRoEoCKzkw)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		NimStringDesc* external;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
		if (!(T3_)) goto LA4_;
		T3_ = belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA((*d).conf, s);
		LA4_: ;
		if (!T3_) goto LA5_;
		external = externalDep__P9b6ldiOs1C1cjAHSU4Jlpg(d, s);
		{
			if (!!(((*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0] == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA9_;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_74));
		}
		LA9_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T15_;
			NimStringDesc* T16_;
			NimStringDesc* T17_;
			NimStringDesc* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA13_;
			nimZeroMem((void*)T15_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T16_ = (NimStringDesc*)0;
			T16_ = prettyLink__wqjxtEP9aQIQkUTKzbjpNkQ(external);
			T17_ = (NimStringDesc*)0;
			T17_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, T16_, ((NI) -1));
			T15_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T17_);
			T18_ = (NimStringDesc*)0;
			T18_ = noschangeFileExt(external, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
			T15_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T18_);
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = percent___xsFAphqq4CRpmuZ79bXVLrA(T15_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], T19_);
		}
		goto LA11_;
		LA13_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T21_;
			NimStringDesc* T22_;
			NimStringDesc* T23_;
			NimStringDesc* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			nimZeroMem((void*)T21_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T22_ = (NimStringDesc*)0;
			T22_ = prettyLink__wqjxtEP9aQIQkUTKzbjpNkQ(external);
			T23_ = (NimStringDesc*)0;
			T23_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, T22_, ((NI) -1));
			T21_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T23_);
			T24_ = (NimStringDesc*)0;
			T24_ = noschangeFileExt(external, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
			T21_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T24_);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T21_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], T25_);
		}
		LA11_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T27_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
		T27_ = (NIM_BOOL)0;
		T27_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
		if (!(T27_)) goto LA28_;
		T27_ = !(((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA28_: ;
		if (!T27_) goto LA29_;
		module = originatingModule__lIu8wX6Beq6dBJgESOFFjg_2(s);
		{
			NIM_BOOL T33_;
			NimStringDesc* complexSymbol;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* symbolOrIdRope;
			NimStringDesc* T36_;
			NimStringDesc* external_2;
			T33_ = (NIM_BOOL)0;
			T33_ = belongsToPackage__cNpgS79aRW1W4TDXo9chSDaA((*d).conf, module);
			if (!T33_) goto LA34_;
			complexSymbol = complexName__9cXtMWiiMWGlqAPzr9aEWCzQ((*s).kind, (*s).ast, (*(*s).name).s);
			T36_ = (NimStringDesc*)0;
			T36_ = newUniquePlainSymbol__SMnsxF7PtS1Zx9aDjvvC7rw(d, complexSymbol);
			symbolOrIdRope = rope__yShmEg9cffWxI7s5XzEKBow(T36_);
			external_2 = externalDep__P9b6ldiOs1C1cjAHSU4Jlpg(d, module);
			{
				if (!!(((*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0] == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA39_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_74));
			}
			LA39_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T45_;
				NimStringDesc* T46_;
				NimStringDesc* T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
				if (!!(((*(*d).conf).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 17)))) goto LA43_;
				nimZeroMem((void*)T45_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T46_ = (NimStringDesc*)0;
				T46_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, (*(*s).name).s, ((NI) -1));
				T45_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T46_);
				T47_ = (NimStringDesc*)0;
				T47_ = noschangeFileExt(external_2, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
				T45_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T47_);
				T45_[2] = symbolOrIdRope;
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T48_ = percent___ypCukdfzc26AjS7pGJ5Q9cw(T45_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], T48_);
			}
			goto LA41_;
			LA43_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T50_;
				NimStringDesc* T51_;
				NimStringDesc* T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
				nimZeroMem((void*)T50_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T51_ = (NimStringDesc*)0;
				T51_ = esc__Tgq9c7oEp9c4LGF7SoXGTh8w((*d).Sup.target, (*(*s).name).s, ((NI) -1));
				T50_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T51_);
				T52_ = (NimStringDesc*)0;
				T52_ = noschangeFileExt(external_2, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
				T50_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T52_);
				T50_[2] = symbolOrIdRope;
				T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T53_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T50_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).section[(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))- 0], T53_);
			}
			LA41_: ;
		}
		LA34_: ;
	}
	goto LA1_;
	LA29_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__KoQU28HwEVx1pDp3hXeOpg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog docFlags) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaNode;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
		pragmaNode = findPragma__0mDn9a9aralwZhM9cLc7HEF9aA(n, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 134));
		T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T2_ = genDeprecationMsg__CsFui9bBKN4zbV9c9cdppnsLA(d, pragmaNode);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).modDeprecationMsg, T2_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	{
		NimStringDesc* T4_;
		T4_ = (NimStringDesc*)0;
		T4_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n);
		add__yG4AKzsBRS1W4MANDlXQeg(&(*d).modDesc, T4_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	{
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	{
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	{
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16), docFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA18_;
						genItem__FFKq9cqnaX9c3oo9a5AloSpuQ(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7) + (NI)((*n).kind - ((NI) 98))), docFlags);
					}
					LA18_: ;
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA23;
					i_3 = i_4;
					generateDoc__KoQU28HwEVx1pDp3hXeOpg(d, (*n)._kind_6.sons->data[i_3], orig, ((tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog) 0));
					i_4 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			NIM_BOOL T27_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T30_;
			T27_ = (NIM_BOOL)0;
			T27_ = checkForFalse__SUIy9a9bqpDkoM66A6tppSaA_2((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T27_)) goto LA28_;
			T30_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T30_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[((NI) 0)]);
			generateDoc__KoQU28HwEVx1pDp3hXeOpg(d, T30_, orig, ((tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog) 0));
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA35;
						i_5 = i_6;
						it = (*n)._kind_6.sons->data[i_5];
						traceDeps__Eq9c0D6KgDDYSrjqwmAUuRg(d, it);
						i_6 += ((NI) 1);
					} LA35: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_2;
			it_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA40;
						i_7 = i_8;
						it_2 = (*n)._kind_6.sons->data[i_7];
						{
							if (!((*it_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA43_;
							{
								NIM_BOOL T47_;
								T47_ = (NIM_BOOL)0;
								T47_ = !(((*d).module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
								if (!(T47_)) goto LA48_;
								T47_ = ((*d).module == (*(*it_2)._kind_4.sym).owner);
								LA48_: ;
								if (!T47_) goto LA49_;
								generateDoc__KoQU28HwEVx1pDp3hXeOpg(d, (*(*it_2)._kind_4.sym).ast, orig, ((tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog) 1));
							}
							goto LA45_;
							LA49_: ;
							{
								if (!!(((*(*it_2)._kind_4.sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA52_;
								exportSym__qYoJMTaZpxeCNRoEoCKzkw(d, (*it_2)._kind_4.sym);
							}
							goto LA45_;
							LA52_: ;
							LA45_: ;
						}
						LA43_: ;
						i_8 += ((NI) 1);
					} LA40: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 119):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 120):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 117):
	{
		traceDeps__Eq9c0D6KgDDYSrjqwmAUuRg(d, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* comm;
		comm = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		getAllRunnableExamples__KTaDQnNH9ae4Bf008FpUeJw(d, n, &comm);
		{
			if (!!((comm == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA59_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).modDesc, comm);
		}
		LA59_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__6UjzL2rSgVAuceHWxn9c01Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d) {
	NimStringDesc* outputDir;
	outputDir = exampleOutputDir__hwg9aq9cMZugC9arDWh9bne3Yw(d);
	{
		NimStringDesc* _;
		tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ* group;
		NI L;
		_ = (NimStringDesc*)0;
		group = (tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*)0;
		L = len__9cIAgXWUH5Nk24xwUJ9bNbtQtables((*d).exampleGroups);
		{
			NI h;
			if (!(((NI) 0) < (*d).exampleGroups.counter)) goto LA4_;
			h = (*d).exampleGroups.first;
			{
				while (1) {
					NI nxt;
					if (!(((NI) 0) <= h)) goto LA7;
					nxt = (*d).exampleGroups.data->data[h].Field1;
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = isFilled__5Qpmu5QqwDY0esVXn6wf7wtables((*d).exampleGroups.data->data[h].Field0);
						if (!T10_) goto LA11_;
						_ = (*d).exampleGroups.data->data[h].Field2;
						group = (*d).exampleGroups.data->data[h].Field3;
						{
							NimStringDesc* outp;
							tyArray__Re75IspeoxXy2oCZHwcRrA T18_;
							tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T19_;
							NimStringDesc* T20_;
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T21_;
							NimStringDesc* cmd;
							tyArray__ICDQ54qlGBxp1TLqclKASg T22_;
							{
								if (!eqStrings((*group).docCmd, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_11))) goto LA16_;
								goto LA13;
							}
							LA16_: ;
							nimZeroMem((void*)T18_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							nimZeroMem((void*)(&T19_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
							nossplitFile((*d).Sup.filename, (&T19_));
							T18_[0] = copyString(T19_.Field1);
							T18_[1] = nimIntToStr((*group).index);
							T20_ = (NimStringDesc*)0;
							T20_ = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_129), T18_, 2);
							outp = slash___QVqo5OOQAdrjFqBsPctklw(outputDir, T20_);
							nimZeroMem((void*)T21_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T21_[0] = copyString((*d).Sup.filename);
							T21_[1] = copyString((*group).rdoccmd);
							T21_[2] = copyString((*group).code);
							asgnRef((void**) (&(*group).code), nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_130), T21_, 3));
							writeFile__D6Pj9c29aCLEJP9beOWa08HYA(outp, (*group).code);
							nimZeroMem((void*)T22_, sizeof(tyArray__ICDQ54qlGBxp1TLqclKASg));
							T22_[0] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_21));
							T22_[1] = nosgetAppFilename();
							T22_[2] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_22));
							T22_[3] = reprEnum((NI)(*(*d).conf).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_));
							T22_[4] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_103));
							T22_[5] = nospquoteShell((*(*d).conf).projectPath);
							T22_[6] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_132));
							T22_[7] = nospquoteShell(outputDir);
							T22_[8] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_133));
							T22_[9] = nospquoteShell(outp);
							T22_[10] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_134));
							T22_[11] = copyString((*group).rdoccmd);
							T22_[12] = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_135));
							T22_[13] = copyString((*group).docCmd);
							cmd = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_131), T22_, 14);
							{
								NI T25_;
								tyArray__24KAM9afIUgUaqBaEBB6r9bg T28_;
								NimStringDesc* T29_;
								T25_ = (NI)0;
								T25_ = nosexecShellCmd(cmd);
								if (!!((T25_ == ((NI) 0)))) goto LA26_;
								nimZeroMem((void*)T28_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
								T28_[0] = copyString(outp);
								T28_[1] = dollar___IgedJtiWLIr01rtDe6Fo8Q((*group));
								T28_[2] = copyString(cmd);
								T29_ = (NimStringDesc*)0;
								T29_ = nsuFormatOpenArray(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_136), T28_, 3);
								quit__q8QKbUwWyOe9b9a1QNJQr71A(T29_, ((NI) 1));
							}
							goto LA23_;
							LA26_: ;
							{
								NimStringDesc* argX60gensym179_;
								NimStringDesc* T31_;
								tyArray__nHXaesL0DJZHyVS07ARPRA T32_;
								NimStringDesc* T33_;
								T31_ = (NimStringDesc*)0;
								T31_ = msgKindToString__pY9bbQrdTPzM2HGfayOe6eQ(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52));
								nimZeroMem((void*)T32_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
								T33_ = (NimStringDesc*)0;
								T33_ = rawNewString((outp ? outp->Sup.len : 0) + 18);
appendString(T33_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_137));
appendString(T33_, outp);
								T32_[0] = T33_;
								argX60gensym179_ = nsuFormatOpenArray(T31_, T32_, 1);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*d).conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52), argX60gensym179_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_138, NIM_TRUE);
							}
							LA23_: ;
						} LA13: ;
					}
					LA11_: ;
					h = nxt;
				} LA7: ;
			}
		}
		LA4_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genSection__PEsLviLPpF9bX8MsjBavO4Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, NIM_BOOL groupedToc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* title;
	NimStringDesc* T5_;
	tyArray__f7nG5LD47BH5K9c6mASit3g T6_;
	tyArray__bQohEW4Jw1ENvElOMs9bxmQ tocSource;
	NimStringDesc* T25_;
	tyArray__f7nG5LD47BH5K9c6mASit3g T26_;
{	{
		if (!((*d).section[(kind)- 0] == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	title = rope__yShmEg9cffWxI7s5XzEKBow(sectionNames__9bFbR0UW0hviZzxnBeyotPA[(kind)- 6]);
	T5_ = (NimStringDesc*)0;
	T5_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_152), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T6_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T6_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (kind)));
	T6_[1] = title;
	T6_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(kind + ((NI) 50)))));
	T6_[3] = (*d).section[(kind)- 0];
	asgnRef((void**) (&(*d).section[(kind)- 0]), ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T5_, TM__5fUAZGW8WPeit3fZaQyNXA_153, 4, T6_, 4));
	nimZeroMem((void*)tocSource, sizeof(tyArray__bQohEW4Jw1ENvElOMs9bxmQ));
	genericAssign((void*)tocSource, (void*)(*d).toc, (&NTI__bQohEW4Jw1ENvElOMs9bxmQ_));
	{
		if (!groupedToc) goto LA9_;
		{
			NimStringDesc* p;
			tyObject_Table__9bHTqygodsMdJIfIXO86mVg colontmp_;
			NI L;
			p = (NimStringDesc*)0;
			nimZeroMem((void*)(&colontmp_), sizeof(tyObject_Table__9bHTqygodsMdJIfIXO86mVg));
			colontmp_.data = (*d).tocTable[(kind)- 0].data;
			colontmp_.counter = (*d).tocTable[(kind)- 0].counter;
			L = len__dx37O9cdYBT1LvwGglU9akrw(colontmp_);
			{
				NI h;
				NI colontmp__2;
				NI T13_;
				NI res;
				h = (NI)0;
				colontmp__2 = (NI)0;
				T13_ = ((colontmp_.data ? colontmp_.data->Sup.len : 0)-1);
				colontmp__2 = T13_;
				res = ((NI) 0);
				{
					while (1) {
						if (!(res <= colontmp__2)) goto LA15;
						h = res;
						{
							NIM_BOOL T18_;
							NimStringDesc* T21_;
							tyArray__duFhZXIIlrbrM62cWjNekg T22_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
							T18_ = (NIM_BOOL)0;
							T18_ = isFilled__5Qpmu5QqwDY0esVXn6wf7wtables(colontmp_.data->data[h].Field0);
							if (!T18_) goto LA19_;
							p = colontmp_.data->data[h].Field1;
							T21_ = (NimStringDesc*)0;
							T21_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_158), ((NimStringDesc*) NIM_NIL));
							nimZeroMem((void*)T22_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
							T22_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (kind)));
							T22_[1] = title;
							T22_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(kind + ((NI) 50)))));
							T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T23_ = X5BX5D___sd3f1kRPAXhIuKDwkllg9cQ((&(*d).tocTable[(kind)- 0]), p);
							T22_[3] = (*T23_);
							T22_[4] = rope__yShmEg9cffWxI7s5XzEKBow(p);
							T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T24_ = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T21_, TM__5fUAZGW8WPeit3fZaQyNXA_159, 5, T22_, 5);
							add__IM4kcMNkkOLJtqdEqSxR8A(&(*d).toc2[(kind)- 0], T24_);
						}
						LA19_: ;
						res += ((NI) 1);
					} LA15: ;
				}
			}
		}
		genericAssign((void*)tocSource, (void*)(*d).toc2, (&NTI__bQohEW4Jw1ENvElOMs9bxmQ_));
	}
	LA9_: ;
	T25_ = (NimStringDesc*)0;
	T25_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_161), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T26_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T26_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (kind)));
	T26_[1] = title;
	T26_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(kind + ((NI) 50)))));
	T26_[3] = tocSource[(kind)- 0];
	asgnRef((void**) (&(*d).toc[(kind)- 0]), ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T25_, TM__5fUAZGW8WPeit3fZaQyNXA_153, 4, T26_, 4));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, relLink__PAa9bhm2IGZzoGk9cubfh9a6w)(NimStringDesc* outDir, NimStringDesc* destFile, NimStringDesc* linkto) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = slash___QVqo5OOQAdrjFqBsPctklw(outDir, linkto);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw(destFile, (&T2_));
	T3_ = (NimStringDesc*)0;
	T3_ = relativeTo__zjjWvxBunys9bbBJHoqyLyQ(T1_, T2_.Field0, 47);
	T4_ = (NimStringDesc*)0;
	T4_ = dollar___1d2waHISqAkJMu7hkyCpZg(T3_);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T4_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOutFile__dxphY5tqCcKvikJIbUMu5Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NIM_BOOL groupedToc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content;
	NimStringDesc* title;
	NI j;
	NimStringDesc* tmp;
	tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* toc;
	NimStringDesc* groupsection;
	NimStringDesc* bodyname;
	NimStringDesc* T38_;
	tyArray__Eng719aVJBoE9cgJDyPOaffg T39_;
	NimStringDesc* T40_;
	NimStringDesc* T41_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	code = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	content = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	title = ((NimStringDesc*) NIM_NIL);
	j = ((NI) 0);
	tmp = ((NimStringDesc*) NIM_NIL);
	T1_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
	T1_ = &d->Sup;
	renderTocEntries__lXmEBiWEMeUQB9cTe0c6XoQ(T1_, (&j), ((NI) 1), (&tmp));
	toc = rope__yShmEg9cffWxI7s5XzEKBow(tmp);
	{
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw i;
		i = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw v;
			NI res;
			v = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
			res = ((NI) 0);
			{
				while (1) {
					NIM_BOOL shouldSort;
					NIM_BOOL T6_;
					if (!(res <= ((NI) 25))) goto LA5;
					v = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) (res));
					i = v;
					T6_ = (NIM_BOOL)0;
					T6_ = ((12288 &((NU32)1<<((NU)(i)&31U)))!=0);
					if (!(T6_)) goto LA7_;
					T6_ = groupedToc;
					LA7_: ;
					shouldSort = T6_;
					genSection__PEsLviLPpF9bX8MsjBavO4Q(d, i, shouldSort);
					add__IM4kcMNkkOLJtqdEqSxR8A(&toc, (*d).toc[(i)- 0]);
					res += ((NI) 1);
				} LA5: ;
			}
		}
	}
	{
		NimStringDesc* T12_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
		if (!!((toc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA10_;
		T12_ = (NimStringDesc*)0;
		T12_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_162), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T13_[0] = toc;
		toc = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T12_, TM__5fUAZGW8WPeit3fZaQyNXA_163, 1, T13_, 1);
	}
	LA10_: ;
	{
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw i_2;
		i_2 = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw v_2;
			NI res_2;
			v_2 = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= ((NI) 25))) goto LA17;
					v_2 = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) (res_2));
					i_2 = v_2;
					add__IM4kcMNkkOLJtqdEqSxR8A(&code, (*d).section[(i_2)- 0]);
					res_2 += ((NI) 1);
				} LA17: ;
			}
		}
	}
	{
		NimStringDesc* external;
		NimStringDesc* T22_;
		NimStringDesc* T23_;
		tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T24_;
		if (!!((((*d).Sup.meta[(((tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg) 1))- 0] ? (*d).Sup.meta[(((tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg) 1))- 0]->Sup.len : 0) == ((NI) 0)))) goto LA20_;
		title = copyString((*d).Sup.meta[(((tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg) 1))- 0]);
		T22_ = (NimStringDesc*)0;
		T22_ = presentationPath__a9cVWkngyzzlrLvtxpnRSvg((*d).conf, (*d).Sup.filename, NIM_FALSE);
		T23_ = (NimStringDesc*)0;
		T23_ = noschangeFileExt(T22_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
		external = nativeToUnixPath__solXjq9b9ca3yY9cmjx52n9a8Q(T23_);
		T24_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
		T24_ = &d->Sup;
		setIndexTerm__59a2OAWg9c9azGlf9aSfMJTaLA(T24_, external, ((NimStringDesc*) NIM_NIL), title, ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) NIM_NIL));
	}
	goto LA18_;
	LA20_: ;
	{
		NimStringDesc* T26_;
		NimStringDesc* T27_;
		T26_ = (NimStringDesc*)0;
		T26_ = presentationPath__a9cVWkngyzzlrLvtxpnRSvg((*d).conf, (*d).Sup.filename, NIM_TRUE);
		T27_ = (NimStringDesc*)0;
		T27_ = noschangeFileExt(T26_, ((NimStringDesc*) NIM_NIL));
		title = dollar___1d2waHISqAkJMu7hkyCpZg(T27_);
	}
	LA18_: ;
	groupsection = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_164), ((NimStringDesc*) NIM_NIL));
	{
		NIM_BOOL T30_;
		T30_ = (NIM_BOOL)0;
		T30_ = (*d).Sup.hasToc;
		if (!(T30_)) goto LA31_;
		T30_ = !((*d).isPureRst);
		LA31_: ;
		if (!T30_) goto LA32_;
		groupsection = setLengthStr(groupsection, ((NI) 0));
		bodyname = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_165));
	}
	goto LA28_;
	LA32_: ;
	{
		if (!(*d).Sup.hasToc) goto LA35_;
		bodyname = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_166));
	}
	goto LA28_;
	LA35_: ;
	{
		bodyname = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_167));
	}
	LA28_: ;
	T38_ = (NimStringDesc*)0;
	T38_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, bodyname, ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T39_, sizeof(tyArray__Eng719aVJBoE9cgJDyPOaffg));
	T39_[0] = rope__yShmEg9cffWxI7s5XzEKBow(title);
	T39_[1] = toc;
	T39_[2] = (*d).modDesc;
	T40_ = (NimStringDesc*)0;
	T40_ = getDateStr__ye3QcrLEUbQh0AniHZYCHg_2();
	T39_[3] = rope__yShmEg9cffWxI7s5XzEKBow(T40_);
	T41_ = (NimStringDesc*)0;
	T41_ = getClockStr__ye3QcrLEUbQh0AniHZYCHg_3();
	T39_[4] = rope__yShmEg9cffWxI7s5XzEKBow(T41_);
	T39_[5] = code;
	T39_[6] = (*d).modDeprecationMsg;
	T39_[7] = relLink__PAa9bhm2IGZzoGk9cubfh9a6w((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_176));
	T39_[8] = rope__yShmEg9cffWxI7s5XzEKBow(groupsection);
	content = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T38_, TM__5fUAZGW8WPeit3fZaQyNXA_168, 9, T39_, 9);
	{
		NimStringDesc* T46_;
		tyArray__2bUjanmTGweqyhItSNsJQA T47_;
		NimStringDesc* T48_;
		NimStringDesc* T49_;
		if (!!((((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 4))&63U)))!=0))) goto LA44_;
		T46_ = (NimStringDesc*)0;
		T46_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ((*d).conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_177), ((NimStringDesc*) NIM_NIL));
		nimZeroMem((void*)T47_, sizeof(tyArray__2bUjanmTGweqyhItSNsJQA));
		T47_[0] = relLink__PAa9bhm2IGZzoGk9cubfh9a6w((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_184));
		T47_[1] = relLink__PAa9bhm2IGZzoGk9cubfh9a6w((*(*d).conf).outDir, (*d).Sup.destFile, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_185));
		T47_[2] = rope__yShmEg9cffWxI7s5XzEKBow(title);
		T47_[3] = toc;
		T47_[4] = (*d).modDesc;
		T48_ = (NimStringDesc*)0;
		T48_ = getDateStr__ye3QcrLEUbQh0AniHZYCHg_2();
		T47_[5] = rope__yShmEg9cffWxI7s5XzEKBow(T48_);
		T49_ = (NimStringDesc*)0;
		T49_ = getClockStr__ye3QcrLEUbQh0AniHZYCHg_3();
		T47_[6] = rope__yShmEg9cffWxI7s5XzEKBow(T49_);
		T47_[7] = content;
		T47_[8] = rope__yShmEg9cffWxI7s5XzEKBow((*d).Sup.meta[(((tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg) 3))- 0]);
		T47_[9] = rope__yShmEg9cffWxI7s5XzEKBow((*d).Sup.meta[(((tyEnum_MetaEnum__HD14RiMbGt9aRJpE4GI3T9cg) 4))- 0]);
		T47_[10] = rope__yShmEg9cffWxI7s5XzEKBow((*d).analytics);
		T47_[11] = (*d).modDeprecationMsg;
		code = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ((*d).conf, T46_, TM__5fUAZGW8WPeit3fZaQyNXA_178, 12, T47_, 12);
	}
	goto LA42_;
	LA44_: ;
	{
		code = content;
	}
	LA42_: ;
	result = code;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__lnHFCgpMa7a239cx3L7ar0g)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NimStringDesc* outfile) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*d).module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = (((*(*d).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils((*(*d).conf).outFile);
			if (!T9_) goto LA10_;
			asgnRef((void**) (&(*(*d).conf).outFile), relativeTo__zjjWvxBunys9bbBJHoqyLyQ(outfile, (*(*d).conf).outDir, 47));
			{
				NIM_BOOL T14_;
				tyTuple__UV3llMMYFckfui8YMBuUZA T17_;
				NimStringDesc* T18_;
				T14_ = (NIM_BOOL)0;
				T14_ = nosisAbsolute((*(*d).conf).outFile);
				if (!T14_) goto LA15_;
				nimZeroMem((void*)(&T17_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				nossplitPath((*(*d).conf).outFile, (&T17_));
				T18_ = (NimStringDesc*)0;
				T18_ = (*(*d).conf).outFile; (*(*d).conf).outFile = copyStringRC1(T17_.Field1);
				if (T18_) nimGCunrefNoCycle(T18_);
			}
			LA15_: ;
		}
		LA10_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__eA6azHzJ9cvJzUy6fY2ILpA)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NIM_BOOL useWarning, NIM_BOOL groupedToc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content;
	runAllExamples__6UjzL2rSgVAuceHWxn9c01Q(d);
	content = genOutFile__dxphY5tqCcKvikJIbUMu5Q(d, groupedToc);
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA3_;
		writeRope__FwuzOBq6SLlanVUstm8q9cA(__stdoutp, content);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* dir;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T6_;
		nimZeroMem((void*)(&T6_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		splitFile__z7B4FbwzX3Y0L1EA2lLGXw((*d).Sup.destFile, (&T6_));
		dir = T6_.Field0;
		noscreateDir(dir);
		updateOutfile__lnHFCgpMa7a239cx3L7ar0g(d, (*d).Sup.destFile);
		{
			NIM_BOOL T9_;
			tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w T12_;
			T9_ = (NIM_BOOL)0;
			T9_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(content, (*d).Sup.destFile);
			if (!!(T9_)) goto LA10_;
			T12_ = (tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w)0;
			{
				if (!useWarning) goto LA15_;
				T12_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12);
			}
			goto LA13_;
			LA15_: ;
			{
				T12_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3);
			}
			LA13_: ;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*d).conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T12_, (*d).Sup.destFile, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_186, NIM_FALSE);
		}
		goto LA7_;
		LA10_: ;
		{
			NimStringDesc* nimr;
			NimStringDesc* T21_;
			NimStringDesc* T22_;
			NimStringDesc* T23_;
			NimStringDesc* T24_;
			if (!!((*d).wroteSupportFiles)) goto LA19_;
			T21_ = (NimStringDesc*)0;
			T21_ = getPrefixDir__oltK69akg0xLqkR2ITKbomg((*d).conf);
			nimr = dollar___hGkBbU4pIQDXq4yGHJbKBQ(T21_);
			T22_ = (NimStringDesc*)0;
			T22_ = interp__a0DsESj69cWZcRAWqDjErOw(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_187), nimr);
			T23_ = (NimStringDesc*)0;
			T23_ = dollar___hGkBbU4pIQDXq4yGHJbKBQ((*(*d).conf).outDir);
			T24_ = (NimStringDesc*)0;
			T24_ = slash___gEyhbzZ1UcxyenWRLJRXNQ(T23_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_188));
			noscopyFile(T22_, T24_);
			{
				NimStringDesc* docHackJs2;
				NimStringDesc* T29_;
				NimStringDesc* T30_;
				NimStringDesc* T31_;
				NimStringDesc* T32_;
				if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 27))&63U)))!=0)) goto LA27_;
				T29_ = (NimStringDesc*)0;
				T29_ = nosgetAppFilename();
				docHackJs2 = getDocHacksJs__uOPHHO9bNZaiu8yCOVxjnyA(nimr, T29_, NIM_FALSE);
				T30_ = (NimStringDesc*)0;
				T30_ = dollar___hGkBbU4pIQDXq4yGHJbKBQ((*(*d).conf).outDir);
				T31_ = (NimStringDesc*)0;
				T31_ = noslastPathPart(docHackJs2);
				T32_ = (NimStringDesc*)0;
				T32_ = slash___gEyhbzZ1UcxyenWRLJRXNQ(T30_, T31_);
				noscopyFile(docHackJs2, T32_);
			}
			LA27_: ;
			(*d).wroteSupportFiles = NIM_TRUE;
		}
		goto LA7_;
		LA19_: ;
		LA7_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__6UjzL2rSgVAuceHWxn9c01Q_2)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d) {
	{
		NimStringDesc* dir;
		NimStringDesc* dest;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T7_;
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 27))&63U)))!=0)) goto LA3_;
		dir = (*(*d).conf).outDir;
		noscreateDir(dir);
		T5_ = (NimStringDesc*)0;
		T5_ = presentationPath__a9cVWkngyzzlrLvtxpnRSvg((*d).conf, (*d).Sup.filename, NIM_FALSE);
		T6_ = (NimStringDesc*)0;
		T6_ = noschangeFileExt(T5_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_189));
		dest = slash___QVqo5OOQAdrjFqBsPctklw(dir, T6_);
		T7_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
		T7_ = &d->Sup;
		writeIndexFile__XQaohh8v9brpMTzazPqfP6g(T7_, dest);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__kgKjuaW9cX0ivwgfDPX9bbdA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d;
{	handleDocOutputOptions__XbQ9cZpzVfEPm68TZ4kxJow(conf);
	ast = parseFile__HSBHiITVPKlv327uAC12yw((*conf).projectMainIdx, cache, conf);
	{
		if (!(ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__4NQNwjts5pclqjg2wHmDug((*conf).projectFull, cache, conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	(*d).Sup.hasToc = NIM_TRUE;
	generateDoc__KoQU28HwEVx1pDp3hXeOpg(d, ast, ast, ((tyEnum_DocFlags__n80LVfoJIDYz0UaY4RmOog) 0));
	writeOutput__eA6azHzJ9cvJzUy6fY2ILpA(d, NIM_FALSE, NIM_FALSE);
	generateIndex__6UjzL2rSgVAuceHWxn9c01Q_2(d);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__3iwzPz66TEml47u8LtfIQg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* j) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___ufBNJwWgb20cY5Bv3NMT7A(j, ((tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*) NIM_NIL));
		if (!!(T3_)) goto LA4_;
		add__8FFZVkexaQ73y9aREGlrY9bQ((*d).jArray, j);
	}
	LA4_: ;
}
static N_INLINE(void, X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* obj, NimStringDesc* key, tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* val) {
	X5BX5Deq___vlnBr1uIbtu0ntnZh6Askg((&(*obj)._kind_6.fields), key, val);
}
static N_INLINE(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, X5BX5D___277k8m8OstpfbY4dHQex6wjson)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node, NimStringDesc* name) {
	tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* result;
	tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q** T1_;
	result = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
	T1_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q**)0;
	T1_ = X5BX5D___l9atGRY9bA25fn4p5uueZfUQ((&(*node)._kind_6.fields), name);
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, genJsonItem__6Yvyha9boYC58GWZQItGmBg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
	tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* result;
	NimStringDesc* name;
	NimStringDesc* comm;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg r;
	tyArray__rhtWm6uYOU6da9bZDT6ryDA T7_;
{	result = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isVisible__2S18TVv8561n8da19ah7VxQ(d, nameNode);
		if (!!(T3_)) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	name = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, nameNode, ((NI) -1));
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = genRecComment__CsFui9bBKN4zbV9c9cdppnsLA_2(d, n);
	comm = dollar___mZ66tEveFIQokq3arf8Klw(T6_);
	nimZeroMem((void*)(&r), sizeof(tyObject_TSrcGen__T8CUsYfvFor5lPGY7PW7Dg));
	initTokRender__fvDS5PTYUI6zuDDOhODswg((&r), n, 14);
	nimZeroMem((void*)T7_, sizeof(tyArray__rhtWm6uYOU6da9bZDT6ryDA));
	T7_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109));
	T7_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(name);
	T7_[1].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_191));
	T7_[1].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(reprEnum((NI)k, (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
	T7_[2].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_104));
	T7_[2].Field1 = percent___NSr46Qz23yGk4m9csPSbQBQ(((NI) ((*n).info.line)));
	T7_[3].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_192));
	T7_[3].Field1 = percent___NSr46Qz23yGk4m9csPSbQBQ(((NI) ((*n).info.col)));
	result = percent___HoVDUa0lAOcINNYBrrSTiA(T7_, 4);
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T12_;
		if (!(((NI) 0) < (comm ? comm->Sup.len : 0))) goto LA10_;
		T12_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T12_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(comm);
		X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_193), T12_);
	}
	LA10_: ;
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T17_;
		if (!(((NI) 0) < (r.buf ? r.buf->Sup.len : 0))) goto LA15_;
		T17_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T17_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(r.buf);
		X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_194), T17_);
	}
	LA15_: ;
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T22_;
		if (!((520192 &((NU32)1<<((NU)(k)&31U)))!=0)) goto LA20_;
		T22_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T22_ = newJObject__nXwnFPu9beTnGPwglrr7ztA_2();
		X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195), T22_);
		{
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T27_;
			NimStringDesc* T28_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T29_;
			if (!!(((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA25_;
			T27_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T27_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
			T28_ = (NimStringDesc*)0;
			T28_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]);
			T29_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T29_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(T28_);
			X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(T27_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_196), T29_);
		}
		LA25_: ;
		{
			NI T32_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T35_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T36_;
			T32_ = (NI)0;
			T32_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 3)]);
			if (!(((NI) 1) < T32_)) goto LA33_;
			T35_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T35_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
			T36_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T36_ = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(T35_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_197), T36_);
		}
		LA33_: ;
		{
			NI paramIdx;
			NI colontmp_;
			NI i;
			paramIdx = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 3)]);
			i = ((NI) 1);
			{
				while (1) {
					if (!(i < colontmp_)) goto LA39;
					paramIdx = i;
					{
						NI identIdx;
						NI colontmp__2;
						NI T41_;
						NI i_2;
						identIdx = (NI)0;
						colontmp__2 = (NI)0;
						T41_ = (NI)0;
						T41_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
						colontmp__2 = (NI)(T41_ - ((NI) 2));
						i_2 = ((NI) 0);
						{
							while (1) {
								NimStringDesc* paramName;
								NimStringDesc* paramType;
								NI T44_;
								if (!(i_2 < colontmp__2)) goto LA43;
								identIdx = i_2;
								paramName = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[identIdx]);
								T44_ = (NI)0;
								T44_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
								paramType = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T44_ - ((NI) 2))]);
								{
									NI T47_;
									NimStringDesc* paramDefault;
									NI T50_;
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T51_;
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T52_;
									tyArray__fG4HAsOMuyKnlovN4zCUaA T53_;
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T54_;
									T47_ = (NI)0;
									T47_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
									if (!!(((*(*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T47_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA48_;
									T50_ = (NI)0;
									T50_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx]);
									paramDefault = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[paramIdx])._kind_6.sons->data[(NI)(T50_ - ((NI) 1))]);
									T51_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T51_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
									T52_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T52_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(T51_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_197));
									nimZeroMem((void*)T53_, sizeof(tyArray__fG4HAsOMuyKnlovN4zCUaA));
									T53_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109));
									T53_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(paramName);
									T53_[1].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_191));
									T53_[1].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(paramType);
									T53_[2].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_198));
									T53_[2].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(paramDefault);
									T54_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T54_ = percent___HoVDUa0lAOcINNYBrrSTiA(T53_, 3);
									add__8FFZVkexaQ73y9aREGlrY9bQ(T52_, T54_);
								}
								goto LA45_;
								LA48_: ;
								{
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T56_;
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T57_;
									tyArray__rnBfBeuXQMeTae3dUyC1Bw T58_;
									tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T59_;
									T56_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T56_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
									T57_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T57_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(T56_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_197));
									nimZeroMem((void*)T58_, sizeof(tyArray__rnBfBeuXQMeTae3dUyC1Bw));
									T58_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109));
									T58_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(paramName);
									T58_[1].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_191));
									T58_[1].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(paramType);
									T59_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
									T59_ = percent___HoVDUa0lAOcINNYBrrSTiA(T58_, 2);
									add__8FFZVkexaQ73y9aREGlrY9bQ(T57_, T59_);
								}
								LA45_: ;
								i_2 += ((NI) 1);
							} LA43: ;
						}
					}
					i += ((NI) 1);
				} LA39: ;
			}
		}
		{
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T64_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T65_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA62_;
			T64_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T64_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
			T65_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T65_ = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(T64_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_199), T65_);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__3;
				pragma = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				colontmp__3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				colontmp__3 = (*n)._kind_6.sons->data[((NI) 4)];
				{
					NI i_3;
					NI colontmp__4;
					NI i_4;
					i_3 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp__3);
					i_4 = ((NI) 0);
					{
						while (1) {
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T70_;
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T71_;
							NimStringDesc* T72_;
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T73_;
							if (!(i_4 < colontmp__4)) goto LA69;
							i_3 = i_4;
							pragma = (*colontmp__3)._kind_6.sons->data[i_3];
							T70_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
							T70_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
							T71_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
							T71_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(T70_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_199));
							T72_ = (NimStringDesc*)0;
							T72_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(pragma);
							T73_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
							T73_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(T72_);
							add__8FFZVkexaQ73y9aREGlrY9bQ(T71_, T73_);
							i_4 += ((NI) 1);
						} LA69: ;
					}
				}
			}
		}
		LA62_: ;
		{
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T78_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T79_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA76_;
			T78_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T78_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
			T79_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T79_ = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
			X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(T78_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_200), T79_);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParam;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__5;
				genericParam = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				colontmp__5 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				colontmp__5 = (*n)._kind_6.sons->data[((NI) 2)];
				{
					NI i_5;
					NI colontmp__6;
					NI i_6;
					i_5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__6 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp__5);
					i_6 = ((NI) 0);
					{
						while (1) {
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* param;
							tyArray__nFPyKpuH1zPi4VuXhWbFAg T84_;
							NimStringDesc* T85_;
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T99_;
							tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T100_;
							if (!(i_6 < colontmp__6)) goto LA83;
							i_5 = i_6;
							genericParam = (*colontmp__5)._kind_6.sons->data[i_5];
							nimZeroMem((void*)T84_, sizeof(tyArray__nFPyKpuH1zPi4VuXhWbFAg));
							T84_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_109));
							T85_ = (NimStringDesc*)0;
							T85_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(genericParam);
							T84_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T85_);
							param = percent___HoVDUa0lAOcINNYBrrSTiA(T84_, 1);
							{
								NI T88_;
								tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T91_;
								T88_ = ((*(*(*genericParam)._kind_4.sym).typ).sons ? (*(*(*genericParam)._kind_4.sym).typ).sons->Sup.len : 0);
								if (!(((NI) 0) < T88_)) goto LA89_;
								T91_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
								T91_ = newJArray__nXwnFPu9beTnGPwglrr7ztA_3();
								X5BX5Deq___WmQhibcOp3ZlzI9bgifjalAjson(param, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_201), T91_);
							}
							LA89_: ;
							{
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** kind;
								tySequence__Ef05srmQTDulnBdXR4Ja6Q* colontmp__7;
								NI i_7;
								NI L;
								NI T93_;
								kind = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
								colontmp__7 = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
								colontmp__7 = (*(*(*genericParam)._kind_4.sym).typ).sons;
								i_7 = ((NI) 0);
								T93_ = (colontmp__7 ? colontmp__7->Sup.len : 0);
								L = T93_;
								{
									while (1) {
										tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T96_;
										NimStringDesc* T97_;
										tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T98_;
										if (!(i_7 < L)) goto LA95;
										kind = &colontmp__7->data[i_7];
										T96_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
										T96_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(param, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_201));
										T97_ = (NimStringDesc*)0;
										T97_ = typeToString__QlvraUan7WbHowhAbvDvdA((*kind), ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
										T98_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
										T98_ = percent___19ag6cl4fMjxytc9arHmLIbw_3(T97_);
										add__8FFZVkexaQ73y9aREGlrY9bQ(T96_, T98_);
										i_7 += ((NI) 1);
									} LA95: ;
								}
							}
							T99_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
							T99_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(result, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_195));
							T100_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
							T100_ = X5BX5D___277k8m8OstpfbY4dHQex6wjson(T99_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_200));
							add__8FFZVkexaQ73y9aREGlrY9bQ(T100_, param);
							i_6 += ((NI) 1);
						} LA83: ;
					}
				}
			}
		}
		LA76_: ;
	}
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateJson__aCcnJCcOFu8Y1ZdiDOUa6Q)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL includeComments) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	{
		{
			tyArray__nFPyKpuH1zPi4VuXhWbFAg T6_;
			NimStringDesc* T7_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T8_;
			if (!includeComments) goto LA4_;
			nimZeroMem((void*)T6_, sizeof(tyArray__nFPyKpuH1zPi4VuXhWbFAg));
			T6_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_190));
			T7_ = (NimStringDesc*)0;
			T7_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n);
			T6_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T7_);
			T8_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T8_ = percent___HoVDUa0lAOcINNYBrrSTiA(T6_, 1);
			add__3iwzPz66TEml47u8LtfIQg(d, T8_);
		}
		goto LA2_;
		LA4_: ;
		{
			NimStringDesc* T10_;
			T10_ = (NimStringDesc*)0;
			T10_ = genComment__1NsSIzkKMtq49acu82VJUxg(d, n);
			add__yG4AKzsBRS1W4MANDlXQeg(&(*d).modDesc, T10_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T12_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T12_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T12_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
		add__3iwzPz66TEml47u8LtfIQg(d, T12_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T14_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T14_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T14_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13));
		add__3iwzPz66TEml47u8LtfIQg(d, T14_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T16_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T16_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T16_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
		add__3iwzPz66TEml47u8LtfIQg(d, T16_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T18_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T18_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T18_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		add__3iwzPz66TEml47u8LtfIQg(d, T18_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T20_;
		T20_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T20_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
		add__3iwzPz66TEml47u8LtfIQg(d, T20_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T22_;
		T22_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T22_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
		add__3iwzPz66TEml47u8LtfIQg(d, T22_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T24_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T24_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
		T24_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16));
		add__3iwzPz66TEml47u8LtfIQg(d, T24_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA28;
					i = i_2;
					{
						tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T33_;
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA31_;
						T33_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
						T33_ = genJsonItem__6Yvyha9boYC58GWZQItGmBg(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7) + (NI)((*n).kind - ((NI) 98))));
						add__3iwzPz66TEml47u8LtfIQg(d, T33_);
					}
					LA31_: ;
					i_2 += ((NI) 1);
				} LA28: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA37;
					i_3 = i_4;
					generateJson__aCcnJCcOFu8Y1ZdiDOUa6Q(d, (*n)._kind_6.sons->data[i_3], includeComments);
					i_4 += ((NI) 1);
				} LA37: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			NIM_BOOL T41_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
			T41_ = (NIM_BOOL)0;
			T41_ = checkForFalse__SUIy9a9bqpDkoM66A6tppSaA_2((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T41_)) goto LA42_;
			T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T44_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[((NI) 0)]);
			generateJson__aCcnJCcOFu8Y1ZdiDOUa6Q(d, T44_, includeComments);
		}
		LA42_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI L;
	NI T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) setLengthSeqV2(&((*s))->Sup, (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutputJson__7W8HhP9cLoIdLMqjvSJvHmg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, NIM_BOOL useWarning) {
	NimStringDesc* modDesc;
	tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* content;
	tyArray__rhtWm6uYOU6da9bZDT6ryDA T16_;
	NimStringDesc* T17_;
	runAllExamples__6UjzL2rSgVAuceHWxn9c01Q(d);
	modDesc = (NimStringDesc*)0;
	{
		NIM_CHAR desc;
		desc = (NIM_CHAR)0;
		{
			NimStringDesc* s;
			s = (NimStringDesc*)0;
			{
				tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* stack;
				if (!!(((*d).modDesc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA5_;
				stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) newSeq((&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), 1);
				asgnRef((void**) (&stack->data[0]), (*d).modDesc);
				{
					while (1) {
						NI T9_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* it;
						T9_ = (stack ? stack->Sup.len : 0);
						if (!(((NI) 0) < T9_)) goto LA8;
						it = pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem((&stack));
						{
							while (1) {
								NI T12_;
								if (!!(((*it).left == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA11;
								stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) incrSeqV3((TGenericSeq*)(stack), (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_));
								T12_ = stack->Sup.len++;
								asgnRef((void**) (&stack->data[T12_]), (*it).right);
								it = (*it).left;
							} LA11: ;
						}
						s = (*it).data;
						{
							NIM_CHAR c;
							NI i;
							NI L;
							c = (NIM_CHAR)0;
							i = ((NI) 0);
							L = (s ? s->Sup.len : 0);
							{
								while (1) {
									if (!(i < L)) goto LA15;
									c = s->data[i];
									desc = c;
									modDesc = addChar(modDesc, desc);
									i += ((NI) 1);
								} LA15: ;
							}
						}
					} LA8: ;
				}
			}
			LA5_: ;
		}
	}
	nimZeroMem((void*)T16_, sizeof(tyArray__rhtWm6uYOU6da9bZDT6ryDA));
	T16_[0].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_202));
	T16_[0].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3((*d).Sup.filename);
	T16_[1].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_203));
	T17_ = (NimStringDesc*)0;
	T17_ = getPackageName__ez7MSoVdvcTOZlBJgbu5Sg((*d).conf, (*d).Sup.filename);
	T16_[1].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(T17_);
	T16_[2].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_204));
	T16_[2].Field1 = percent___19ag6cl4fMjxytc9arHmLIbw_3(modDesc);
	T16_[3].Field0 = copyString(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_205));
	T16_[3].Field1 = (*d).jArray;
	content = percent___HoVDUa0lAOcINNYBrrSTiA(T16_, 4);
	{
		NimStringDesc* T22_;
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA20_;
		T22_ = (NimStringDesc*)0;
		T22_ = dollar___79aIqF5QC8ZRJgu2hlv9bdjw(content);
		write__PArlm09bKklm2BLsCg6YtaA(__stdoutp, T22_);
	}
	goto LA18_;
	LA20_: ;
	{
		FILE* f;
		f = (FILE*)0;
		{
			NIM_BOOL T26_;
			NimStringDesc* T29_;
			T26_ = (NIM_BOOL)0;
			T26_ = open__gq12VLhVO0NBzUTnGgz4nw(&f, (*d).Sup.destFile, ((tyEnum_FileMode__ZJfK20XeZ9bv2j1pZjw9aswg) 1), ((NI) -1));
			if (!T26_) goto LA27_;
			T29_ = (NimStringDesc*)0;
			T29_ = dollar___79aIqF5QC8ZRJgu2hlv9bdjw(content);
			write__PArlm09bKklm2BLsCg6YtaA(f, T29_);
			close__fU6ZlJAtQ9bre04EDZLdGsA_3(f);
			updateOutfile__lnHFCgpMa7a239cx3L7ar0g(d, (*d).Sup.destFile);
		}
		goto LA24_;
		LA27_: ;
		{
			tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T31_;
			NimStringDesc* T32_;
			T31_ = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs((*d).conf, (*d).Sup.filename, ((NI) -1), ((NI) -1));
			T32_ = (NimStringDesc*)0;
			T32_ = rawNewString(((*d).Sup.destFile ? (*d).Sup.destFile->Sup.len : 0) + 34);
appendString(T32_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_206));
appendString(T32_, (*d).Sup.destFile);
appendString(T32_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_207));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*d).conf, T31_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__5fUAZGW8WPeit3fZaQyNXA_208, NIM_FALSE);
		}
		LA24_: ;
	}
	LA18_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__G9aVujEhUM3YWsYQBFeTRfQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* dir, NimStringDesc* outFile) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content;
	NimStringDesc* T1_;
	NimStringDesc* outFile_2;
	NimStringDesc* filename;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
	NimStringDesc* T7_;
	tyArray__ovcl1w9aI1ZmKzg6fGNtM9bQ T8_;
	NimStringDesc* T9_;
	NimStringDesc* T10_;
	T1_ = (NimStringDesc*)0;
	T1_ = mergeIndexes__gnBYZcMG5WPYB3f83P6f9ag(dir);
	content = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	outFile_2 = copyString(outFile);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__bFmAIl9aL9a1UuSf9ckLiDlVwpathutils(outFile_2);
		if (!T4_) goto LA5_;
		outFile_2 = noschangeFileExt(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_176), ((NimStringDesc*) NIM_NIL));
	}
	LA5_: ;
	filename = getOutFile__wyg2NQihYStyX9aXfJMkKlg(conf, outFile_2, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
	T7_ = (NimStringDesc*)0;
	T7_ = getConfigVar__nT6pi8CimjduqrsM6Cc8mQ(conf, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_177), ((NimStringDesc*) NIM_NIL));
	nimZeroMem((void*)T8_, sizeof(tyArray__ovcl1w9aI1ZmKzg6fGNtM9bQ));
	T8_[0] = relLink__PAa9bhm2IGZzoGk9cubfh9a6w((*conf).outDir, filename, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_184));
	T8_[1] = relLink__PAa9bhm2IGZzoGk9cubfh9a6w((*conf).outDir, filename, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_185));
	T8_[2] = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_210));
	T8_[3] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T8_[4] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T9_ = (NimStringDesc*)0;
	T9_ = getDateStr__ye3QcrLEUbQh0AniHZYCHg_2();
	T8_[5] = rope__yShmEg9cffWxI7s5XzEKBow(T9_);
	T10_ = (NimStringDesc*)0;
	T10_ = getClockStr__ye3QcrLEUbQh0AniHZYCHg_3();
	T8_[6] = rope__yShmEg9cffWxI7s5XzEKBow(T10_);
	T8_[7] = content;
	T8_[8] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T8_[9] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T8_[10] = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	code = ropeFormatNamedVars__C7idxrvpR7GOGT9c4FWXrBQ(conf, T7_, TM__5fUAZGW8WPeit3fZaQyNXA_209, 11, T8_, 11);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(code, filename);
		if (!!(T13_)) goto LA14_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), filename, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_211, NIM_FALSE);
	}
	LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__Zb29b9be2mdWzzb1jYhPz69aw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NimStringDesc* outExt) {
	NimStringDesc* filen;
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d;
	tyObject_RstNode__CjRS2xrmuD58kdGedE3yyg* rst;
	NimStringDesc* T1_;
	NimStringDesc* modDesc;
	tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* T2_;
	filen = nosaddFileExt(filename, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_212));
	d = newDocumentor__4NQNwjts5pclqjg2wHmDug(filen, cache, conf, outExt, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	(*d).isPureRst = NIM_TRUE;
	T1_ = (NimStringDesc*)0;
	T1_ = readFile__4PGnM9bWmsH0Nu7dnr3XzgA(filen);
	rst = parseRst__U0R9a9aB9ccn8lJ7U1XqFb10Q(T1_, filen, ((NI) 0), ((NI) 1), (&(*d).Sup.hasToc), 12, conf);
	modDesc = rawNewString(((NI) 30000));
	T2_ = (tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg*)0;
	T2_ = &d->Sup;
	renderRstToOut__9bVWgX0SWmhEi3eHlrcMD8g(T2_, rst, (&modDesc));
	asgnRef((void**) (&(*d).modDesc), rope__yShmEg9cffWxI7s5XzEKBow(modDesc));
	writeOutput__eA6azHzJ9cvJzUy6fY2ILpA(d, NIM_FALSE, NIM_FALSE);
	generateIndex__6UjzL2rSgVAuceHWxn9c01Q_2(d);
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__kgKjuaW9cX0ivwgfDPX9bbdA_2)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	commandRstAux__Zb29b9be2mdWzzb1jYhPz69aw(cache, conf, (*conf).projectFull, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46));
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__kgKjuaW9cX0ivwgfDPX9bbdA_3)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	commandRstAux__Zb29b9be2mdWzzb1jYhPz69aw(cache, conf, (*conf).projectFull, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_213));
}
static N_NIMCALL(void, Marker_tyRef__SNRao7b4hOZKnbHC8HR0gg)(void* p, NI op) {
	tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA* a;
	a = (tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA* colonenvP_;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T1_;
	colonenvP_ = (tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*) ClE_0;
	T1_ = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs((*colonenvP_).conf1, (*d).filename, ((NI) -1), ((NI) -1));
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, T1_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_215), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__5fUAZGW8WPeit3fZaQyNXA_216, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, commandJson__kgKjuaW9cX0ivwgfDPX9bbdA_4)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA* colonenv_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d;
	tyProc__XtNNqpdSSaHFEnbiw4OQrw T5_;
	tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* json;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content;
	NimStringDesc* T6_;
{	colonenv_ = (tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*)0;
	colonenv_ = (tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*) newObj((&NTI__SNRao7b4hOZKnbHC8HR0gg_), sizeof(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA));
	(*colonenv_).Sup.m_type = (&NTI__jwayR6zaxkEYAMp3GS09bOA_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	ast = parseFile__HSBHiITVPKlv327uAC12yw((*(*colonenv_).conf1).projectMainIdx, cache, (*colonenv_).conf1);
	{
		if (!(ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__4NQNwjts5pclqjg2wHmDug((*(*colonenv_).conf1).projectFull, cache, (*colonenv_).conf1, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	nimZeroMem((void*)(&T5_), sizeof(tyProc__XtNNqpdSSaHFEnbiw4OQrw));
	T5_.ClP_0 = colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA; T5_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*d).Sup.onTestSnippet.ClE_0), T5_.ClE_0);
	(*d).Sup.onTestSnippet.ClP_0 = T5_.ClP_0;
	(*d).Sup.hasToc = NIM_TRUE;
	generateJson__aCcnJCcOFu8Y1ZdiDOUa6Q(d, ast, NIM_TRUE);
	json = (*d).jArray;
	T6_ = (NimStringDesc*)0;
	T6_ = pretty__6ucoq7dFiVhOGmHlWNWbTg(json, ((NI) 2));
	content = rope__yShmEg9cffWxI7s5XzEKBow(T6_);
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA9_;
		writeRope__FwuzOBq6SLlanVUstm8q9cA(__stdoutp, content);
	}
	goto LA7_;
	LA9_: ;
	{
		NimStringDesc* filename;
		filename = getOutFile__wyg2NQihYStyX9aXfJMkKlg((*colonenv_).conf1, (*(*colonenv_).conf1).projectName, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_217));
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(content, filename);
			if (!!(T14_)) goto LA15_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), filename, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_218, NIM_FALSE);
		}
		LA15_: ;
	}
	LA7_: ;
	}BeforeRet_: ;
}
static N_NIMCALL(void, Marker_tyRef__sHJ3bK9btAJ66R8tJi9bFYHg)(void* p, NI op) {
	tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ* a;
	a = (tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*)p;
	nimGCvisit((void*)(*a).conf1, op);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA_2)(tyObject_RstGenerator__yF9cB1II0vYb2F0YKmIiArg* d, NimStringDesc* filename, NimStringDesc* cmd, NI status, NimStringDesc* content, void* ClE_0) {
	tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ* colonenvP_;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T1_;
	colonenvP_ = (tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*) ClE_0;
	T1_ = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs((*colonenvP_).conf1, (*d).filename, ((NI) -1), ((NI) -1));
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenvP_).conf1, T1_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51), ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_215), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__5fUAZGW8WPeit3fZaQyNXA_220, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genTagsItem__tmOrGY09ab3EZGuwH5pi26w)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nameNode, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = getName__X4ox39cm9bzH8GS36cF3gOsQ(d, nameNode, ((NI) -1));
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 1);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_221));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateTags__MfiAsDFdBFUXqSzZDl4T9bg)(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	{
		{
			NIM_BOOL T4_;
			NimStringDesc* stripped;
			NimStringDesc* T7_;
			T4_ = (NIM_BOOL)0;
			T4_ = nsuStartsWith((*n).comment, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_66));
			if (!T4_) goto LA5_;
			T7_ = (NimStringDesc*)0;
			T7_ = substr__iGg0RIKceRvsmvq8FUHOEw((*n).comment, ((NI) 2));
			stripped = nsuStrip(T7_, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_85);
			add__yG4AKzsBRS1W4MANDlXQeg(r, stripped);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	{
		NimStringDesc* T9_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T9_ = (NimStringDesc*)0;
		T9_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T9_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		NimStringDesc* T11_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T11_ = (NimStringDesc*)0;
		T11_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T11_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	{
		NimStringDesc* T13_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T13_ = (NimStringDesc*)0;
		T13_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T13_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		NimStringDesc* T15_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T15_ = (NimStringDesc*)0;
		T15_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T15_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		NimStringDesc* T17_;
		T17_ = (NimStringDesc*)0;
		T17_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T17_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	{
		NimStringDesc* T19_;
		T19_ = (NimStringDesc*)0;
		T19_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T19_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		NimStringDesc* T21_;
		documentRaises__hkgQwVnJ9aLSGn9aEOV0GSag((*d).cache, n);
		T21_ = (NimStringDesc*)0;
		T21_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, n, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16));
		add__yG4AKzsBRS1W4MANDlXQeg(r, T21_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA25;
					i = i_2;
					{
						NimStringDesc* T30_;
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA28_;
						T30_ = (NimStringDesc*)0;
						T30_ = genTagsItem__tmOrGY09ab3EZGuwH5pi26w(d, (*n)._kind_6.sons->data[i], (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7) + (NI)((*n).kind - ((NI) 98))));
						add__yG4AKzsBRS1W4MANDlXQeg(r, T30_);
					}
					LA28_: ;
					i_2 += ((NI) 1);
				} LA25: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA34;
					i_3 = i_4;
					generateTags__MfiAsDFdBFUXqSzZDl4T9bg(d, (*n)._kind_6.sons->data[i_3], r);
					i_4 += ((NI) 1);
				} LA34: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			NIM_BOOL T38_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T41_;
			T38_ = (NIM_BOOL)0;
			T38_ = checkForFalse__SUIy9a9bqpDkoM66A6tppSaA_2((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			if (!!(T38_)) goto LA39_;
			T41_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T41_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[((NI) 0)]);
			generateTags__MfiAsDFdBFUXqSzZDl4T9bg(d, T41_, r);
		}
		LA39_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, commandTags__kgKjuaW9cX0ivwgfDPX9bbdA_5)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ* colonenv_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
	tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ* d;
	tyProc__XtNNqpdSSaHFEnbiw4OQrw T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content;
{	colonenv_ = (tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*)0;
	colonenv_ = (tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*) newObj((&NTI__sHJ3bK9btAJ66R8tJi9bFYHg_), sizeof(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ));
	(*colonenv_).Sup.m_type = (&NTI__pwUZDPkEs6xKitbL0Cjk9cQ_);
	asgnRef((void**) (&(*colonenv_).conf1), conf);
	ast = parseFile__HSBHiITVPKlv327uAC12yw((*(*colonenv_).conf1).projectMainIdx, cache, (*colonenv_).conf1);
	{
		if (!(ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	d = newDocumentor__4NQNwjts5pclqjg2wHmDug((*(*colonenv_).conf1).projectFull, cache, (*colonenv_).conf1, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_46), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	nimZeroMem((void*)(&T5_), sizeof(tyProc__XtNNqpdSSaHFEnbiw4OQrw));
	T5_.ClP_0 = colonanonymous___UTjUNeQ2pv3JQPQGAnBmrA_2; T5_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*d).Sup.onTestSnippet.ClE_0), T5_.ClE_0);
	(*d).Sup.onTestSnippet.ClP_0 = T5_.ClP_0;
	(*d).Sup.hasToc = NIM_TRUE;
	content = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	generateTags__MfiAsDFdBFUXqSzZDl4T9bg(d, ast, &content);
	{
		if (!(((*(*d).conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 23))&63U)))!=0)) goto LA8_;
		writeRope__FwuzOBq6SLlanVUstm8q9cA(__stdoutp, content);
	}
	goto LA6_;
	LA8_: ;
	{
		NimStringDesc* filename;
		filename = getOutFile__wyg2NQihYStyX9aXfJMkKlg((*colonenv_).conf1, (*(*colonenv_).conf1).projectName, ((NimStringDesc*) &TM__5fUAZGW8WPeit3fZaQyNXA_222));
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(content, filename);
			if (!!(T13_)) goto LA14_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*colonenv_).conf1, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), filename, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__5fUAZGW8WPeit3fZaQyNXA_223, NIM_FALSE);
		}
		LA14_: ;
	}
	LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_docgenDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_2_2[2];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_3_20[20];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_4_4[4];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_10_3[3];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_28_3[3];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_60_2[2];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_214_2[2];
static TNimNode* TM__5fUAZGW8WPeit3fZaQyNXA_219_2[2];
static TNimNode TM__5fUAZGW8WPeit3fZaQyNXA_0[46];

/* section: NIM_merge_TYPE_INIT3 */
NTI__bjZ39beKZKuX6eBUmfaMw0A_.size = sizeof(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A);
NTI__bjZ39beKZKuX6eBUmfaMw0A_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A);
NTI__bjZ39beKZKuX6eBUmfaMw0A_.kind = 17;
NTI__bjZ39beKZKuX6eBUmfaMw0A_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_2_2[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[1];
TM__5fUAZGW8WPeit3fZaQyNXA_0[1].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[1].offset = offsetof(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[1].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[1].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_2_2[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[2];
TM__5fUAZGW8WPeit3fZaQyNXA_0[2].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[2].offset = offsetof(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A, conf1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[2].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[2].name = "conf1";
TM__5fUAZGW8WPeit3fZaQyNXA_0[0].len = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[0].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[0].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_2_2[0];
NTI__bjZ39beKZKuX6eBUmfaMw0A_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[0];
NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_.size = sizeof(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*);
NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___bjZ39beKZKuX6eBUmfaMw0A*);
NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_.kind = 22;
NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_.base = (&NTI__bjZ39beKZKuX6eBUmfaMw0A_);
NTI__V3MI5pMOk7mgnWO9c9b9czAZQ_.marker = Marker_tyRef__V3MI5pMOk7mgnWO9c9b9czAZQ;
NTI__aItnR9bvqDIftcasLwUztVQ_.size = sizeof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ);
NTI__aItnR9bvqDIftcasLwUztVQ_.align = NIM_ALIGNOF(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ);
NTI__aItnR9bvqDIftcasLwUztVQ_.kind = 17;
NTI__aItnR9bvqDIftcasLwUztVQ_.base = (&NTI__yF9cB1II0vYb2F0YKmIiArg_);
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[4];
TM__5fUAZGW8WPeit3fZaQyNXA_0[4].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[4].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, modDesc);
TM__5fUAZGW8WPeit3fZaQyNXA_0[4].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[4].name = "modDesc";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[5];
TM__5fUAZGW8WPeit3fZaQyNXA_0[5].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[5].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, module);
TM__5fUAZGW8WPeit3fZaQyNXA_0[5].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[5].name = "module";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[2] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[6];
TM__5fUAZGW8WPeit3fZaQyNXA_0[6].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[6].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, modDeprecationMsg);
TM__5fUAZGW8WPeit3fZaQyNXA_0[6].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[6].name = "modDeprecationMsg";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[3] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[7];
NTI__bQohEW4Jw1ENvElOMs9bxmQ_.size = sizeof(tyArray__bQohEW4Jw1ENvElOMs9bxmQ);
NTI__bQohEW4Jw1ENvElOMs9bxmQ_.align = NIM_ALIGNOF(tyArray__bQohEW4Jw1ENvElOMs9bxmQ);
NTI__bQohEW4Jw1ENvElOMs9bxmQ_.kind = 16;
NTI__bQohEW4Jw1ENvElOMs9bxmQ_.base = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
NTI__bQohEW4Jw1ENvElOMs9bxmQ_.flags = 2;
TM__5fUAZGW8WPeit3fZaQyNXA_0[7].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[7].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, toc);
TM__5fUAZGW8WPeit3fZaQyNXA_0[7].typ = (&NTI__bQohEW4Jw1ENvElOMs9bxmQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[7].name = "toc";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[4] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[8];
TM__5fUAZGW8WPeit3fZaQyNXA_0[8].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[8].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, toc2);
TM__5fUAZGW8WPeit3fZaQyNXA_0[8].typ = (&NTI__bQohEW4Jw1ENvElOMs9bxmQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[8].name = "toc2";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[5] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[9];
TM__5fUAZGW8WPeit3fZaQyNXA_0[9].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[9].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, section);
TM__5fUAZGW8WPeit3fZaQyNXA_0[9].typ = (&NTI__bQohEW4Jw1ENvElOMs9bxmQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[9].name = "section";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[6] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[10];
NTI__TmA6vhsDrA5kGEbtiSS2wg_.size = sizeof(tyArray__TmA6vhsDrA5kGEbtiSS2wg);
NTI__TmA6vhsDrA5kGEbtiSS2wg_.align = NIM_ALIGNOF(tyArray__TmA6vhsDrA5kGEbtiSS2wg);
NTI__TmA6vhsDrA5kGEbtiSS2wg_.kind = 16;
NTI__TmA6vhsDrA5kGEbtiSS2wg_.base = (&NTI__9bHTqygodsMdJIfIXO86mVg_);
NTI__TmA6vhsDrA5kGEbtiSS2wg_.flags = 2;
TM__5fUAZGW8WPeit3fZaQyNXA_0[10].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[10].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, tocTable);
TM__5fUAZGW8WPeit3fZaQyNXA_0[10].typ = (&NTI__TmA6vhsDrA5kGEbtiSS2wg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[10].name = "tocTable";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[7] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[11];
TM__5fUAZGW8WPeit3fZaQyNXA_0[11].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[11].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, indexValFilename);
TM__5fUAZGW8WPeit3fZaQyNXA_0[11].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[11].name = "indexValFilename";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[8] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[12];
TM__5fUAZGW8WPeit3fZaQyNXA_0[12].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[12].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, analytics);
TM__5fUAZGW8WPeit3fZaQyNXA_0[12].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[12].name = "analytics";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[9] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[13];
TM__5fUAZGW8WPeit3fZaQyNXA_0[13].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[13].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, seenSymbols);
TM__5fUAZGW8WPeit3fZaQyNXA_0[13].typ = (&NTI__n9cmoMXcDs47wYDFGEXuCfw_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[13].name = "seenSymbols";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[10] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[14];
TM__5fUAZGW8WPeit3fZaQyNXA_0[14].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[14].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, jArray);
TM__5fUAZGW8WPeit3fZaQyNXA_0[14].typ = (&NTI__zfzzuQ8txrdZAYK0WGWpHg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[14].name = "jArray";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[11] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[15];
TM__5fUAZGW8WPeit3fZaQyNXA_0[15].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[15].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, types);
TM__5fUAZGW8WPeit3fZaQyNXA_0[15].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[15].name = "types";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[12] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[16];
TM__5fUAZGW8WPeit3fZaQyNXA_0[16].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[16].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, isPureRst);
TM__5fUAZGW8WPeit3fZaQyNXA_0[16].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[16].name = "isPureRst";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[13] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[17];
TM__5fUAZGW8WPeit3fZaQyNXA_0[17].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[17].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, conf);
TM__5fUAZGW8WPeit3fZaQyNXA_0[17].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[17].name = "conf";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[14] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[18];
TM__5fUAZGW8WPeit3fZaQyNXA_0[18].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[18].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, cache);
TM__5fUAZGW8WPeit3fZaQyNXA_0[18].typ = (&NTI__lnkYNZP9asc88UfiEGjLrbA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[18].name = "cache";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[15] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[19];
TM__5fUAZGW8WPeit3fZaQyNXA_0[19].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[19].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, exampleCounter);
TM__5fUAZGW8WPeit3fZaQyNXA_0[19].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[19].name = "exampleCounter";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[16] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[20];
TM__5fUAZGW8WPeit3fZaQyNXA_0[20].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[20].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, emitted);
TM__5fUAZGW8WPeit3fZaQyNXA_0[20].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[20].name = "emitted";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[17] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[21];
TM__5fUAZGW8WPeit3fZaQyNXA_0[21].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[21].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, thisDir);
TM__5fUAZGW8WPeit3fZaQyNXA_0[21].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[21].name = "thisDir";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[18] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[22];
NTI__fmIjjJC59a002tPvpD7yKSQ_.size = sizeof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ);
NTI__fmIjjJC59a002tPvpD7yKSQ_.align = NIM_ALIGNOF(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ);
NTI__fmIjjJC59a002tPvpD7yKSQ_.kind = 18;
NTI__fmIjjJC59a002tPvpD7yKSQ_.base = 0;
NTI__fmIjjJC59a002tPvpD7yKSQ_.flags = 2;
TM__5fUAZGW8WPeit3fZaQyNXA_4_4[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[24];
TM__5fUAZGW8WPeit3fZaQyNXA_0[24].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[24].offset = offsetof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ, rdoccmd);
TM__5fUAZGW8WPeit3fZaQyNXA_0[24].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[24].name = "rdoccmd";
TM__5fUAZGW8WPeit3fZaQyNXA_4_4[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[25];
TM__5fUAZGW8WPeit3fZaQyNXA_0[25].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[25].offset = offsetof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ, docCmd);
TM__5fUAZGW8WPeit3fZaQyNXA_0[25].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[25].name = "docCmd";
TM__5fUAZGW8WPeit3fZaQyNXA_4_4[2] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[26];
TM__5fUAZGW8WPeit3fZaQyNXA_0[26].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[26].offset = offsetof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ, code);
TM__5fUAZGW8WPeit3fZaQyNXA_0[26].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[26].name = "code";
TM__5fUAZGW8WPeit3fZaQyNXA_4_4[3] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[27];
TM__5fUAZGW8WPeit3fZaQyNXA_0[27].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[27].offset = offsetof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ, index);
TM__5fUAZGW8WPeit3fZaQyNXA_0[27].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[27].name = "index";
TM__5fUAZGW8WPeit3fZaQyNXA_0[23].len = 4; TM__5fUAZGW8WPeit3fZaQyNXA_0[23].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[23].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_4_4[0];
NTI__fmIjjJC59a002tPvpD7yKSQ_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[23];
NTI__12SjKZyLpJKBYPLZVcoGLA_.size = sizeof(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*);
NTI__12SjKZyLpJKBYPLZVcoGLA_.align = NIM_ALIGNOF(tyObject_ExampleGroupcolonObjectType___fmIjjJC59a002tPvpD7yKSQ*);
NTI__12SjKZyLpJKBYPLZVcoGLA_.kind = 22;
NTI__12SjKZyLpJKBYPLZVcoGLA_.base = (&NTI__fmIjjJC59a002tPvpD7yKSQ_);
NTI__12SjKZyLpJKBYPLZVcoGLA_.flags = 2;
NTI__12SjKZyLpJKBYPLZVcoGLA_.marker = Marker_tyRef__12SjKZyLpJKBYPLZVcoGLA;
TM__5fUAZGW8WPeit3fZaQyNXA_0[22].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[22].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, exampleGroups);
TM__5fUAZGW8WPeit3fZaQyNXA_0[22].typ = (&NTI__82OdS5RTON4FvDz04E3cFw_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[22].name = "exampleGroups";
TM__5fUAZGW8WPeit3fZaQyNXA_3_20[19] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[28];
TM__5fUAZGW8WPeit3fZaQyNXA_0[28].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[28].offset = offsetof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ, wroteSupportFiles);
TM__5fUAZGW8WPeit3fZaQyNXA_0[28].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[28].name = "wroteSupportFiles";
TM__5fUAZGW8WPeit3fZaQyNXA_0[3].len = 20; TM__5fUAZGW8WPeit3fZaQyNXA_0[3].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[3].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_3_20[0];
NTI__aItnR9bvqDIftcasLwUztVQ_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[3];
NTI__ZoZ1pRtzmEiOBBpTrqMZHA_.size = sizeof(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*);
NTI__ZoZ1pRtzmEiOBBpTrqMZHA_.align = NIM_ALIGNOF(tyObject_TDocumentor__aItnR9bvqDIftcasLwUztVQ*);
NTI__ZoZ1pRtzmEiOBBpTrqMZHA_.kind = 22;
NTI__ZoZ1pRtzmEiOBBpTrqMZHA_.base = (&NTI__aItnR9bvqDIftcasLwUztVQ_);
NTI__ZoZ1pRtzmEiOBBpTrqMZHA_.marker = Marker_tyRef__ZoZ1pRtzmEiOBBpTrqMZHA;
NTI__o58RO4LYcVDmmDyTJ0uhVw_.size = sizeof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw);
NTI__o58RO4LYcVDmmDyTJ0uhVw_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw);
NTI__o58RO4LYcVDmmDyTJ0uhVw_.kind = 17;
NTI__o58RO4LYcVDmmDyTJ0uhVw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_10_3[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[30];
TM__5fUAZGW8WPeit3fZaQyNXA_0[30].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[30].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[30].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[30].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_10_3[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[31];
TM__5fUAZGW8WPeit3fZaQyNXA_0[31].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[31].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw, d1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[31].typ = (&NTI__aItnR9bvqDIftcasLwUztVQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[31].name = "d1";
TM__5fUAZGW8WPeit3fZaQyNXA_10_3[2] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[32];
TM__5fUAZGW8WPeit3fZaQyNXA_0[32].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[32].offset = offsetof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw, outp2);
TM__5fUAZGW8WPeit3fZaQyNXA_0[32].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[32].name = "outp2";
TM__5fUAZGW8WPeit3fZaQyNXA_0[29].len = 3; TM__5fUAZGW8WPeit3fZaQyNXA_0[29].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[29].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_10_3[0];
NTI__o58RO4LYcVDmmDyTJ0uhVw_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[29];
NTI__ihldeoD3pGN083UxUgAFWg_.size = sizeof(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*);
NTI__ihldeoD3pGN083UxUgAFWg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___o58RO4LYcVDmmDyTJ0uhVw*);
NTI__ihldeoD3pGN083UxUgAFWg_.kind = 22;
NTI__ihldeoD3pGN083UxUgAFWg_.base = (&NTI__o58RO4LYcVDmmDyTJ0uhVw_);
NTI__ihldeoD3pGN083UxUgAFWg_.marker = Marker_tyRef__ihldeoD3pGN083UxUgAFWg;
NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_.size = sizeof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg);
NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg);
NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_.kind = 17;
NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_28_3[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[34];
TM__5fUAZGW8WPeit3fZaQyNXA_0[34].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[34].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[34].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[34].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_28_3[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[35];
TM__5fUAZGW8WPeit3fZaQyNXA_0[35].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[35].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg, conf1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[35].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[35].name = "conf1";
TM__5fUAZGW8WPeit3fZaQyNXA_28_3[2] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[36];
TM__5fUAZGW8WPeit3fZaQyNXA_0[36].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[36].offset = offsetof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg, file22);
TM__5fUAZGW8WPeit3fZaQyNXA_0[36].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[36].name = "file22";
TM__5fUAZGW8WPeit3fZaQyNXA_0[33].len = 3; TM__5fUAZGW8WPeit3fZaQyNXA_0[33].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[33].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_28_3[0];
NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[33];
NTI__c2g79crEiD9bqYYWD2mguKAA_.size = sizeof(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*);
NTI__c2g79crEiD9bqYYWD2mguKAA_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___CvM9bpa9bcUSX0YhTrauQ9bEg*);
NTI__c2g79crEiD9bqYYWD2mguKAA_.kind = 22;
NTI__c2g79crEiD9bqYYWD2mguKAA_.base = (&NTI__CvM9bpa9bcUSX0YhTrauQ9bEg_);
NTI__c2g79crEiD9bqYYWD2mguKAA_.marker = Marker_tyRef__c2g79crEiD9bqYYWD2mguKAA;
NTI__4EIPlYmwmzq4foglAJUuOg_.size = sizeof(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg);
NTI__4EIPlYmwmzq4foglAJUuOg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg);
NTI__4EIPlYmwmzq4foglAJUuOg_.kind = 17;
NTI__4EIPlYmwmzq4foglAJUuOg_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_60_2[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[38];
TM__5fUAZGW8WPeit3fZaQyNXA_0[38].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[38].offset = offsetof(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[38].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[38].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_60_2[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[39];
TM__5fUAZGW8WPeit3fZaQyNXA_0[39].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[39].offset = offsetof(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg, conf1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[39].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[39].name = "conf1";
TM__5fUAZGW8WPeit3fZaQyNXA_0[37].len = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[37].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[37].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_60_2[0];
NTI__4EIPlYmwmzq4foglAJUuOg_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[37];
NTI__QWqhrbgPD84P9aNEkDLWGug_.size = sizeof(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*);
NTI__QWqhrbgPD84P9aNEkDLWGug_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_parseRst___4EIPlYmwmzq4foglAJUuOg*);
NTI__QWqhrbgPD84P9aNEkDLWGug_.kind = 22;
NTI__QWqhrbgPD84P9aNEkDLWGug_.base = (&NTI__4EIPlYmwmzq4foglAJUuOg_);
NTI__QWqhrbgPD84P9aNEkDLWGug_.marker = Marker_tyRef__QWqhrbgPD84P9aNEkDLWGug;
NTI__jwayR6zaxkEYAMp3GS09bOA_.size = sizeof(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA);
NTI__jwayR6zaxkEYAMp3GS09bOA_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA);
NTI__jwayR6zaxkEYAMp3GS09bOA_.kind = 17;
NTI__jwayR6zaxkEYAMp3GS09bOA_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_214_2[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[41];
TM__5fUAZGW8WPeit3fZaQyNXA_0[41].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[41].offset = offsetof(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[41].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[41].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_214_2[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[42];
TM__5fUAZGW8WPeit3fZaQyNXA_0[42].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[42].offset = offsetof(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA, conf1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[42].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[42].name = "conf1";
TM__5fUAZGW8WPeit3fZaQyNXA_0[40].len = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[40].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[40].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_214_2[0];
NTI__jwayR6zaxkEYAMp3GS09bOA_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[40];
NTI__SNRao7b4hOZKnbHC8HR0gg_.size = sizeof(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*);
NTI__SNRao7b4hOZKnbHC8HR0gg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___jwayR6zaxkEYAMp3GS09bOA*);
NTI__SNRao7b4hOZKnbHC8HR0gg_.kind = 22;
NTI__SNRao7b4hOZKnbHC8HR0gg_.base = (&NTI__jwayR6zaxkEYAMp3GS09bOA_);
NTI__SNRao7b4hOZKnbHC8HR0gg_.marker = Marker_tyRef__SNRao7b4hOZKnbHC8HR0gg;
NTI__pwUZDPkEs6xKitbL0Cjk9cQ_.size = sizeof(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ);
NTI__pwUZDPkEs6xKitbL0Cjk9cQ_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ);
NTI__pwUZDPkEs6xKitbL0Cjk9cQ_.kind = 17;
NTI__pwUZDPkEs6xKitbL0Cjk9cQ_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__5fUAZGW8WPeit3fZaQyNXA_219_2[0] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[44];
TM__5fUAZGW8WPeit3fZaQyNXA_0[44].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[44].offset = offsetof(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ, colonstate_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[44].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[44].name = ":state";
TM__5fUAZGW8WPeit3fZaQyNXA_219_2[1] = &TM__5fUAZGW8WPeit3fZaQyNXA_0[45];
TM__5fUAZGW8WPeit3fZaQyNXA_0[45].kind = 1;
TM__5fUAZGW8WPeit3fZaQyNXA_0[45].offset = offsetof(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ, conf1);
TM__5fUAZGW8WPeit3fZaQyNXA_0[45].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__5fUAZGW8WPeit3fZaQyNXA_0[45].name = "conf1";
TM__5fUAZGW8WPeit3fZaQyNXA_0[43].len = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[43].kind = 2; TM__5fUAZGW8WPeit3fZaQyNXA_0[43].sons = &TM__5fUAZGW8WPeit3fZaQyNXA_219_2[0];
NTI__pwUZDPkEs6xKitbL0Cjk9cQ_.node = &TM__5fUAZGW8WPeit3fZaQyNXA_0[43];
NTI__sHJ3bK9btAJ66R8tJi9bFYHg_.size = sizeof(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*);
NTI__sHJ3bK9btAJ66R8tJi9bFYHg_.align = NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___pwUZDPkEs6xKitbL0Cjk9cQ*);
NTI__sHJ3bK9btAJ66R8tJi9bFYHg_.kind = 22;
NTI__sHJ3bK9btAJ66R8tJi9bFYHg_.base = (&NTI__pwUZDPkEs6xKitbL0Cjk9cQ_);
NTI__sHJ3bK9btAJ66R8tJi9bFYHg_.marker = Marker_tyRef__sHJ3bK9btAJ66R8tJi9bFYHg;
}

