/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q;
typedef struct tyObject_Operators__apNm0zcYroUpNRird62c9aQ tyObject_Operators__apNm0zcYroUpNRird62c9aQ;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ tySequence__8Np6tlClE5az1CyqZdN19bQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA;
typedef struct tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug;
typedef struct tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag;
typedef struct tySequence__7PsCyIDXDb8nGSU5UlS9cAA tySequence__7PsCyIDXDb8nGSU5UlS9cAA;
typedef struct tySequence__QAWA9c8ge5HfZnhFNlb9c9ajA tySequence__QAWA9c8ge5HfZnhFNlb9c9ajA;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_VarIndex__9bUY0kR5KFdp9cLhJiAMwmwA tyObject_VarIndex__9bUY0kR5KFdp9cLhJiAMwmwA;
typedef struct tyObject_Connection__EevFKe104MtQGkxxkLKkgg tyObject_Connection__EevFKe104MtQGkxxkLKkgg;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3AyzgbaZVZwTUW9bffBh5Vw) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
struct tyObject_Operators__apNm0zcYroUpNRird62c9aQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLe;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLt;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opAnd;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opOr;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opIsNil;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opEq;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opAdd;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opSub;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opMul;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opDiv;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opLen;
};
struct tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q {
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* s;
tyObject_Operators__apNm0zcYroUpNRird62c9aQ o;
NIM_BOOL beSmart;
};
struct tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exc;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tags;
NI bottom;
NI inTryStmt;
NI inExceptOrFinallyStmt;
NI leftPartOfAsgn;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ownerModule;
tySequence__qwqHTkRvwhrRyENtudHQ7g* init;
tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q guards;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* locked;
NIM_BOOL gcUnsafe;
NIM_BOOL isRecursive;
NIM_BOOL isTopLevel;
NIM_BOOL hasSideEffect;
NIM_BOOL inEnforcedGcSafe;
NIM_BOOL hasDangerousAssign;
NIM_BOOL inEnforcedNoSideEffects;
NI16 maxLockLevel;
NI16 currLockLevel;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg currOptions;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw;
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NU8 tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw[21];
typedef NU8 tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA;
typedef NimStringDesc* tyArray__JXkBzVsE9bvmcpuZvrueLVg[6];
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA {
NI oldLocked;
NI16 oldLockLevel;
NIM_BOOL enforcedGcSafety;
NIM_BOOL enforceNoSideEffects;
NI oldExc;
NI oldTags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exc;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tags;
};
typedef NU8 tySet_tyEnum_SubgraphFlag__mxQvR0HTC631bhUr6jBDDw;
struct tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q mutatedHere;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q connectedVia;
tySet_tyEnum_SubgraphFlag__mxQvR0HTC631bhUr6jBDDw flags;
NI maxMutation;
NI minConnection;
tySequence__qwqHTkRvwhrRyENtudHQ7g* mutations;
};
typedef NU8 tySet_tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg;
typedef NU8 tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg;
struct tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag {
NI abstractTime;
tySequence__7PsCyIDXDb8nGSU5UlS9cAA* s;
tySequence__QAWA9c8ge5HfZnhFNlb9c9ajA* graphs;
tySet_tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg goals;
NIM_BOOL unanalysableMutation;
NI inAsgnSource;
NI inConstructor;
NI inNoSideEffectSection;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_VarIndexKind__TA6PMQGIDoHplflSd7kZxA;
struct tyObject_Connection__EevFKe104MtQGkxxkLKkgg {
tyEnum_VarIndexKind__TA6PMQGIDoHplflSd7kZxA kind;
union{
NI parent;
NI graphIndex;
};
};
typedef NU8 tySet_tyEnum_VarFlag__F7v3qXI9a6XJkYmtFhBnwUQ;
struct tyObject_VarIndex__9bUY0kR5KFdp9cLhJiAMwmwA {
tyObject_Connection__EevFKe104MtQGkxxkLKkgg con;
tySet_tyEnum_VarFlag__F7v3qXI9a6XJkYmtFhBnwUQ flags;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
NI reassignedTo;
NI aliveStart;
NI aliveEnd;
tySequence__qwqHTkRvwhrRyENtudHQ7g* borrowsFrom;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__8Np6tlClE5az1CyqZdN19bQ {
  TGenericSeq Sup;
  tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__7PsCyIDXDb8nGSU5UlS9cAA {
  TGenericSeq Sup;
  tyObject_VarIndex__9bUY0kR5KFdp9cLhJiAMwmwA data[SEQ_DECL_SIZE];
};
struct tySequence__QAWA9c8ge5HfZnhFNlb9c9ajA {
  TGenericSeq Sup;
  tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, effectSpec__bT2fsf3zXYRpjYdeea19aAA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw effectType);
N_LIB_PRIVATE N_NIMCALL(void, checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* real, NimStringDesc* msg, NIM_BOOL hints, tyProc__3AyzgbaZVZwTUW9bffBh5Vw effectPredicate, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hintsArg);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* real);
N_LIB_PRIVATE N_NIMCALL(NI, safeInheritanceDiff__1dM2iQB5qStJfnn3684ijQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, excType__9cjUze5Qh6q4dDt6ZAfifVg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEbase__1YNMkqhT4DZf7hJB9cvjIhQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___75vsOXLrqmx5LmVlMWaymw)(NI16 x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasRealBody__cg1RHKu9b2GcnK3fmjpRj2Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, initEffects__pOwRnuq5NhYw7g0tfye2Ww)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* t, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, initOperators__3Mq69aIkPINTsOZ4I5g1jZA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, track__BxqWoS9czp4uFup6HfSkCeA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, useVar__v49b6RRBfUBabmq9bN9c9bCQLA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocalVar__YlEQSKBgYhMDInPoOkeWuQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(NIM_BOOL, contains__RQ7v5MK0dOhApn0wj6F1iAsystem)(NI* a, NI aLen_0, NI item);
static N_INLINE(NI, find__9cqYOCx35UdU7TYhesWvYeAsystem)(NI* a, NI aLen_0, NI item);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, useVarNoInitCheck__njQS7vGGH2ZwpdWseR6sDg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, guardGlobal__uVcH3kEIXSlUY0aC9bdqVgg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard);
static N_INLINE(NIM_BOOL, isGCedMem__nPImuPGZIdcrAfCNyf4oxAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__fT360j3udq5hTrgFOZDAIA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* reason);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__3isNyHKb0U1OCnClmflXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(void, addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefectException__YPjOkGV9axAnGR3UfLeWZ1g_10)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, throws__w7qDRJXgbGJ5Q2Q6r7yA9cw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createRaise__2aachO6llLVwCKPPPmABpQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void, trackCall__BxqWoS9czp4uFup6HfSkCeA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstExpr__A7gcXCy5E3uGBy5F37NoHA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, mergeLockLevels__HPKPawBmCdQfQSjvglxVug)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI16 lockLevel);
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__y9cx8hmVKlu7WWOs4onCwGQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, mergeRaises__Rh0mhUmoZCBMPFUCtmsUAA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(void, mergeTags__Rh0mhUmoZCBMPFUCtmsUAA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(void, addTag__hDlm2Cal6ET3nLFp2KWZCw_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createTag__2aachO6llLVwCKPPPmABpQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(void, warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(NIM_BOOL, isNoEffectList__heeP9bq2P1AFVYhYVYTOP0gsempass2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isForwardedProc__tEyNhG8jDpteKMTOJUposQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isIndirectCall__zEd2da81SkcO4ecZFErcPQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, assumeTheWorst__o1siCCwJ4v3zTcbZrQcFkA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, importedFromC__tEyNhG8jDpteKMTOJUposQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* reason);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(void, trackOperandForIndirectCall__5bSCYZG1o5kKwugYUxHjSQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caller);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isTrival__MqKxDwYfGT3leajDQaUrBwsempass2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caller);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedProcVar__zEd2da81SkcO4ecZFErcPQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, invalidateFacts__no3iuruVlFxE0wQ8HA9b4ZA)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(void, makeVolatile__wBsQA9b2lpv7DoSOuGohRUAsempass2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType);
N_LIB_PRIVATE N_NIMCALL(void, procVarCheck__zRRYqNfXt0mVIBCxaEomVg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAddrNode__OTZyO2oJpdYpHVBZuRXuRQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__3PkUvehQ5keciM9cue9ayMTw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kinds);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA, impliesNotNil__x6MUw3H3bS3WZ5DYhXX61Q)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, paramType__JPWM4hjtH3zx9bI8pJf7Xsg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op, NI i);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, initVarViaNew__v49b6RRBfUBabmq9bN9c9bCQLA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, initVar__9cnMyHEtl3Vw3Eik8EejmRA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL volatileCheck);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__5TEFk9a9cl6Se9bkEpUPsbTTg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx);
N_LIB_PRIVATE N_NIMCALL(void, checkLe__7CUcxkdNhLZqHv8xsVpwiQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA, proveLe__gquZ4TuLCn9anC5O4OWI4Og)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowBound__Esza4n69a5U9bzlDTK04VArg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, highBound__9cbEq5HLZRHFpEqTjJwMYDA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_Operators__apNm0zcYroUpNRird62c9aQ* o);
static N_INLINE(NI, find__jfydvRaAcnbXyRZInRGcjwsystem)(tyArray__JXkBzVsE9bvmcpuZvrueLVg a, NimStringDesc* item);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, checkForSink__2juoX30KP12DlcWVrUGDWw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, add__9a8CdZqChTyqzq5bpSL3TzA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, guardDotAccess__v49b6RRBfUBabmq9bN9c9bCQLA_3)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTree__Uv9a9aANFtV79cIvUP5jEeyVA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(void, checkFieldAccess__gGwSETIBbm3kg36plDGFGg)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, trackTryStmt__BxqWoS9czp4uFup6HfSkCeA_3)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addToIntersection__GUjE16ZHjCWJzHju9cSiIyw)(tySequence__8Np6tlClE5az1CyqZdN19bQ** inter, NI s);
N_LIB_PRIVATE N_NIMCALL(void, catchesAll__6VQZamBo8lrDCYlUIh7Ojg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, catches__2xMHinEcocVG5PHlkSFsaQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* e);
N_LIB_PRIVATE N_NIMCALL(void, trackPragmaStmt__BxqWoS9czp4uFup6HfSkCeA_4)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, listEffects__xF9av1b77SGV0Yx9cMchZI5w)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a);
N_LIB_PRIVATE N_NIMCALL(void, addAsgnFact__0CHSuARDyWZ57Xrosqy78w)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(void, trackCase__BxqWoS9czp4uFup6HfSkCeA_5)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, interestingCaseExpr__Cjb9am4YBBe69cf2PXGW7teQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m);
N_LIB_PRIVATE N_NIMCALL(void, addCaseBranchFacts__c6dE6J2nt777cGY9brPJUJA)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, breaksBlock__tEyNhG8jDpteKMTOJUposQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, trackIf__BxqWoS9czp4uFup6HfSkCeA_6)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addFact__ybuIey7mglQLm61kxh9aaLg)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nn);
N_LIB_PRIVATE N_NIMCALL(void, addFactNeg__no3iuruVlFxE0wQ8HA9b4ZA_2)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, trackBlock__BxqWoS9czp4uFup6HfSkCeA_7)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__9cP6JNeOKqczaXCI4Zo4SBQ_5)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op);
N_LIB_PRIVATE N_NIMCALL(void, addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(void, addFactLt__i9aAoMzJNp9aw6KruJgPZ0Ng_2)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(void, addDiscriminantFact__no3iuruVlFxE0wQ8HA9b4ZA_3)(tyObject_TModel__yUzvq5GhzqHyDCdSXqIv1Q* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, createBlockContext__TopuOXu0dZKMo9cbsDb040g)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* Result);
N_LIB_PRIVATE N_NIMCALL(void, lockLocations__lHiCtldbW2F1ISjGLbel5Q)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma);
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__89axjo8eKrzLzKfec1W1U5g)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, castBlock__N7knXaDQwsgL82WukZJVdw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc);
N_LIB_PRIVATE N_NIMCALL(void, applyBlockContext__mGV64s49b4A3mxXAc5kqSLw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc);
N_LIB_PRIVATE N_NIMCALL(void, unapplyBlockContext__mGV64s49b4A3mxXAc5kqSLw_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc);
N_LIB_PRIVATE N_NIMCALL(void, checkRange__rXwUdIKp4I5JvdsIihJhKA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSinkTypeForParam__YPjOkGV9axAnGR3UfLeWZ1g_11)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
static N_INLINE(NIM_BOOL, isClosure__EhCVbB6PynSh7XFAFVMiJA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, propSpec__bT2fsf3zXYRpjYdeea19aAA_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw effectType);
N_LIB_PRIVATE N_NIMCALL(void, patchResult__T8bpelbsT0Sbtnlr0eIYAA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, computeGraphPartitions__8NgHqAHLnGXB2Yk7BCbglQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tySet_tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg goals, tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSideEffect__o7Sjy4adraWNg67FeaH7Nw)(tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag* c, tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug* info);
N_LIB_PRIVATE N_NIMCALL(void, checkBorrowedLocations__c6SN0feu9c665e6zxXN9bWMA)(tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag* par, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config);
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__lVcAQCWPXcnHjv24XqLtlg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL onlyWarning, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__EXjdAOBUD8wdsldqC70dag)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL onlyWarning, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* cycleCheck, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___Ksyu2fr8gIEvUey9aJnQyIw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug* g);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_3, "/home/runner/work/nightlies/nightlies/nim/compiler/sempass2.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_2 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1161),
((NI) 16)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_4, "\'$1\' cannot raise \'$2\'", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_5 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1167),
((NI) 15)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_6, "can raise an unlisted exception: ", 33);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_7, "Exception", 9);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_8, "can have an unlisted effect: ", 29);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_9, "base method is GC-safe, but \'$1\' is not", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_10 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1185),
((NI) 14)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_11, "base method has lock level $1, but dispatcher has $2", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_12 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1194),
((NI) 13)}
;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
extern TNimType NTI__qwqHTkRvwhrRyENtudHQ7g_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_13 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 283),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_14 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 285),
((NI) 15)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_15, "unguarded access: ", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_16 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 143),
((NI) 14)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_17, "expected lock level < ", 22);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_18, " but got lock level ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_19 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 484),
((NI) 17)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_20, "RootEffect", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_21 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 208),
((NI) 9)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_22, "(", 1);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_23, ", ", 2);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_24, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_25 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 563),
((NI) 19)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_26, " is not GC safe", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_27 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 601),
((NI) 16)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_28, "\'$1\' cannot be passed to a procvar", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_29 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 508),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__wkTG4eaV3t1uo3x09apjcwA_30 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00,
0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_31, "cannot prove \'$1\' is not nil", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_32 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 531),
((NI) 15)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_33, "\'$1\' is provably nil", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_34 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 534),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_35 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 798),
((NI) 17)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_36, "cannot prove: ", 14);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_37, " <= ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_38 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 716),
((NI) 11)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_39, "can prove: ", 11);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_40, " > ", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_41 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 721),
((NI) 11)}
;
extern NIM_CONST tyArray__JXkBzVsE9bvmcpuZvrueLVg AttachedOpToStr__gGSR5Ulzx6g21lOISgt9aWA;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_42, "=", 1);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_43, "could not turn \'$1\' to a sink parameter", 39);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_45, "/home/runner/work/nightlies/nightlies/nim/compiler/sinkparamete"
"r_inference.nim", 78);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_44 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_45),
((NI) 50),
((NI) 15)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_46, "invalid guard field: ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_47 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 166),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_48 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 179),
((NI) 14)}
;
extern TNimType NTI__8Np6tlClE5az1CyqZdN19bQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_49 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 361),
((NI) 33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_50 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 362),
((NI) 33)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_51, "_", 1);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_52, "..", 2);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_53, "countup", 7);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_54, "countdown", 9);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_55, "..<", 3);
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_56, "locks pragma without argument", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_57 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 114),
((NI) 14)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_58, "invalid lock level: ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_59 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 121),
((NI) 18)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_60, "multi-lock requires the same static lock level for every operan"
"d", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_61 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 124),
((NI) 18)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_62, "invalid nested locking", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_63 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 130),
((NI) 16)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_64, "invalid pragma block: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_65 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 897),
((NI) 14)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_66, "result", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_67 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1284),
((NI) 13)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_68, "routine has no return type, but .requires contains \'result\'", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_69 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 706),
((NI) 16)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_70, "\'$#\' is not GC-safe as it accesses \'$#\' which is a global using"
" GC\'ed memory", 76);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_71 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 239),
((NI) 13)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_72, "\'$#\' is not GC-safe as it calls \'$#\'", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_73 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 246),
((NI) 13)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_74, "\'$#\' is not GC-safe as it performs an indirect call via \'$#\'", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_75 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 250),
((NI) 13)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_76, "\'$#\' is not GC-safe as it performs an indirect call here", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_77 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 254),
((NI) 13)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_78, "\'$1\' can have side effects", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_79 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1330),
((NI) 16)}
;
STRING_LITERAL(TM__wkTG4eaV3t1uo3x09apjcwA_80, "declared lock level is $1, but real lock level is $2", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_81 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1339),
((NI) 11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__wkTG4eaV3t1uo3x09apjcwA_82 = {((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_3),
((NI) 1207),
((NI) 19)}
;
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__wkTG4eaV3t1uo3x09apjcwA_83 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x80, 0x1f, 0x04, 0x04, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x80, 0x00}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* real, NimStringDesc* msg, NIM_BOOL hints, tyProc__3AyzgbaZVZwTUW9bffBh5Vw effectPredicate, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hintsArg) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg used;
	nimZeroMem((void*)(&used), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&used));
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
		r = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(real);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					r = (*real)._kind_6.sons->data[i];
					{
						NimStringDesc* T14_;
						NimStringDesc* T15_;
						{
							NI s;
							NI colontmp__2;
							NI i_3;
							s = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(spec);
							i_3 = ((NI) 0);
							{
								while (1) {
									if (!(i_3 < colontmp__2)) goto LA8;
									s = i_3;
									{
										NIM_BOOL T11_;
										T11_ = (NIM_BOOL)0;
										T11_ = effectPredicate(g, (*spec)._kind_6.sons->data[s], r);
										if (!T11_) goto LA12_;
										incl__jENnK9c9bPE73pKmo2vYjpqg((&used), s);
										goto LA5;
									}
									LA12_: ;
									i_3 += ((NI) 1);
								} LA8: ;
							}
						}
						pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*g).config, (*spec).info, ((NimStringDesc*) NIM_NIL));
						T14_ = (NimStringDesc*)0;
						T15_ = (NimStringDesc*)0;
						T15_ = typeToString__QlvraUan7WbHowhAbvDvdA((*r).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
						T14_ = rawNewString((msg ? msg->Sup.len : 0) + (T15_ ? T15_->Sup.len : 0) + 0);
appendString(T14_, msg);
appendString(T14_, T15_);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*r).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_2, NIM_FALSE);
						popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*g).config);
					} LA5: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		if (!hints) goto LA18_;
		{
			NI s_2;
			NI colontmp__3;
			NI i_4;
			s_2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(spec);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__3)) goto LA22;
					s_2 = i_4;
					{
						NIM_BOOL T25_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T28_;
						NimStringDesc* T29_;
						T25_ = (NIM_BOOL)0;
						T25_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&used), s_2);
						if (!!(T25_)) goto LA26_;
						nimZeroMem((void*)T28_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T28_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(hintsArg, 0);
						T28_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*spec)._kind_6.sons->data[s_2], 0);
						T29_ = (NimStringDesc*)0;
						T29_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_4), T28_, 2);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*(*spec)._kind_6.sons->data[s_2]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 57), T29_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_5, NIM_FALSE);
					}
					LA26_: ;
					i_4 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	LA18_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEbase__1YNMkqhT4DZf7hJB9cvjIhQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ(g, info, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_7));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, excType__9cjUze5Qh6q4dDt6ZAfifVg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		if (T3_) goto LA4_;
		T3_ = ((*n).typ == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		t = getEbase__1YNMkqhT4DZf7hJB9cvjIhQ(g, (*n).info);
	}
	goto LA1_;
	LA5_: ;
	{
		t = (*n).typ;
	}
	LA1_: ;
	result = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36275087638268176));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* real) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*(*spec).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57))) goto LA3_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** t;
			NI i;
			NI L;
			NI T6_;
			t = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i = ((NI) 0);
			T6_ = ((*(*spec).typ).sons ? (*(*spec).typ).sons->Sup.len : 0);
			L = T6_;
			{
				while (1) {
					if (!(i < L)) goto LA8;
					t = &(*(*spec).typ).sons->data[i];
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
						NI T12_;
						T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T11_ = excType__9cjUze5Qh6q4dDt6ZAfifVg(g, real);
						T12_ = (NI)0;
						T12_ = safeInheritanceDiff__1dM2iQB5qStJfnn3684ijQ(T11_, (*t));
						if (!(T12_ <= ((NI) 0))) goto LA13_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA13_: ;
					i += ((NI) 1);
				} LA8: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
		NI T17_;
		T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T16_ = excType__9cjUze5Qh6q4dDt6ZAfifVg(g, real);
		T17_ = (NI)0;
		T17_ = safeInheritanceDiff__1dM2iQB5qStJfnn3684ijQ(T16_, (*spec).typ);
		result = (T17_ <= ((NI) 0));
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkMethodEffects__r9asNVglvzXEd9bIUN8ENKaA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* branch) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* actual;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* raisesSpec;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tagsSpec;
{	actual = (*(*(*branch).typ).n)._kind_6.sons->data[((NI) 0)];
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(actual);
		if (!!((T3_ == ((NI) 5)))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	p = (*(*disp).ast)._kind_6.sons->data[((NI) 4)];
	raisesSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170));
	{
		if (!!((raisesSpec == 0))) goto LA8_;
		checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ(g, raisesSpec, (*actual)._kind_6.sons->data[((NI) 0)], ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_6), NIM_FALSE, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	LA8_: ;
	tagsSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175));
	{
		if (!!((tagsSpec == 0))) goto LA12_;
		checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ(g, tagsSpec, (*actual)._kind_6.sons->data[((NI) 3)], ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_8), NIM_FALSE, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	LA12_: ;
	{
		NIM_BOOL T16_;
		NimStringDesc* T20_;
		T16_ = (NIM_BOOL)0;
		T16_ = (((*disp).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0);
		if (!(T16_)) goto LA17_;
		T16_ = ((130 & (*(*branch).typ).flags) == 0);
		LA17_: ;
		if (!T16_) goto LA18_;
		T20_ = (NimStringDesc*)0;
		T20_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_9), (*(*branch).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*branch).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_10, NIM_FALSE);
	}
	LA18_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T25_;
		NimStringDesc* T26_;
		if (!((*(*disp).typ).lockLevel < (*(*branch).typ).lockLevel)) goto LA23_;
		nimZeroMem((void*)T25_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T25_[0] = dollar___75vsOXLrqmx5LmVlMWaymw((*(*branch).typ).lockLevel);
		T25_[1] = dollar___75vsOXLrqmx5LmVlMWaymw((*(*disp).typ).lockLevel);
		T26_ = (NimStringDesc*)0;
		T26_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_11), T25_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*branch).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 45), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_12, NIM_FALSE);
	}
	LA23_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasRealBody__cg1RHKu9b2GcnK3fmjpRj2Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((80 & (*s).flags) == 0);
	return result;
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(void, initEffects__pOwRnuq5NhYw7g0tfye2Ww)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* t, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	if ((*effects)._kind_6.sons) { nimGCunrefNoCycle((*effects)._kind_6.sons); (*effects)._kind_6.sons = NIM_NIL; }
	(*effects)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 5));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*s).info));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*s).info));
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), (*g).emptyNode);
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), (*g).emptyNode);
	asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 4)]), (*g).emptyNode);
	unsureAsgnRef((void**) (&(*t).exc), (*effects)._kind_6.sons->data[((NI) 0)]);
	unsureAsgnRef((void**) (&(*t).tags), (*effects)._kind_6.sons->data[((NI) 3)]);
	unsureAsgnRef((void**) (&(*t).owner), s);
	unsureAsgnRef((void**) (&(*t).ownerModule), getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s));
	unsureAsgnRef((void**) (&(*t).init), NIM_NIL);
	unsureAsgnRef((void**) (&(*t).guards.s), NIM_NIL);
	initOperators__3Mq69aIkPINTsOZ4I5g1jZA(g, (&(*t).guards.o));
	(*t).currOptions = ((*(*g).config).options | (*s).options);
	(*t).guards.beSmart = (((*t).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0);
	unsureAsgnRef((void**) (&(*t).locked), NIM_NIL);
	unsureAsgnRef((void**) (&(*t).graph), g);
	unsureAsgnRef((void**) (&(*t).config), (*g).config);
	unsureAsgnRef((void**) (&(*t).c), c);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocalVar__YlEQSKBgYhMDInPoOkeWuQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((2304 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = ((*s).owner == (*a).owner);
	LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA6_;
	T1_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	LA6_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, find__9cqYOCx35UdU7TYhesWvYeAsystem)(NI* a, NI aLen_0, NI item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI* i;
		NI i_2;
		i = (NI*)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!((*i) == item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__RQ7v5MK0dOhApn0wj6F1iAsystem)(NI* a, NI aLen_0, NI item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__9cqYOCx35UdU7TYhesWvYeAsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, guardGlobal__uVcH3kEIXSlUY0aC9bdqVgg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard) {
{	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** L;
		NI i;
		NI L_2;
		NI T2_;
		L = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		i = ((NI) 0);
		T2_ = ((*a).locked ? (*a).locked->Sup.len : 0);
		L_2 = T2_;
		{
			while (1) {
				if (!(i < L_2)) goto LA4;
				L = &(*a).locked->data[i];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*L)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
					if (!(T7_)) goto LA8_;
					T7_ = ((*(*L))._kind_4.sym == guard);
					LA8_: ;
					if (!T7_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NimStringDesc* T15_;
		NimStringDesc* T16_;
		if (!!((*a).isTopLevel)) goto LA13_;
		T15_ = (NimStringDesc*)0;
		T16_ = (NimStringDesc*)0;
		T16_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + 18);
appendString(T15_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_15));
appendString(T15_, T16_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_16, NIM_FALSE);
	}
	LA13_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isGCedMem__nPImuPGZIdcrAfCNyf4oxAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((289406976 &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__fT360j3udq5hTrgFOZDAIA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* reason) {
	{
		if (!!((*a).inEnforcedGcSafe)) goto LA3_;
		(*a).gcUnsafe = NIM_TRUE;
		{
			if (!((520192 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			asgnRef((void**) (&(*(*a).owner)._kind_2.gcUnsafetyReason), reason);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useVarNoInitCheck__njQS7vGGH2ZwpdWseR6sDg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((67108872 & (*s).flags) == 0));
		if (!(T4_)) goto LA5_;
		T4_ = ((768 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !(((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 259)));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			if (!!(((*s)._kind_4.guard == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA11_;
			guardGlobal__uVcH3kEIXSlUY0aC9bdqVgg(a, n, (*s)._kind_4.guard);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			NIM_BOOL T17_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((67108872 & (*s).flags) == 8);
			if (!(T15_)) goto LA16_;
			T17_ = (NIM_BOOL)0;
			T17_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 22))&63U)))!=0);
			if (T17_) goto LA18_;
			T17_ = isGCedMem__nPImuPGZIdcrAfCNyf4oxAast((*s).typ);
			LA18_: ;
			T15_ = T17_;
			LA16_: ;
			if (!T15_) goto LA19_;
			markGcUnsafe__fT360j3udq5hTrgFOZDAIA(a, s);
			{
				if (!!((*a).inEnforcedNoSideEffects)) goto LA23_;
				(*a).hasSideEffect = NIM_TRUE;
			}
			LA23_: ;
		}
		goto LA13_;
		LA19_: ;
		{
			{
				if (!!((*a).inEnforcedNoSideEffects)) goto LA28_;
				(*a).hasSideEffect = NIM_TRUE;
			}
			LA28_: ;
		}
		LA13_: ;
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useVar__v49b6RRBfUBabmq9bN9c9bCQLA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	s = (*n)._kind_4.sym;
	{
		if (!(((NI) 0) < (*a).inExceptOrFinallyStmt)) goto LA3_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 43)) & 63);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(a, s);
		if (!T7_) goto LA8_;
		{
			NI T14_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA12_;
			unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
			T14_ = (*a).init->Sup.len++;
			(*a).init->data[T14_] = (*s).Sup.id;
		}
		goto LA10_;
		LA12_: ;
		{
			NIM_BOOL T16_;
			NI T27_;
			T16_ = (NIM_BOOL)0;
			T16_ = contains__RQ7v5MK0dOhApn0wj6F1iAsystem((*a).init->data, ((*a).init ? (*a).init->Sup.len : 0), (*s).Sup.id);
			if (!!(T16_)) goto LA17_;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ((*s).typ);
				if (!T21_) goto LA22_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 34), (*(*s).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_13, NIM_FALSE);
			}
			goto LA19_;
			LA22_: ;
			{
				if (!((*a).leftPartOfAsgn <= ((NI) 0))) goto LA25_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 42), (*(*s).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_14, NIM_FALSE);
			}
			goto LA19_;
			LA25_: ;
			LA19_: ;
			unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
			T27_ = (*a).init->Sup.len++;
			(*a).init->data[T27_] = (*s).Sup.id;
		}
		goto LA10_;
		LA17_: ;
		LA10_: ;
	}
	LA8_: ;
	useVarNoInitCheck__njQS7vGGH2ZwpdWseR6sDg(a, n, s);
}
N_LIB_PRIVATE N_NIMCALL(void, throws__w7qDRJXgbGJ5Q2Q6r7yA9cw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			if (!!((orig == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA9_;
			x = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
			(*x).info = (*orig).info;
			add__P8dDSotTW25BkfbyspojGg(tracked, x);
		}
		goto LA7_;
		LA9_: ;
		{
			add__P8dDSotTW25BkfbyspojGg(tracked, n);
		}
		LA7_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* aa;
{	aa = (*a).exc;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(aa);
		i_2 = (*a).bottom;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
					NIM_BOOL T8_;
					T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T6_ = excType__9cjUze5Qh6q4dDt6ZAfifVg((*a).graph, (*aa)._kind_6.sons->data[i]);
					T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T7_ = excType__9cjUze5Qh6q4dDt6ZAfifVg((*a).graph, e);
					T8_ = (NIM_BOOL)0;
					T8_ = sameType__3isNyHKb0U1OCnClmflXSg(T6_, T7_, 0);
					if (!T8_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		if (!!(((*e).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA13_;
		{
			NIM_BOOL T17_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = (((*(*a).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 47))&63U)))!=0);
			if (T17_) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = isDefectException__YPjOkGV9axAnGR3UfLeWZ1g_10((*e).typ);
			T17_ = !(T19_);
			LA18_: ;
			if (!T17_) goto LA20_;
			throws__w7qDRJXgbGJ5Q2Q6r7yA9cw((*a).exc, e, comesFrom);
		}
		LA20_: ;
	}
	LA13_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
{	{
		if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw((*tracked).graph, (*tracked).c, typ, info);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0);
		if (T7_) goto LA8_;
		T7_ = (((*(*tracked).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		LA8_: ;
		if (!T7_) goto LA9_;
		(*(*tracked).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createRaise__2aachO6llLVwCKPPPmABpQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4));
	asgnRef((void**) (&(*result).typ), getEbase__1YNMkqhT4DZf7hJB9cvjIhQ(g, (*n).info));
	{
		if (!!((n == 0))) goto LA3_;
		(*result).info = (*n).info;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeLockLevels__HPKPawBmCdQfQSjvglxVug)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI16 lockLevel) {
	{
		if (!((*tracked).currLockLevel <= lockLevel)) goto LA3_;
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			if (!(((NI16) 0) < (*tracked).currLockLevel)) goto LA7_;
			T9_ = (NimStringDesc*)0;
			T10_ = (NimStringDesc*)0;
			T10_ = dollar___75vsOXLrqmx5LmVlMWaymw((*tracked).currLockLevel);
			T11_ = (NimStringDesc*)0;
			T11_ = dollar___75vsOXLrqmx5LmVlMWaymw(lockLevel);
			T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + (T11_ ? T11_->Sup.len : 0) + 42);
appendString(T9_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_17));
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_18));
appendString(T9_, T11_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_19, NIM_FALSE);
		}
		LA7_: ;
		(*tracked).maxLockLevel = (((*tracked).maxLockLevel >= lockLevel) ? (*tracked).maxLockLevel : lockLevel);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__y9cx8hmVKlu7WWOs4onCwGQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NI16 result;
	result = (NI16)0;
	result = (*(*s).typ).lockLevel;
	{
		if (!(result == ((NI16) -1))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((4160 & (*s).flags) == 0));
			if (T7_) goto LA8_;
			T7_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			result = ((NI16) 0);
		}
		goto LA5_;
		LA9_: ;
		{
			result = ((NI16) 1001);
		}
		LA5_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeRaises__Rh0mhUmoZCBMPFUCtmsUAA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!(b == 0)) goto LA3_;
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = createRaise__2aachO6llLVwCKPPPmABpQ((*a).graph, comesFrom);
		addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(a, T5_, comesFrom);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effect;
			effect = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(b);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						effect = (*b)._kind_6.sons->data[i];
						addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(a, effect, comesFrom);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addTag__hDlm2Cal6ET3nLFp2KWZCw_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* aa;
{	aa = (*a).tags;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(aa);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
					NIM_BOOL T8_;
					T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*aa)._kind_6.sons->data[i]).typ, IL64(36275087638268176));
					T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36275087638268176));
					T8_ = (NIM_BOOL)0;
					T8_ = sameType__3isNyHKb0U1OCnClmflXSg(T6_, T7_, 0);
					if (!T8_) goto LA9_;
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	throws__w7qDRJXgbGJ5Q2Q6r7yA9cw((*a).tags, e, comesFrom);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createTag__2aachO6llLVwCKPPPmABpQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4));
	asgnRef((void**) (&(*result).typ), sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ(g, (*n).info, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_20)));
	{
		if (!!((n == 0))) goto LA3_;
		(*result).info = (*n).info;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeTags__Rh0mhUmoZCBMPFUCtmsUAA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* comesFrom) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!(b == 0)) goto LA3_;
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = createTag__2aachO6llLVwCKPPPmABpQ_2((*a).graph, comesFrom);
		addTag__hDlm2Cal6ET3nLFp2KWZCw_2(a, T5_, comesFrom);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effect;
			effect = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(b);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						effect = (*b)._kind_6.sons->data[i];
						addTag__hDlm2Cal6ET3nLFp2KWZCw_2(a, effect, comesFrom);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 40), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_21, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spec;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tagSpec;
	NI16 T20_;
	pragma = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	spec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(pragma, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170));
	mergeRaises__Rh0mhUmoZCBMPFUCtmsUAA(tracked, spec, n);
	tagSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(pragma, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175));
	mergeTags__Rh0mhUmoZCBMPFUCtmsUAA_2(tracked, tagSpec, n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((130 & (*(*s).typ).flags) == 0);
		if (!(T3_)) goto LA4_;
		T3_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 40));
			if (!T9_) goto LA10_;
			warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg(n, (*tracked).config);
		}
		LA10_: ;
		markGcUnsafe__fT360j3udq5hTrgFOZDAIA(tracked, s);
	}
	LA5_: ;
	{
		if (!!((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0))) goto LA14_;
		{
			if (!!((*tracked).inEnforcedNoSideEffects)) goto LA18_;
			(*tracked).hasSideEffect = NIM_TRUE;
		}
		LA18_: ;
	}
	LA14_: ;
	T20_ = (NI16)0;
	T20_ = getLockLevel__y9cx8hmVKlu7WWOs4onCwGQ(s);
	mergeLockLevels__HPKPawBmCdQfQSjvglxVug(tracked, n, T20_);
}
static N_INLINE(NIM_BOOL, isNoEffectList__heeP9bq2P1AFVYhYVYTOP0gsempass2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NIM_BOOL T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NI)0;
	T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T1_ = (T2_ == ((NI) 0));
	if (T1_) goto LA3_;
	T4_ = (NIM_BOOL)0;
	T4_ = ((*n)._kind_6.sons->data[((NI) 3)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	if (!(T4_)) goto LA5_;
	T4_ = ((*n)._kind_6.sons->data[((NI) 0)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	LA5_: ;
	T1_ = T4_;
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isForwardedProc__tEyNhG8jDpteKMTOJUposQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isIndirectCall__zEd2da81SkcO4ecZFErcPQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T8_;
		if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3))) goto LA6_;
		T8_ = (NIM_BOOL)0;
		T8_ = !((owner == (*(*n)._kind_4.sym).owner));
		if (T8_) goto LA9_;
		T8_ = (owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		LA9_: ;
		result = T8_;
	}
	goto LA1_;
	LA6_: ;
	{
		if (!!(((520192 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0))) goto LA11_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA11_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, assumeTheWorst__o1siCCwJ4v3zTcbZrQcFkA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	NI16 lockLevel;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = createRaise__2aachO6llLVwCKPPPmABpQ((*tracked).graph, n);
	addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(tracked, T1_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = createTag__2aachO6llLVwCKPPPmABpQ_2((*tracked).graph, n);
	addTag__hDlm2Cal6ET3nLFp2KWZCw_2(tracked, T2_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	{
		if (!((*op).lockLevel == ((NI16) -1))) goto LA5_;
		lockLevel = ((NI16) 1001);
	}
	goto LA3_;
	LA5_: ;
	{
		lockLevel = (*op).lockLevel;
	}
	LA3_: ;
	mergeLockLevels__HPKPawBmCdQfQSjvglxVug(tracked, n, lockLevel);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, importedFromC__tEyNhG8jDpteKMTOJUposQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* reason) {
	{
		if (!!((*a).inEnforcedGcSafe)) goto LA3_;
		(*a).gcUnsafe = NIM_TRUE;
		{
			if (!((520192 &((NU32)1<<((NU)((*(*a).owner).kind)&31U)))!=0)) goto LA7_;
			{
				if (!((*reason).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA11_;
				asgnRef((void**) (&(*(*a).owner)._kind_2.gcUnsafetyReason), (*reason)._kind_4.sym);
			}
			goto LA9_;
			LA11_: ;
			{
				asgnRef((void**) (&(*(*a).owner)._kind_2.gcUnsafetyReason), newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), (*(*a).owner).name, (*a).owner, (*reason).info, 0));
			}
			LA9_: ;
		}
		LA7_: ;
	}
	LA3_: ;
}
static N_INLINE(NIM_BOOL, isTrival__MqKxDwYfGT3leajDQaUrBwsempass2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caller) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*caller).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 92) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 143) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 148) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 149) || (*(*caller)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 142));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_22));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_23));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_24));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedProcVar__zEd2da81SkcO4ecZFErcPQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (owner == (*(*n)._kind_4.sym).owner);
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, makeVolatile__wBsQA9b2lpv7DoSOuGohRUAsempass2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*a).inTryStmt);
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*a).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 1));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9)) & 63);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, procVarCheck__zRRYqNfXt0mVIBCxaEomVg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						procVarCheck__zRRYqNfXt0mVIBCxaEomVg_2(x, conf);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NimStringDesc* T16_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T11_)) goto LA12_;
		T11_ = !(((*(*n)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = ((520192 &((NU32)1<<((NU)((*(*n)._kind_4.sym).kind)&31U)))!=0);
		LA13_: ;
		if (!T10_) goto LA14_;
		T16_ = (NimStringDesc*)0;
		T16_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_28), (*(*(*n)._kind_4.sym).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_29, NIM_FALSE);
	}
	goto LA1_;
	LA14_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType_2;
{	n_2 = skipConv__BH9abOhPX8pH0DnEWlRxmlw(n);
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (paramType == 0);
		if (T3_) goto LA4_;
		T3_ = !(((*paramType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T7_ = skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ(n_2);
		procVarCheck__zRRYqNfXt0mVIBCxaEomVg_2(T7_, (*tracked).config);
	}
	LA5_: ;
	paramType_2 = skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2(paramType, IL64(36134350135273744));
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ntyp;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = !((paramType_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T11_)) goto LA12_;
		T11_ = (((*paramType_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = !(((*n_2).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA13_: ;
		if (!T10_) goto LA14_;
		ntyp = skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2((*n_2).typ, IL64(211106240921600));
		{
			NIM_BOOL T18_;
			tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T47_;
			T18_ = (NIM_BOOL)0;
			T18_ = !((ntyp == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T18_)) goto LA19_;
			T18_ = !((((*ntyp).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
			LA19_: ;
			if (!T18_) goto LA20_;
			{
				NIM_BOOL T24_;
				T24_ = (NIM_BOOL)0;
				T24_ = isAddrNode__OTZyO2oJpdYpHVBZuRXuRQ(n_2);
				if (!T24_) goto LA25_;
				{
					NIM_BOOL T29_;
					T29_ = (NIM_BOOL)0;
					T29_ = containsNode__3PkUvehQ5keciM9cue9ayMTw(n_2, TM__wkTG4eaV3t1uo3x09apjcwA_30);
					if (!!(T29_)) goto LA30_;
					goto BeforeRet_;
				}
				LA30_: ;
			}
			goto LA22_;
			LA25_: ;
			{
				NIM_BOOL T33_;
				NIM_BOOL T34_;
				NIM_BOOL T35_;
				NIM_BOOL T36_;
				NIM_BOOL T40_;
				NIM_BOOL T41_;
				T33_ = (NIM_BOOL)0;
				T34_ = (NIM_BOOL)0;
				T35_ = (NIM_BOOL)0;
				T36_ = (NIM_BOOL)0;
				T36_ = ((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T36_)) goto LA37_;
				T36_ = ((520192 &((NU32)1<<((NU)((*(*n_2)._kind_4.sym).kind)&31U)))!=0);
				LA37_: ;
				T35_ = T36_;
				if (T35_) goto LA38_;
				T35_ = ((*n_2).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*n_2).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*n_2).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) && (*n_2).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52) || (*n_2).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) && (*n_2).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159));
				LA38_: ;
				T34_ = T35_;
				if (T34_) goto LA39_;
				T40_ = (NIM_BOOL)0;
				T41_ = (NIM_BOOL)0;
				T41_ = ((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
				if (!(T41_)) goto LA42_;
				T41_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				LA42_: ;
				T40_ = T41_;
				if (!(T40_)) goto LA43_;
				T40_ = ((*(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 144));
				LA43_: ;
				T34_ = T40_;
				LA39_: ;
				T33_ = T34_;
				if (T33_) goto LA44_;
				T33_ = ((*(*n_2).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
				LA44_: ;
				if (!T33_) goto LA45_;
				goto BeforeRet_;
			}
			goto LA22_;
			LA45_: ;
			LA22_: ;
			T47_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
			T47_ = impliesNotNil__x6MUw3H3bS3WZ5DYhXX61Q((&(*tracked).guards), n_2);
			switch (T47_) {
			case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
			{
				NimStringDesc* T49_;
				NimStringDesc* T50_;
				T49_ = (NimStringDesc*)0;
				T49_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n_2, 0);
				T50_ = (NimStringDesc*)0;
				T50_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_31), T49_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T50_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_32, NIM_FALSE);
			}
			break;
			case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
			{
				NimStringDesc* T52_;
				NimStringDesc* T53_;
				T52_ = (NimStringDesc*)0;
				T52_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n_2, 0);
				T53_ = (NimStringDesc*)0;
				T53_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_33), T52_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T53_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_34, NIM_FALSE);
			}
			break;
			case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
			{
			}
			break;
			}
		}
		LA20_: ;
	}
	LA14_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackOperandForIndirectCall__5bSCYZG1o5kKwugYUxHjSQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caller) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op;
	a = skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ(n);
	op = (*a).typ;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		NIM_BOOL T10_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effectList;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = !((op == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = ((*op).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw(n);
		T4_ = !(((*T8_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)));
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA9_;
		T10_ = (NIM_BOOL)0;
		T10_ = isTrival__MqKxDwYfGT3leajDQaUrBwsempass2(caller);
		T3_ = !(T10_);
		LA9_: ;
		if (!T3_) goto LA11_;
		{
			NimStringDesc* argX60gensym175_;
			if (!!(((*(*(*op).n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152)))) goto LA15_;
			argX60gensym175_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__wkTG4eaV3t1uo3x09apjcwA_25);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*tracked).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym175_, TM__wkTG4eaV3t1uo3x09apjcwA_25);
		}
		LA15_: ;
		effectList = (*(*op).n)._kind_6.sons->data[((NI) 0)];
		s = skipConv__BH9abOhPX8pH0DnEWlRxmlw(n);
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*s).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61));
			if (!(T19_)) goto LA20_;
			T19_ = ((*(*(*s)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA20_: ;
			if (!T19_) goto LA21_;
			s = (*s)._kind_6.sons->data[((NI) 1)];
		}
		LA21_: ;
		{
			NIM_BOOL T25_;
			NIM_BOOL T26_;
			T25_ = (NIM_BOOL)0;
			T26_ = (NIM_BOOL)0;
			T26_ = ((*s).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T26_)) goto LA27_;
			T26_ = ((520192 &((NU32)1<<((NU)((*(*s)._kind_4.sym).kind)&31U)))!=0);
			LA27_: ;
			T25_ = T26_;
			if (!(T25_)) goto LA28_;
			T25_ = isNoEffectList__heeP9bq2P1AFVYhYVYTOP0gsempass2(effectList);
			LA28_: ;
			if (!T25_) goto LA29_;
			propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw(tracked, n, (*s)._kind_4.sym);
		}
		goto LA23_;
		LA29_: ;
		{
			NIM_BOOL T32_;
			T32_ = (NIM_BOOL)0;
			T32_ = isNoEffectList__heeP9bq2P1AFVYhYVYTOP0gsempass2(effectList);
			if (!T32_) goto LA33_;
			{
				NIM_BOOL T37_;
				T37_ = (NIM_BOOL)0;
				T37_ = isForwardedProc__tEyNhG8jDpteKMTOJUposQ(n);
				if (!T37_) goto LA38_;
				propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw(tracked, n, (*n)._kind_4.sym);
			}
			goto LA35_;
			LA38_: ;
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = isOwnedProcVar__zEd2da81SkcO4ecZFErcPQ_2(a, (*tracked).owner);
				if (!!(T41_)) goto LA42_;
				assumeTheWorst__o1siCCwJ4v3zTcbZrQcFkA(tracked, n, op);
			}
			goto LA35_;
			LA42_: ;
			LA35_: ;
			{
				NIM_BOOL T46_;
				NIM_BOOL T48_;
				T46_ = (NIM_BOOL)0;
				T46_ = ((130 & (*op).flags) == 0);
				if (!(T46_)) goto LA47_;
				T48_ = (NIM_BOOL)0;
				T48_ = isOwnedProcVar__zEd2da81SkcO4ecZFErcPQ_2(a, (*tracked).owner);
				T46_ = !(T48_);
				LA47_: ;
				if (!T46_) goto LA49_;
				{
					NIM_BOOL T53_;
					T53_ = (NIM_BOOL)0;
					T53_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 40));
					if (!T53_) goto LA54_;
					warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg(n, (*tracked).config);
				}
				LA54_: ;
				markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw(tracked, a);
			}
			goto LA44_;
			LA49_: ;
			{
				NIM_BOOL T57_;
				NIM_BOOL T59_;
				T57_ = (NIM_BOOL)0;
				T57_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0));
				if (!(T57_)) goto LA58_;
				T59_ = (NIM_BOOL)0;
				T59_ = isOwnedProcVar__zEd2da81SkcO4ecZFErcPQ_2(a, (*tracked).owner);
				T57_ = !(T59_);
				LA58_: ;
				if (!T57_) goto LA60_;
				{
					if (!!((*tracked).inEnforcedNoSideEffects)) goto LA64_;
					(*tracked).hasSideEffect = NIM_TRUE;
				}
				LA64_: ;
			}
			goto LA44_;
			LA60_: ;
			LA44_: ;
		}
		goto LA23_;
		LA33_: ;
		{
			mergeRaises__Rh0mhUmoZCBMPFUCtmsUAA(tracked, (*effectList)._kind_6.sons->data[((NI) 0)], n);
			mergeTags__Rh0mhUmoZCBMPFUCtmsUAA_2(tracked, (*effectList)._kind_6.sons->data[((NI) 3)], n);
			{
				if (!((130 & (*op).flags) == 0)) goto LA69_;
				{
					NIM_BOOL T73_;
					T73_ = (NIM_BOOL)0;
					T73_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 40));
					if (!T73_) goto LA74_;
					warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg(n, (*tracked).config);
				}
				LA74_: ;
				markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw(tracked, a);
			}
			goto LA67_;
			LA69_: ;
			{
				if (!!((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0))) goto LA77_;
				{
					if (!!((*tracked).inEnforcedNoSideEffects)) goto LA81_;
					(*tracked).hasSideEffect = NIM_TRUE;
				}
				LA81_: ;
			}
			goto LA67_;
			LA77_: ;
			LA67_: ;
		}
		LA23_: ;
	}
	LA11_: ;
	{
		NIM_BOOL T85_;
		T85_ = (NIM_BOOL)0;
		T85_ = !((paramType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T85_)) goto LA86_;
		T85_ = ((8388608 &((NU64)1<<((NU)((*paramType).kind)&63U)))!=0);
		LA86_: ;
		if (!T85_) goto LA87_;
		invalidateFacts__no3iuruVlFxE0wQ8HA9b4ZA((&(*tracked).guards), n);
		{
			NIM_BOOL T91_;
			T91_ = (NIM_BOOL)0;
			T91_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T91_)) goto LA92_;
			T91_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(tracked, (*n)._kind_4.sym);
			LA92_: ;
			if (!T91_) goto LA93_;
			makeVolatile__wBsQA9b2lpv7DoSOuGohRUAsempass2(tracked, (*n)._kind_4.sym);
		}
		LA93_: ;
	}
	LA87_: ;
	{
		NIM_BOOL T97_;
		NIM_BOOL T98_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* argtype;
		T97_ = (NIM_BOOL)0;
		T98_ = (NIM_BOOL)0;
		T98_ = !((paramType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T98_)) goto LA99_;
		T98_ = ((*paramType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		LA99_: ;
		T97_ = T98_;
		if (!(T97_)) goto LA100_;
		T97_ = (((*paramType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7))&63U)))!=0);
		LA100_: ;
		if (!T97_) goto LA101_;
		argtype = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*a).typ, IL64(36134350135273744));
		{
			NIM_BOOL T105_;
			NIM_BOOL T106_;
			NimStringDesc* T111_;
			NimStringDesc* T112_;
			T105_ = (NIM_BOOL)0;
			T106_ = (NIM_BOOL)0;
			T106_ = ((*argtype).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T106_)) goto LA107_;
			T106_ = ((130 & (*argtype).flags) == 0);
			LA107_: ;
			T105_ = T106_;
			if (!(T105_)) goto LA108_;
			T105_ = !((*tracked).inEnforcedGcSafe);
			LA108_: ;
			if (!T105_) goto LA109_;
			T111_ = (NimStringDesc*)0;
			T112_ = (NimStringDesc*)0;
			T112_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
			T111_ = rawNewString((T112_ ? T112_->Sup.len : 0) + 15);
appendString(T111_, T112_);
appendString(T111_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_26));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T111_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_27, NIM_FALSE);
		}
		LA109_: ;
	}
	LA101_: ;
	notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ(tracked, n, paramType);
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, paramType__JPWM4hjtH3zx9bI8pJf7Xsg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op, NI i) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((op == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__5mJADrRYkP3r9auuiuDZN9cQast(op);
		T3_ = (i < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		result = (*op).sons->data[i];
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initVar__9cnMyHEtl3Vw3Eik8EejmRA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL volatileCheck) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T7_;
		NI T22_;
		T7_ = (NIM_BOOL)0;
		T7_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(a, s);
		if (!T7_) goto LA8_;
		{
			if (!volatileCheck) goto LA12_;
			makeVolatile__wBsQA9b2lpv7DoSOuGohRUAsempass2(a, s);
		}
		LA12_: ;
		{
			NI* x;
			NI i;
			NI L;
			NI T15_;
			x = (NI*)0;
			i = ((NI) 0);
			T15_ = ((*a).init ? (*a).init->Sup.len : 0);
			L = T15_;
			{
				while (1) {
					if (!(i < L)) goto LA17;
					x = (&(*a).init->data[i]);
					{
						if (!((*x) == (*s).Sup.id)) goto LA20_;
						goto BeforeRet_;
					}
					LA20_: ;
					i += ((NI) 1);
				} LA17: ;
			}
		}
		unsureAsgnRef((void**) (&(*a).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*a).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
		T22_ = (*a).init->Sup.len++;
		(*a).init->data[T22_] = (*s).Sup.id;
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initVarViaNew__v49b6RRBfUBabmq9bN9c9bCQLA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = (*n)._kind_4.sym;
	{
		if (!(((393216 & (*(*s).typ).flags) & ~ 131072)==0)) goto LA7_;
		initVar__9cnMyHEtl3Vw3Eik8EejmRA(a, n, NIM_TRUE);
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(a, s);
		if (!T10_) goto LA11_;
		makeVolatile__wBsQA9b2lpv7DoSOuGohRUAsempass2(a, s);
	}
	goto LA5_;
	LA11_: ;
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLe__7CUcxkdNhLZqHv8xsVpwiQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T1_;
	T1_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
	T1_ = proveLe__gquZ4TuLCn9anC5O4OWI4Og((&(*c).guards), a, b);
	switch (T1_) {
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 0):
	{
		NimStringDesc* T3_;
		NimStringDesc* T4_;
		NimStringDesc* T5_;
		T3_ = (NimStringDesc*)0;
		T4_ = (NimStringDesc*)0;
		T4_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(a);
		T5_ = (NimStringDesc*)0;
		T5_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(b);
		T3_ = rawNewString((T4_ ? T4_->Sup.len : 0) + (T5_ ? T5_->Sup.len : 0) + 18);
appendString(T3_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_36));
appendString(T3_, T4_);
appendString(T3_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_37));
appendString(T3_, T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*c).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T3_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_38, NIM_FALSE);
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 2):
	{
	}
	break;
	case ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1):
	{
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T8_ = (NimStringDesc*)0;
		T9_ = (NimStringDesc*)0;
		T9_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(a);
		T10_ = (NimStringDesc*)0;
		T10_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(b);
		T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 14);
appendString(T8_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_39));
appendString(T8_, T9_);
appendString(T8_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_40));
appendString(T8_, T10_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*c).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 39), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_41, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__5TEFk9a9cl6Se9bkEpUPsbTTg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = lowBound__Esza4n69a5U9bzlDTK04VArg((*c).config, arr);
	checkLe__7CUcxkdNhLZqHv8xsVpwiQ(c, T1_, idx);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = highBound__9cbEq5HLZRHFpEqTjJwMYDA((*c).config, arr, (&(*c).guards.o));
	checkLe__7CUcxkdNhLZqHv8xsVpwiQ(c, idx, T2_);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__jfydvRaAcnbXyRZInRGcjwsystem)(tyArray__JXkBzVsE9bvmcpuZvrueLVg a, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc* i;
		tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg i_2;
		i = (NimStringDesc*)0;
		i_2 = ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0);
		{
			if (!(i_2 <= ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))) goto LA4_;
			{
				while (1) {
					i = a[(i_2)- 0];
					{
						if (!eqStrings(i, item)) goto LA10_;
						goto BeforeRet_;
					}
					LA10_: ;
					result += ((NI) 1);
					{
						if (!(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5) <= i_2)) goto LA14_;
						goto LA6;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				}
			} LA6: ;
		}
		LA4_: ;
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((IL64(-9223372036854775680) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkForSink__2juoX30KP12DlcWVrUGDWw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
{	{
		if (!!((((*config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 26))&31U)))!=0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*arg).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*arg)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*arg)._kind_4.sym).owner == owner);
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA14_;
			T11_ = !(((*owner).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA14_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA15_;
			T10_ = ((*(*owner).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA15_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA16_;
			T9_ = !(((IL64(2147483664) & (*(*(*arg)._kind_4.sym).typ).flags) == 0));
			LA16_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA17_;
			T8_ = !(((IL64(105553124655104) &((NU64)1<<((NU)((*(*(*arg)._kind_4.sym).typ).kind)&63U)))!=0));
			LA17_: ;
			if (!T8_) goto LA18_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* argType;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* sinkType;
				if (!!((((*owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5))&63U)))!=0))) goto LA22_;
				argType = (*(*arg)._kind_4.sym).typ;
				sinkType = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46), owner);
				(*sinkType).size = (*argType).size;
				(*sinkType).align = (*argType).align;
				(*sinkType).paddingAtEnd = (*argType).paddingAtEnd;
				add__9a8CdZqChTyqzq5bpSL3TzA(sinkType, argType);
				asgnRef((void**) (&(*(*arg)._kind_4.sym).typ), sinkType);
				asgnRef((void**) (&(*(*owner).typ).sons->data[(NI)((*(*arg)._kind_4.sym).position + ((NI) 1))]), sinkType);
			}
			goto LA20_;
			LA22_: ;
			{
				tyArray__nHXaesL0DJZHyVS07ARPRA T27_;
				NimStringDesc* T28_;
				if (!!((((*(*arg)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5))&63U)))!=0))) goto LA25_;
				(*(*arg)._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5)) & 63);
				nimZeroMem((void*)T27_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T27_[0] = copyString((*(*(*arg)._kind_4.sym).name).s);
				T28_ = (NimStringDesc*)0;
				T28_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_43), T27_, 1);
				liMessage__Q6JNH4uRwLyZrj0dJakHew(config, (*arg).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 75), T28_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_44, NIM_FALSE);
			}
			goto LA20_;
			LA25_: ;
			LA20_: ;
		}
		LA18_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		{
			NIM_BOOL T32_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
			T32_ = (NIM_BOOL)0;
			T32_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*arg).typ);
			if (!!(T32_)) goto LA33_;
			T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T35_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(arg);
			checkForSink__2juoX30KP12DlcWVrUGDWw(config, owner, T35_);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
			branch = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(arg);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value;
						if (!(i_2 < colontmp_)) goto LA40;
						i = i_2;
						branch = (*arg)._kind_6.sons->data[i];
						value = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
						{
							NIM_BOOL T43_;
							T43_ = (NIM_BOOL)0;
							T43_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*value).typ);
							if (!!(T43_)) goto LA44_;
							checkForSink__2juoX30KP12DlcWVrUGDWw(config, owner, value);
						}
						LA44_: ;
						i_2 += ((NI) 1);
					} LA40: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(arg);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value_2;
					if (!(i_4 < colontmp__2)) goto LA49;
					i_3 = i_4;
					value_2 = lastSon__UPSW0jLTX5qJL51YMUAHgw((*arg)._kind_6.sons->data[i_3]);
					{
						NIM_BOOL T52_;
						T52_ = (NIM_BOOL)0;
						T52_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*value_2).typ);
						if (!!(T52_)) goto LA53_;
						checkForSink__2juoX30KP12DlcWVrUGDWw(config, owner, value_2);
					}
					LA53_: ;
					i_4 += ((NI) 1);
				} LA49: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	{
		checkForSink__2juoX30KP12DlcWVrUGDWw(config, owner, (*arg)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackCall__BxqWoS9czp4uFup6HfSkCeA_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* op;
	a = (*n)._kind_6.sons->data[((NI) 0)];
	op = (*a).typ;
	{
		if (!!(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
			if (!(T7_)) goto LA8_;
			T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
			T7_ = !(((*T9_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)));
			LA8_: ;
			if (!T7_) goto LA10_;
			createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
		}
		LA10_: ;
	}
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
		T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T14_ = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*tracked).ownerModule, n, (*tracked).graph);
		if (!(T14_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61));
			if (!(T19_)) goto LA20_;
			T19_ = ((*(*(*a)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA20_: ;
			if (!T19_) goto LA21_;
			a = (*a)._kind_6.sons->data[((NI) 1)];
		}
		LA21_: ;
		{
			NIM_BOOL T25_;
			NIM_BOOL T26_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effectList;
			T25_ = (NIM_BOOL)0;
			T26_ = (NIM_BOOL)0;
			T26_ = !((op == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T26_)) goto LA27_;
			T26_ = ((*op).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA27_: ;
			T25_ = T26_;
			if (!(T25_)) goto LA28_;
			T25_ = ((*(*(*op).n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152));
			LA28_: ;
			if (!T25_) goto LA29_;
			{
				NI16 T39_;
				if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA33_;
				{
					if (!((*a)._kind_4.sym == (*tracked).owner)) goto LA37_;
					(*tracked).isRecursive = NIM_TRUE;
				}
				LA37_: ;
				T39_ = (NI16)0;
				T39_ = getLockLevel__y9cx8hmVKlu7WWOs4onCwGQ((*a)._kind_4.sym);
				mergeLockLevels__HPKPawBmCdQfQSjvglxVug(tracked, n, T39_);
				{
					if (!(((*(*a)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 13))&63U)))!=0)) goto LA42_;
					{
						if (!!((*tracked).inEnforcedNoSideEffects)) goto LA46_;
						(*tracked).hasSideEffect = NIM_TRUE;
					}
					LA46_: ;
				}
				LA42_: ;
			}
			goto LA31_;
			LA33_: ;
			{
				mergeLockLevels__HPKPawBmCdQfQSjvglxVug(tracked, n, (*op).lockLevel);
			}
			LA31_: ;
			effectList = (*(*op).n)._kind_6.sons->data[((NI) 0)];
			{
				NIM_BOOL T51_;
				T51_ = (NIM_BOOL)0;
				T51_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T51_)) goto LA52_;
				T51_ = ((*(*a)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
				LA52_: ;
				if (!T51_) goto LA53_;
				propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw(tracked, n, (*a)._kind_4.sym);
			}
			goto LA49_;
			LA53_: ;
			{
				NIM_BOOL T56_;
				T56_ = (NIM_BOOL)0;
				T56_ = isNoEffectList__heeP9bq2P1AFVYhYVYTOP0gsempass2(effectList);
				if (!T56_) goto LA57_;
				{
					NIM_BOOL T61_;
					T61_ = (NIM_BOOL)0;
					T61_ = isForwardedProc__tEyNhG8jDpteKMTOJUposQ(a);
					if (!T61_) goto LA62_;
					propagateEffects__qMyzHs0lMHQEwa9bFI7hAAw(tracked, n, (*a)._kind_4.sym);
				}
				goto LA59_;
				LA62_: ;
				{
					NIM_BOOL T65_;
					T65_ = (NIM_BOOL)0;
					T65_ = isIndirectCall__zEd2da81SkcO4ecZFErcPQ(a, (*tracked).owner);
					if (!T65_) goto LA66_;
					assumeTheWorst__o1siCCwJ4v3zTcbZrQcFkA(tracked, n, op);
					{
						NIM_BOOL T70_;
						NIM_BOOL T72_;
						T70_ = (NIM_BOOL)0;
						T70_ = ((130 & (*op).flags) == 0);
						if (!(T70_)) goto LA71_;
						T72_ = (NIM_BOOL)0;
						T72_ = importedFromC__tEyNhG8jDpteKMTOJUposQ_2(a);
						T70_ = !(T72_);
						LA71_: ;
						if (!T70_) goto LA73_;
						{
							NIM_BOOL T77_;
							T77_ = (NIM_BOOL)0;
							T77_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
							if (!(T77_)) goto LA78_;
							T77_ = ((*a)._kind_4.sym == (*tracked).owner);
							LA78_: ;
							if (!!(T77_)) goto LA79_;
							{
								NIM_BOOL T83_;
								T83_ = (NIM_BOOL)0;
								T83_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 40));
								if (!T83_) goto LA84_;
								warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg(n, (*tracked).config);
							}
							LA84_: ;
							markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw(tracked, a);
						}
						LA79_: ;
					}
					LA73_: ;
					{
						NIM_BOOL T88_;
						NIM_BOOL T90_;
						T88_ = (NIM_BOOL)0;
						T88_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0));
						if (!(T88_)) goto LA89_;
						T90_ = (NIM_BOOL)0;
						T90_ = importedFromC__tEyNhG8jDpteKMTOJUposQ_2(a);
						T88_ = !(T90_);
						LA89_: ;
						if (!T88_) goto LA91_;
						{
							NIM_BOOL T95_;
							T95_ = (NIM_BOOL)0;
							T95_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
							if (!(T95_)) goto LA96_;
							T95_ = ((*a)._kind_4.sym == (*tracked).owner);
							LA96_: ;
							if (!!(T95_)) goto LA97_;
							{
								if (!!((*tracked).inEnforcedNoSideEffects)) goto LA101_;
								(*tracked).hasSideEffect = NIM_TRUE;
							}
							LA101_: ;
						}
						LA97_: ;
					}
					LA91_: ;
				}
				goto LA59_;
				LA66_: ;
				LA59_: ;
			}
			goto LA49_;
			LA57_: ;
			{
				mergeRaises__Rh0mhUmoZCBMPFUCtmsUAA(tracked, (*effectList)._kind_6.sons->data[((NI) 0)], n);
				mergeTags__Rh0mhUmoZCBMPFUCtmsUAA_2(tracked, (*effectList)._kind_6.sons->data[((NI) 3)], n);
				{
					NIM_BOOL T106_;
					NIM_BOOL T108_;
					T106_ = (NIM_BOOL)0;
					T106_ = ((130 & (*op).flags) == 0);
					if (!(T106_)) goto LA107_;
					T108_ = (NIM_BOOL)0;
					T108_ = importedFromC__tEyNhG8jDpteKMTOJUposQ_2(a);
					T106_ = !(T108_);
					LA107_: ;
					if (!T106_) goto LA109_;
					{
						NIM_BOOL T113_;
						T113_ = (NIM_BOOL)0;
						T113_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T113_)) goto LA114_;
						T113_ = ((*a)._kind_4.sym == (*tracked).owner);
						LA114_: ;
						if (!!(T113_)) goto LA115_;
						{
							NIM_BOOL T119_;
							T119_ = (NIM_BOOL)0;
							T119_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 40));
							if (!T119_) goto LA120_;
							warnAboutGcUnsafe__zRRYqNfXt0mVIBCxaEomVg(n, (*tracked).config);
						}
						LA120_: ;
						markGcUnsafe__SIsG8puDD6rYUjLgyxYdWw(tracked, a);
					}
					LA115_: ;
				}
				LA109_: ;
				{
					NIM_BOOL T124_;
					NIM_BOOL T126_;
					T124_ = (NIM_BOOL)0;
					T124_ = !((((*op).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0));
					if (!(T124_)) goto LA125_;
					T126_ = (NIM_BOOL)0;
					T126_ = importedFromC__tEyNhG8jDpteKMTOJUposQ_2(a);
					T124_ = !(T126_);
					LA125_: ;
					if (!T124_) goto LA127_;
					{
						NIM_BOOL T131_;
						T131_ = (NIM_BOOL)0;
						T131_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T131_)) goto LA132_;
						T131_ = ((*a)._kind_4.sym == (*tracked).owner);
						LA132_: ;
						if (!!(T131_)) goto LA133_;
						{
							if (!!((*tracked).inEnforcedNoSideEffects)) goto LA137_;
							(*tracked).hasSideEffect = NIM_TRUE;
						}
						LA137_: ;
					}
					LA133_: ;
				}
				LA127_: ;
			}
			LA49_: ;
		}
		LA29_: ;
		{
			NIM_BOOL T141_;
			T141_ = (NIM_BOOL)0;
			T141_ = !(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
			if (T141_) goto LA142_;
			T141_ = !(((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 246)));
			LA142_: ;
			if (!T141_) goto LA143_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T148_;
						if (!(i_2 < colontmp_)) goto LA147;
						i = i_2;
						T148_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T148_ = paramType__JPWM4hjtH3zx9bI8pJf7Xsg(op, i);
						trackOperandForIndirectCall__5bSCYZG1o5kKwugYUxHjSQ(tracked, (*n)._kind_6.sons->data[i], T148_, a);
						i_2 += ((NI) 1);
					} LA147: ;
				}
			}
		}
		LA143_: ;
		{
			NIM_BOOL T151_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
			T151_ = (NIM_BOOL)0;
			T151_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T151_)) goto LA152_;
			T151_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 32) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 34));
			LA152_: ;
			if (!T151_) goto LA153_;
			arg = (*n)._kind_6.sons->data[((NI) 1)];
			initVarViaNew__v49b6RRBfUBabmq9bN9c9bCQLA_2(tracked, arg);
			{
				NIM_BOOL T157_;
				NI T158_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T160_;
				T157_ = (NIM_BOOL)0;
				T158_ = (NI)0;
				T158_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*arg).typ);
				T157_ = !((T158_ == ((NI) 0)));
				if (!(T157_)) goto LA159_;
				T160_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T160_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*arg).typ);
				T157_ = !(((262144 & (*T160_).flags) == 0));
				LA159_: ;
				if (!T157_) goto LA161_;
				{
					NIM_BOOL T165_;
					NIM_BOOL T166_;
					T165_ = (NIM_BOOL)0;
					T166_ = (NIM_BOOL)0;
					T166_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 34));
					if (!(T166_)) goto LA167_;
					T166_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*(*n)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
					LA167_: ;
					T165_ = T166_;
					if (!(T165_)) goto LA168_;
					T165_ = ((*(*n)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(0));
					LA168_: ;
					if (!T165_) goto LA169_;
				}
				goto LA163_;
				LA169_: ;
				{
					NimStringDesc* T172_;
					T172_ = (NimStringDesc*)0;
					T172_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(arg);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*arg).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 34), T172_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_35, NIM_FALSE);
				}
				LA163_: ;
			}
			LA161_: ;
			{
				NI T175_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T178_;
				T175_ = (NI)0;
				T175_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				if (!(((NI) 0) < T175_)) goto LA176_;
				T178_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T178_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, T178_, (*n).info);
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, (*n).info);
			}
			LA176_: ;
		}
		goto LA149_;
		LA153_: ;
		{
			NIM_BOOL T180_;
			NIM_BOOL T181_;
			T180_ = (NIM_BOOL)0;
			T181_ = (NIM_BOOL)0;
			T181_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T181_)) goto LA182_;
			T181_ = ((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5) || (*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 6));
			LA182_: ;
			T180_ = T181_;
			if (!(T180_)) goto LA183_;
			T180_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0);
			LA183_: ;
			if (!T180_) goto LA184_;
			checkBounds__5TEFk9a9cl6Se9bkEpUPsbTTg(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 2)]);
		}
		goto LA149_;
		LA184_: ;
		LA149_: ;
		{
			NIM_BOOL T188_;
			T188_ = (NIM_BOOL)0;
			T188_ = !(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
			if (T188_) goto LA189_;
			T188_ = !(((*(*a)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 263)));
			LA189_: ;
			if (!T188_) goto LA190_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA194;
						i_3 = i_4;
						track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_3]);
						i_4 += ((NI) 1);
					} LA194: ;
				}
			}
		}
		LA190_: ;
	}
	LA15_: ;
	{
		NIM_BOOL T197_;
		NIM_BOOL T198_;
		NIM_BOOL T199_;
		NI opKind;
		NimStringDesc* T205_;
		T197_ = (NIM_BOOL)0;
		T198_ = (NIM_BOOL)0;
		T199_ = (NIM_BOOL)0;
		T199_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T199_)) goto LA200_;
		T199_ = (((NI) 0) < ((*(*(*a)._kind_4.sym).name).s ? (*(*(*a)._kind_4.sym).name).s->Sup.len : 0));
		LA200_: ;
		T198_ = T199_;
		if (!(T198_)) goto LA201_;
		T198_ = ((NU8)((*(*(*a)._kind_4.sym).name).s->data[((NI) 0)]) == (NU8)(61));
		LA201_: ;
		T197_ = T198_;
		if (!(T197_)) goto LA202_;
		T197_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
		LA202_: ;
		if (!T197_) goto LA203_;
		T205_ = (NimStringDesc*)0;
		T205_ = nsuNormalize((*(*(*a)._kind_4.sym).name).s);
		opKind = find__jfydvRaAcnbXyRZInRGcjwsystem(AttachedOpToStr__gGSR5Ulzx6g21lOISgt9aWA, T205_);
		{
			if (!eqStrings((*(*(*a)._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_42))) goto LA208_;
			opKind = ((NI) 1);
		}
		LA208_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			if (!!((opKind == ((NI) -1)))) goto LA212_;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, 8388624);
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op_2;
				if (!!(((*a)._kind_4.sym == (*t).attachedOps[(opKind)- 0]))) goto LA216_;
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, t, (*n).info);
				op_2 = (*t).attachedOps[(opKind)- 0];
				{
					if (!!((op_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA220_;
					asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym), op_2);
				}
				LA220_: ;
			}
			LA216_: ;
		}
		LA212_: ;
	}
	LA203_: ;
	{
		NIM_BOOL T224_;
		T224_ = (NIM_BOOL)0;
		T224_ = !((op == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T224_)) goto LA225_;
		T224_ = ((*op).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		LA225_: ;
		if (!T224_) goto LA226_;
		{
			NI i_5;
			NI colontmp__3;
			NI T229_;
			NI T230_;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			T229_ = (NI)0;
			T229_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			T230_ = (NI)0;
			T230_ = len__5mJADrRYkP3r9auuiuDZN9cQast(op);
			colontmp__3 = ((T229_ <= T230_) ? T229_ : T230_);
			i_6 = ((NI) 1);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA232;
					i_5 = i_6;
					switch ((*(*op).sons->data[i_5]).kind) {
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
					{
						createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*op).sons->data[i_5]).sons->data[((NI) 0)], (*n).info);
						checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, (*n)._kind_6.sons->data[i_5]);
					}
					break;
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
					{
						(*tracked).hasDangerousAssign = NIM_TRUE;
					}
					break;
					default:
					{
					}
					break;
					}
					i_6 += ((NI) 1);
				} LA232: ;
			}
		}
	}
	LA226_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, guardDotAccess__v49b6RRBfUBabmq9bN9c9bCQLA_3)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* g;
{	ri = (*n)._kind_6.sons->data[((NI) 1)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*ri)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	g = (*(*ri)._kind_4.sym)._kind_4.guard;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (g == 0);
		if (T9_) goto LA10_;
		T9_ = (*a).isTopLevel;
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
		if (!((*g).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0))) goto LA15_;
		field = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
			if (!(T19_)) goto LA20_;
			T19_ = !(((*ty).n == 0));
			LA20_: ;
			if (!T19_) goto LA21_;
			field = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*ty).n, (*g).name);
		}
		goto LA17_;
		LA21_: ;
		{
			{
				while (1) {
					NIM_BOOL T26_;
					T26_ = (NIM_BOOL)0;
					T26_ = !((ty == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T26_)) goto LA27_;
					T26_ = ((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
					LA27_: ;
					if (!T26_) goto LA25;
					field = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*ty).n, (*g).name);
					{
						if (!!((field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA30_;
						goto LA24;
					}
					LA30_: ;
					ty = (*ty).sons->data[((NI) 0)];
					{
						if (!(ty == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA34_;
						goto LA24;
					}
					LA34_: ;
					ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(36275087638268176));
				} LA25: ;
			} LA24: ;
		}
		LA17_: ;
		{
			NimStringDesc* T40_;
			if (!(field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA38_;
			T40_ = (NimStringDesc*)0;
			T40_ = rawNewString(((*(*g).name).s ? (*(*g).name).s->Sup.len : 0) + 21);
appendString(T40_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_46));
appendString(T40_, (*(*g).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T40_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_47, NIM_FALSE);
			goto BeforeRet_;
		}
		LA38_: ;
		g = field;
	}
	LA15_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dot;
		NimStringDesc* T54_;
		NimStringDesc* T55_;
		if (!((*g).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))) goto LA43_;
		dot = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45), (*n).info, ((NI) 2));
		asgnRef((void**) (&(*dot)._kind_6.sons->data[((NI) 0)]), (*n)._kind_6.sons->data[((NI) 0)]);
		asgnRef((void**) (&(*dot)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(g));
		asgnRef((void**) (&(*dot).typ), (*g).typ);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** L;
			NI i;
			NI L_2;
			NI T46_;
			L = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			i = ((NI) 0);
			T46_ = ((*a).locked ? (*a).locked->Sup.len : 0);
			L_2 = T46_;
			{
				while (1) {
					if (!(i < L_2)) goto LA48;
					L = &(*a).locked->data[i];
					{
						NIM_BOOL T51_;
						T51_ = (NIM_BOOL)0;
						T51_ = sameTree__Uv9a9aANFtV79cIvUP5jEeyVA(dot, (*L));
						if (!T51_) goto LA52_;
						goto BeforeRet_;
					}
					LA52_: ;
					i += ((NI) 1);
				} LA48: ;
			}
		}
		T54_ = (NimStringDesc*)0;
		T55_ = (NimStringDesc*)0;
		T55_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T54_ = rawNewString((T55_ ? T55_->Sup.len : 0) + 18);
appendString(T54_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_15));
appendString(T54_, T55_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T54_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_48, NIM_FALSE);
	}
	goto LA41_;
	LA43_: ;
	{
		guardGlobal__uVcH3kEIXSlUY0aC9bdqVgg(a, n, g);
	}
	LA41_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addToIntersection__GUjE16ZHjCWJzHju9cSiIyw)(tySequence__8Np6tlClE5az1CyqZdN19bQ** inter, NI s) {
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T9_;
	NI T10_;
{	{
		NI j;
		NI colontmp_;
		NI T2_;
		NI i;
		j = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*inter) ? (*inter)->Sup.len : 0);
		colontmp_ = T2_;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA4;
				j = i;
				{
					if (!(s == (*inter)->data[j].Field0)) goto LA7_;
					(*inter)->data[j].Field1 += ((NI) 1);
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	T9_.Field0 = s;
	T9_.Field1 = ((NI) 1);
	unsureAsgnRef((void**) (&(*inter)), (tySequence__8Np6tlClE5az1CyqZdN19bQ*) incrSeqV3((TGenericSeq*)((*inter)), (&NTI__8Np6tlClE5az1CyqZdN19bQ_)));
	T10_ = (*inter)->Sup.len++;
	(*inter)->data[T10_] = T9_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, catchesAll__6VQZamBo8lrDCYlUIh7Ojg)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked) {
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).exc);
		if (!(((NI) 0) < T3_)) goto LA4_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*tracked).exc)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((*tracked).bottom))));
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, catches__2xMHinEcocVG5PHlkSFsaQ)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* e) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* e_2;
	NI L;
	NI i;
	e_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(e, IL64(36275087638268176));
	L = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).exc);
	i = (*tracked).bottom;
	{
		while (1) {
			if (!(i < L)) goto LA2;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
				NI T6_;
				T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T5_ = excType__9cjUze5Qh6q4dDt6ZAfifVg((*tracked).graph, (*(*tracked).exc)._kind_6.sons->data[i]);
				T6_ = (NI)0;
				T6_ = safeInheritanceDiff__1dM2iQB5qStJfnn3684ijQ(T5_, e_2);
				if (!(T6_ <= ((NI) 0))) goto LA7_;
				asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons->data[i]), (*(*tracked).exc)._kind_6.sons->data[(NI)(L - ((NI) 1))]);
				L -= ((NI) 1);
			}
			goto LA3_;
			LA7_: ;
			{
				i += ((NI) 1);
			}
			LA3_: ;
		} LA2: ;
	}
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).exc);
		if (!(((NI) 0) < T12_)) goto LA13_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*tracked).exc)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (L))));
	}
	goto LA10_;
	LA13_: ;
	{
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackTryStmt__BxqWoS9czp4uFup6HfSkCeA_3)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldBottom;
	NI oldState;
	NI T1_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI branches;
	NIM_BOOL hasFinally;
	oldBottom = (*tracked).bottom;
	(*tracked).bottom = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).exc);
	T1_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T1_;
	inter = NIM_NIL;
	(*tracked).inTryStmt += ((NI) 1);
	track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
	(*tracked).inTryStmt -= ((NI) 1);
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		colontmp_ = T3_;
		i_2 = oldState;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				addToIntersection__GUjE16ZHjCWJzHju9cSiIyw((&inter), (*tracked).init->data[i]);
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	branches = ((NI) 1);
	hasFinally = NIM_FALSE;
	(*tracked).inExceptOrFinallyStmt += ((NI) 1);
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
				if (!(i_4 < colontmp__2)) goto LA8;
				i_3 = i_4;
				b = (*n)._kind_6.sons->data[i_3];
				{
					if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87))) goto LA11_;
					branches += ((NI) 1);
					{
						NI T15_;
						T15_ = (NI)0;
						T15_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
						if (!(T15_ == ((NI) 1))) goto LA16_;
						catchesAll__6VQZamBo8lrDCYlUIh7Ojg(tracked);
					}
					goto LA13_;
					LA16_: ;
					{
						{
							NI j;
							NI colontmp__3;
							NI T20_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T20_ = (NI)0;
							T20_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
							colontmp__3 = (NI)(T20_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA22;
									j = i_5;
									{
										NIM_BOOL T25_;
										T25_ = (NIM_BOOL)0;
										T25_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*b)._kind_6.sons->data[j]);
										if (!T25_) goto LA26_;
										catches__2xMHinEcocVG5PHlkSFsaQ(tracked, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]).typ);
										createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)]).typ, (*(*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)]).info);
									}
									goto LA23_;
									LA26_: ;
									{
										catches__2xMHinEcocVG5PHlkSFsaQ(tracked, (*(*b)._kind_6.sons->data[j]).typ);
									}
									LA23_: ;
									i_5 += ((NI) 1);
								} LA22: ;
							}
						}
					}
					LA13_: ;
				}
				goto LA9_;
				LA11_: ;
				{
				}
				LA9_: ;
				i_4 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI i_6;
		NI colontmp__4;
		NI i_7;
		i_6 = (NI)0;
		colontmp__4 = (NI)0;
		colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_7 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b_2;
				if (!(i_7 < colontmp__4)) goto LA32;
				i_6 = i_7;
				b_2 = (*n)._kind_6.sons->data[i_6];
				{
					NI T37_;
					if (!((*b_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87))) goto LA35_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
					T37_ = (NI)0;
					T37_ = len__P89cqdlERShb9alU3iC0yj8wast(b_2);
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*b_2)._kind_6.sons->data[(NI)(T37_ - ((NI) 1))]);
					{
						NI i_8;
						NI colontmp__5;
						NI T39_;
						NI i_9;
						i_8 = (NI)0;
						colontmp__5 = (NI)0;
						T39_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
						colontmp__5 = T39_;
						i_9 = oldState;
						{
							while (1) {
								if (!(i_9 < colontmp__5)) goto LA41;
								i_8 = i_9;
								addToIntersection__GUjE16ZHjCWJzHju9cSiIyw((&inter), (*tracked).init->data[i_8]);
								i_9 += ((NI) 1);
							} LA41: ;
						}
					}
				}
				goto LA33_;
				LA35_: ;
				{
					NI T43_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
					T43_ = (NI)0;
					T43_ = len__P89cqdlERShb9alU3iC0yj8wast(b_2);
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*b_2)._kind_6.sons->data[(NI)(T43_ - ((NI) 1))]);
					hasFinally = NIM_TRUE;
				}
				LA33_: ;
				i_7 += ((NI) 1);
			} LA32: ;
		}
	}
	(*tracked).bottom = oldBottom;
	(*tracked).inExceptOrFinallyStmt -= ((NI) 1);
	{
		if (!!(hasFinally)) goto LA46_;
		unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	}
	LA46_: ;
	{
		NI* id;
		NI* count;
		NI i_10;
		NI L;
		NI T49_;
		id = (NI*)0;
		count = (NI*)0;
		i_10 = ((NI) 0);
		T49_ = (inter ? inter->Sup.len : 0);
		L = T49_;
		{
			while (1) {
				if (!(i_10 < L)) goto LA51;
				id = (&inter->data[i_10].Field0);
				count = (&inter->data[i_10].Field1);
				{
					NI T56_;
					if (!((*count) == branches)) goto LA54_;
					unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
					T56_ = (*tracked).init->Sup.len++;
					(*tracked).init->data[T56_] = (*id);
				}
				LA54_: ;
				i_10 += ((NI) 1);
			} LA51: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, listEffects__xF9av1b77SGV0Yx9cMchZI5w)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
		e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*a).exc);
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T5_;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					e = (*(*a).exc)._kind_6.sons->data[i];
					T5_ = (NimStringDesc*)0;
					T5_ = typeToString__QlvraUan7WbHowhAbvDvdA((*e).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 80), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_49, NIM_FALSE);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e_2;
		e_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*a).tags);
			i_4 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T10_;
					if (!(i_4 < colontmp__2)) goto LA9;
					i_3 = i_4;
					e_2 = (*(*a).tags)._kind_6.sons->data[i_3];
					T10_ = (NimStringDesc*)0;
					T10_ = typeToString__QlvraUan7WbHowhAbvDvdA((*e_2).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*e_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 80), T10_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_50, NIM_FALSE);
					i_4 += ((NI) 1);
				} LA9: ;
			}
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, trackPragmaStmt__BxqWoS9czp4uFup6HfSkCeA_4)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw pragma;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				pragma = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(it);
				{
					if (!(pragma == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 174))) goto LA6_;
					listEffects__xF9av1b77SGV0Yx9cMchZI5w(tracked);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, breaksBlock__tEyNhG8jDpteKMTOJUposQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	NIM_BOOL T6_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	result = (NIM_BOOL)0;
	it = n;
	{
		while (1) {
			NIM_BOOL T3_;
			NI T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
			if (!(T3_)) goto LA4_;
			T5_ = (NI)0;
			T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
			T3_ = (((NI) 0) < T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			it = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
		} LA2: ;
	}
	T6_ = (NIM_BOOL)0;
	T6_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108));
	if (T6_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T9_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	if (!(T9_)) goto LA10_;
	T9_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	LA10_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA11_;
	T8_ = (((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16))&63U)))!=0);
	LA11_: ;
	T6_ = T8_;
	LA7_: ;
	result = T6_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, trackCase__BxqWoS9czp4uFup6HfSkCeA_5)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldState;
	NI T1_;
	NI oldFacts;
	NI T2_;
	NIM_BOOL stringCase;
	NIM_BOOL T3_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
	NIM_BOOL interesting;
	NIM_BOOL T6_;
	NIM_BOOL T7_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI toCover;
	track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T1_;
	T2_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
	oldFacts = T2_;
	T3_ = (NIM_BOOL)0;
	T3_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	if (!(T3_)) goto LA4_;
	T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T5_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710672));
	T3_ = ((IL64(1031060586496) &((NU64)1<<((NU)((*T5_).kind)&63U)))!=0);
	LA4_: ;
	stringCase = T3_;
	T6_ = (NIM_BOOL)0;
	T7_ = (NIM_BOOL)0;
	T7_ = !(stringCase);
	if (!(T7_)) goto LA8_;
	T7_ = interestingCaseExpr__Cjb9am4YBBe69cf2PXGW7teQ((*n)._kind_6.sons->data[((NI) 0)]);
	LA8_: ;
	T6_ = T7_;
	if (!(T6_)) goto LA9_;
	T6_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 35));
	LA9_: ;
	interesting = T6_;
	inter = NIM_NIL;
	toCover = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				if (!(i_2 < colontmp_)) goto LA12;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
				{
					if (!interesting) goto LA15_;
					unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
					addCaseBranchFacts__c6dE6J2nt777cGY9brPJUJA((&(*tracked).guards), n, i);
				}
				LA15_: ;
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					i_4 = ((NI) 0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA19;
							i_3 = i_4;
							track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*branch)._kind_6.sons->data[i_3]);
							i_4 += ((NI) 1);
						} LA19: ;
					}
				}
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
					NIM_BOOL T23_;
					T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T22_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
					T23_ = (NIM_BOOL)0;
					T23_ = breaksBlock__tEyNhG8jDpteKMTOJUposQ_3(T22_);
					if (!!(T23_)) goto LA24_;
					toCover += ((NI) 1);
				}
				LA24_: ;
				{
					NI i_5;
					NI colontmp__3;
					NI T27_;
					NI i_6;
					i_5 = (NI)0;
					colontmp__3 = (NI)0;
					T27_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
					colontmp__3 = T27_;
					i_6 = oldState;
					{
						while (1) {
							if (!(i_6 < colontmp__3)) goto LA29;
							i_5 = i_6;
							addToIntersection__GUjE16ZHjCWJzHju9cSiIyw((&inter), (*tracked).init->data[i_5]);
							i_6 += ((NI) 1);
						} LA29: ;
					}
				}
				i_2 += ((NI) 1);
			} LA12: ;
		}
	}
	unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	{
		NIM_BOOL T32_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T34_;
		T32_ = (NIM_BOOL)0;
		T32_ = !(stringCase);
		if (T32_) goto LA33_;
		T34_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T34_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		T32_ = ((*T34_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88));
		LA33_: ;
		if (!T32_) goto LA35_;
		{
			NI* id;
			NI* count;
			NI i_7;
			NI L;
			NI T38_;
			id = (NI*)0;
			count = (NI*)0;
			i_7 = ((NI) 0);
			T38_ = (inter ? inter->Sup.len : 0);
			L = T38_;
			{
				while (1) {
					if (!(i_7 < L)) goto LA40;
					id = (&inter->data[i_7].Field0);
					count = (&inter->data[i_7].Field1);
					{
						NI T45_;
						if (!(toCover <= (*count))) goto LA43_;
						unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
						T45_ = (*tracked).init->Sup.len++;
						(*tracked).init->data[T45_] = (*id);
					}
					LA43_: ;
					i_7 += ((NI) 1);
				} LA40: ;
			}
		}
	}
	LA35_: ;
	unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, trackIf__BxqWoS9czp4uFup6HfSkCeA_6)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI oldFacts;
	NI T1_;
	NI oldState;
	NI T2_;
	tySequence__8Np6tlClE5az1CyqZdN19bQ* inter;
	NI toCover;
	track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T1_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
	oldFacts = T1_;
	addFact__ybuIey7mglQLm61kxh9aaLg((&(*tracked).guards), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
	T2_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
	oldState = T2_;
	inter = NIM_NIL;
	toCover = ((NI) 0);
	track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = breaksBlock__tEyNhG8jDpteKMTOJUposQ_3((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
		if (!!(T5_)) goto LA6_;
		toCover += ((NI) 1);
	}
	LA6_: ;
	{
		NI i;
		NI colontmp_;
		NI T9_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T9_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		colontmp_ = T9_;
		i_2 = oldState;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA11;
				i = i_2;
				addToIntersection__GUjE16ZHjCWJzHju9cSiIyw((&inter), (*tracked).init->data[i]);
				i_2 += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				if (!(i_4 < colontmp__2)) goto LA14;
				i_3 = i_4;
				branch = (*n)._kind_6.sons->data[i_3];
				unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
				{
					NI j;
					NI colontmp__3;
					NI res;
					j = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = (NI)(i_3 - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= colontmp__3)) goto LA17;
							j = res;
							addFactNeg__no3iuruVlFxE0wQ8HA9b4ZA_2((&(*tracked).guards), (*(*n)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
							res += ((NI) 1);
						} LA17: ;
					}
				}
				{
					NI T20_;
					T20_ = (NI)0;
					T20_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					if (!(((NI) 1) < T20_)) goto LA21_;
					addFact__ybuIey7mglQLm61kxh9aaLg((&(*tracked).guards), (*branch)._kind_6.sons->data[((NI) 0)]);
				}
				LA21_: ;
				unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
				{
					NI i_5;
					NI colontmp__4;
					NI i_6;
					i_5 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					i_6 = ((NI) 0);
					{
						while (1) {
							if (!(i_6 < colontmp__4)) goto LA25;
							i_5 = i_6;
							track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*branch)._kind_6.sons->data[i_5]);
							i_6 += ((NI) 1);
						} LA25: ;
					}
				}
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
					NIM_BOOL T29_;
					T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T28_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
					T29_ = (NIM_BOOL)0;
					T29_ = breaksBlock__tEyNhG8jDpteKMTOJUposQ_3(T28_);
					if (!!(T29_)) goto LA30_;
					toCover += ((NI) 1);
				}
				LA30_: ;
				{
					NI i_7;
					NI colontmp__5;
					NI T33_;
					NI i_8;
					i_7 = (NI)0;
					colontmp__5 = (NI)0;
					T33_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
					colontmp__5 = T33_;
					i_8 = oldState;
					{
						while (1) {
							if (!(i_8 < colontmp__5)) goto LA35;
							i_7 = i_8;
							addToIntersection__GUjE16ZHjCWJzHju9cSiIyw((&inter), (*tracked).init->data[i_7]);
							i_8 += ((NI) 1);
						} LA35: ;
					}
				}
				i_4 += ((NI) 1);
			} LA14: ;
		}
	}
	unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T38_;
		NI T39_;
		T38_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T38_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		T39_ = (NI)0;
		T39_ = len__P89cqdlERShb9alU3iC0yj8wast(T38_);
		if (!(T39_ == ((NI) 1))) goto LA40_;
		{
			NI* id;
			NI* count;
			NI i_9;
			NI L;
			NI T43_;
			id = (NI*)0;
			count = (NI*)0;
			i_9 = ((NI) 0);
			T43_ = (inter ? inter->Sup.len : 0);
			L = T43_;
			{
				while (1) {
					if (!(i_9 < L)) goto LA45;
					id = (&inter->data[i_9].Field0);
					count = (&inter->data[i_9].Field1);
					{
						NI T50_;
						if (!(toCover <= (*count))) goto LA48_;
						unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*tracked).init), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
						T50_ = (*tracked).init->Sup.len++;
						(*tracked).init->data[T50_] = (*id);
					}
					LA48_: ;
					i_9 += ((NI) 1);
				} LA45: ;
			}
		}
	}
	LA40_: ;
	unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
}
N_LIB_PRIVATE N_NIMCALL(void, trackBlock__BxqWoS9czp4uFup6HfSkCeA_7)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI oldState;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA3_;
		oldState = ((NI) -1);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					{
						NIM_BOOL T10_;
						T10_ = (NIM_BOOL)0;
						T10_ = hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q((*n)._kind_6.sons->data[i], ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110));
						if (!T10_) goto LA11_;
						{
							NI T17_;
							if (!(oldState < ((NI) 0))) goto LA15_;
							T17_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
							oldState = T17_;
						}
						LA15_: ;
					}
					LA11_: ;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			if (!(((NI) 0) < oldState)) goto LA20_;
			unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
		}
		LA20_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, n);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op) {
	NIM_BOOL result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (NIM_BOOL)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(op);
	result = (((*T1_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createBlockContext__TopuOXu0dZKMo9cbsDb040g)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* Result) {
	NI T1_;
	(*Result).oldLocked = 0;
	(*Result).oldLockLevel = 0;
	(*Result).enforcedGcSafety = 0;
	(*Result).enforceNoSideEffects = 0;
	(*Result).oldExc = 0;
	(*Result).oldTags = 0;
	unsureAsgnRef((void**)&(*Result).exc, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).tags, NIM_NIL);
	T1_ = ((*tracked).locked ? (*tracked).locked->Sup.len : 0);
	(*Result).oldLocked = T1_;
	(*Result).oldLockLevel = (*tracked).currLockLevel;
	(*Result).enforcedGcSafety = NIM_FALSE;
	(*Result).enforceNoSideEffects = NIM_FALSE;
	(*Result).oldExc = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).exc);
	(*Result).oldTags = len__P89cqdlERShb9alU3iC0yj8wast((*tracked).tags);
}
N_LIB_PRIVATE N_NIMCALL(NI16, getLockLevel__89axjo8eKrzLzKfec1W1U5g)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NI16 result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	result = (NI16)0;
	t_2 = t;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t_2);
		T3_ = (T5_ == ((NI) 3));
		LA4_: ;
		if (!T3_) goto LA6_;
		t_2 = (*t_2).sons->data[((NI) 1)];
	}
	LA6_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
		if (!(T11_)) goto LA12_;
		T11_ = !(((*t_2).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = ((*(*t_2).n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*(*t_2).n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10));
		LA13_: ;
		if (!T10_) goto LA14_;
		result = ((NI16) ((*(*t_2).n)._kind_1.intVal));
	}
	LA14_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, lockLocations__lHiCtldbW2F1ISjGLbel5Q)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma) {
	NI16 firstLL;
{	{
		if (!!(((*pragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*pragma).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_56), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_57, NIM_FALSE);
		goto BeforeRet_;
	}
	LA3_: ;
	firstLL = ((NI16) -1);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp_;
		x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp_ = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			NI i;
			NI colontmp__2;
			NI i_2;
			i = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp_);
			i_2 = ((NI) 0);
			{
				while (1) {
					NI16 thisLL;
					NI T27_;
					if (!(i_2 < colontmp__2)) goto LA8;
					i = i_2;
					x = (*colontmp_)._kind_6.sons->data[i];
					thisLL = getLockLevel__89axjo8eKrzLzKfec1W1U5g((*x).typ);
					{
						if (!!((thisLL == ((NI16) 0)))) goto LA11_;
						{
							NIM_BOOL T15_;
							NimStringDesc* T19_;
							NimStringDesc* T20_;
							T15_ = (NIM_BOOL)0;
							T15_ = (thisLL < ((NI16) 0));
							if (T15_) goto LA16_;
							T15_ = (((NI16) 1000) < thisLL);
							LA16_: ;
							if (!T15_) goto LA17_;
							T19_ = (NimStringDesc*)0;
							T20_ = (NimStringDesc*)0;
							T20_ = dollar___75vsOXLrqmx5LmVlMWaymw(thisLL);
							T19_ = rawNewString((T20_ ? T20_->Sup.len : 0) + 20);
appendString(T19_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_58));
appendString(T19_, T20_);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_59, NIM_FALSE);
						}
						goto LA13_;
						LA17_: ;
						{
							if (!(firstLL < ((NI16) 0))) goto LA22_;
							firstLL = thisLL;
						}
						goto LA13_;
						LA22_: ;
						{
							if (!!((firstLL == thisLL))) goto LA25_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_60), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_61, NIM_FALSE);
						}
						goto LA13_;
						LA25_: ;
						LA13_: ;
						(*a).maxLockLevel = (((*a).maxLockLevel >= firstLL) ? (*a).maxLockLevel : firstLL);
					}
					LA11_: ;
					unsureAsgnRef((void**) (&(*a).locked), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*a).locked), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
					T27_ = (*a).locked->Sup.len++;
					asgnRef((void**) (&(*a).locked->data[T27_]), x);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	{
		NIM_BOOL T30_;
		T30_ = (NIM_BOOL)0;
		T30_ = (((NI16) 0) <= firstLL);
		if (!(T30_)) goto LA31_;
		T30_ = !((firstLL == (*a).currLockLevel));
		LA31_: ;
		if (!T30_) goto LA32_;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = (((NI16) 0) < (*a).currLockLevel);
			if (!(T36_)) goto LA37_;
			T36_ = ((*a).currLockLevel <= firstLL);
			LA37_: ;
			if (!T36_) goto LA38_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*a).config, (*pragma).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_62), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_63, NIM_FALSE);
		}
		LA38_: ;
		(*a).currLockLevel = firstLL;
	}
	LA32_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, castBlock__N7knXaDQwsgL82WukZJVdw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc) {
	tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T1_;
	T1_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
	T1_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(pragma);
	switch (T1_) {
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 107):
	{
		(*bc).enforcedGcSafety = NIM_TRUE;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 106):
	{
		(*bc).enforceNoSideEffects = NIM_TRUE;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		n = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA7_;
			unsureAsgnRef((void**) (&(*bc).tags), n);
		}
		goto LA5_;
		LA7_: ;
		{
			unsureAsgnRef((void**) (&(*bc).tags), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*pragma).info));
			add__P8dDSotTW25BkfbyspojGg((*bc).tags, n);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
		n_2 = (*pragma)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA13_;
			unsureAsgnRef((void**) (&(*bc).exc), n_2);
		}
		goto LA11_;
		LA13_: ;
		{
			unsureAsgnRef((void**) (&(*bc).exc), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*pragma).info));
			add__P8dDSotTW25BkfbyspojGg((*bc).exc, n_2);
		}
		LA11_: ;
	}
	break;
	default:
	{
		NimStringDesc* T17_;
		NimStringDesc* T18_;
		T17_ = (NimStringDesc*)0;
		T18_ = (NimStringDesc*)0;
		T18_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(pragma);
		T17_ = rawNewString((T18_ ? T18_->Sup.len : 0) + 22);
appendString(T17_, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_64));
appendString(T17_, T18_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*tracked).config, (*pragma).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T17_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_65, NIM_FALSE);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, applyBlockContext__mGV64s49b4A3mxXAc5kqSLw)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc) {
	{
		if (!(*bc).enforcedGcSafety) goto LA3_;
		(*tracked).inEnforcedGcSafe = NIM_TRUE;
	}
	LA3_: ;
	{
		if (!(*bc).enforceNoSideEffects) goto LA7_;
		(*tracked).inEnforcedNoSideEffects = NIM_TRUE;
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, unapplyBlockContext__mGV64s49b4A3mxXAc5kqSLw_2)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA* bc) {
	{
		if (!(*bc).enforcedGcSafety) goto LA3_;
		(*tracked).inEnforcedGcSafe = NIM_FALSE;
	}
	LA3_: ;
	{
		if (!(*bc).enforceNoSideEffects) goto LA7_;
		(*tracked).inEnforcedNoSideEffects = NIM_FALSE;
	}
	LA7_: ;
	unsureAsgnRef((void**) (&(*tracked).locked), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).locked)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((*bc).oldLocked))));
	(*tracked).currLockLevel = (*bc).oldLockLevel;
	{
		if (!!(((*bc).exc == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA11_;
		asgnRef((void**) (&(*(*tracked).exc)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*tracked).exc)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((*bc).oldExc))));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
			e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*bc).exc);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						e = (*(*bc).exc)._kind_6.sons->data[i];
						addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(tracked, e, e);
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
	}
	LA11_: ;
	{
		if (!!(((*bc).tags == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA19_;
		asgnRef((void**) (&(*(*tracked).tags)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*tracked).tags)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((*bc).oldTags))));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t;
			t = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*bc).tags);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA24;
						i_3 = i_4;
						t = (*(*bc).tags)._kind_6.sons->data[i_3];
						addTag__hDlm2Cal6ET3nLFp2KWZCw_2(tracked, t, t);
						i_4 += ((NI) 1);
					} LA24: ;
				}
			}
		}
	}
	LA19_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkRange__rXwUdIKp4I5JvdsIihJhKA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lowBound;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* highBound;
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20))) goto LA3_;
		lowBound = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*t).n)._kind_6.sons->data[((NI) 0)]);
		(*lowBound).info = (*value).info;
		highBound = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*t).n)._kind_6.sons->data[((NI) 1)]);
		(*highBound).info = (*value).info;
		checkLe__7CUcxkdNhLZqHv8xsVpwiQ(c, lowBound, value);
		checkLe__7CUcxkdNhLZqHv8xsVpwiQ(c, value, highBound);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, track__BxqWoS9czp4uFup6HfSkCeA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* tracked, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		useVar__v49b6RRBfUBabmq9bN9c9bCQLA(tracked, n);
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = !(((*(*n)._kind_4.sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T4_)) goto LA5_;
			T4_ = (((*(*(*n)._kind_4.sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0);
			LA5_: ;
			if (!T4_) goto LA6_;
			(*(*tracked).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = !(!(((IL64(2147483664) & (*(*n).typ).flags) == 0)));
				if (!(T10_)) goto LA11_;
				T10_ = sameType__3isNyHKb0U1OCnClmflXSg((*n).typ, (*(*n)._kind_4.sym).typ, 0);
				LA11_: ;
				if (!T10_) goto LA12_;
				asgnRef((void**) (&(*n).typ), (*(*n)._kind_4.sym).typ);
			}
			LA12_: ;
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	{
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T17_)) goto LA18_;
			T17_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			LA18_: ;
			if (!T17_) goto LA19_;
			useVarNoInitCheck__njQS7vGGH2ZwpdWseR6sDg(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		}
		goto LA15_;
		LA19_: ;
		{
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA15_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA25_;
			(*(*n)._kind_6.sons->data[((NI) 0)]).info = (*n).info;
			addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(tracked, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA29;
						i = i_2;
						track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA29: ;
				}
			}
			createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
		}
		goto LA23_;
		LA25_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
			T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T31_ = createRaise__2aachO6llLVwCKPPPmABpQ((*tracked).graph, n);
			addRaiseEffect__hDlm2Cal6ET3nLFp2KWZCw(tracked, T31_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		}
		LA23_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		trackCall__BxqWoS9czp4uFup6HfSkCeA_2(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		guardDotAccess__v49b6RRBfUBabmq9bN9c9bCQLA_3(tracked, n);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA36;
					i_3 = i_4;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_3]);
					i_4 += ((NI) 1);
				} LA36: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = hasWarn__zh6OC34d9cPUHXjZ4qVA9bkw((*tracked).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 35));
			if (!T40_) goto LA41_;
			checkFieldAccess__gGwSETIBbm3kg36plDGFGg((&(*tracked).guards), n, (*tracked).config);
		}
		LA41_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	{
		trackTryStmt__BxqWoS9czp4uFup6HfSkCeA_3(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		trackPragmaStmt__BxqWoS9czp4uFup6HfSkCeA_4(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
		initVar__9cnMyHEtl3Vw3Eik8EejmRA(tracked, (*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
		invalidateFacts__no3iuruVlFxE0wQ8HA9b4ZA((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn += ((NI) 1);
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn -= ((NI) 1);
		addAsgnFact__0CHSuARDyWZ57Xrosqy78w((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
		notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
		{
			if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA48_;
			createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
		}
		LA48_: ;
		{
			NIM_BOOL T52_;
			NIM_BOOL T54_;
			T52_ = (NIM_BOOL)0;
			T52_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
			if (T52_) goto LA53_;
			T54_ = (NIM_BOOL)0;
			T54_ = isLocalVar__YlEQSKBgYhMDInPoOkeWuQ(tracked, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			T52_ = !(T54_);
			LA53_: ;
			if (!T52_) goto LA55_;
			checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				NIM_BOOL T59_;
				T59_ = (NIM_BOOL)0;
				T59_ = !((*tracked).hasDangerousAssign);
				if (!(T59_)) goto LA60_;
				T59_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
				LA60_: ;
				if (!T59_) goto LA61_;
				(*tracked).hasDangerousAssign = NIM_TRUE;
			}
			LA61_: ;
		}
		LA55_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* last;
						if (!(i_6 < colontmp__3)) goto LA67;
						i_5 = i_6;
						child = (*n)._kind_6.sons->data[i_5];
						last = lastSon__UPSW0jLTX5qJL51YMUAHgw(child);
						{
							if (!!(((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA70_;
							track__BxqWoS9czp4uFup6HfSkCeA(tracked, last);
						}
						LA70_: ;
						{
							if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA74_;
							{
								NI T80_;
								if (!((*child).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA78_;
								T80_ = (NI)0;
								T80_ = len__P89cqdlERShb9alU3iC0yj8wast(child);
								createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*child)._kind_6.sons->data[(NI)(T80_ - ((NI) 1))]).typ, (*child).info);
								{
									NI i_7;
									NI colontmp__4;
									NI T82_;
									NI i_8;
									i_7 = (NI)0;
									colontmp__4 = (NI)0;
									T82_ = (NI)0;
									T82_ = len__P89cqdlERShb9alU3iC0yj8wast(child);
									colontmp__4 = (NI)(T82_ - ((NI) 2));
									i_8 = ((NI) 0);
									{
										while (1) {
											if (!(i_8 < colontmp__4)) goto LA84;
											i_7 = i_8;
											createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*child)._kind_6.sons->data[i_7]).typ, (*child).info);
											i_8 += ((NI) 1);
										} LA84: ;
									}
								}
							}
							goto LA76_;
							LA78_: ;
							{
								createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*child)._kind_6.sons->data[((NI) 0)]).typ, (*child).info);
							}
							LA76_: ;
						}
						LA74_: ;
						{
							NIM_BOOL T88_;
							T88_ = (NIM_BOOL)0;
							T88_ = ((*child).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35));
							if (!(T88_)) goto LA89_;
							T88_ = !(((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
							LA89_: ;
							if (!T88_) goto LA90_;
							{
								NI i_9;
								NI colontmp__5;
								NI T93_;
								NI i_10;
								i_9 = (NI)0;
								colontmp__5 = (NI)0;
								T93_ = (NI)0;
								T93_ = len__P89cqdlERShb9alU3iC0yj8wast(child);
								colontmp__5 = (NI)(T93_ - ((NI) 2));
								i_10 = ((NI) 0);
								{
									while (1) {
										if (!(i_10 < colontmp__5)) goto LA95;
										i_9 = i_10;
										initVar__9cnMyHEtl3Vw3Eik8EejmRA(tracked, (*child)._kind_6.sons->data[i_9], NIM_FALSE);
										addAsgnFact__0CHSuARDyWZ57Xrosqy78w((&(*tracked).guards), (*child)._kind_6.sons->data[i_9], last);
										notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ(tracked, last, (*(*child)._kind_6.sons->data[i_9]).typ);
										i_10 += ((NI) 1);
									} LA95: ;
								}
							}
						}
						goto LA86_;
						LA90_: ;
						{
							NIM_BOOL T97_;
							T97_ = (NIM_BOOL)0;
							T97_ = ((*child).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36));
							if (!(T97_)) goto LA98_;
							T97_ = !(((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
							LA98_: ;
							if (!T97_) goto LA99_;
							{
								NI i_11;
								NI colontmp__6;
								NI T102_;
								NI i_12;
								i_11 = (NI)0;
								colontmp__6 = (NI)0;
								T102_ = (NI)0;
								T102_ = len__P89cqdlERShb9alU3iC0yj8wast(child);
								colontmp__6 = (NI)(T102_ - ((NI) 1));
								i_12 = ((NI) 0);
								{
									while (1) {
										if (!(i_12 < colontmp__6)) goto LA104;
										i_11 = i_12;
										{
											{
												NIM_BOOL T108_;
												NIM_BOOL T110_;
												T108_ = (NIM_BOOL)0;
												T108_ = ((*(*child)._kind_6.sons->data[i_11]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
												if (T108_) goto LA109_;
												T110_ = (NIM_BOOL)0;
												T110_ = ((*(*child)._kind_6.sons->data[i_11]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
												if (!(T110_)) goto LA111_;
												T110_ = eqStrings((*(*(*(*child)._kind_6.sons->data[i_11])._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_51));
												LA111_: ;
												T108_ = T110_;
												LA109_: ;
												if (!T108_) goto LA112_;
												goto LA105;
											}
											LA112_: ;
											initVar__9cnMyHEtl3Vw3Eik8EejmRA(tracked, (*child)._kind_6.sons->data[i_11], NIM_FALSE);
											{
												if (!((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA116_;
												addAsgnFact__0CHSuARDyWZ57Xrosqy78w((&(*tracked).guards), (*child)._kind_6.sons->data[i_11], (*last)._kind_6.sons->data[i_11]);
												notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ(tracked, (*last)._kind_6.sons->data[i_11], (*(*child)._kind_6.sons->data[i_11]).typ);
											}
											LA116_: ;
										} LA105: ;
										i_12 += ((NI) 1);
									} LA104: ;
								}
							}
						}
						goto LA86_;
						LA99_: ;
						LA86_: ;
						i_6 += ((NI) 1);
					} LA67: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child_2;
			child_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_13;
				NI colontmp__7;
				NI i_14;
				i_13 = (NI)0;
				colontmp__7 = (NI)0;
				colontmp__7 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_14 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* last_2;
						if (!(i_14 < colontmp__7)) goto LA122;
						i_13 = i_14;
						child_2 = (*n)._kind_6.sons->data[i_13];
						last_2 = lastSon__UPSW0jLTX5qJL51YMUAHgw(child_2);
						track__BxqWoS9czp4uFup6HfSkCeA(tracked, last_2);
						i_14 += ((NI) 1);
					} LA122: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		trackCase__BxqWoS9czp4uFup6HfSkCeA_5(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		trackIf__BxqWoS9czp4uFup6HfSkCeA_6(tracked, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		trackBlock__BxqWoS9czp4uFup6HfSkCeA_7(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		{
			NIM_BOOL T129_;
			T129_ = (NIM_BOOL)0;
			T129_ = isTrue__9cP6JNeOKqczaXCI4Zo4SBQ_5((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T129_) goto LA130_;
			trackBlock__BxqWoS9czp4uFup6HfSkCeA_7(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
		}
		goto LA127_;
		LA130_: ;
		{
			NI oldState;
			NI T133_;
			NI oldFacts;
			NI T134_;
			T133_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
			oldState = T133_;
			T134_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
			oldFacts = T134_;
			addFact__ybuIey7mglQLm61kxh9aaLg((&(*tracked).guards), (*n)._kind_6.sons->data[((NI) 0)]);
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState))));
			unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts))));
		}
		LA127_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		NI oldState_2;
		NI T136_;
		NI oldFacts_2;
		NI T137_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* iterCall;
		NI T138_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
		NI T175_;
		T136_ = ((*tracked).init ? (*tracked).init->Sup.len : 0);
		oldState_2 = T136_;
		T137_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
		oldFacts_2 = T137_;
		T138_ = (NI)0;
		T138_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		iterCall = (*n)._kind_6.sons->data[(NI)(T138_ - ((NI) 2))];
		{
			NIM_BOOL T141_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
			T141_ = (NIM_BOOL)0;
			T141_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0);
			if (!(T141_)) goto LA142_;
			T141_ = ((*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*iterCall).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
			LA142_: ;
			if (!T141_) goto LA143_;
			op = (*iterCall)._kind_6.sons->data[((NI) 0)];
			{
				NIM_BOOL T147_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* iterVar;
				T147_ = (NIM_BOOL)0;
				T147_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T147_)) goto LA148_;
				T147_ = fromSystem__koLUZmQCBRKFmUFVrVvuPQastalgo((*op)._kind_4.sym);
				LA148_: ;
				if (!T147_) goto LA149_;
				iterVar = (*n)._kind_6.sons->data[((NI) 0)];
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_52))) goto LA151_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_53))) goto LA151_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_54))) goto LA151_;
				if (eqStrings((*(*(*op)._kind_4.sym).name).s, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_55))) goto LA152_;
				goto LA153_;
				LA151_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lower;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* upper;
					lower = (*iterCall)._kind_6.sons->data[((NI) 1)];
					upper = (*iterCall)._kind_6.sons->data[((NI) 2)];
					addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng((&(*tracked).guards), lower, iterVar);
					addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng((&(*tracked).guards), iterVar, upper);
				}
				goto LA154_;
				LA152_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lower_2;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* upper_2;
					lower_2 = (*iterCall)._kind_6.sons->data[((NI) 1)];
					upper_2 = (*iterCall)._kind_6.sons->data[((NI) 2)];
					addFactLe__i9aAoMzJNp9aw6KruJgPZ0Ng((&(*tracked).guards), lower_2, iterVar);
					addFactLt__i9aAoMzJNp9aw6KruJgPZ0Ng_2((&(*tracked).guards), iterVar, upper_2);
				}
				goto LA154_;
				LA153_: ;
				{
				}
				LA154_: ;
			}
			LA149_: ;
		}
		LA143_: ;
		{
			NI i_15;
			NI colontmp__8;
			NI T159_;
			NI i_16;
			i_15 = (NI)0;
			colontmp__8 = (NI)0;
			T159_ = (NI)0;
			T159_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp__8 = (NI)(T159_ - ((NI) 2));
			i_16 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					if (!(i_16 < colontmp__8)) goto LA161;
					i_15 = i_16;
					it = (*n)._kind_6.sons->data[i_15];
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, it);
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA164_;
						{
							if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA168_;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
								x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								{
									NI i_17;
									NI colontmp__9;
									NI i_18;
									i_17 = (NI)0;
									colontmp__9 = (NI)0;
									colontmp__9 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
									i_18 = ((NI) 0);
									{
										while (1) {
											if (!(i_18 < colontmp__9)) goto LA173;
											i_17 = i_18;
											x = (*it)._kind_6.sons->data[i_17];
											createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*x).typ, (*x).info);
											i_18 += ((NI) 1);
										} LA173: ;
									}
								}
							}
						}
						goto LA166_;
						LA168_: ;
						{
							createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*it).typ, (*it).info);
						}
						LA166_: ;
					}
					LA164_: ;
					i_16 += ((NI) 1);
				} LA161: ;
			}
		}
		T175_ = (NI)0;
		T175_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		loopBody = (*n)._kind_6.sons->data[(NI)(T175_ - ((NI) 1))];
		{
			NIM_BOOL T178_;
			NI T180_;
			T178_ = (NIM_BOOL)0;
			T178_ = !(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
			if (!(T178_)) goto LA179_;
			T180_ = (NI)0;
			T180_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(iterCall);
			T178_ = (((NI) 1) < T180_);
			LA179_: ;
			if (!T178_) goto LA181_;
			{
				NIM_BOOL T185_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T187_;
				T185_ = (NIM_BOOL)0;
				T185_ = !(((*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T185_)) goto LA186_;
				T187_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T187_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
				T185_ = !(((IL64(281475110928384) &((NU64)1<<((NU)((*T187_).kind)&63U)))!=0));
				LA186_: ;
				if (!T185_) goto LA188_;
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*iterCall)._kind_6.sons->data[((NI) 1)]).typ, (*(*iterCall)._kind_6.sons->data[((NI) 1)]).info);
			}
			LA188_: ;
		}
		LA181_: ;
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, iterCall);
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, loopBody);
		unsureAsgnRef((void**) (&(*tracked).init), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) setLengthSeqV2(&((*tracked).init)->Sup, (&NTI__qwqHTkRvwhrRyENtudHQ7g_), ((NI) (oldState_2))));
		unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts_2))));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	{
		NI oldFacts_3;
		NI T191_;
		T191_ = ((*tracked).guards.s ? (*tracked).guards.s->Sup.len : 0);
		oldFacts_3 = T191_;
		{
			NI i_19;
			NI colontmp__10;
			NI i_20;
			i_19 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_20 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x_2;
					if (!(i_20 < colontmp__10)) goto LA194;
					i_19 = i_20;
					x_2 = (*n)._kind_6.sons->data[i_19];
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, x_2);
					{
						NIM_BOOL T197_;
						T197_ = (NIM_BOOL)0;
						T197_ = ((*(*x_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T197_)) goto LA198_;
						T197_ = (((*(*(*x_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20))&63U)))!=0);
						LA198_: ;
						if (!T197_) goto LA199_;
						addDiscriminantFact__no3iuruVlFxE0wQ8HA9b4ZA_3((&(*tracked).guards), x_2);
					}
					LA199_: ;
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA203_;
						createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*x_2)._kind_6.sons->data[((NI) 1)]).typ, (*n).info);
					}
					LA203_: ;
					{
						if (!((*x_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA207_;
						{
							if (!((*(*x_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA211_;
							notNilCheck__FX9ajqYTj7Kqx6JBznhB5sQ(tracked, (*x_2)._kind_6.sons->data[((NI) 1)], (*(*(*x_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).typ);
						}
						LA211_: ;
						checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, (*x_2)._kind_6.sons->data[((NI) 1)]);
					}
					goto LA205_;
					LA207_: ;
					{
						checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, x_2);
					}
					LA205_: ;
					i_20 += ((NI) 1);
				} LA194: ;
			}
		}
		unsureAsgnRef((void**) (&(*tracked).guards.s), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*tracked).guards.s)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (oldFacts_3))));
		{
			if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA216_;
			{
				NIM_BOOL T220_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T222_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T225_;
				T220_ = (NIM_BOOL)0;
				T220_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T220_)) goto LA221_;
				T222_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T222_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
				T220_ = ((*T222_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22));
				LA221_: ;
				if (!T220_) goto LA223_;
				T225_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T225_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*n).typ);
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, T225_, (*n).info);
			}
			LA223_: ;
			createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
		}
		LA216_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		{
			NI i_21;
			NI colontmp__11;
			NI i_22;
			i_21 = (NI)0;
			colontmp__11 = (NI)0;
			colontmp__11 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_22 = ((NI) 0);
			{
				while (1) {
					if (!(i_22 < colontmp__11)) goto LA229;
					i_21 = i_22;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_21]);
					{
						if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA232_;
						{
							if (!((*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA236_;
							createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*(*n)._kind_6.sons->data[i_21])._kind_6.sons->data[((NI) 0)]).typ, (*n).info);
						}
						goto LA234_;
						LA236_: ;
						{
							createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[i_21]).typ, (*n).info);
						}
						LA234_: ;
					}
					LA232_: ;
					checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, (*n)._kind_6.sons->data[i_21]);
					i_22 += ((NI) 1);
				} LA229: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 91):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaList;
		tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA bc;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T248_;
		pragmaList = (*n)._kind_6.sons->data[((NI) 0)];
		nimZeroMem((void*)(&bc), sizeof(tyObject_PragmaBlockContext__DP9bc9bSMlNScWp9cz3kkmIBA));
		createBlockContext__TopuOXu0dZKMo9cbsDb040g(tracked, (&bc));
		{
			NI i_23;
			NI colontmp__12;
			NI i_24;
			i_23 = (NI)0;
			colontmp__12 = (NI)0;
			colontmp__12 = len__P89cqdlERShb9alU3iC0yj8wast(pragmaList);
			i_24 = ((NI) 0);
			{
				while (1) {
					tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw pragma;
					if (!(i_24 < colontmp__12)) goto LA242;
					i_23 = i_24;
					pragma = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw((*pragmaList)._kind_6.sons->data[i_23]);
					switch (pragma) {
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 218):
					{
						lockLocations__lHiCtldbW2F1ISjGLbel5Q(tracked, (*pragmaList)._kind_6.sons->data[i_23]);
					}
					break;
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 107):
					{
						bc.enforcedGcSafety = NIM_TRUE;
					}
					break;
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 106):
					{
						bc.enforceNoSideEffects = NIM_TRUE;
					}
					break;
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 9):
					{
						castBlock__N7knXaDQwsgL82WukZJVdw(tracked, (*(*pragmaList)._kind_6.sons->data[i_23])._kind_6.sons->data[((NI) 1)], (&bc));
					}
					break;
					default:
					{
					}
					break;
					}
					i_24 += ((NI) 1);
				} LA242: ;
			}
		}
		applyBlockContext__mGV64s49b4A3mxXAc5kqSLw(tracked, (&bc));
		T248_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T248_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, T248_);
		unapplyBlockContext__mGV64s49b4A3mxXAc5kqSLw_2(tracked, (&bc));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		{
			NI T253_;
			T253_ = (NI)0;
			T253_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T253_ == ((NI) 2))) goto LA254_;
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA258_;
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
			}
			LA258_: ;
		}
		LA254_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		{
			NI T263_;
			T263_ = (NI)0;
			T263_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T263_ == ((NI) 2))) goto LA264_;
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA268_;
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
				{
					if (!!(((*(*(*n)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)))) goto LA272_;
					createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, (*(*n)._kind_6.sons->data[((NI) 1)]).info);
				}
				LA272_: ;
			}
			LA268_: ;
			{
				if (!(((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0)) goto LA276_;
				checkRange__rXwUdIKp4I5JvdsIihJhKA(tracked, (*n)._kind_6.sons->data[((NI) 1)], (*n).typ);
			}
			LA276_: ;
		}
		LA264_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	{
		{
			NI T281_;
			T281_ = (NI)0;
			T281_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T281_ == ((NI) 1))) goto LA282_;
			track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA286_;
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
				createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (*(*n)._kind_6.sons->data[((NI) 0)]).info);
			}
			LA286_: ;
			{
				if (!(((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0)) goto LA290_;
				checkRange__rXwUdIKp4I5JvdsIihJhKA(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*n).typ);
			}
			LA290_: ;
		}
		LA282_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		{
			NI i_25;
			NI colontmp__13;
			NI i_26;
			i_25 = (NI)0;
			colontmp__13 = (NI)0;
			colontmp__13 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_26 = ((NI) 0);
			{
				while (1) {
					if (!(i_26 < colontmp__13)) goto LA295;
					i_25 = i_26;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_25]);
					checkForSink__2juoX30KP12DlcWVrUGDWw((*tracked).config, (*tracked).owner, (*n)._kind_6.sons->data[i_25]);
					i_26 += ((NI) 1);
				} LA295: ;
			}
		}
		{
			if (!!(((*(*tracked).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA298_;
			createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw(tracked, (*n).typ, (*n).info);
		}
		LA298_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		{
			NIM_BOOL T303_;
			NI T305_;
			T303_ = (NIM_BOOL)0;
			T303_ = (((*tracked).currOptions &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0);
			if (!(T303_)) goto LA304_;
			T305_ = (NI)0;
			T305_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T303_ = (T305_ == ((NI) 2));
			LA304_: ;
			if (!T303_) goto LA306_;
			{
				NIM_BOOL T310_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T312_;
				T310_ = (NIM_BOOL)0;
				T310_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T310_)) goto LA311_;
				T312_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T312_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087632017680));
				T310_ = !(((*T312_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)));
				LA311_: ;
				if (!T310_) goto LA313_;
				checkBounds__5TEFk9a9cl6Se9bkEpUPsbTTg(tracked, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
			}
			LA313_: ;
		}
		LA306_: ;
		track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[((NI) 0)]);
		(*tracked).leftPartOfAsgn -= ((NI) 1);
		{
			NI i_27;
			NI colontmp__14;
			NI i_28;
			i_27 = (NI)0;
			colontmp__14 = (NI)0;
			colontmp__14 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_28 = ((NI) 1);
			{
				while (1) {
					if (!(i_28 < colontmp__14)) goto LA317;
					i_27 = i_28;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_27]);
					i_28 += ((NI) 1);
				} LA317: ;
			}
		}
		(*tracked).leftPartOfAsgn += ((NI) 1);
	}
	break;
	default:
	{
		{
			NI i_29;
			NI colontmp__15;
			NI i_30;
			i_29 = (NI)0;
			colontmp__15 = (NI)0;
			colontmp__15 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_30 = ((NI) 0);
			{
				while (1) {
					if (!(i_30 < colontmp__15)) goto LA321;
					i_29 = i_30;
					track__BxqWoS9czp4uFup6HfSkCeA(tracked, (*n)._kind_6.sons->data[i_29]);
					i_30 += ((NI) 1);
				} LA321: ;
			}
		}
	}
	break;
	}
}
static N_INLINE(NIM_BOOL, isClosure__EhCVbB6PynSh7XFAFVMiJA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T1_)) goto LA2_;
	T1_ = ((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, patchResult__T8bpelbsT0Sbtnlr0eIYAA)(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
		fn = (*c).owner;
		{
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NI T15_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T11_ = !((fn == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T11_)) goto LA12_;
			T11_ = ((520192 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0);
			LA12_: ;
			T10_ = T11_;
			if (!(T10_)) goto LA13_;
			T10_ = !(((*fn).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA13_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA14_;
			T15_ = (NI)0;
			T15_ = len__P89cqdlERShb9alU3iC0yj8wast((*fn).ast);
			T9_ = (((NI) 7) < T15_);
			LA14_: ;
			if (!T9_) goto LA16_;
			asgnRef((void**) (&(*n)._kind_4.sym), (*(*(*fn).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym);
		}
		goto LA7_;
		LA16_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*c).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_68), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_69, NIM_FALSE);
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA22;
					i = i_2;
					patchResult__T8bpelbsT0Sbtnlr0eIYAA(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__EXjdAOBUD8wdsldqC70dag)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL onlyWarning, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* cycleCheck, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* u;
	u = (*s)._kind_2.gcUnsafetyReason;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msgKind;
		T3_ = (NIM_BOOL)0;
		T3_ = !((u == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(cycleCheck, (*u).Sup.id);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		{
			if (!onlyWarning) goto LA10_;
			msgKind = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 41);
		}
		goto LA8_;
		LA10_: ;
		{
			msgKind = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10);
		}
		LA8_: ;
		switch ((*u).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T14_;
			NimStringDesc* T15_;
			nimZeroMem((void*)T14_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T14_[0] = copyString((*(*s).name).s);
			T14_[1] = copyString((*(*u).name).s);
			T15_ = (NimStringDesc*)0;
			T15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_70), T14_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*s).info, msgKind, T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_71, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T17_;
			NimStringDesc* T18_;
			listGcUnsafety__EXjdAOBUD8wdsldqC70dag(u, NIM_TRUE, cycleCheck, conf);
			nimZeroMem((void*)T17_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T17_[0] = copyString((*(*s).name).s);
			T17_[1] = copyString((*(*u).name).s);
			T18_ = (NimStringDesc*)0;
			T18_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_72), T17_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*s).info, msgKind, T18_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_73, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21):
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T20_;
			NimStringDesc* T21_;
			nimZeroMem((void*)T20_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T20_[0] = copyString((*(*s).name).s);
			T20_[1] = copyString((*(*u).name).s);
			T21_ = (NimStringDesc*)0;
			T21_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_74), T20_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*s).info, msgKind, T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_75, NIM_FALSE);
		}
		break;
		default:
		{
			NimStringDesc* T23_;
			T23_ = (NimStringDesc*)0;
			T23_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_76), (*(*s).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*u).info, msgKind, T23_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_77, NIM_FALSE);
		}
		break;
		}
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listGcUnsafety__lVcAQCWPXcnHjv24XqLtlg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL onlyWarning, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg cycleCheck;
	nimZeroMem((void*)(&cycleCheck), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&cycleCheck));
	listGcUnsafety__EXjdAOBUD8wdsldqC70dag(s, onlyWarning, (&cycleCheck), conf);
}
N_LIB_PRIVATE N_NIMCALL(void, trackProc__P9bJkIGwY9beKGfhhcBedbpg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body) {
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects;
	tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA t;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* raisesSpec;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tagsSpec;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* requiresSpec;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ensuresSpec;
	tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug mutationInfo;
{	g = (*c).graph;
	effects = (*(*(*s).typ).n)._kind_6.sons->data[((NI) 0)];
	{
		if (!!(((*effects).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = hasRealBody__cg1RHKu9b2GcnK3fmjpRj2Q(s);
		if (!!(T7_)) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(effects);
		if (!(T12_ == ((NI) 5))) goto LA13_;
		goto BeforeRet_;
	}
	LA13_: ;
	nimZeroMem((void*)(&t), sizeof(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA));
	initEffects__pOwRnuq5NhYw7g0tfye2Ww(g, effects, s, (&t), c);
	track__BxqWoS9czp4uFup6HfSkCeA((&t), body);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
		if (!!(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA17_;
		params = (*(*s).typ).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					if (!(i_2 < colontmp_)) goto LA21;
					i = i_2;
					param = (*(*params)._kind_6.sons->data[i])._kind_4.sym;
					typ = (*param).typ;
					{
						NIM_BOOL T24_;
						NIM_BOOL T26_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
						T24_ = (NIM_BOOL)0;
						T24_ = isSinkTypeForParam__YPjOkGV9axAnGR3UfLeWZ1g_11(typ);
						if (T24_) goto LA25_;
						T26_ = (NIM_BOOL)0;
						T26_ = ((48 &((NU16)1<<((NU)((*t.config).selectedGC)&15U)))!=0);
						if (!(T26_)) goto LA27_;
						T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T28_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
						T26_ = isClosure__EhCVbB6PynSh7XFAFVMiJA_2ast(T28_);
						LA27_: ;
						T24_ = T26_;
						LA25_: ;
						if (!T24_) goto LA29_;
						createTypeBoundOps__vMq8tMiEAonPcaM6b0S8dw((&t), typ, (*param).info);
					}
					LA29_: ;
					i_2 += ((NI) 1);
				} LA21: ;
			}
		}
	}
	LA17_: ;
	{
		NIM_BOOL T33_;
		NIM_BOOL T34_;
		NIM_BOOL T35_;
		NIM_BOOL T37_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T39_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* res;
		T33_ = (NIM_BOOL)0;
		T34_ = (NIM_BOOL)0;
		T35_ = (NIM_BOOL)0;
		T35_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*(*s).typ).sons->data[((NI) 0)]);
		T34_ = !(T35_);
		if (!(T34_)) goto LA36_;
		T37_ = (NIM_BOOL)0;
		T37_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ((*(*s).typ).sons->data[((NI) 0)]);
		if (T37_) goto LA38_;
		T39_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T39_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*s).typ).sons->data[((NI) 0)], IL64(36134350135273744));
		T37_ = ((*T39_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
		LA38_: ;
		T34_ = T37_;
		LA36_: ;
		T33_ = T34_;
		if (!(T33_)) goto LA40_;
		T33_ = ((94208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA40_: ;
		if (!T33_) goto LA41_;
		res = (*(*(*s).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym;
		{
			NIM_BOOL T45_;
			T45_ = (NIM_BOOL)0;
			T45_ = contains__RQ7v5MK0dOhApn0wj6F1iAsystem(t.init->data, (t.init ? t.init->Sup.len : 0), (*res).Sup.id);
			if (!!(T45_)) goto LA46_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*body).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 34), ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_66), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_67, NIM_FALSE);
		}
		LA46_: ;
	}
	LA41_: ;
	p = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	raisesSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170));
	{
		if (!!((raisesSpec == 0))) goto LA50_;
		checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ(g, raisesSpec, t.exc, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_6), NIM_TRUE, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA, (*(*s).ast)._kind_6.sons->data[((NI) 0)]);
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), raisesSpec);
	}
	LA50_: ;
	tagsSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175));
	{
		if (!!((tagsSpec == 0))) goto LA54_;
		checkRaisesSpec__w5LfM8JTuyN2kw68wN2kkQ(g, tagsSpec, t.tags, ((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_8), NIM_FALSE, subtypeRelation__9c89bgUvhZDQIUChjftpSMgA, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), tagsSpec);
	}
	LA54_: ;
	requiresSpec = propSpec__bT2fsf3zXYRpjYdeea19aAA_2(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 176));
	{
		if (!!((requiresSpec == 0))) goto LA58_;
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), requiresSpec);
	}
	LA58_: ;
	ensuresSpec = propSpec__bT2fsf3zXYRpjYdeea19aAA_2(p, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 177));
	{
		if (!!((ensuresSpec == 0))) goto LA62_;
		patchResult__T8bpelbsT0Sbtnlr0eIYAA((&t), ensuresSpec);
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), ensuresSpec);
	}
	LA62_: ;
	nimZeroMem((void*)(&mutationInfo), sizeof(tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug));
	nimZeroMem((void*)(&mutationInfo), sizeof(tyObject_MutationInfo__0Sg6dzXBBdtdBAkDWxEFug));
	{
		tySet_tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg goals;
		tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag partitions;
		if (!!(((12288 & (*c).features) == 0))) goto LA66_;
		goals = 0;
		{
			if (!(((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 12))&15U)))!=0)) goto LA70_;
			goals |= ((NU8)1)<<((((tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg) 0)) & 7);
		}
		LA70_: ;
		{
			if (!(((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 13))&15U)))!=0)) goto LA74_;
			goals |= ((NU8)1)<<((((tyEnum_Goal__JuPChZ1Q9aI1A9aNNAM6t8Pg) 1)) & 7);
		}
		LA74_: ;
		nimZeroMem((void*)(&partitions), sizeof(tyObject_Partitions__BXM20779cYW9aXU5vArQdV9ag));
		computeGraphPartitions__8NgHqAHLnGXB2Yk7BCbglQ(s, body, (*g).config, goals, (&partitions));
		{
			NIM_BOOL T78_;
			T78_ = (NIM_BOOL)0;
			T78_ = !(t.hasSideEffect);
			if (!(T78_)) goto LA79_;
			T78_ = t.hasDangerousAssign;
			LA79_: ;
			if (!T78_) goto LA80_;
			t.hasSideEffect = hasSideEffect__o7Sjy4adraWNg67FeaH7Nw((&partitions), (&mutationInfo));
		}
		LA80_: ;
		{
			if (!(((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 13))&15U)))!=0)) goto LA84_;
			checkBorrowedLocations__c6SN0feu9c665e6zxXN9bWMA((&partitions), body, (*g).config);
		}
		LA84_: ;
	}
	LA66_: ;
	{
		NIM_BOOL T88_;
		T88_ = (NIM_BOOL)0;
		T88_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0);
		if (!(T88_)) goto LA89_;
		T88_ = t.gcUnsafe;
		LA89_: ;
		if (!T88_) goto LA90_;
		{
			NIM_BOOL T94_;
			T94_ = (NIM_BOOL)0;
			T94_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 22))&63U)))!=0);
			if (!(T94_)) goto LA95_;
			T94_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 24))&63U)))!=0);
			LA95_: ;
			if (!T94_) goto LA96_;
			listGcUnsafety__lVcAQCWPXcnHjv24XqLtlg(s, NIM_FALSE, (*g).config);
		}
		goto LA92_;
		LA96_: ;
		{
			listGcUnsafety__lVcAQCWPXcnHjv24XqLtlg(s, NIM_TRUE, (*g).config);
		}
		LA92_: ;
	}
	LA90_: ;
	{
		NIM_BOOL T101_;
		NimStringDesc* T105_;
		NimStringDesc* T106_;
		NimStringDesc* T107_;
		T101_ = (NIM_BOOL)0;
		T101_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 12))&63U)))!=0);
		if (!(T101_)) goto LA102_;
		T101_ = t.hasSideEffect;
		LA102_: ;
		if (!T101_) goto LA103_;
		T105_ = (NimStringDesc*)0;
		T106_ = (NimStringDesc*)0;
		T106_ = nsuFormatSingleElem(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_78), (*(*s).name).s);
		T107_ = (NimStringDesc*)0;
		T107_ = dollar___Ksyu2fr8gIEvUey9aJnQyIw((*g).config, (&mutationInfo));
		T105_ = rawNewString((T106_ ? T106_->Sup.len : 0) + (T107_ ? T107_->Sup.len : 0) + 0);
appendString(T105_, T106_);
appendString(T105_, T107_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T105_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_79, NIM_FALSE);
	}
	LA103_: ;
	{
		if (!!(t.gcUnsafe)) goto LA110_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7)) & 63);
	}
	LA110_: ;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = !(t.hasSideEffect);
		if (!(T114_)) goto LA115_;
		T114_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 13))&63U)))!=0));
		LA115_: ;
		if (!T114_) goto LA116_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1)) & 63);
	}
	LA116_: ;
	{
		if (!((*(*s).typ).lockLevel == ((NI16) -1))) goto LA120_;
		(*(*s).typ).lockLevel = t.maxLockLevel;
	}
	goto LA118_;
	LA120_: ;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T125_;
		NimStringDesc* T126_;
		if (!((*(*s).typ).lockLevel < t.maxLockLevel)) goto LA123_;
		nimZeroMem((void*)T125_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T125_[0] = dollar___75vsOXLrqmx5LmVlMWaymw((*(*s).typ).lockLevel);
		T125_[1] = dollar___75vsOXLrqmx5LmVlMWaymw(t.maxLockLevel);
		T126_ = (NimStringDesc*)0;
		T126_ = nsuFormatOpenArray(((NimStringDesc*) &TM__wkTG4eaV3t1uo3x09apjcwA_80), T125_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 45), T126_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__wkTG4eaV3t1uo3x09apjcwA_81, NIM_FALSE);
	}
	goto LA118_;
	LA123_: ;
	LA118_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setEffectsForProcType__anXKpeIcfo8QOiHQxzurxw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects;
{	effects = (*(*t).n)._kind_6.sons->data[((NI) 0)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25)));
		if (T3_) goto LA4_;
		T3_ = !(((*effects).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* raisesSpec;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tagsSpec;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* requiresSpec;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ensuresSpec;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA9_;
		{
			NI T13_;
			NimStringDesc* argX60gensym473_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast(effects);
			if (!!((T13_ == ((NI) 0)))) goto LA14_;
			argX60gensym473_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__wkTG4eaV3t1uo3x09apjcwA_82);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym473_, TM__wkTG4eaV3t1uo3x09apjcwA_82);
		}
		LA14_: ;
		if ((*effects)._kind_6.sons) { nimGCunrefNoCycle((*effects)._kind_6.sons); (*effects)._kind_6.sons = NIM_NIL; }
		(*effects)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 5));
		raisesSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(n, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170));
		{
			if (!!((raisesSpec == 0))) goto LA18_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 0)]), raisesSpec);
		}
		LA18_: ;
		tagsSpec = effectSpec__bT2fsf3zXYRpjYdeea19aAA(n, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175));
		{
			if (!!((tagsSpec == 0))) goto LA22_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 3)]), tagsSpec);
		}
		LA22_: ;
		requiresSpec = propSpec__bT2fsf3zXYRpjYdeea19aAA_2(n, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 176));
		{
			if (!!((requiresSpec == 0))) goto LA26_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 1)]), requiresSpec);
		}
		LA26_: ;
		ensuresSpec = propSpec__bT2fsf3zXYRpjYdeea19aAA_2(n, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 177));
		{
			if (!!((ensuresSpec == 0))) goto LA30_;
			asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 2)]), ensuresSpec);
		}
		LA30_: ;
		asgnRef((void**) (&(*effects)._kind_6.sons->data[((NI) 4)]), n);
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackStmt__QaQdy9beybDhOWYNIJD0SGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isTopLevel) {
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* effects;
	tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA t;
{	{
		if (!((TM__wkTG4eaV3t1uo3x09apjcwA_83[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	g = (*c).graph;
	effects = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*n).info);
	nimZeroMem((void*)(&t), sizeof(tyObject_TEffects__vxIpB3oPhn77OqeaB81hCA));
	initEffects__pOwRnuq5NhYw7g0tfye2Ww(g, effects, module, (&t), c);
	t.isTopLevel = isTopLevel;
	track__BxqWoS9czp4uFup6HfSkCeA((&t), n);
	}BeforeRet_: ;
}
