/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <math.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_HSlice__fqLtJsaN5foHLgxLTScotw tyObject_HSlice__fqLtJsaN5foHLgxLTScotw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyTuple__UpiOGlu5Ux6DLM73wSrdpg;
typedef struct tyTuple__5L3fCt9bX0gyEcO30ervPLw tyTuple__5L3fCt9bX0gyEcO30ervPLw;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
struct tyObject_HSlice__fqLtJsaN5foHLgxLTScotw {
tyObject_Int128__9a9axPfb75jdWY25AamJewkA a;
tyObject_Int128__9a9axPfb75jdWY25AamJewkA b;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg;
struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg {
NimStringDesc* Field0;
NI Field1;
tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyArray__8d8P9caia9cszVjIJKsQGMQA[25];
typedef NU8 tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg;
struct tyTuple__5L3fCt9bX0gyEcO30ervPLw {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg Field12;
};
typedef tyTuple__5L3fCt9bX0gyEcO30ervPLw tyArray__geAxQ09aiJ4i2plLZEkYDpg[31];
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA {
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TNodeKind__D37bGuL0oC9aRhwdwBfWpFg;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getIntLitType__R31RMSlMd8WWIYpM0EKGkA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* literal);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA onError);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldUnarySub__UMNjeN5XEAds9b7hPTh2mew)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___7c5Zw7H31uJfWmmhZe9aEqw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, minus___mAwxaUUL6Ssa3kRZvdXw3A)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg)(NF floatVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNode__FUOXigLcQdNOaWKUo0hkTg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NF floatVal);
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__dgNNhprrT2HlJglL2Nc3EA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, minus___Sp7OcCEIFoBYolB6PB1fAg_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__ZBiVpGjOydV7ZjeElrE9cFQ)(NI64 arg);
N_LIB_PRIVATE N_NIMCALL(NI64, cardSet__rIy8FkZfgdui9cmJlRrbtNA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnsigned__YPjOkGV9axAnGR3UfLeWZ1g_8)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, maskBytes__mCeI1aTUCq0DR4c0npiCOg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg, NI numbytes);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, bitnot__mAwxaUUL6Ssa3kRZvdXw3A_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lengthOrd__hjogdnp59cMX1rwmjikBhqw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__161i7kexvUAISxPtGBRWYw)(NI arg);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldAbs__UMNjeN5XEAds9b7hPTh2mew_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, abs__mAwxaUUL6Ssa3kRZvdXw3A_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldAdd__eO3oIXEaZawTO9bn7BTLVKg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, plus___Sp7OcCEIFoBYolB6PB1fAg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__tKrCexoXEqWZqpc9cqPD83g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA res);
static N_INLINE(NIM_BOOL, contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
static N_INLINE(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw, dotdot___SGmrVHErX3j2AKHYB8sGjgsystem)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lastOrd__hjogdnp59cMX1rwmjikBhqw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldSub__eO3oIXEaZawTO9bn7BTLVKg_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldMul__eO3oIXEaZawTO9bn7BTLVKg_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, star___Kt56c9bv0oafdrZNxf9cKpNg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA lhs, tyObject_Int128__9a9axPfb75jdWY25AamJewkA rhs);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___7c5Zw7H31uJfWmmhZe9aEqw_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__eu59anK1RU2Rk1MDZxLqq9ag)(NI8 arg);
N_LIB_PRIVATE N_NIMCALL(NI8, toInt8__6cQbCFpX4H8O19aEOrsPYrw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__1szweXXq3RBN50owrYu2Xw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__bA9cKzDjr9aTHOeg7zwjs6cw)(NI16 arg);
N_LIB_PRIVATE N_NIMCALL(NI16, toInt16__79as9b2pi2JJfykcqECr9ch7w)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__hTMQ3QGzeZAKnBAJ4tvqqA)(NI32 arg);
N_LIB_PRIVATE N_NIMCALL(NI32, toInt32__6rExDXcEPWSTMgIhAkSSEg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__wP9c9a79bp9aIubg2xUNp1Mcxw)(NU8 arg);
N_LIB_PRIVATE N_NIMCALL(NU8, toUInt8__E8LsZ2FZdbNGEBWOogFqvA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__3Thi9cL5j9aXHbydU7kR8Czw)(NU16 arg);
N_LIB_PRIVATE N_NIMCALL(NU16, toUInt16__hjUYKwZ2UG0FJDQ3iCDmeg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__YpxIye9cNDLmo81kNcCyWqA)(NU32 arg);
N_LIB_PRIVATE N_NIMCALL(NU32, toUInt32__7WRBGD756FORxqb7aY1Z0w)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__TDVoY1DSlNtMNULcUFRJzA)(NU64 arg);
N_LIB_PRIVATE N_NIMCALL(NU64, toUInt64__eSidVZnVWqCQ9ctpa3OHXuA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, div__Sp7OcCEIFoBYolB6PB1fAg_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, mod__Sp7OcCEIFoBYolB6PB1fAg_5)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStr__P2DOsHG6Jk4Siab3L2qwUg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(NIM_BOOL, ltpercent___m9aFrKvWqPsM3WKrwczIr9bAsystem)(NI64 x, NI64 y);
static N_INLINE(NIM_BOOL, lteqpercent___m9aFrKvWqPsM3WKrwczIr9bA_2system)(NI64 x, NI64 y);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, bitand__Sp7OcCEIFoBYolB6PB1fAg_6)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, bitor__Sp7OcCEIFoBYolB6PB1fAg_4)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, bitxor__Sp7OcCEIFoBYolB6PB1fAg_7)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsSets__Jr5d2PbcnAZ0pFa4Ny88lg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalSets__Jr5d2PbcnAZ0pFa4Ny88lg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, intersectSets__DJXyM0ZYUUgI9bAP6orixDA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, unionSets__DJXyM0ZYUUgI9bAP6orixDA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, diffSets__DJXyM0ZYUUgI9bAP6orixDA_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNodeT__9cl7myBS6dfbP30fsccozTQ)(NimStringDesc* strVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSet__b4nxsJCvqXRlyalSWskgNA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elem);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___W2wbDjPGDCaBwLQM6yLUQg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimFloatToStr)(NF f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, ordinalValToString__1UtzyyNfA4Pde4QCgge15Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___xL5gyZrjbGMarSdRAXOo9ag_2)(NI64 a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__9bbrBm0brnGO9cOW9coVJSCaQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__Wd9alT05EZZXVF7dib5G9cYg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getDateStr__ye3QcrLEUbQh0AniHZYCHg_2)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getClockStr__ye3QcrLEUbQh0AniHZYCHg_3)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getAppType__pFThSxTIx1UddS3Wdyr9bkQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__jkXTnxDf8MX1Pmks3s0XxA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* symbol);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc**, nstTake)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseBool__Y9cQyzddf88poHkzlcfsPIA)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, base__PfgI9ap7WOnsRfFV4znQ27w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
static N_INLINE(NIM_BOOL, isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstIfExpr__2kStqt7u4DPR9b4UNFMJdQg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstExpr__A7gcXCy5E3uGBy5F37NoHA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value);
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b);
N_LIB_PRIVATE N_NIMCALL(NF, firstFloat__5WwccqVm6xApk9c8p9c1efRA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NF, lastFloat__5WwccqVm6xApk9c8p9c1efRA_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getArrayConstr__A7gcXCy5E3uGBy5F37NoHA_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, magicCall__A7gcXCy5E3uGBy5F37NoHA_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalOp__naTMtRq9avUKkKDwI0csDMg)(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldConStrStr__A7gcXCy5E3uGBy5F37NoHA_4)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__hutrgrWnBjOoG19cbpgmANA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NF, toFloat64__PDwVTbOO2Rlwlg5dKjIRyQ)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldConv__MlnTAS4JHv81FgG2EV9ci3g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NIM_BOOL check);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__HaskCaz5YmXySs9c9c3vJN8A)(NIM_BOOL arg);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__Ds1OEQoxqjWJ62lsdr6soA)(NF arg);
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__LmBGzflgpD7jusLMkw9aLgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, transitionIntKind__VaXqiHBsdA0MNhmXnesuRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__D37bGuL0oC9aRhwdwBfWpFg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldArrayAccess__A7gcXCy5E3uGBy5F37NoHA_5)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimInt64ToStr)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldFieldAccess__A7gcXCy5E3uGBy5F37NoHA_6)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);

/* section: NIM_merge_DATA */
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Max__zlJMNfqX7LwCYj0PF6ncWQ;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA One__asIdv19bIr70QgMTVvq2zyQ;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Zero__1ed0M9aQUqqSQVhLxSQO9bCw;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_2, "constant folding for shl", 24);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_4, "/home/runner/work/nightlies/nightlies/nim/compiler/semfold.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_3 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 214),
((NI) 23)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_5, "constant folding for ashr", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_6 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 242),
((NI) 23)}
;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA NegOne__d9bDUxsqvMi69cXPELCoXEuA;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_7, "false", 5);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_8, "true", 4);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_9, "ordinalValToString", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_10 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 88),
((NI) 42)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_11, "Cannot convert int literal to $1. The value is invalid.", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_12 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 95),
((NI) 14)}
;
extern NIM_CONST tyArray__8d8P9caia9cszVjIJKsQGMQA CPU__uYXopJX8pM87pQDCtmgWfQ;
extern NIM_CONST tyArray__geAxQ09aiJ4i2plLZEkYDpg OS__Jx0qy9c9bSo4fGkMxUfUaAaw;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_13, "lib", 3);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_14, "staticlib", 9);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_15, "gui", 3);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_16, "console", 7);
extern TNimType NTI__yoNlBGx0D2tRizIdhQuENw_;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_18, "{.intdefine.} const was set to an invalid integer: \'", 52);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_19, "\'", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_20 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 547),
((NI) 22)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_22, "{.booldefine.} const was set to an invalid bool: \'", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_23 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 562),
((NI) 22)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_24, "getConstIfExpr()", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_25 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 358),
((NI) 23)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_27, "can\'t compute offsetof on this ast", 34);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_29, "/home/runner/work/nightlies/nightlies/nim/compiler/sizealignoff"
"setimpl.nim", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_28 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_29),
((NI) 493),
((NI) 16)}
;
extern TNimType NTI__9cxMi1BPLc3UKt9br86bGfGQ_;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_30, "over- or underflow", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_31 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 647),
((NI) 16)}
;
extern TNimType NTI__n3A4gjRrFZBuNnTYx1h9a8w_;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_32, "division by zero", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_33 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 649),
((NI) 16)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_34, "conversion from $1 to $2 is invalid", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_35 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 701),
((NI) 16)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_36, "semfold.nim(425, 20) `false` ", 29);
extern TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_37, "cannot convert ", 15);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_38, " to ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_39 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 402),
((NI) 14)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_40, "index out of bounds, the container is empty", 43);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_41, "index ", 6);
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_42, " not in 0 .. ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_43 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 476),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_44 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 480),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_45 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 486),
((NI) 16)}
;
STRING_LITERAL(TM__JtgqXuJaW0Uz9aqyNPWIZsw_46, "field not found: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_47 = {((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_4),
((NI) 505),
((NI) 12)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g(intVal, (*n).typ);
	{
		if (!((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31))) goto LA3_;
		asgnRef((void**) (&(*result).typ), getIntLitType__R31RMSlMd8WWIYpM0EKGkA(g, result));
	}
	LA3_: ;
	(*result).info = (*n).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldUnarySub__UMNjeN5XEAds9b7hPTh2mew)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
		NIM_BOOL T4_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T7_;
		T3_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*n).typ);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(a, T3_);
		if (!!(T4_)) goto LA5_;
		T7_ = minus___mAwxaUUL6Ssa3kRZvdXw3A(a);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T7_, n, g);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg)(NF floatVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
		if (!((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37))) goto LA4_;
		result = newFloatNode__FUOXigLcQdNOaWKUo0hkTg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 17), floatVal);
	}
	goto LA1_;
	LA4_: ;
	{
		result = newFloatNode__FUOXigLcQdNOaWKUo0hkTg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16), floatVal);
	}
	LA1_: ;
	asgnRef((void**) (&(*result).typ), (*n).typ);
	(*result).info = (*n).info;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldAbs__UMNjeN5XEAds9b7hPTh2mew_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
		NIM_BOOL T4_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T7_;
		T3_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*n).typ);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(a, T3_);
		if (!!(T4_)) goto LA5_;
		T7_ = abs__mAwxaUUL6Ssa3kRZvdXw3A_3(a);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T7_, n, g);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2((*s).a, value);
	if (!(T1_)) goto LA2_;
	T1_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(value, (*s).b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw, dotdot___SGmrVHErX3j2AKHYB8sGjgsystem)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b) {
	tyObject_HSlice__fqLtJsaN5foHLgxLTScotw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__tKrCexoXEqWZqpc9cqPD83g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA res) {
	NIM_BOOL result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T1_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T2_;
	tyObject_HSlice__fqLtJsaN5foHLgxLTScotw T3_;
	result = (NIM_BOOL)0;
	T1_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(conf, (*n).typ);
	T2_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(conf, (*n).typ);
	T3_ = dotdot___SGmrVHErX3j2AKHYB8sGjgsystem(T1_, T2_);
	result = contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem((&T3_), res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldAdd__eO3oIXEaZawTO9bn7BTLVKg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA res;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	res = plus___Sp7OcCEIFoBYolB6PB1fAg(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__tKrCexoXEqWZqpc9cqPD83g((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(res, n, g);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldSub__eO3oIXEaZawTO9bn7BTLVKg_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA res;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	res = minus___Sp7OcCEIFoBYolB6PB1fAg_2(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__tKrCexoXEqWZqpc9cqPD83g((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(res, n, g);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldMul__eO3oIXEaZawTO9bn7BTLVKg_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA res;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	res = star___Kt56c9bv0oafdrZNxf9cKpNg(a, b);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__tKrCexoXEqWZqpc9cqPD83g((*g).config, n, res);
		if (!T3_) goto LA4_;
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(res, n, g);
		goto BeforeRet_;
	}
	LA4_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, cmpStrings)(NimStringDesc* a, NimStringDesc* b) {
	NI result;
	NI alen;
	NI blen;
	NI minlen;
	result = (NI)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	minlen = ((alen <= blen) ? alen : blen);
	{
		int T5_;
		if (!(((NI) 0) < minlen)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((size_t) (minlen)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI) 0))) goto LA8_;
			result = (NI)(alen - blen);
		}
		LA8_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (NI)(alen - blen);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___m9aFrKvWqPsM3WKrwczIr9bAsystem)(NI64 x, NI64 y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU64) (x))) < (NU64)(((NU64) (y))));
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___m9aFrKvWqPsM3WKrwczIr9bA_2system)(NI64 x, NI64 y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU64) (x))) <= (NU64)(((NU64) (y))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNodeT__9cl7myBS6dfbP30fsccozTQ)(NimStringDesc* strVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), strVal);
	asgnRef((void**) (&(*result).typ), (*n).typ);
	(*result).info = (*n).info;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, ordinalValToString__1UtzyyNfA4Pde4QCgge15Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	NimStringDesc* result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA x;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (NimStringDesc*)0;
	x = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*a).typ, IL64(36134350136322320));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		NI64 T2_;
		T2_ = (NI64)0;
		T2_ = toInt64__1szweXXq3RBN50owrYu2Xw(x);
		result = nimCharToStr(((NIM_CHAR) (((NI) ((NI64)(T2_ & IL64(255)))))));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		tyArray__nHXaesL0DJZHyVS07ARPRA T21_;
		NimStringDesc* T22_;
		n = (*t).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
					if (!(i_2 < colontmp_)) goto LA6;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA9_;
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, (*a).info, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_9), TM__JtgqXuJaW0Uz9aqyNPWIZsw_10);
					}
					LA9_: ;
					field = (*(*n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = eqeq___xL5gyZrjbGMarSdRAXOo9ag_2(((NI64) ((*field).position)), x);
						if (!T13_) goto LA14_;
						{
							if (!((*field).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA18_;
							result = copyString((*(*field).name).s);
							goto BeforeRet_;
						}
						goto LA16_;
						LA18_: ;
						{
							result = copyString((*(*field).ast)._kind_3.strVal);
							goto BeforeRet_;
						}
						LA16_: ;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA6: ;
			}
		}
		nimZeroMem((void*)T21_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
		T21_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T22_ = (NimStringDesc*)0;
		T22_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_11), T21_, 1);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_12, NIM_FALSE);
	}
	break;
	default:
	{
		result = dollar___W2wbDjPGDCaBwLQM6yLUQg(x);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalOp__naTMtRq9avUKkKDwI0csDMg)(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	switch (m) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 31):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T2_;
		T2_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T2_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 43):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T4_;
		T4_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T4_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 94):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
		T6_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		result = foldUnarySub__UMNjeN5XEAds9b7hPTh2mew(T6_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 100):
	{
		NF T8_;
		T8_ = (NF)0;
		T8_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(-(T8_), n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T10_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T11_;
		T10_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T11_ = minus___Sp7OcCEIFoBYolB6PB1fAg_2(One__asIdv19bIr70QgMTVvq2zyQ, T10_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T11_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 42):
	{
		NI64 T13_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T14_;
		T13_ = (NI64)0;
		T13_ = cardSet__rIy8FkZfgdui9cmJlRrbtNA((*g).config, a);
		T14_ = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ(T13_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T14_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 98):
	{
		{
			NIM_BOOL T18_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T21_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T22_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T23_;
			T18_ = (NIM_BOOL)0;
			T18_ = isUnsigned__YPjOkGV9axAnGR3UfLeWZ1g_8((*n).typ);
			if (!T18_) goto LA19_;
			T21_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T22_ = bitnot__mAwxaUUL6Ssa3kRZvdXw3A_2(T21_);
			T23_ = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T22_, ((NI) ((*(*n).typ).size)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T23_, n, g);
		}
		goto LA16_;
		LA19_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T25_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T26_;
			T25_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T26_ = bitnot__mAwxaUUL6Ssa3kRZvdXw3A_2(T25_);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T26_, n, g);
		}
		LA16_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 38):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T28_;
		T28_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*g).config, (*a).typ);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T28_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 39):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 36):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 37):
	{
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA32_;
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(Zero__1ed0M9aQUqqSQVhLxSQO9bCw, n, g);
		}
		goto LA30_;
		LA32_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T37_;
			if (!((*a).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*a).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA35_;
			T37_ = toInt128__161i7kexvUAISxPtGBRWYw(((*a)._kind_3.strVal ? (*a)._kind_3.strVal->Sup.len : 0));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T37_, n, g);
		}
		goto LA30_;
		LA35_: ;
		{
			NI T39_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T40_;
			T39_ = (NI)0;
			T39_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
			T40_ = toInt128__161i7kexvUAISxPtGBRWYw(T39_);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T40_, n, g);
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 97):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 99):
	{
		result = a;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 95):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T43_;
		T43_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		result = foldAbs__UMNjeN5XEAds9b7hPTh2mew_2(T43_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 51):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T45_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T46_;
		T45_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T46_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		result = foldAdd__eO3oIXEaZawTO9bn7BTLVKg(T45_, T46_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T48_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T49_;
		T48_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T49_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		result = foldSub__eO3oIXEaZawTO9bn7BTLVKg_2(T48_, T49_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 46):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T51_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T52_;
		T51_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T52_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		result = foldAdd__eO3oIXEaZawTO9bn7BTLVKg(T51_, T52_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 47):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T54_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T55_;
		T54_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T55_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		result = foldSub__eO3oIXEaZawTO9bn7BTLVKg_2(T54_, T55_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 48):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T57_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T58_;
		T57_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T58_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		result = foldMul__eO3oIXEaZawTO9bn7BTLVKg_3(T57_, T58_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 63):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T60_;
		argA = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argB = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		{
			NIM_BOOL T63_;
			T63_ = (NIM_BOOL)0;
			T63_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(argA, argB);
			if (!T63_) goto LA64_;
			T60_ = argA;
		}
		goto LA61_;
		LA64_: ;
		{
			T60_ = argB;
		}
		LA61_: ;
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T60_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 64):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA_2;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB_2;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T68_;
		argA_2 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argB_2 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		{
			NIM_BOOL T71_;
			T71_ = (NIM_BOOL)0;
			T71_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(argB_2, argA_2);
			if (!T71_) goto LA72_;
			T68_ = argA_2;
		}
		goto LA69_;
		LA72_: ;
		{
			T68_ = argB_2;
		}
		LA69_: ;
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T68_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 58):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T76_;
		T76_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T76_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350136322320));
		switch ((*T76_).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T78_;
			NI8 T79_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T80_;
			NI64 T81_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T82_;
			T78_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T79_ = (NI8)0;
			T79_ = toInt8__6cQbCFpX4H8O19aEOrsPYrw(T78_);
			T80_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T81_ = (NI64)0;
			T81_ = toInt64__1szweXXq3RBN50owrYu2Xw(T80_);
			T82_ = toInt128__eu59anK1RU2Rk1MDZxLqq9ag((NI8)((NU64)(T79_) << (NU64)(T81_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T82_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T84_;
			NI16 T85_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T86_;
			NI64 T87_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T88_;
			T84_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T85_ = (NI16)0;
			T85_ = toInt16__79as9b2pi2JJfykcqECr9ch7w(T84_);
			T86_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T87_ = (NI64)0;
			T87_ = toInt64__1szweXXq3RBN50owrYu2Xw(T86_);
			T88_ = toInt128__bA9cKzDjr9aTHOeg7zwjs6cw((NI16)((NU64)(T85_) << (NU64)(T87_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T88_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T90_;
			NI32 T91_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T92_;
			NI64 T93_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T94_;
			T90_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T91_ = (NI32)0;
			T91_ = toInt32__6rExDXcEPWSTMgIhAkSSEg(T90_);
			T92_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T93_ = (NI64)0;
			T93_ = toInt64__1szweXXq3RBN50owrYu2Xw(T92_);
			T94_ = toInt128__hTMQ3QGzeZAKnBAJ4tvqqA((NI32)((NU64)(T91_) << (NU64)(T93_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T94_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T96_;
			NI64 T97_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T98_;
			NI64 T99_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T100_;
			T96_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T97_ = (NI64)0;
			T97_ = toInt64__1szweXXq3RBN50owrYu2Xw(T96_);
			T98_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T99_ = (NI64)0;
			T99_ = toInt64__1szweXXq3RBN50owrYu2Xw(T98_);
			T100_ = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ((NI64)((NU64)(T97_) << (NU64)(T99_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T100_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
		{
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T106_;
				NI32 T107_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T108_;
				NI64 T109_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T110_;
				if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA104_;
				T106_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
				T107_ = (NI32)0;
				T107_ = toInt32__6rExDXcEPWSTMgIhAkSSEg(T106_);
				T108_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
				T109_ = (NI64)0;
				T109_ = toInt64__1szweXXq3RBN50owrYu2Xw(T108_);
				T110_ = toInt128__hTMQ3QGzeZAKnBAJ4tvqqA((NI32)((NU64)(T107_) << (NU64)(T109_)));
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T110_, n, g);
			}
			goto LA102_;
			LA104_: ;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T112_;
				NI64 T113_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T114_;
				NI64 T115_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T116_;
				T112_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
				T113_ = (NI64)0;
				T113_ = toInt64__1szweXXq3RBN50owrYu2Xw(T112_);
				T114_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
				T115_ = (NI64)0;
				T115_ = toInt64__1szweXXq3RBN50owrYu2Xw(T114_);
				T116_ = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ((NI64)((NU64)(T113_) << (NU64)(T115_)));
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T116_, n, g);
			}
			LA102_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T118_;
			NU8 T119_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T120_;
			NI64 T121_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T122_;
			T118_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T119_ = (NU8)0;
			T119_ = toUInt8__E8LsZ2FZdbNGEBWOogFqvA(T118_);
			T120_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T121_ = (NI64)0;
			T121_ = toInt64__1szweXXq3RBN50owrYu2Xw(T120_);
			T122_ = toInt128__wP9c9a79bp9aIubg2xUNp1Mcxw((NU8)((NU64)(T119_) << (NU64)(T121_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T122_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T124_;
			NU16 T125_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T126_;
			NI64 T127_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T128_;
			T124_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T125_ = (NU16)0;
			T125_ = toUInt16__hjUYKwZ2UG0FJDQ3iCDmeg(T124_);
			T126_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T127_ = (NI64)0;
			T127_ = toInt64__1szweXXq3RBN50owrYu2Xw(T126_);
			T128_ = toInt128__3Thi9cL5j9aXHbydU7kR8Czw((NU16)((NU64)(T125_) << (NU64)(T127_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T128_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T130_;
			NU32 T131_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T132_;
			NI64 T133_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T134_;
			T130_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T131_ = (NU32)0;
			T131_ = toUInt32__7WRBGD756FORxqb7aY1Z0w(T130_);
			T132_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T133_ = (NI64)0;
			T133_ = toInt64__1szweXXq3RBN50owrYu2Xw(T132_);
			T134_ = toInt128__YpxIye9cNDLmo81kNcCyWqA((NU32)((NU64)(T131_) << (NU64)(T133_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T134_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T136_;
			NU64 T137_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T138_;
			NI64 T139_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T140_;
			T136_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T137_ = (NU64)0;
			T137_ = toUInt64__eSidVZnVWqCQ9ctpa3OHXuA(T136_);
			T138_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T139_ = (NI64)0;
			T139_ = toInt64__1szweXXq3RBN50owrYu2Xw(T138_);
			T140_ = toInt128__TDVoY1DSlNtMNULcUFRJzA((NU64)((NU64)(T137_) << (NU64)(T139_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T140_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40):
		{
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T146_;
				NU32 T147_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T148_;
				NI64 T149_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T150_;
				if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA144_;
				T146_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
				T147_ = (NU32)0;
				T147_ = toUInt32__7WRBGD756FORxqb7aY1Z0w(T146_);
				T148_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
				T149_ = (NI64)0;
				T149_ = toInt64__1szweXXq3RBN50owrYu2Xw(T148_);
				T150_ = toInt128__YpxIye9cNDLmo81kNcCyWqA((NU32)((NU64)(T147_) << (NU64)(T149_)));
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T150_, n, g);
			}
			goto LA142_;
			LA144_: ;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T152_;
				NU64 T153_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T154_;
				NI64 T155_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T156_;
				T152_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
				T153_ = (NU64)0;
				T153_ = toUInt64__eSidVZnVWqCQ9ctpa3OHXuA(T152_);
				T154_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
				T155_ = (NI64)0;
				T155_ = toInt64__1szweXXq3RBN50owrYu2Xw(T154_);
				T156_ = toInt128__TDVoY1DSlNtMNULcUFRJzA((NU64)((NU64)(T153_) << (NU64)(T155_)));
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T156_, n, g);
			}
			LA142_: ;
		}
		break;
		default:
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, (*n).info, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_2), TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57):
	{
		NU64 a_2;
		union { tyObject_Int128__9a9axPfb75jdWY25AamJewkA source; NU64 dest; } LOC159;
		NU64 b_2;
		union { tyObject_Int128__9a9axPfb75jdWY25AamJewkA source; NU64 dest; } LOC160;
		NI64 c_2;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T175_;
		LOC159.source = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		a_2 = LOC159.dest;
		LOC160.source = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		b_2 = LOC160.dest;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T165_;
			if (!((NU64)(0ULL) < (NU64)(b_2))) goto LA163_;
			T165_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T165_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350136322320));
			switch ((*T165_).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
			{
				a_2 = (NU64)(a_2 & 255ULL);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
			{
				a_2 = (NU64)(a_2 & 65535ULL);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
			{
				a_2 = (NU64)(a_2 & 4294967295ULL);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
			{
				{
					if (!((*(*g).config).target.intSize == ((NI) 4))) goto LA172_;
					a_2 = (NU64)(a_2 & 4294967295ULL);
				}
				LA172_: ;
			}
			break;
			default:
			{
			}
			break;
			}
		}
		LA163_: ;
		c_2 = ((NI64) ((NU64)((NU64)(a_2) >> (NU64)(b_2))));
		T175_ = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ(c_2);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T175_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 59):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T177_;
		T177_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T177_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350136322320));
		switch ((*T177_).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T179_;
			NI8 T180_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T181_;
			NI8 T182_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T183_;
			T179_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T180_ = (NI8)0;
			T180_ = toInt8__6cQbCFpX4H8O19aEOrsPYrw(T179_);
			T181_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T182_ = (NI8)0;
			T182_ = toInt8__6cQbCFpX4H8O19aEOrsPYrw(T181_);
			T183_ = toInt128__eu59anK1RU2Rk1MDZxLqq9ag((NI8)((NI8)(T180_) >> (NU8)(T182_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T183_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T185_;
			NI16 T186_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T187_;
			NI16 T188_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T189_;
			T185_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T186_ = (NI16)0;
			T186_ = toInt16__79as9b2pi2JJfykcqECr9ch7w(T185_);
			T187_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T188_ = (NI16)0;
			T188_ = toInt16__79as9b2pi2JJfykcqECr9ch7w(T187_);
			T189_ = toInt128__bA9cKzDjr9aTHOeg7zwjs6cw((NI16)((NI16)(T186_) >> (NU16)(T188_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T189_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T191_;
			NI32 T192_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T193_;
			NI32 T194_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T195_;
			T191_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T192_ = (NI32)0;
			T192_ = toInt32__6rExDXcEPWSTMgIhAkSSEg(T191_);
			T193_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T194_ = (NI32)0;
			T194_ = toInt32__6rExDXcEPWSTMgIhAkSSEg(T193_);
			T195_ = toInt128__hTMQ3QGzeZAKnBAJ4tvqqA((NI32)((NI32)(T192_) >> (NU32)(T194_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T195_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T197_;
			NI64 T198_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T199_;
			NI64 T200_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T201_;
			T197_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T198_ = (NI64)0;
			T198_ = toInt64__1szweXXq3RBN50owrYu2Xw(T197_);
			T199_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T200_ = (NI64)0;
			T200_ = toInt64__1szweXXq3RBN50owrYu2Xw(T199_);
			T201_ = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ((NI64)((NI64)(T198_) >> (NU64)(T200_)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T201_, n, g);
		}
		break;
		default:
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, (*n).info, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_5), TM__JtgqXuJaW0Uz9aqyNPWIZsw_6);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 49):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA_3;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB_3;
		argA_3 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argB_3 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		{
			NIM_BOOL T206_;
			NIM_BOOL T207_;
			NIM_BOOL T209_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T210_;
			NIM_BOOL T211_;
			NIM_BOOL T213_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T216_;
			T206_ = (NIM_BOOL)0;
			T207_ = (NIM_BOOL)0;
			T207_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_3, Zero__1ed0M9aQUqqSQVhLxSQO9bCw);
			T206_ = !(T207_);
			if (!(T206_)) goto LA208_;
			T209_ = (NIM_BOOL)0;
			T210_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*n).typ);
			T211_ = (NIM_BOOL)0;
			T211_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argA_3, T210_);
			T209_ = !(T211_);
			if (T209_) goto LA212_;
			T213_ = (NIM_BOOL)0;
			T213_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_3, NegOne__d9bDUxsqvMi69cXPELCoXEuA);
			T209_ = !(T213_);
			LA212_: ;
			T206_ = T209_;
			LA208_: ;
			if (!T206_) goto LA214_;
			T216_ = div__Sp7OcCEIFoBYolB6PB1fAg_3(argA_3, argB_3);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T216_, n, g);
		}
		LA214_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 50):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA_4;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB_4;
		argA_4 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argB_4 = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		{
			NIM_BOOL T220_;
			NIM_BOOL T221_;
			NIM_BOOL T223_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T224_;
			NIM_BOOL T225_;
			NIM_BOOL T227_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T230_;
			T220_ = (NIM_BOOL)0;
			T221_ = (NIM_BOOL)0;
			T221_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_4, Zero__1ed0M9aQUqqSQVhLxSQO9bCw);
			T220_ = !(T221_);
			if (!(T220_)) goto LA222_;
			T223_ = (NIM_BOOL)0;
			T224_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*n).typ);
			T225_ = (NIM_BOOL)0;
			T225_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argA_4, T224_);
			T223_ = !(T225_);
			if (T223_) goto LA226_;
			T227_ = (NIM_BOOL)0;
			T227_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_4, NegOne__d9bDUxsqvMi69cXPELCoXEuA);
			T223_ = !(T227_);
			LA226_: ;
			T220_ = T223_;
			LA222_: ;
			if (!T220_) goto LA228_;
			T230_ = mod__Sp7OcCEIFoBYolB6PB1fAg_5(argA_4, argB_4);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T230_, n, g);
		}
		LA228_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 53):
	{
		NF T232_;
		NF T233_;
		T232_ = (NF)0;
		T232_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T233_ = (NF)0;
		T233_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(((NF)(T232_) + (NF)(T233_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 54):
	{
		NF T235_;
		NF T236_;
		T235_ = (NF)0;
		T235_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T236_ = (NF)0;
		T236_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(((NF)(T235_) - (NF)(T236_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 55):
	{
		NF T238_;
		NF T239_;
		T238_ = (NF)0;
		T238_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T239_ = (NF)0;
		T239_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(((NF)(T238_) * (NF)(T239_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 56):
	{
		NF T241_;
		NF T242_;
		T241_ = (NF)0;
		T241_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T242_ = (NF)0;
		T242_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(((NF)(T241_) / (NF)(T242_)), n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 143):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T244_;
		T244_ = toInt128__161i7kexvUAISxPtGBRWYw(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T244_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 72):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 86):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 80):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 83):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T246_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T247_;
		NIM_BOOL T248_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T249_;
		T246_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T247_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(b, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T248_ = (NIM_BOOL)0;
		T248_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T246_, T247_);
		T249_ = toInt128__161i7kexvUAISxPtGBRWYw(T248_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T249_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 71):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 85):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 79):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 82):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T251_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T252_;
		NIM_BOOL T253_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T254_;
		T251_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T252_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(b, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T253_ = (NIM_BOOL)0;
		T253_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T251_, T252_);
		T254_ = toInt128__161i7kexvUAISxPtGBRWYw(T253_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T254_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 70):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 84):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 78):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 81):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T256_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T257_;
		NIM_BOOL T258_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T259_;
		T256_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T257_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(b, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T258_ = (NIM_BOOL)0;
		T258_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T256_, T257_);
		T259_ = toInt128__161i7kexvUAISxPtGBRWYw(T258_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T259_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 75):
	{
		NF T261_;
		NF T262_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T263_;
		T261_ = (NF)0;
		T261_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T262_ = (NF)0;
		T262_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		T263_ = toInt128__161i7kexvUAISxPtGBRWYw((T261_ < T262_));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T263_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 74):
	{
		NF T265_;
		NF T266_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T267_;
		T265_ = (NF)0;
		T265_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T266_ = (NF)0;
		T266_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		T267_ = toInt128__161i7kexvUAISxPtGBRWYw((T265_ <= T266_));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T267_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 73):
	{
		NF T269_;
		NF T270_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T271_;
		T269_ = (NF)0;
		T269_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T270_ = (NF)0;
		T270_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(b);
		T271_ = toInt128__161i7kexvUAISxPtGBRWYw((T269_ == T270_));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T271_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 118):
	{
		NimStringDesc* T273_;
		NimStringDesc* T274_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T275_;
		T273_ = (NimStringDesc*)0;
		T273_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(a);
		T274_ = (NimStringDesc*)0;
		T274_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(b);
		T275_ = toInt128__161i7kexvUAISxPtGBRWYw((cmpStrings(T273_, T274_) < 0));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T275_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 117):
	{
		NimStringDesc* T277_;
		NimStringDesc* T278_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T279_;
		T277_ = (NimStringDesc*)0;
		T277_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(a);
		T278_ = (NimStringDesc*)0;
		T278_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(b);
		T279_ = toInt128__161i7kexvUAISxPtGBRWYw((cmpStrings(T277_, T278_) <= 0));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T279_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 116):
	{
		NimStringDesc* T281_;
		NimStringDesc* T282_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T283_;
		T281_ = (NimStringDesc*)0;
		T281_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(a);
		T282_ = (NimStringDesc*)0;
		T282_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(b);
		T283_ = toInt128__161i7kexvUAISxPtGBRWYw(eqStrings(T281_, T282_));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T283_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 77):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T285_;
		NI64 T286_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T287_;
		NI64 T288_;
		NIM_BOOL T289_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T290_;
		T285_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T286_ = (NI64)0;
		T286_ = toInt64__1szweXXq3RBN50owrYu2Xw(T285_);
		T287_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(b, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T288_ = (NI64)0;
		T288_ = toInt64__1szweXXq3RBN50owrYu2Xw(T287_);
		T289_ = (NIM_BOOL)0;
		T289_ = ltpercent___m9aFrKvWqPsM3WKrwczIr9bAsystem(T286_, T288_);
		T290_ = toInt128__161i7kexvUAISxPtGBRWYw(T289_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T290_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 76):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T292_;
		NI64 T293_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T294_;
		NI64 T295_;
		NIM_BOOL T296_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T297_;
		T292_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T293_ = (NI64)0;
		T293_ = toInt64__1szweXXq3RBN50owrYu2Xw(T292_);
		T294_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(b, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T295_ = (NI64)0;
		T295_ = toInt64__1szweXXq3RBN50owrYu2Xw(T294_);
		T296_ = (NIM_BOOL)0;
		T296_ = lteqpercent___m9aFrKvWqPsM3WKrwczIr9bA_2system(T293_, T295_);
		T297_ = toInt128__161i7kexvUAISxPtGBRWYw(T296_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T297_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 60):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T299_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T300_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T301_;
		T299_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T300_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T301_ = bitand__Sp7OcCEIFoBYolB6PB1fAg_6(T299_, T300_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T301_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 61):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T303_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T304_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T305_;
		T303_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T304_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T305_ = bitor__Sp7OcCEIFoBYolB6PB1fAg_4(T303_, T304_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T305_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 62):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 90):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T307_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T308_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T309_;
		T307_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T308_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T309_ = bitxor__Sp7OcCEIFoBYolB6PB1fAg_7(T307_, T308_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T309_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 65):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA val;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T311_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T312_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T313_;
		T311_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T312_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T313_ = plus___Sp7OcCEIFoBYolB6PB1fAg(T311_, T312_);
		val = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T313_, ((NI) ((*(*n).typ).size)));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(val, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA val_2;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T315_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T316_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T317_;
		T315_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T316_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T317_ = minus___Sp7OcCEIFoBYolB6PB1fAg_2(T315_, T316_);
		val_2 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T317_, ((NI) ((*(*n).typ).size)));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(val_2, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 67):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA val_3;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T319_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T320_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T321_;
		T319_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		T320_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		T321_ = star___Kt56c9bv0oafdrZNxf9cKpNg(T319_, T320_);
		val_3 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T321_, ((NI) ((*(*n).typ).size)));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(val_3, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 69):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA_5;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T323_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB_5;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T324_;
		T323_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argA_5 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T323_, ((NI) ((*(*a).typ).size)));
		T324_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		argB_5 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T324_, ((NI) ((*(*a).typ).size)));
		{
			NIM_BOOL T327_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T330_;
			T327_ = (NIM_BOOL)0;
			T327_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_5, Zero__1ed0M9aQUqqSQVhLxSQO9bCw);
			if (!!(T327_)) goto LA328_;
			T330_ = mod__Sp7OcCEIFoBYolB6PB1fAg_5(argA_5, argB_5);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T330_, n, g);
		}
		LA328_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 68):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argA_6;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T332_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA argB_6;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T333_;
		T332_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
		argA_6 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T332_, ((NI) ((*(*a).typ).size)));
		T333_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
		argB_6 = maskBytes__mCeI1aTUCq0DR4c0npiCOg(T333_, ((NI) ((*(*a).typ).size)));
		{
			NIM_BOOL T336_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T339_;
			T336_ = (NIM_BOOL)0;
			T336_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(argB_6, Zero__1ed0M9aQUqqSQVhLxSQO9bCw);
			if (!!(T336_)) goto LA337_;
			T339_ = div__Sp7OcCEIFoBYolB6PB1fAg_3(argA_6, argB_6);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T339_, n, g);
		}
		LA337_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 120):
	{
		NIM_BOOL T341_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T342_;
		T341_ = (NIM_BOOL)0;
		T341_ = containsSets__Jr5d2PbcnAZ0pFa4Ny88lg((*g).config, a, b);
		T342_ = toInt128__161i7kexvUAISxPtGBRWYw(T341_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T342_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 119):
	{
		NIM_BOOL T344_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T345_;
		T344_ = (NIM_BOOL)0;
		T344_ = equalSets__Jr5d2PbcnAZ0pFa4Ny88lg_2((*g).config, a, b);
		T345_ = toInt128__161i7kexvUAISxPtGBRWYw(T344_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T345_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121):
	{
		NIM_BOOL T347_;
		NIM_BOOL T349_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T350_;
		T347_ = (NIM_BOOL)0;
		T347_ = containsSets__Jr5d2PbcnAZ0pFa4Ny88lg((*g).config, a, b);
		if (!(T347_)) goto LA348_;
		T349_ = (NIM_BOOL)0;
		T349_ = equalSets__Jr5d2PbcnAZ0pFa4Ny88lg_2((*g).config, a, b);
		T347_ = !(T349_);
		LA348_: ;
		T350_ = toInt128__161i7kexvUAISxPtGBRWYw(T347_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T350_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 122):
	{
		result = intersectSets__DJXyM0ZYUUgI9bAP6orixDA((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 123):
	{
		result = unionSets__DJXyM0ZYUUgI9bAP6orixDA_2((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 124):
	{
		result = diffSets__DJXyM0ZYUUgI9bAP6orixDA_3((*g).config, a, b);
		(*result).info = (*n).info;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 125):
	{
		NimStringDesc* T355_;
		NimStringDesc* T356_;
		NimStringDesc* T357_;
		T355_ = (NimStringDesc*)0;
		T356_ = (NimStringDesc*)0;
		T356_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2(a);
		T357_ = (NimStringDesc*)0;
		T357_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2(b);
		T355_ = rawNewString((T356_ ? T356_->Sup.len : 0) + (T357_ ? T357_->Sup.len : 0) + 0);
appendString(T355_, T356_);
appendString(T355_, T357_);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T355_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134):
	{
		NIM_BOOL T359_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T360_;
		T359_ = (NIM_BOOL)0;
		T359_ = inSet__b4nxsJCvqXRlyalSWskgNA(a, b);
		T360_ = toInt128__161i7kexvUAISxPtGBRWYw(T359_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T360_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 135):
	{
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 103):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 104):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T363_;
		NimStringDesc* T364_;
		T363_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T364_ = (NimStringDesc*)0;
		T364_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(T363_);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T364_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 102):
	{
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T368_;
			NIM_BOOL T369_;
			T368_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
			T369_ = (NIM_BOOL)0;
			T369_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T368_, IL64(0));
			if (!T369_) goto LA370_;
			result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_7), n, g);
		}
		goto LA366_;
		LA370_: ;
		{
			result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_8), n, g);
		}
		LA366_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 105):
	{
		NF T374_;
		NimStringDesc* T375_;
		T374_ = (NF)0;
		T374_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
		T375_ = (NimStringDesc*)0;
		T375_ = nimFloatToStr(T374_);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T375_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 106):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 101):
	{
		{
			NimStringDesc* s;
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA379_;
			s = ((NimStringDesc*) NIM_NIL);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** b_3;
				tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
				NI i;
				NI L;
				NI T382_;
				b_3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
				colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
				colontmp_ = (*a)._kind_6.sons;
				i = ((NI) 0);
				T382_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T382_;
				{
					while (1) {
						NimStringDesc* T385_;
						if (!(i < L)) goto LA384;
						b_3 = &colontmp_->data[i];
						T385_ = (NimStringDesc*)0;
						T385_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2((*b_3));
						s = resizeString(s, (T385_ ? T385_->Sup.len : 0) + 0);
appendString(s, T385_);
						i += ((NI) 1);
					} LA384: ;
				}
			}
			result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(s, n, g);
		}
		goto LA377_;
		LA379_: ;
		{
			NimStringDesc* T387_;
			T387_ = (NimStringDesc*)0;
			T387_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2(a);
			result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T387_, n, g);
		}
		LA377_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107):
	{
		NimStringDesc* T389_;
		T389_ = (NimStringDesc*)0;
		T389_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2(a);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T389_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 108):
	{
		NimStringDesc* T391_;
		T391_ = (NimStringDesc*)0;
		T391_ = ordinalValToString__1UtzyyNfA4Pde4QCgge15Q(a, g);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T391_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 144):
	{
		result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(a);
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 206):
	{
		NimStringDesc* T394_;
		NIM_BOOL T395_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T396_;
		T394_ = (NimStringDesc*)0;
		T394_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(a);
		T395_ = (NIM_BOOL)0;
		T395_ = testCompileOption__9bbrBm0brnGO9cOW9coVJSCaQ((*g).config, T394_, (*n).info);
		T396_ = toInt128__161i7kexvUAISxPtGBRWYw(T395_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T396_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 207):
	{
		NimStringDesc* T398_;
		NimStringDesc* T399_;
		NIM_BOOL T400_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T401_;
		T398_ = (NimStringDesc*)0;
		T398_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(a);
		T399_ = (NimStringDesc*)0;
		T399_ = getStr__P2DOsHG6Jk4Siab3L2qwUg(b);
		T400_ = (NIM_BOOL)0;
		T400_ = testCompileOptionArg__Wd9alT05EZZXVF7dib5G9cYg((*g).config, T398_, T399_, (*n).info);
		T401_ = toInt128__161i7kexvUAISxPtGBRWYw(T400_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T401_, n, g);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 92):
	{
		NIM_BOOL T403_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T404_;
		T403_ = (NIM_BOOL)0;
		T403_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA(a, b, NIM_TRUE);
		T404_ = toInt128__161i7kexvUAISxPtGBRWYw(T403_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T404_, n, g);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getAppType__pFThSxTIx1UddS3Wdyr9bkQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7))&63U)))!=0)) goto LA3_;
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_13), n, g);
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 8))&63U)))!=0)) goto LA6_;
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_14), n, g);
	}
	goto LA1_;
	LA6_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0)) goto LA9_;
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_15), n, g);
	}
	goto LA1_;
	LA9_: ;
	{
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_16), n, g);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, info);
	{
		if (!!(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA3_;
		asgnRef((void**) (&(*result).typ), newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), (*s).owner));
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ((*result).typ, (*s).typ);
	}
	goto LA1_;
	LA3_: ;
	{
		asgnRef((void**) (&(*result).typ), (*s).typ);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstIfExpr__2kStqt7u4DPR9b4UNFMJdQg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NI T6_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
					T6_ = (NI)0;
					T6_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!(T6_ == ((NI) 2))) goto LA7_;
					e = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(c, (*it)._kind_6.sons->data[((NI) 0)], g);
					{
						if (!(e == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA11_;
						result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
						goto BeforeRet_;
					}
					LA11_: ;
					{
						tyObject_Int128__9a9axPfb75jdWY25AamJewkA T15_;
						NIM_BOOL T16_;
						T15_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(e, Max__zlJMNfqX7LwCYj0PF6ncWQ);
						T16_ = (NIM_BOOL)0;
						T16_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T15_, IL64(0));
						if (!!(T16_)) goto LA17_;
						{
							if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA21_;
							result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(c, (*it)._kind_6.sons->data[((NI) 1)], g);
							{
								if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA25_;
								goto BeforeRet_;
							}
							LA25_: ;
						}
						LA21_: ;
					}
					LA17_: ;
				}
				goto LA4_;
				LA7_: ;
				{
					NI T28_;
					T28_ = (NI)0;
					T28_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!(T28_ == ((NI) 1))) goto LA29_;
					{
						if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA33_;
						result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(c, (*it)._kind_6.sons->data[((NI) 0)], g);
					}
					LA33_: ;
				}
				goto LA4_;
				LA29_: ;
				{
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, (*it).info, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_24), TM__JtgqXuJaW0Uz9aqyNPWIZsw_25);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b) {
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getArrayConstr__A7gcXCy5E3uGBy5F37NoHA_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, n, g);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA8_;
			result = n;
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, magicCall__A7gcXCy5E3uGBy5F37NoHA_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ <= ((NI) 1))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	a = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 1)], g);
	b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 2) < T12_)) goto LA13_;
		b = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 2)], g);
		{
			if (!(b == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA17_;
			goto BeforeRet_;
		}
		LA17_: ;
		{
			NI T21_;
			T21_ = (NI)0;
			T21_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 3) < T21_)) goto LA22_;
			c = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 3)], g);
			{
				if (!(c == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA26_;
				goto BeforeRet_;
			}
			LA26_: ;
		}
		LA22_: ;
	}
	LA13_: ;
	result = evalOp__naTMtRq9avUKkKDwI0csDMg((*s).magic, n, a, b, c, g);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldConStrStr__A7gcXCy5E3uGBy5F37NoHA_4)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*n).info, (*n).typ);
	asgnRef((void**) (&(*result)._kind_3.strVal), ((NimStringDesc*) NIM_NIL));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				NimStringDesc* T8_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[i], g);
				{
					if (!(a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA6_;
					result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA6_: ;
				T8_ = (NimStringDesc*)0;
				T8_ = getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2(a);
				asgnRef((void**) (&(*result)._kind_3.strVal), resizeString((*result)._kind_3.strVal, (T8_ ? T8_->Sup.len : 0) + 0));
appendString((*result)._kind_3.strVal, T8_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__hutrgrWnBjOoG19cbpgmANA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		switch ((*b).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T4_;
			T3_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(a);
			T4_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			result = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T3_, T4_);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
		{
			NF T6_;
			T6_ = (NF)0;
			T6_ = round((*b)._kind_2.floatVal);
			result = ((*a)._kind_1.intVal <= ((NI64) (((NI) (T6_)))));
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		switch ((*b).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
		{
			result = ((*a)._kind_2.floatVal <= (*b)._kind_2.floatVal);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T11_;
			NF T12_;
			T11_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(b);
			T12_ = (NF)0;
			T12_ = toFloat64__PDwVTbOO2Rlwlg5dKjIRyQ(T11_);
			result = ((*a)._kind_2.floatVal <= T12_);
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__LmBGzflgpD7jusLMkw9aLgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	{
		NIM_BOOL T3_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T4_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*n).typ);
		T3_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(value, T4_);
		if (T3_) goto LA5_;
		T6_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*g).config, (*n).typ);
		T3_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T6_, value);
		LA5_: ;
		if (!T3_) goto LA7_;
		T9_ = (NimStringDesc*)0;
		T10_ = (NimStringDesc*)0;
		T10_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(value);
		T11_ = (NimStringDesc*)0;
		T11_ = typeToString__QlvraUan7WbHowhAbvDvdA((*n).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + (T11_ ? T11_->Sup.len : 0) + 19);
appendString(T9_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_37));
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_38));
appendString(T9_, T11_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_39, NIM_FALSE);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldConv__MlnTAS4JHv81FgG2EV9ci3g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NIM_BOOL check) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dstTyp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* srcTyp;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	dstTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350136322064));
	srcTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*a).typ, IL64(36134350136322064));
	switch ((*dstTyp).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
		{
			NF T3_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T4_;
			T3_ = (NF)0;
			T3_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
			T4_ = toInt128__HaskCaz5YmXySs9c9c3vJN8A(!((T3_ == 0.0)));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T4_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
			NIM_BOOL T7_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T8_;
			T6_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
			T7_ = (NIM_BOOL)0;
			T7_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T6_, IL64(0));
			T8_ = toInt128__HaskCaz5YmXySs9c9c3vJN8A(!(T7_));
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T8_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		default:
		{
			{
				NimStringDesc* T15_;
				if (!NIM_TRUE) goto LA13_;
				T15_ = (NimStringDesc*)0;
				T15_ = rawNewString((reprEnum((NI)(*srcTyp).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*srcTyp).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 29);
appendString(T15_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_36));
appendString(T15_, reprEnum((NI)(*srcTyp).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
				failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(T15_);
			}
			LA13_: ;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
		{
			NF T18_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T19_;
			T18_ = (NF)0;
			T18_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(a);
			T19_ = toInt128__Ds1OEQoxqjWJ62lsdr6soA(T18_);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T19_, n, g);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA val;
			val = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
			{
				if (!check) goto LA23_;
				rangeCheck__LmBGzflgpD7jusLMkw9aLgw(n, val, g);
			}
			LA23_: ;
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(val, n, g);
			{
				if (!((*dstTyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*dstTyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44))) goto LA27_;
				transitionIntKind__VaXqiHBsdA0MNhmXnesuRw(result, ((tyEnum_TNodeKind__D37bGuL0oC9aRhwdwBfWpFg) 11));
			}
			LA27_: ;
		}
		break;
		default:
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		}
		{
			NIM_BOOL T32_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T36_;
			T32_ = (NIM_BOOL)0;
			T32_ = check;
			if (!(T32_)) goto LA33_;
			T32_ = ((*result).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*result).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
			LA33_: ;
			if (!T32_) goto LA34_;
			T36_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(result);
			rangeCheck__LmBGzflgpD7jusLMkw9aLgw(n, T36_, g);
		}
		LA34_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
	{
		switch ((*srcTyp).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T39_;
			NF T40_;
			T39_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(a, Max__zlJMNfqX7LwCYj0PF6ncWQ);
			T40_ = (NF)0;
			T40_ = toFloat64__PDwVTbOO2Rlwlg5dKjIRyQ(T39_);
			result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(T40_, n, g);
		}
		break;
		default:
		{
			result = a;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
	}
	break;
	default:
	{
		result = a;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldArrayAccess__A7gcXCy5E3uGBy5F37NoHA_5)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y;
	NI64 idx;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (x == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T3_) goto LA4_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*x).typ, IL64(70368744179728));
		T3_ = ((*T5_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	y = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 1)], g);
	{
		if (!(y == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	T12_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(y, Max__zlJMNfqX7LwCYj0PF6ncWQ);
	idx = toInt64__1szweXXq3RBN50owrYu2Xw(T12_);
	switch ((*x).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		{
			NIM_BOOL T16_;
			NI T18_;
			T16_ = (NIM_BOOL)0;
			T16_ = (IL64(0) <= idx);
			if (!(T16_)) goto LA17_;
			T18_ = (NI)0;
			T18_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
			T16_ = (idx < ((NI64) (T18_)));
			LA17_: ;
			if (!T16_) goto LA19_;
			result = (*x)._kind_6.sons->data[idx];
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA23_;
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			LA23_: ;
		}
		goto LA14_;
		LA19_: ;
		{
			NimStringDesc* T26_;
			NimStringDesc* T27_;
			NimStringDesc* T38_;
			T26_ = (NimStringDesc*)0;
			T27_ = (NimStringDesc*)0;
			{
				NI T30_;
				T30_ = (NI)0;
				T30_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
				if (!((NI)(T30_ - ((NI) 1)) < ((NI) 0))) goto LA31_;
				T27_ = copyString(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_40));
			}
			goto LA28_;
			LA31_: ;
			{
				NimStringDesc* T34_;
				NimStringDesc* T35_;
				NI T36_;
				NimStringDesc* T37_;
				T34_ = (NimStringDesc*)0;
				T35_ = (NimStringDesc*)0;
				T35_ = nimInt64ToStr(idx);
				T36_ = (NI)0;
				T36_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
				T37_ = (NimStringDesc*)0;
				T37_ = nimIntToStr((NI)(T36_ - ((NI) 1)));
				T34_ = rawNewString((T35_ ? T35_->Sup.len : 0) + (T37_ ? T37_->Sup.len : 0) + 19);
appendString(T34_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_41));
appendString(T34_, T35_);
appendString(T34_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_42));
appendString(T34_, T37_);
				T27_ = T34_;
			}
			LA28_: ;
			T38_ = (NimStringDesc*)0;
			T38_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
			T26_ = rawNewString((T27_ ? T27_->Sup.len : 0) + (T38_ ? T38_->Sup.len : 0) + 0);
appendString(T26_, T27_);
appendString(T26_, T38_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_43, NIM_FALSE);
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T40_;
		NI64 T41_;
		T40_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*x).typ);
		T41_ = (NI64)0;
		T41_ = toInt64__1szweXXq3RBN50owrYu2Xw(T40_);
		idx -= T41_;
		{
			NIM_BOOL T44_;
			NI T46_;
			T44_ = (NIM_BOOL)0;
			T44_ = (IL64(0) <= idx);
			if (!(T44_)) goto LA45_;
			T46_ = (NI)0;
			T46_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
			T44_ = (idx < ((NI64) (T46_)));
			LA45_: ;
			if (!T44_) goto LA47_;
			result = (*x)._kind_6.sons->data[idx];
		}
		goto LA42_;
		LA47_: ;
		{
			NimStringDesc* T50_;
			NimStringDesc* T51_;
			NimStringDesc* T62_;
			T50_ = (NimStringDesc*)0;
			T51_ = (NimStringDesc*)0;
			{
				NI T54_;
				T54_ = (NI)0;
				T54_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
				if (!((NI)(T54_ - ((NI) 1)) < ((NI) 0))) goto LA55_;
				T51_ = copyString(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_40));
			}
			goto LA52_;
			LA55_: ;
			{
				NimStringDesc* T58_;
				NimStringDesc* T59_;
				NI T60_;
				NimStringDesc* T61_;
				T58_ = (NimStringDesc*)0;
				T59_ = (NimStringDesc*)0;
				T59_ = nimInt64ToStr(idx);
				T60_ = (NI)0;
				T60_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
				T61_ = (NimStringDesc*)0;
				T61_ = nimIntToStr((NI)(T60_ - ((NI) 1)));
				T58_ = rawNewString((T59_ ? T59_->Sup.len : 0) + (T61_ ? T61_->Sup.len : 0) + 19);
appendString(T58_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_41));
appendString(T58_, T59_);
appendString(T58_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_42));
appendString(T58_, T61_);
				T51_ = T58_;
			}
			LA52_: ;
			T62_ = (NimStringDesc*)0;
			T62_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
			T50_ = rawNewString((T51_ ? T51_->Sup.len : 0) + (T62_ ? T62_->Sup.len : 0) + 0);
appendString(T50_, T51_);
appendString(T50_, T62_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T50_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_44, NIM_FALSE);
		}
		LA42_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5), (*x).info, (*n).typ);
		{
			NIM_BOOL T66_;
			T66_ = (NIM_BOOL)0;
			T66_ = (IL64(0) <= idx);
			if (!(T66_)) goto LA67_;
			T66_ = (idx < ((NI64) (((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0))));
			LA67_: ;
			if (!T66_) goto LA68_;
			(*result)._kind_1.intVal = ((NI64) (((NU8)((*x)._kind_3.strVal->data[idx]))));
		}
		goto LA64_;
		LA68_: ;
		{
			NimStringDesc* T71_;
			NimStringDesc* T72_;
			NimStringDesc* T81_;
			T71_ = (NimStringDesc*)0;
			T72_ = (NimStringDesc*)0;
			{
				if (!((NI)(((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0) - ((NI) 1)) < ((NI) 0))) goto LA75_;
				T72_ = copyString(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_40));
			}
			goto LA73_;
			LA75_: ;
			{
				NimStringDesc* T78_;
				NimStringDesc* T79_;
				NimStringDesc* T80_;
				T78_ = (NimStringDesc*)0;
				T79_ = (NimStringDesc*)0;
				T79_ = nimInt64ToStr(idx);
				T80_ = (NimStringDesc*)0;
				T80_ = nimIntToStr((NI)(((*x)._kind_3.strVal ? (*x)._kind_3.strVal->Sup.len : 0) - ((NI) 1)));
				T78_ = rawNewString((T79_ ? T79_->Sup.len : 0) + (T80_ ? T80_->Sup.len : 0) + 19);
appendString(T78_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_41));
appendString(T78_, T79_);
appendString(T78_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_42));
appendString(T78_, T80_);
				T72_ = T78_;
			}
			LA73_: ;
			T81_ = (NimStringDesc*)0;
			T81_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
			T71_ = rawNewString((T72_ ? T72_->Sup.len : 0) + (T81_ ? T81_->Sup.len : 0) + 0);
appendString(T71_, T72_);
appendString(T71_, T81_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T71_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_45, NIM_FALSE);
		}
		LA64_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, foldFieldAccess__A7gcXCy5E3uGBy5F37NoHA_6)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
	NimStringDesc* T22_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (x == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	field = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	{
		NI i;
		NI colontmp_;
		NI colontmp__2;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp__2 = (NI)0;
		colontmp_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(x);
		i_2 = colontmp_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp__2)) goto LA9;
				i = i_2;
				it = (*x)._kind_6.sons->data[i];
				{
					if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA12_;
					result = (*x)._kind_6.sons->data[(*field).position];
					{
						if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA16_;
						result = (*result)._kind_6.sons->data[((NI) 1)];
					}
					LA16_: ;
					goto BeforeRet_;
				}
				LA12_: ;
				{
					if (!((*(*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id == (*(*field).name).Sup.id)) goto LA20_;
					result = (*(*x)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)];
					goto BeforeRet_;
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	T22_ = (NimStringDesc*)0;
	T22_ = rawNewString(((*(*field).name).s ? (*(*field).name).s->Sup.len : 0) + 17);
appendString(T22_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_46));
appendString(T22_, (*(*field).name).s);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_47, NIM_FALSE);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstExpr__A7gcXCy5E3uGBy5F37NoHA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = (*n)._kind_4.sym;
		switch ((*s).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
			T3_ = toInt128__161i7kexvUAISxPtGBRWYw((*s).position);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T3_, n, g);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
		{
			switch ((*s).magic) {
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 196):
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T6_;
				T6_ = toInt128__161i7kexvUAISxPtGBRWYw((((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0));
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T6_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 197):
			{
				NimStringDesc* T8_;
				T8_ = (NimStringDesc*)0;
				T8_ = getDateStr__ye3QcrLEUbQh0AniHZYCHg_2();
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T8_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 198):
			{
				NimStringDesc* T10_;
				T10_ = (NimStringDesc*)0;
				T10_ = getClockStr__ye3QcrLEUbQh0AniHZYCHg_3();
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T10_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 200):
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
				T12_ = toInt128__161i7kexvUAISxPtGBRWYw(CPU__uYXopJX8pM87pQDCtmgWfQ[((*(*g).config).target.targetCPU)- 1].Field2);
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T12_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 201):
			{
				NimStringDesc* T14_;
				T14_ = (NimStringDesc*)0;
				T14_ = nsuToLowerAsciiStr(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*(*g).config).target.targetOS)- 1].Field0);
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T14_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 202):
			{
				NimStringDesc* T16_;
				T16_ = (NimStringDesc*)0;
				T16_ = nsuToLowerAsciiStr(CPU__uYXopJX8pM87pQDCtmgWfQ[((*(*g).config).target.targetCPU)- 1].Field0);
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T16_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 203):
			{
				NimStringDesc* T18_;
				T18_ = (NimStringDesc*)0;
				T18_ = nsuToLowerAsciiStr(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*(*g).config).target.hostOS)- 1].Field0);
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T18_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 204):
			{
				NimStringDesc* T20_;
				T20_ = (NimStringDesc*)0;
				T20_ = nsuToLowerAsciiStr(CPU__uYXopJX8pM87pQDCtmgWfQ[((*(*g).config).target.hostCPU)- 1].Field0);
				result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T20_, n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 205):
			{
				result = getAppType__pFThSxTIx1UddS3Wdyr9bkQ(n, g);
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 260):
			{
				{
					NIM_BOOL T25_;
					TSafePoint TM__JtgqXuJaW0Uz9aqyNPWIZsw_17;
					NimStringDesc** T28_;
					NI T29_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T30_;
					T25_ = (NIM_BOOL)0;
					T25_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*g).config, (*(*s).name).s);
					if (!T25_) goto LA26_;
					pushSafePoint(&TM__JtgqXuJaW0Uz9aqyNPWIZsw_17);
					TM__JtgqXuJaW0Uz9aqyNPWIZsw_17.status = _setjmp(TM__JtgqXuJaW0Uz9aqyNPWIZsw_17.context);
					if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_17.status == 0) {
					T28_ = (NimStringDesc**)0;
					T28_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					T29_ = (NI)0;
					T29_ = nsuParseInt((*T28_));
					T30_ = toInt128__161i7kexvUAISxPtGBRWYw(T29_);
					result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T30_, n, g);
					popSafePoint();
					}
					else {
						popSafePoint();
						if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
							NimStringDesc* T33_;
							NimStringDesc** T34_;
							TM__JtgqXuJaW0Uz9aqyNPWIZsw_17.status = 0;
							T33_ = (NimStringDesc*)0;
							T34_ = (NimStringDesc**)0;
							T34_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
							T33_ = rawNewString(((*T34_) ? (*T34_)->Sup.len : 0) + 53);
appendString(T33_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_18));
appendString(T33_, (*T34_));
appendString(T33_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_19));
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T33_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_20, NIM_FALSE);
							popCurrentException();
						}
					}
					if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_17.status != 0) reraiseException();
				}
				goto LA23_;
				LA26_: ;
				{
					result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast);
				}
				LA23_: ;
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 261):
			{
				{
					NIM_BOOL T39_;
					NimStringDesc** T42_;
					T39_ = (NIM_BOOL)0;
					T39_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*g).config, (*(*s).name).s);
					if (!T39_) goto LA40_;
					T42_ = (NimStringDesc**)0;
					T42_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ((*T42_), n, g);
				}
				goto LA37_;
				LA40_: ;
				{
					result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast);
				}
				LA37_: ;
			}
			break;
			case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 262):
			{
				{
					NIM_BOOL T47_;
					TSafePoint TM__JtgqXuJaW0Uz9aqyNPWIZsw_21;
					NimStringDesc** T50_;
					NIM_BOOL T51_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T52_;
					T47_ = (NIM_BOOL)0;
					T47_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*g).config, (*(*s).name).s);
					if (!T47_) goto LA48_;
					pushSafePoint(&TM__JtgqXuJaW0Uz9aqyNPWIZsw_21);
					TM__JtgqXuJaW0Uz9aqyNPWIZsw_21.status = _setjmp(TM__JtgqXuJaW0Uz9aqyNPWIZsw_21.context);
					if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_21.status == 0) {
					T50_ = (NimStringDesc**)0;
					T50_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
					T51_ = (NIM_BOOL)0;
					T51_ = parseBool__Y9cQyzddf88poHkzlcfsPIA((*T50_));
					T52_ = toInt128__161i7kexvUAISxPtGBRWYw(((NI) (T51_)));
					result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T52_, n, g);
					popSafePoint();
					}
					else {
						popSafePoint();
						if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
							NimStringDesc* T55_;
							NimStringDesc** T56_;
							TM__JtgqXuJaW0Uz9aqyNPWIZsw_21.status = 0;
							T55_ = (NimStringDesc*)0;
							T56_ = (NimStringDesc**)0;
							T56_ = nstTake((*(*g).config).symbols, (*(*s).name).s);
							T55_ = rawNewString(((*T56_) ? (*T56_)->Sup.len : 0) + 51);
appendString(T55_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_22));
appendString(T55_, (*T56_));
appendString(T55_, ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_19));
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T55_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_23, NIM_FALSE);
							popCurrentException();
						}
					}
					if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_21.status != 0) reraiseException();
				}
				goto LA45_;
				LA48_: ;
				{
					result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast);
				}
				LA45_: ;
			}
			break;
			default:
			{
				result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast);
			}
			break;
			}
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
		{
			result = n;
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
		{
			{
				NIM_BOOL T63_;
				T63_ = (NIM_BOOL)0;
				T63_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T63_)) goto LA64_;
				T63_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
				LA64_: ;
				if (!T63_) goto LA65_;
				result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
			}
			LA65_: ;
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
		{
			{
				if (!!(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA70_;
				result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
			}
			LA70_: ;
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
		{
			{
				if (!((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA75_;
				{
					NIM_BOOL T79_;
					T79_ = (NIM_BOOL)0;
					T79_ = !(((*(*s).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
					if (!(T79_)) goto LA80_;
					T79_ = !((((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0));
					LA80_: ;
					if (!T79_) goto LA81_;
					result = (*(*s).typ).n;
					asgnRef((void**) (&(*result).typ), base__PfgI9ap7WOnsRfFV4znQ27w((*s).typ));
				}
				LA81_: ;
			}
			goto LA73_;
			LA75_: ;
			{
				NIM_BOOL T84_;
				T84_ = (NIM_BOOL)0;
				T84_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes((*s).typ);
				if (!T84_) goto LA85_;
				result = (*(*s).typ).n;
			}
			goto LA73_;
			LA85_: ;
			{
				result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
			}
			LA73_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		result = getConstIfExpr__2kStqt7u4DPR9b4UNFMJdQg(m, n, g);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		TSafePoint TM__JtgqXuJaW0Uz9aqyNPWIZsw_26;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA94_;
			goto BeforeRet_;
		}
		LA94_: ;
		s_2 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T98_;
			T98_ = (NIM_BOOL)0;
			T98_ = !(((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12)));
			if (!(T98_)) goto LA99_;
			T98_ = !(((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13)));
			LA99_: ;
			if (!T98_) goto LA100_;
			goto BeforeRet_;
		}
		LA100_: ;
		pushSafePoint(&TM__JtgqXuJaW0Uz9aqyNPWIZsw_26);
		TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.status = _setjmp(TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.context);
		if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.status == 0) {
		switch ((*s_2).magic) {
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0):
		{
			popSafePoint();
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 8):
		{
			{
				tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T106_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T107_;
				NIM_BOOL T108_;
				NF T111_;
				T106_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38));
				T107_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T107_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
				T108_ = (NIM_BOOL)0;
				T108_ = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T106_, (*T107_).kind);
				if (!T108_) goto LA109_;
				T111_ = (NF)0;
				T111_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(T111_, n, g);
			}
			goto LA104_;
			LA109_: ;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T113_;
				T113_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T113_, n, g);
			}
			LA104_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9):
		{
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T117_;
				T117_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T117_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(45282286886758672));
				if (!!(((*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24) || (*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28) || (*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29) || (*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48)))) goto LA118_;
				{
					tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T122_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T123_;
					NIM_BOOL T124_;
					NF T127_;
					T122_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38));
					T123_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T123_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
					T124_ = (NIM_BOOL)0;
					T124_ = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T122_, (*T123_).kind);
					if (!T124_) goto LA125_;
					T127_ = (NF)0;
					T127_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
					result = newFloatNodeT__xN1c38fm4sSoVyZd2uUvXg(T127_, n, g);
				}
				goto LA120_;
				LA125_: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T129_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T130_;
					T129_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T129_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
					T130_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*g).config, T129_);
					result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T130_, n, g);
				}
				LA120_: ;
			}
			goto LA115_;
			LA118_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				a = getArrayConstr__A7gcXCy5E3uGBy5F37NoHA_2(m, (*n)._kind_6.sons->data[((NI) 1)], g);
				{
					NI T136_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T137_;
					if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA134_;
					T136_ = (NI)0;
					T136_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					T137_ = toInt128__161i7kexvUAISxPtGBRWYw((NI)(T136_ - ((NI) 1)));
					result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T137_, n, g);
				}
				LA134_: ;
			}
			LA115_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 36):
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
			a_2 = getArrayConstr__A7gcXCy5E3uGBy5F37NoHA_2(m, (*n)._kind_6.sons->data[((NI) 1)], g);
			{
				NI T143_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T144_;
				if (!((*a_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA141_;
				T143_ = (NI)0;
				T143_ = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
				T144_ = toInt128__161i7kexvUAISxPtGBRWYw(T143_);
				result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T144_, n, g);
			}
			goto LA139_;
			LA141_: ;
			{
				result = magicCall__A7gcXCy5E3uGBy5F37NoHA_3(m, n, g);
			}
			LA139_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 38):
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T147_;
			T147_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T147_, n, g);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 10):
		{
			tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym129_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym129_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym129_;
			NI64 sizeX60gensym129_;
			configX60gensym129_ = (*g).config;
			nodeX60gensym129_ = n;
			typX60gensym129_ = (*(*nodeX60gensym129_)._kind_6.sons->data[((NI) 1)]).typ;
			computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym129_, typX60gensym129_);
			sizeX60gensym129_ = (*typX60gensym129_).size;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resX60gensym129_;
				if (!(IL64(0) <= sizeX60gensym129_)) goto LA151_;
				resX60gensym129_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), sizeX60gensym129_);
				(*resX60gensym129_).info = (*nodeX60gensym129_).info;
				asgnRef((void**) (&(*resX60gensym129_).typ), (*nodeX60gensym129_).typ);
				result = resX60gensym129_;
			}
			goto LA149_;
			LA151_: ;
			{
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			}
			LA149_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 11):
		{
			tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym132_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym132_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym132_;
			NI16 alignX60gensym132_;
			configX60gensym132_ = (*g).config;
			nodeX60gensym132_ = n;
			typX60gensym132_ = (*(*nodeX60gensym132_)._kind_6.sons->data[((NI) 1)]).typ;
			computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym132_, typX60gensym132_);
			alignX60gensym132_ = (*typX60gensym132_).align;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resX60gensym132_;
				if (!(((NI16) 0) <= alignX60gensym132_)) goto LA157_;
				resX60gensym132_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (alignX60gensym132_)));
				(*resX60gensym132_).info = (*nodeX60gensym132_).info;
				asgnRef((void**) (&(*resX60gensym132_).typ), (*nodeX60gensym132_).typ);
				result = resX60gensym132_;
			}
			goto LA155_;
			LA157_: ;
			{
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			}
			LA155_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 12):
		{
			tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym135_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym135_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile dotExprX60gensym135_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* valueX60gensym135_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* memberX60gensym135_;
			NI offsetX60gensym135_;
			configX60gensym135_ = (*g).config;
			nodeX60gensym135_ = n;
			dotExprX60gensym135_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				{
					if (!((*(*nodeX60gensym135_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA164_;
					dotExprX60gensym135_ = (*nodeX60gensym135_)._kind_6.sons->data[((NI) 1)];
				}
				goto LA162_;
				LA164_: ;
				{
					if (!((*(*nodeX60gensym135_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46))) goto LA167_;
					dotExprX60gensym135_ = (*(*nodeX60gensym135_)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
				}
				goto LA162_;
				LA167_: ;
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew(configX60gensym135_, (*nodeX60gensym135_).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_27), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_28, NIM_FALSE);
				}
				LA162_: ;
			}
			valueX60gensym135_ = (*dotExprX60gensym135_)._kind_6.sons->data[((NI) 0)];
			memberX60gensym135_ = (*dotExprX60gensym135_)._kind_6.sons->data[((NI) 1)];
			computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym135_, (*valueX60gensym135_).typ);
			offsetX60gensym135_ = (*(*memberX60gensym135_)._kind_4.sym).offset;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tmpX60gensym135_;
				if (!(((NI) 0) <= offsetX60gensym135_)) goto LA172_;
				tmpX60gensym135_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (offsetX60gensym135_)));
				(*tmpX60gensym135_).info = (*nodeX60gensym135_).info;
				asgnRef((void**) (&(*tmpX60gensym135_).typ), (*nodeX60gensym135_).typ);
				result = tmpX60gensym135_;
			}
			goto LA170_;
			LA172_: ;
			{
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			}
			LA170_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 140):
		{
			NimStringDesc* T176_;
			T176_ = (NimStringDesc*)0;
			T176_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 1)], 4);
			result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T176_, n, g);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 125):
		{
			result = foldConStrStr__A7gcXCy5E3uGBy5F37NoHA_4(m, n, g);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 14):
		{
		}
		break;
		default:
		{
			result = magicCall__A7gcXCy5E3uGBy5F37NoHA_3(m, n, g);
		}
		break;
		}
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__9cxMi1BPLc3UKt9br86bGfGQ_))) {
				TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.status = 0;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_30), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_31, NIM_FALSE);
				popCurrentException();
			}
			else 			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__n3A4gjRrFZBuNnTYx1h9a8w_))) {
				TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.status = 0;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_32), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_33, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__JtgqXuJaW0Uz9aqyNPWIZsw_26.status != 0) reraiseException();
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_3;
		a_3 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
		{
			if (!!((a_3 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA186_;
			result = n;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), a_3);
		}
		LA186_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	{
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
		{
			NI i;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son;
			i = (NI)0;
			son = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_2;
				NI colontmp_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_3 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_4;
						if (!(i_3 < colontmp_)) goto LA192;
						i_2 = i_3;
						i = i_2;
						son = (*n)._kind_6.sons->data[i_2];
						a_4 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, son, g);
						{
							if (!(a_4 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA195_;
							result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
							goto BeforeRet_;
						}
						LA195_: ;
						add__P8dDSotTW25BkfbyspojGg(result, a_4);
						i_3 += ((NI) 1);
					} LA192: ;
				}
			}
		}
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 4)) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_5;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		a_5 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
		{
			if (!(a_5 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA200_;
			goto BeforeRet_;
		}
		LA200_: ;
		b = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 1)], g);
		{
			if (!(b == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA204_;
			goto BeforeRet_;
		}
		LA204_: ;
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
		add__P8dDSotTW25BkfbyspojGg(result, a_5);
		add__P8dDSotTW25BkfbyspojGg(result, b);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
		{
			NIM_BOOL T209_;
			NI T210_;
			T209_ = (NIM_BOOL)0;
			T210_ = (NI)0;
			T210_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T209_ = (((NI) 0) < T210_);
			if (!(T209_)) goto LA211_;
			T209_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
			LA211_: ;
			if (!T209_) goto LA212_;
			{
				NI i_4;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* expr;
				i_4 = (NI)0;
				expr = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i_5;
					NI colontmp__2;
					NI i_6;
					i_5 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					i_6 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exprNew;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_6;
							if (!(i_6 < colontmp__2)) goto LA217;
							i_5 = i_6;
							i_4 = i_5;
							expr = (*n)._kind_6.sons->data[i_5];
							exprNew = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(expr);
							add__P8dDSotTW25BkfbyspojGg(exprNew, (*expr)._kind_6.sons->data[((NI) 0)]);
							a_6 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*expr)._kind_6.sons->data[((NI) 1)], g);
							{
								if (!(a_6 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA220_;
								result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
								goto BeforeRet_;
							}
							LA220_: ;
							add__P8dDSotTW25BkfbyspojGg(exprNew, a_6);
							add__P8dDSotTW25BkfbyspojGg(result, exprNew);
							i_6 += ((NI) 1);
						} LA217: ;
					}
				}
			}
		}
		goto LA207_;
		LA212_: ;
		{
			{
				NI i_7;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* expr_2;
				i_7 = (NI)0;
				expr_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i_8;
					NI colontmp__3;
					NI i_9;
					i_8 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					i_9 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_7;
							if (!(i_9 < colontmp__3)) goto LA226;
							i_8 = i_9;
							i_7 = i_8;
							expr_2 = (*n)._kind_6.sons->data[i_8];
							a_7 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, expr_2, g);
							{
								if (!(a_7 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA229_;
								result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
								goto BeforeRet_;
							}
							LA229_: ;
							add__P8dDSotTW25BkfbyspojGg(result, a_7);
							i_9 += ((NI) 1);
						} LA226: ;
					}
				}
			}
		}
		LA207_: ;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 4)) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_8;
		a_8 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
		{
			if (!(a_8 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA234_;
			goto BeforeRet_;
		}
		LA234_: ;
		{
			NIM_BOOL T238_;
			T238_ = (NIM_BOOL)0;
			T238_ = leValueConv__hutrgrWnBjOoG19cbpgmANA((*n)._kind_6.sons->data[((NI) 1)], a_8);
			if (!(T238_)) goto LA239_;
			T238_ = leValueConv__hutrgrWnBjOoG19cbpgmANA(a_8, (*n)._kind_6.sons->data[((NI) 2)]);
			LA239_: ;
			if (!T238_) goto LA240_;
			result = a_8;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		goto LA236_;
		LA240_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T243_;
			NimStringDesc* T244_;
			nimZeroMem((void*)T243_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T243_[0] = typeToString__QlvraUan7WbHowhAbvDvdA((*(*n)._kind_6.sons->data[((NI) 0)]).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T243_[1] = typeToString__QlvraUan7WbHowhAbvDvdA((*n).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T244_ = (NimStringDesc*)0;
			T244_ = nsuFormatOpenArray(((NimStringDesc*) &TM__JtgqXuJaW0Uz9aqyNPWIZsw_34), T243_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T244_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_35, NIM_FALSE);
		}
		LA236_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_9;
		a_9 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 0)], g);
		{
			if (!(a_9 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA248_;
			goto BeforeRet_;
		}
		LA248_: ;
		result = a_9;
		asgnRef((void**) (&(*result).typ), (*n).typ);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_10;
		a_10 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 1)], g);
		{
			if (!(a_10 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA253_;
			goto BeforeRet_;
		}
		LA253_: ;
		result = foldConv__MlnTAS4JHv81FgG2EV9ci3g(n, a_10, g, NIM_TRUE);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_11;
		a_11 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[((NI) 1)], g);
		{
			if (!(a_11 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA258_;
			goto BeforeRet_;
		}
		LA258_: ;
		{
			NIM_BOOL T262_;
			T262_ = (NIM_BOOL)0;
			T262_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T262_)) goto LA263_;
			T262_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50));
			LA263_: ;
			if (!T262_) goto LA264_;
			result = a_11;
			asgnRef((void**) (&(*result).typ), (*n).typ);
		}
		LA264_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		result = foldArrayAccess__A7gcXCy5E3uGBy5F37NoHA_5(m, n, g);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		result = foldFieldAccess__A7gcXCy5E3uGBy5F37NoHA_6(m, n, g);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		result = foldFieldAccess__A7gcXCy5E3uGBy5F37NoHA_6(m, (*n)._kind_6.sons->data[((NI) 0)], g);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		NI i_10;
		i_10 = ((NI) 0);
		{
			while (1) {
				NI T272_;
				T272_ = (NI)0;
				T272_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				if (!(i_10 <= (NI)(T272_ - ((NI) 2)))) goto LA271;
				{
					if (!((*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24) || (*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125) || (*(*n)._kind_6.sons->data[i_10]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA275_;
					i_10 += ((NI) 1);
				}
				goto LA273_;
				LA275_: ;
				{
					goto LA270;
				}
				LA273_: ;
			} LA271: ;
		} LA270: ;
		{
			NI T280_;
			T280_ = (NI)0;
			T280_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(i_10 == (NI)(T280_ - ((NI) 1)))) goto LA281_;
			result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(m, (*n)._kind_6.sons->data[i_10], g);
		}
		LA281_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
