/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg;
typedef struct tyTuple__5L3fCt9bX0gyEcO30ervPLw tyTuple__5L3fCt9bX0gyEcO30ervPLw;
typedef struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyTuple__UpiOGlu5Ux6DLM73wSrdpg;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA;
struct tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg {
  RootObj Sup;
NI pos;
NIM_BOOL inShortState;
NIM_BOOL allowWhitespaceAfterColon;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* longNoVal;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cmds;
NI idx;
tyEnum_CmdLineKind__XkdXq9atxjiuhkFFh0XYrSA kind;
NimStringDesc* key;
NimStringDesc* val;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg {
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a;
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b;
};
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg tyArray__vRMVBJdMPxNRfDfsYvXF0A[4];
typedef NU8 tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ;
typedef NU8 tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg;
struct tyTuple__5L3fCt9bX0gyEcO30ervPLw {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg Field12;
};
typedef tyTuple__5L3fCt9bX0gyEcO30ervPLw tyArray__geAxQ09aiJ4i2plLZEkYDpg[31];
typedef NU8 tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg;
struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg {
NimStringDesc* Field0;
NI Field1;
tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyArray__8d8P9caia9cszVjIJKsQGMQA[25];
typedef NU8 tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringDesc* s, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosunixToNativePath)(NimStringDesc* path, NimStringDesc* drive);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, npocmdLineRest)(tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__2yh9cer0ymNRHlOOg8P7IuA)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, expectArg__9cWjALn36XqpUyv43volzuw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addPrefix__uQmxTBj1ckq1MOOT9c5uRLA)(NimStringDesc* switch_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuToLowerAsciiStr)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__KV0xCsBzaN9coqb7PG9au0oQ)(NimStringDesc* s, NimStringDesc* sub);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, removeTrailingDirSep__nbuWUOJELn5idXbWiYOmOA)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, addPath__yQoptEnH9cvj9cZKgjcndthg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processCfgPath__1o4k2J9bsj2wWBwUjUj9atgQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuUnescape)(NimStringDesc* s, NimStringDesc* prefix, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___gEyhbzZ1UcxyenWRLJRXNQ)(NimStringDesc* head, NimStringDesc* tail);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pathSubs__paMedXIWX6si307wASTsQQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* p, NimStringDesc* config);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processPath__yr9b8Qf5CxXVgMiRouka8Dg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL notRelativeToProj);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__hhED57tMl0Iaa5bOg9cJaig)(NimStringDesc* key, NimStringDesc* default_0);
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___0U8YTiSB6NvFwgvyimFN2Q)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(void, nimblePath__yQoptEnH9cvj9cZKgjcndthg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__9cWjALn36XqpUyv43volzuw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, disableNimblePath__CQGypz7djD4eDZIXokhWpg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, clearNimblePath__CQGypz7djD4eDZIXokhWpg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___RkPToIJrmXtRS03VT1CneA)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toAbsoluteDir__jHVASw8gMU0B9bVk9atXU77g)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g, parseEnum__EKag4hBbNgjEXLqLxqglTQ)(NimStringDesc* s, tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g default_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__iY5h7sfVXAoUjuXGnmW9bAw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc** cmd, NimStringDesc** arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* switch_0, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__znuJizGq3isbcihOOtUY0A)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__7owBQPsmnvBN9cWaUPu9bYcQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__Jsd6LfkMRIXL9b0vzcHVYOA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__VWI2GZGxWbHzjYJHzOr3dA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__VWI2GZGxWbHzjYJHzOr3dA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__jbuLFmyuMzkCVahVfmlYeA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__O9arH9bYenXLOr27ZSmcQnEw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ)(NimStringDesc* arg, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw state, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w, findStr__ksT2oQUquwtB1u6JxjTCFw)(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg a, NimStringDesc* s, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w default_0);
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b);
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
N_LIB_PRIVATE N_NIMCALL(void, listHints__O9arH9bYenXLOr27ZSmcQnEw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__UhPXgqyDuuU9cKcS8FM883w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVSCompatible__nRr0tdRhl8rTyvIdRrQiFA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOptionCmd__siPDo9a2eQzwubdmcIGchWg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOptionCmd__siPDo9a2eQzwubdmcIGchWg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findModule__Y3iZ4DSoNguudlBW9cSwa2A)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* modulename, NimStringDesc* currentModule);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ, nameToOS__iaKZ3jKfqDIiIRvch1tYwg)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listOSnames__WnkSGhffTY6oNw2hLBbKUQ)(void);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__08masX9a9bS9a9b87wx8moDG9aQ)(tyObject_Target__9abOl5DLX8suLujOaHSvGzw* t, tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ o, tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag c);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag, nameToCPU__xntkVpXHPIZMT9cuNDXtepg)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, listCPUnames__WnkSGhffTY6oNw2hLBbKUQ_2)(void);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__WMrF6tFDO8y2YcugTwQDgA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__PO49anyWCbe63GYNOs9cVuvg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__BzRTaQ6LrPDZKEKt9bswkOQ flags);
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__PlZXt6qHCDDk29c9ac4IuLGA)(NI8 x);
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__WMrF6tFDO8y2YcugTwQDgA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass);
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__WMrF6tFDO8y2YcugTwQDgA_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass);
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__WMrF6tFDO8y2YcugTwQDgA_4)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCommandLineDesc__ssYZeuyrx9c44xJxPRKx1jQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__YVZCqlK3fKyVR367JpYgKA)(NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, setCC__Ep9cdURuQvSQKtNomcBwdFQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* ccname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, track__HHQbKxjjZZnOezuSelLvtA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ*, nsuSplitChar)(NimStringDesc* s, NIM_CHAR sep, NI maxsplit);
N_LIB_PRIVATE N_NIMCALL(NI, npuParseInt)(NimStringDesc* s, NI* number, NI start);
static N_INLINE(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__NPagzbOMpGo9aqJmfnDrITg)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__HHQbKxjjZZnOezuSelLvtA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__fHp3umDqKLlqmAGYAQvEUA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__9cWjALn36XqpUyv43volzuw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, inclDynlibOverride__mKOqGVEJPH4IP05mQ0BZkA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* lib);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ, parseEnum__qIaeVZYC2IcNaPaw4CHbjg)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA, parseEnum__JiBTkh7mRNMhfnA62LJ6xA)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* c, NimStringDesc* define);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__t8RT1Qk4s0rBX8YbKQ0DBQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__6QeR1iJ9b9aIgKE4A0vKaYTQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* key, NimStringDesc* val);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__jYnZYpCgdCpukBZK9bxcw9bQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* lib);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_2, ".nims", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_3, "e", 1);
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_4, "path", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_5, "p", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_6, "nimblepath", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_7, "babelpath", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_8, "nonimblepath", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_9, "nobabelpath", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_10, "clearnimblepath", 15);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_11, "excludepath", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_12, "nimcache", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_13, "out", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_14, "o", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_15, "outdir", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_16, "usenimcache", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_17, "docseesrcurl", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_18, "docroot", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_19, "backend", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_20, "b", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_21, "doccmd", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_22, "mainmodule", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_23, "m", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_24, "define", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_25, "d", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_26, "undef", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_27, "u", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_28, "symbol", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_29, "compile", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_30, "link", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_31, "debuginfo", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_32, "embedsrc", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_33, "compileonly", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_34, "c", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_35, "nolinking", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_36, "nomain", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_37, "forcebuild", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_38, "f", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_39, "project", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_40, "gc", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_41, "warnings", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_42, "w", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_43, "warning", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_44, "hint", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_45, "warningaserror", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_46, "hints", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_47, "threadanalysis", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_48, "stacktrace", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_49, "stacktracemsgs", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_50, "excessivestacktrace", 19);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_51, "linetrace", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_52, "debugger", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_53, "g", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_54, "profiler", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_55, "memtracker", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_56, "hotcodereloading", 16);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_57, "nilseqs", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_58, "checks", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_59, "x", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_60, "floatchecks", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_61, "infchecks", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_62, "nanchecks", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_63, "nilchecks", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_64, "objchecks", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_65, "fieldchecks", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_66, "rangechecks", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_67, "boundchecks", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_68, "refchecks", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_69, "overflowchecks", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_70, "staticboundchecks", 17);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_71, "stylechecks", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_72, "linedir", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_73, "assertions", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_74, "a", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_75, "deadcodeelim", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_76, "threads", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_77, "tlsemulation", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_78, "taintmode", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_79, "implicitstatic", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_80, "patterns", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_81, "trmacros", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_82, "opt", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_83, "app", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_84, "passc", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_85, "t", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_86, "passl", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_87, "l", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_88, "cincludes", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_89, "clibdir", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_90, "clib", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_91, "header", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_92, "index", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_93, "import", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_94, "include", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_95, "listcmd", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_96, "asm", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_97, "genmapping", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_98, "os", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_99, "cpu", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_100, "run", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_101, "r", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_102, "maxloopiterationsvm", 19);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_103, "errormax", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_104, "verbosity", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_105, "parallelbuild", 13);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_106, "version", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_107, "v", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_108, "advanced", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_109, "fullhelp", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_110, "help", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_111, "h", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_112, "symbolfiles", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_113, "incremental", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_114, "skipcfg", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_115, "skipprojcfg", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_116, "skipusercfg", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_117, "skipparentcfg", 13);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_118, "genscript", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_119, "gendeps", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_120, "colors", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_121, "lib", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_122, "putenv", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_123, "cc", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_124, "track", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_125, "trackdirty", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_126, "suggest", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_127, "def", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_128, "eval", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_129, "context", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_130, "usages", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_131, "stdout", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_132, "listfullpaths", 13);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_133, "dynliboverride", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_134, "dynliboverrideall", 17);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_135, "cs", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_136, "experimental", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_137, "legacy", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_138, "nocppexceptions", 15);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_139, "exceptions", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_140, "cppdefine", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_141, "newruntime", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_142, "seqsv2", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_143, "stylecheck", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_144, "showallmismatches", 17);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_145, "cppcompiletonamespace", 21);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_146, "docinternal", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_147, "multimethods", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_148, "expandmacro", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_149, "expandarc", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_150, "useversion", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_151, "benchmarkvm", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_152, "profilevm", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_153, "sinkinference", 13);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_154, "cursorinference", 15);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_155, "panics", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_156, "sourcemap", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_157, "deepcopy", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_158, "argument for command line option expected: \'$1\'", 47);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_159, "-", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_160, "--", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_162, "/home/runner/work/nightlies/nightlies/nim/compiler/commands.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_161 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 170),
((NI) 14)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_163, "$nimblepath", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_164, "$nimbledir", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_165, "nimbledir", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_166, "\"", 1);
extern TNimType NTI__yoNlBGx0D2tRizIdhQuENw_;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_168, "invalid path: ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_169 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 349),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_171 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 335),
((NI) 14)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_172, "NIMBLE_DIR", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_173, "pkgs", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_174, "invalid argument for command line option: \'$1\'", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_175 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 174),
((NI) 14)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_176, "on", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_177, "off", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_178, "\'on\' or \'off\' expected, but \'$1\' found", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_179 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 166),
((NI) 18)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_180, "@default", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_181, "invalid backend: \'$1\'", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_182 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 444),
((NI) 46)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__brsa2DgNdQAKzy1F0pSZlA_183 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_184, " ", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_185, "invalid command line option: \'$1\'", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_186 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 124),
((NI) 30)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_187 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 125),
((NI) 18)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_188, "nimQuirky", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_189, "true", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_190, "js", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_191, "boehm", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_192, "refc", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_193, "v2", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_194, "markandsweep", 12);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_195, "destructors", 11);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_196, "arc", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_197, "orc", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_198, "hooks", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_199, "go", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_200, "none", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_201, "stack", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_202, "regions", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_203, "boehmgc", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_204, "--gc:v2 is deprecated; using default gc", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_205 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 503),
((NI) 15)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_206, "gcmarkandsweep", 14);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_207, "gcdestructors", 13);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_208, "gcarc", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_209, "nimSeqsV2", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_210, "nimV2", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_211, "gcorc", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_212, "gchooks", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_213, "gogc", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_214, "nogc", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_215, "gcregions", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_216, "\'arc\', \'orc\', \'markAndSweep\', \'boehm\', \'go\', \'none\', \'regions\',"
" or \'refc\' expected, but \'$1\' found", 98);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_217 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 541),
((NI) 22)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_218, "list", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_219, "\'on\', \'off\' or \'list\' expected, but \'$1\' found", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_220 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 159),
((NI) 18)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_221, "unknown hint: ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_222 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 198),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_223, "unknown warning: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_224 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 202),
((NI) 20)}
;
static NIM_CONST tyArray__Re75IspeoxXy2oCZHwcRrA TM__brsa2DgNdQAKzy1F0pSZlA_225 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176),
((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_226 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 207),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_227 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 150),
((NI) 18)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_228, "native", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_229, "gdb", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_230, "expected native|gdb|on|off but found ", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_231 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 563),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_232, "useNimRtl", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_233, "/MD", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_234, "speed", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_235, "size", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_236, "\'none\', \'speed\' or \'size\' expected, but \'$1\' found", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_237 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 627),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_238, "gui", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_239, "console", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_240, "staticlib", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_241, "executable", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_242, "guiapp", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_243, "consoleapp", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_244, "library", 7);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_245, "dll", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_246, "\'gui\', \'console\' or \'lib\' expected, but \'$1\' found", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_247 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 649),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_248, ", ", 2);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_249, "unknown OS: \'$1\'. Available options are: $2", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_250 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 690),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_251, "unknown CPU: \'$1\'. Available options are: $2", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_252 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 698),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_253, "invalid verbosity level: \'$1\'", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_254 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 718),
((NI) 16)}
;
extern NIM_CONST tyArray__vRMVBJdMPxNRfDfsYvXF0A NotesVerbosity__DnFX9bU018gdYu1P77fbdxQ;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_255, "Nim Compiler Version $1 [$2: $3]\012Compiled at $4\012Copyright (c) 2"
"006-2020 by Andreas Rumpf\012", 89);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_256, "1.4.2", 5);
extern NIM_CONST tyArray__geAxQ09aiJ4i2plLZEkYDpg OS__Jx0qy9c9bSo4fGkMxUfUaAaw;
extern NIM_CONST tyArray__8d8P9caia9cszVjIJKsQGMQA CPU__uYXopJX8pM87pQDCtmgWfQ;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_257, "2020-11-30", 10);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_258, "git hash: 3fb5157ab1b666a5a5c34efde0f357a82d433d04", 50);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_259, "active boot switches: -d:release -d:danger", 42);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_260, "Advanced commands:\012    compileToC, cc          compile project "
"with C code generator\012    compileToCpp, cpp       compile projec"
"t to C++ code\012    compileToOC, objc       compile project to Obj"
"ective C code\012    js                      compile project to Jav"
"ascript\012    e                       run a Nimscript file\012    rst"
"2html                convert a reStructuredText file to HTML\012   "
"                         use `--docCmd:skip` to skip compiling s"
"nippets\012    rst2tex                 convert a reStructuredText f"
"ile to TeX\012    jsondoc                 extract the documentation"
" to a json file\012    ctags                   create a tags file\012 "
"   buildIndex              build an index for the whole document"
"ation\012    genDepend               generate a DOT file containing"
" the\012                            module dependency graph\012    dum"
"p                    dump all defined conditionals and search pa"
"ths\012                            see also: --dump.format:json (us"
"eful with: `| jq`)\012    check                   checks the projec"
"t for syntax and semantic\012\012Runtime checks (see -x):\012  --objCheck"
"s:on|off        turn obj conversion checks on|off\012  --fieldCheck"
"s:on|off      turn case variant field checks on|off\012  --rangeChe"
"cks:on|off      turn range checks on|off\012  --boundChecks:on|off "
"     turn bound checks on|off\012  --overflowChecks:on|off   turn i"
"nt over-/underflow checks on|off\012  --floatChecks:on|off      tur"
"n all floating point (NaN/Inf) checks on|off\012  --nanChecks:on|of"
"f        turn NaN checks on|off\012  --infChecks:on|off        turn"
" Inf checks on|off\012  --refChecks:on|off        turn ref checks o"
"n|off (only for --newruntime)\012\012Advanced options:\012  -o:FILE, --ou"
"t:FILE       set the output filename\012  --outdir:DIR             "
" set the path where the output file will be written\012  --usenimca"
"che             will use `outdir=$nimcache`, whichever it resolv"
"es\012                            to after all options have been pr"
"ocessed\012  --stdout:on|off           output to stdout\012  --colors:"
"on|off           turn compiler messages coloring on|off\012  --list"
"FullPaths:on|off    list full paths in messages\012  -w:on|off|list"
", --warnings:on|off|list\012                            turn all wa"
"rnings on|off or list all available\012  --warning[X]:on|off       "
"turn specific warning X on|off\012  --hints:on|off|list       turn "
"all hints on|off or list all available\012  --hint[X]:on|off       "
"   turn specific hint X on|off\012  --warningAsError[X]:on|off\012    "
"                        turn specific warning X into an error on"
"|off\012  --styleCheck:off|hint|error\012                            p"
"roduce hints or errors for Nim identifiers that\012                "
"            do not adhere to Nim\'s official style guide\012        "
"                    https://nim-lang.org/docs/nep1.html\012  --show"
"AllMismatches:on|off\012                            show all mismat"
"ching candidates in overloading\012                            reso"
"lution\012  --lib:PATH                set the system library path\012 "
" --import:PATH             add an automatically imported module\012"
"  --include:PATH            add an automatically included module"
"\012  --nimcache:PATH           set the path used for generated fil"
"es\012                            see also https://nim-lang.org/doc"
"s/nimc.html#compiler-usage-generated-c-code-directory\012  -c, --co"
"mpileOnly:on|off  compile Nim files only; do not assemble or lin"
"k\012  --noLinking:on|off        compile Nim and generated files bu"
"t do not link\012  --noMain:on|off           do not generate a main"
" procedure\012  --genScript:on|off        generate a compile script"
" (in the \'nimcache\'\012                            subdirectory nam"
"ed \'compile_$project$scriptext\'),\012                            im"
"plies --compileOnly\012  --genDeps:on|off          generate a \'.dep"
"s\' file containing the dependencies\012  --os:SYMBOL               "
"set the target operating system (cross-compilation)\012  --cpu:SYMB"
"OL              set the target processor (cross-compilation)\012  -"
"-debuginfo:on|off        enables debug information\012  -t, --passC"
":OPTION        pass an option to the C compiler\012  -l, --passL:OP"
"TION        pass an option to the linker\012  --cc:SYMBOL          "
"     specify the C compiler\012  --cincludes:DIR           modify t"
"he C compiler header search path\012  --clibdir:DIR             mod"
"ify the linker library search path\012  --clib:LIBNAME            l"
"ink an additional C library\012                            (you sho"
"uld omit platform-specific extensions)\012  --project              "
"   document the whole project (doc)\012  --docRoot:path            "
"`nim doc --docRoot:/foo --project --outdir:docs /foo/sub/main.ni"
"m`\012                            generates: docs/sub/main.html\012   "
"                         if path == @pkg, will use nimble file e"
"nclosing dir\012                            if path == @path, will "
"use first matching dir in `--path`\012                            i"
"f path == @default (the default and most useful), will use\012     "
"                       best match among @pkg,@path.\012            "
"                if these are nonexistent, will use project path\012"
"  -b, --backend:c|cpp|js|objc sets backend to use with commands "
"like `nim doc` or `nim r`\012  --docCmd:cmd              if `cmd =="
" skip`, skips runnableExamples\012                            else,"
" runs runnableExamples with given options, e.g.:\012               "
"             `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:u"
"rl        activate \'see source\' for doc command\012                "
"            (see doc.item.seesrc in config/nimdoc.cfg)\012  --docIn"
"ternal             also generate documentation for non-exported "
"symbols\012  --lineDir:on|off          generation of #line directiv"
"e on|off\012  --embedsrc:on|off         embeds the original source "
"code as comments\012                            in the generated ou"
"tput\012  --threadanalysis:on|off   turn thread analysis on|off\012  -"
"-tlsEmulation:on|off     turn thread local storage emulation on|"
"off\012  --taintMode:on|off        turn taint mode on|off\012  --impli"
"citStatic:on|off   turn implicit compile time evaluation on|off\012"
"  --trmacros:on|off         turn term rewriting macros on|off\012  "
"--multimethods:on|off     turn multi-methods on|off\012  --memTrack"
"er:on|off       turn memory tracker on|off\012  --hotCodeReloading:"
"on|off\012                            turn support for hot code rel"
"oading on|off\012  --excessiveStackTrace:on|off\012                   "
"         stack traces use full file paths\012  --stackTraceMsgs:on|"
"off   enable user defined stack frame msgs via `setFrameMsg`\012  -"
"-nilseqs:on|off          allow \'nil\' for strings/seqs for\012      "
"                      backwards compatibility\012  --seqsv2:on|off "
"          use the new string/seq implementation based on\012       "
"                     destructors\012  --skipCfg:on|off          do "
"not read the nim installation\'s configuration file\012  --skipUserC"
"fg:on|off      do not read the user\'s configuration file\012  --ski"
"pParentCfg:on|off    do not read the parent dirs\' configuration "
"files\012  --skipProjCfg:on|off      do not read the project\'s conf"
"iguration file\012  --gc:refc|arc|orc|markAndSweep|boehm|go|none|re"
"gions\012                            select the GC to use; default "
"is \'refc\'\012  --exceptions:setjmp|cpp|goto\012                       "
"     select the exception handling implementation\012  --index:on|o"
"ff            turn index file generation on|off\012  --putenv:key=v"
"alue        set an environment variable\012  --NimblePath:PATH     "
"    add a path for Nimble support\012  --noNimblePath            de"
"activate the Nimble path\012  --clearNimblePath         empty the l"
"ist of Nimble package search paths\012  --cppCompileToNamespace:nam"
"espace\012                            use the provided namespace fo"
"r the generated C++ code,\012                            if no name"
"space is provided \"Nim\" will be used\012  --expandMacro:MACRO      "
" dump every generated AST from MACRO\012  --expandArc:PROCNAME     "
" show how PROCNAME looks like after diverse optimizations\012      "
"                      before the final backend phase (mostly ARC"
"/ORC specific)\012  --excludePath:PATH        exclude a path from t"
"he list of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL"
" so that dynlib:SYMBOL\012                            has no effect"
" and can be statically linked instead;\012                         "
"   symbol matching is fuzzy so\012                            that "
"--dynlibOverride:lua matches\012                            dynlib:"
" \"liblua.so.3\"\012  --dynlibOverrideAll\012                           "
" disables the effects of the dynlib pragma\012  --listCmd          "
"       list the compilation commands; can be combined with\012     "
"                       `--hint:exec:on` and `--hint:link:on`\012  -"
"-asm                     produce assembler code\012  --parallelBuil"
"d:0|1|...   perform a parallel build\012                           "
" value = number of processors (0 for auto-detect)\012  --incrementa"
"l:on|off      only recompile the changed modules (experimental!)"
"\012  --verbosity:0|1|2|3       set Nim\'s verbosity level (1 is def"
"ault)\012  --errorMax:N              stop compilation after N error"
"s; 0 means unlimited\012  --maxLoopIterationsVM:N   set max iterati"
"ons for all VM loops\012  --experimental:implicitDeref|dotOperators"
"|callOperator|parallel|destructor|notnil|dynamicBindSym|forLoopM"
"acros|caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|s"
"trictFuncs|views\012                            enable experimental"
" language feature\012  --legacy:allowSemcheckedAstModification|chec"
"kUnsignedConversions\012                            enable obsolete"
"/legacy language feature\012  --useVersion:1.0          emulate Nim"
" version X of the Nim compiler\012  --profiler:on|off         enabl"
"e profiling; requires `import nimprof`, and\012                    "
"        works better with `--stackTrace:on`\012                    "
"        see also https://nim-lang.github.io/Nim/estp.html\012  --be"
"nchmarkVM:on|off      enable benchmarking of VM code with cpuTim"
"e()\012  --profileVM:on|off        enable compile time VM profiler\012"
"  --sinkInference:on|off    en-/disable sink parameter inference"
" (default: on)\012  --panics:on|off           turn panics into proc"
"ess terminations (default: off)\012  --deepcopy:on|off         enab"
"le \'system.deepCopy\' for ``--gc:arc|orc``\012", 10025);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_261, "::\012\012    nim command [options] [projectfile] [arguments]\012\012Comman"
"d:\012    compile, c              compile project with default code"
" generator (C)\012    r                       compile to $nimcache/"
"projname, run with [arguments]\012                            using"
" backend specified by `--backend` (default: c)\012    doc          "
"           generate the documentation for inputfile for\012        "
"                    backend specified by `--backend` (default: c"
")\012\012Arguments:\012  arguments are passed to the program being run (i"
"f --run option is selected)\012\012Options:\012  -p, --path:PATH         "
"  add path to search paths\012  -d, --define:SYMBOL(:VAL)\012         "
"                   define a conditional symbol\012                 "
"           (Optionally: Define the value for that symbol,\012      "
"                      see: \"compile time define pragmas\")\012  -u, "
"--undef:SYMBOL        undefine a conditional symbol\012  -f, --forc"
"eBuild:on|off   force rebuilding of all modules\012  --stackTrace:o"
"n|off       turn stack tracing on|off\012  --lineTrace:on|off      "
"  turn line tracing on|off\012  --threads:on|off          turn supp"
"ort for multi-threading on|off\012  -x, --checks:on|off       turn "
"all runtime checks on|off\012  -a, --assertions:on|off   turn asser"
"tions on|off\012  --opt:none|speed|size     optimize not at all or "
"for speed|size\012                            Note: use -d:release "
"for a release build!\012  --debugger:native         Use native debu"
"gger (gdb)\012  --app:console|gui|lib|staticlib\012                   "
"         generate a console app|GUI app|DLL|static library\012  -r,"
" --run                 run the compiled program with given argum"
"ents\012  --fullhelp                show all command line switches\012"
"  -h, --help                show this help\012  -v, --version      "
"       show detailed version information\012\012Note, single letter op"
"tions that take an argument require a colon. E.g. -p:PATH.\012Advan"
"ced commands:\012    compileToC, cc          compile project with C"
" code generator\012    compileToCpp, cpp       compile project to C"
"++ code\012    compileToOC, objc       compile project to Objective"
" C code\012    js                      compile project to Javascrip"
"t\012    e                       run a Nimscript file\012    rst2html "
"               convert a reStructuredText file to HTML\012         "
"                   use `--docCmd:skip` to skip compiling snippet"
"s\012    rst2tex                 convert a reStructuredText file to"
" TeX\012    jsondoc                 extract the documentation to a "
"json file\012    ctags                   create a tags file\012    bui"
"ldIndex              build an index for the whole documentation\012"
"    genDepend               generate a DOT file containing the\012 "
"                           module dependency graph\012    dump     "
"               dump all defined conditionals and search paths\012  "
"                          see also: --dump.format:json (useful w"
"ith: `| jq`)\012    check                   checks the project for "
"syntax and semantic\012\012Runtime checks (see -x):\012  --objChecks:on|o"
"ff        turn obj conversion checks on|off\012  --fieldChecks:on|o"
"ff      turn case variant field checks on|off\012  --rangeChecks:on"
"|off      turn range checks on|off\012  --boundChecks:on|off      t"
"urn bound checks on|off\012  --overflowChecks:on|off   turn int ove"
"r-/underflow checks on|off\012  --floatChecks:on|off      turn all "
"floating point (NaN/Inf) checks on|off\012  --nanChecks:on|off     "
"   turn NaN checks on|off\012  --infChecks:on|off        turn Inf c"
"hecks on|off\012  --refChecks:on|off        turn ref checks on|off "
"(only for --newruntime)\012\012Advanced options:\012  -o:FILE, --out:FILE"
"       set the output filename\012  --outdir:DIR              set t"
"he path where the output file will be written\012  --usenimcache   "
"          will use `outdir=$nimcache`, whichever it resolves\012   "
"                         to after all options have been processe"
"d\012  --stdout:on|off           output to stdout\012  --colors:on|off"
"           turn compiler messages coloring on|off\012  --listFullPa"
"ths:on|off    list full paths in messages\012  -w:on|off|list, --wa"
"rnings:on|off|list\012                            turn all warnings"
" on|off or list all available\012  --warning[X]:on|off       turn s"
"pecific warning X on|off\012  --hints:on|off|list       turn all hi"
"nts on|off or list all available\012  --hint[X]:on|off          tur"
"n specific hint X on|off\012  --warningAsError[X]:on|off\012          "
"                  turn specific warning X into an error on|off\012 "
" --styleCheck:off|hint|error\012                            produce"
" hints or errors for Nim identifiers that\012                      "
"      do not adhere to Nim\'s official style guide\012              "
"              https://nim-lang.org/docs/nep1.html\012  --showAllMis"
"matches:on|off\012                            show all mismatching "
"candidates in overloading\012                            resolution"
"\012  --lib:PATH                set the system library path\012  --imp"
"ort:PATH             add an automatically imported module\012  --in"
"clude:PATH            add an automatically included module\012  --n"
"imcache:PATH           set the path used for generated files\012   "
"                         see also https://nim-lang.org/docs/nimc"
".html#compiler-usage-generated-c-code-directory\012  -c, --compileO"
"nly:on|off  compile Nim files only; do not assemble or link\012  --"
"noLinking:on|off        compile Nim and generated files but do n"
"ot link\012  --noMain:on|off           do not generate a main proce"
"dure\012  --genScript:on|off        generate a compile script (in t"
"he \'nimcache\'\012                            subdirectory named \'co"
"mpile_$project$scriptext\'),\012                            implies "
"--compileOnly\012  --genDeps:on|off          generate a \'.deps\' fil"
"e containing the dependencies\012  --os:SYMBOL               set th"
"e target operating system (cross-compilation)\012  --cpu:SYMBOL    "
"          set the target processor (cross-compilation)\012  --debug"
"info:on|off        enables debug information\012  -t, --passC:OPTIO"
"N        pass an option to the C compiler\012  -l, --passL:OPTION  "
"      pass an option to the linker\012  --cc:SYMBOL               s"
"pecify the C compiler\012  --cincludes:DIR           modify the C c"
"ompiler header search path\012  --clibdir:DIR             modify th"
"e linker library search path\012  --clib:LIBNAME            link an"
" additional C library\012                            (you should om"
"it platform-specific extensions)\012  --project                 doc"
"ument the whole project (doc)\012  --docRoot:path            `nim d"
"oc --docRoot:/foo --project --outdir:docs /foo/sub/main.nim`\012   "
"                         generates: docs/sub/main.html\012         "
"                   if path == @pkg, will use nimble file enclosi"
"ng dir\012                            if path == @path, will use fi"
"rst matching dir in `--path`\012                            if path"
" == @default (the default and most useful), will use\012           "
"                 best match among @pkg,@path.\012                  "
"          if these are nonexistent, will use project path\012  -b, "
"--backend:c|cpp|js|objc sets backend to use with commands like `"
"nim doc` or `nim r`\012  --docCmd:cmd              if `cmd == skip`"
", skips runnableExamples\012                            else, runs "
"runnableExamples with given options, e.g.:\012                     "
"       `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:url    "
"    activate \'see source\' for doc command\012                      "
"      (see doc.item.seesrc in config/nimdoc.cfg)\012  --docInternal"
"             also generate documentation for non-exported symbol"
"s\012  --lineDir:on|off          generation of #line directive on|o"
"ff\012  --embedsrc:on|off         embeds the original source code a"
"s comments\012                            in the generated output\012 "
" --threadanalysis:on|off   turn thread analysis on|off\012  --tlsEm"
"ulation:on|off     turn thread local storage emulation on|off\012  "
"--taintMode:on|off        turn taint mode on|off\012  --implicitSta"
"tic:on|off   turn implicit compile time evaluation on|off\012  --tr"
"macros:on|off         turn term rewriting macros on|off\012  --mult"
"imethods:on|off     turn multi-methods on|off\012  --memTracker:on|"
"off       turn memory tracker on|off\012  --hotCodeReloading:on|off"
"\012                            turn support for hot code reloading"
" on|off\012  --excessiveStackTrace:on|off\012                         "
"   stack traces use full file paths\012  --stackTraceMsgs:on|off   "
"enable user defined stack frame msgs via `setFrameMsg`\012  --nilse"
"qs:on|off          allow \'nil\' for strings/seqs for\012            "
"                backwards compatibility\012  --seqsv2:on|off       "
"    use the new string/seq implementation based on\012             "
"               destructors\012  --skipCfg:on|off          do not re"
"ad the nim installation\'s configuration file\012  --skipUserCfg:on|"
"off      do not read the user\'s configuration file\012  --skipParen"
"tCfg:on|off    do not read the parent dirs\' configuration files\012"
"  --skipProjCfg:on|off      do not read the project\'s configurat"
"ion file\012  --gc:refc|arc|orc|markAndSweep|boehm|go|none|regions\012"
"                            select the GC to use; default is \'re"
"fc\'\012  --exceptions:setjmp|cpp|goto\012                            s"
"elect the exception handling implementation\012  --index:on|off    "
"        turn index file generation on|off\012  --putenv:key=value  "
"      set an environment variable\012  --NimblePath:PATH         ad"
"d a path for Nimble support\012  --noNimblePath            deactiva"
"te the Nimble path\012  --clearNimblePath         empty the list of"
" Nimble package search paths\012  --cppCompileToNamespace:namespace"
"\012                            use the provided namespace for the "
"generated C++ code,\012                            if no namespace "
"is provided \"Nim\" will be used\012  --expandMacro:MACRO       dump "
"every generated AST from MACRO\012  --expandArc:PROCNAME      show "
"how PROCNAME looks like after diverse optimizations\012            "
"                before the final backend phase (mostly ARC/ORC s"
"pecific)\012  --excludePath:PATH        exclude a path from the lis"
"t of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL so th"
"at dynlib:SYMBOL\012                            has no effect and c"
"an be statically linked instead;\012                            sym"
"bol matching is fuzzy so\012                            that --dynl"
"ibOverride:lua matches\012                            dynlib: \"libl"
"ua.so.3\"\012  --dynlibOverrideAll\012                            disab"
"les the effects of the dynlib pragma\012  --listCmd                "
" list the compilation commands; can be combined with\012           "
"                 `--hint:exec:on` and `--hint:link:on`\012  --asm  "
"                   produce assembler code\012  --parallelBuild:0|1|"
"...   perform a parallel build\012                            value"
" = number of processors (0 for auto-detect)\012  --incremental:on|o"
"ff      only recompile the changed modules (experimental!)\012  --v"
"erbosity:0|1|2|3       set Nim\'s verbosity level (1 is default)\012"
"  --errorMax:N              stop compilation after N errors; 0 m"
"eans unlimited\012  --maxLoopIterationsVM:N   set max iterations fo"
"r all VM loops\012  --experimental:implicitDeref|dotOperators|callO"
"perator|parallel|destructor|notnil|dynamicBindSym|forLoopMacros|"
"caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|strictF"
"uncs|views\012                            enable experimental langu"
"age feature\012  --legacy:allowSemcheckedAstModification|checkUnsig"
"nedConversions\012                            enable obsolete/legac"
"y language feature\012  --useVersion:1.0          emulate Nim versi"
"on X of the Nim compiler\012  --profiler:on|off         enable prof"
"iling; requires `import nimprof`, and\012                          "
"  works better with `--stackTrace:on`\012                          "
"  see also https://nim-lang.github.io/Nim/estp.html\012  --benchmar"
"kVM:on|off      enable benchmarking of VM code with cpuTime()\012  "
"--profileVM:on|off        enable compile time VM profiler\012  --si"
"nkInference:on|off    en-/disable sink parameter inference (defa"
"ult: on)\012  --panics:on|off           turn panics into process te"
"rminations (default: off)\012  --deepcopy:on|off         enable \'sy"
"stem.deepCopy\' for ``--gc:arc|orc``\012", 11875);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_262, "::\012\012    nim command [options] [projectfile] [arguments]\012\012Comman"
"d:\012    compile, c              compile project with default code"
" generator (C)\012    r                       compile to $nimcache/"
"projname, run with [arguments]\012                            using"
" backend specified by `--backend` (default: c)\012    doc          "
"           generate the documentation for inputfile for\012        "
"                    backend specified by `--backend` (default: c"
")\012\012Arguments:\012  arguments are passed to the program being run (i"
"f --run option is selected)\012\012Options:\012  -p, --path:PATH         "
"  add path to search paths\012  -d, --define:SYMBOL(:VAL)\012         "
"                   define a conditional symbol\012                 "
"           (Optionally: Define the value for that symbol,\012      "
"                      see: \"compile time define pragmas\")\012  -u, "
"--undef:SYMBOL        undefine a conditional symbol\012  -f, --forc"
"eBuild:on|off   force rebuilding of all modules\012  --stackTrace:o"
"n|off       turn stack tracing on|off\012  --lineTrace:on|off      "
"  turn line tracing on|off\012  --threads:on|off          turn supp"
"ort for multi-threading on|off\012  -x, --checks:on|off       turn "
"all runtime checks on|off\012  -a, --assertions:on|off   turn asser"
"tions on|off\012  --opt:none|speed|size     optimize not at all or "
"for speed|size\012                            Note: use -d:release "
"for a release build!\012  --debugger:native         Use native debu"
"gger (gdb)\012  --app:console|gui|lib|staticlib\012                   "
"         generate a console app|GUI app|DLL|static library\012  -r,"
" --run                 run the compiled program with given argum"
"ents\012  --fullhelp                show all command line switches\012"
"  -h, --help                show this help\012  -v, --version      "
"       show detailed version information\012\012Note, single letter op"
"tions that take an argument require a colon. E.g. -p:PATH.\012", 1850);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_263, "the compiler was not built with incremental compilation feature"
"s; bootstrap with -d:nimIncremental to enable", 108);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_264 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 743),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_265, "writeonly", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_266, "readonly", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_267, "invalid option for --incremental: ", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_268 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 752),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_269, "FILE,LINE,COLUMN expected", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_270 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 373),
((NI) 27)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_271, "$1 is not a valid number", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_272 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 376),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_273 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 378),
((NI) 14)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_274, "DIRTY_BUFFER,ORIGINAL_FILE,LINE,COLUMN expected", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_275 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 357),
((NI) 27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_276 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 361),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_277 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 363),
((NI) 14)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_279, "unknown experimental feature", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_280 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 814),
((NI) 18)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_282, "unknown obsolete feature", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_283 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 819),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_284, "noCppExceptions", 15);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_285, "cpp", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_286, "setjmp", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_287, "quirky", 6);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_288, "goto", 4);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_289, "\'goto\', \'setjump\', \'cpp\' or \'quirky\' expected, but \'$1\' found", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_290 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 830),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_291, "commands.nim(838, 15) `conf != nil` ", 36);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_292, "nimOwnedEnabled", 15);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_293, "error", 5);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_294, "\'off\', \'hint\' or \'error\' expected, but \'$1\' found", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_295 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 857),
((NI) 20)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_296, "Nim", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_297, "cppCompileToNamespace", 21);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_298, "T", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_299, "1.0", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_300, "1.2", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_301, "NimMajor", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_302, "1", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_303, "NimMinor", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_304, "0", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_305, "NimPatch", 8);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_306, "100", 3);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_307, "nimOldRelativePathBehavior", 26);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_308, "nimDoesntTrackDefects", 21);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_309, "2", 1);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_310, "unknown Nim version; currently supported values are: {1.0}", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_311 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 896),
((NI) 16)}
;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_312, "nimPanics", 9);
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_313, "stdinfile", 9);
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q gCmdLineInfo__yhfh3fjBy4h9bf6keLoh9aXQ;
STRING_LITERAL(TM__brsa2DgNdQAKzy1F0pSZlA_314, "generational", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_315 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 252),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_316 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 258),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_317 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 268),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_318 = {((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_162),
((NI) 277),
((NI) 20)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw eqTypeFlags__9aJCM4BDGbCJ8tj1Vz9bDB7g;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processArgument__MHrYBQtd7a5cMBE9clMgEKg)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p, NI* argsCount, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*argsCount) == ((NI) 0))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T10_;
			T7_ = (NIM_BOOL)0;
			T7_ = nsuEndsWith((*p).key, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_2));
			if (!T7_) goto LA8_;
			T10_ = (NimStringDesc*)0;
			T10_ = (*config).command; (*config).command = copyStringRC1(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_3));
			if (T10_) nimGCunrefNoCycle(T10_);
			(*config).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 2)) & 63);
			asgnRef((void**) (&(*config).projectName), nosunixToNativePath((*p).key, ((NimStringDesc*) NIM_NIL)));
			asgnRef((void**) (&(*config).arguments), npocmdLineRest(p));
			result = NIM_TRUE;
		}
		goto LA5_;
		LA8_: ;
		{
			NimStringDesc* T14_;
			if (!!((pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 1)))) goto LA12_;
			T14_ = (NimStringDesc*)0;
			T14_ = (*config).command; (*config).command = copyStringRC1((*p).key);
			if (T14_) nimGCunrefNoCycle(T14_);
		}
		goto LA5_;
		LA12_: ;
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI T20_;
			NimStringDesc* T21_;
			if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA18_;
			asgnRef((void**) (&(*config).commandArgs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*config).commandArgs), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T20_ = (*config).commandArgs->Sup.len++;
			T21_ = (NimStringDesc*)0;
			T21_ = (*config).commandArgs->data[T20_]; (*config).commandArgs->data[T20_] = copyStringRC1((*p).key);
			if (T21_) nimGCunrefNoCycle(T21_);
		}
		LA18_: ;
		{
			if (!((*argsCount) == ((NI) 1))) goto LA24_;
			{
				if (!(((*config).projectName ? (*config).projectName->Sup.len : 0) == ((NI) 0))) goto LA28_;
				asgnRef((void**) (&(*config).projectName), nosunixToNativePath((*p).key, ((NimStringDesc*) NIM_NIL)));
			}
			LA28_: ;
			asgnRef((void**) (&(*config).arguments), npocmdLineRest(p));
			result = NIM_TRUE;
		}
		LA24_: ;
	}
	LA1_: ;
	(*argsCount) += ((NI) 1);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addPrefix__uQmxTBj1ckq1MOOT9c5uRLA)(NimStringDesc* switch_0) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		NimStringDesc* T5_;
		if (!((switch_0 ? switch_0->Sup.len : 0) <= ((NI) 1))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = rawNewString((switch_0 ? switch_0->Sup.len : 0) + 1);
appendString(T5_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_159));
appendString(T5_, switch_0);
		result = T5_;
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T7_;
		T7_ = (NimStringDesc*)0;
		T7_ = rawNewString((switch_0 ? switch_0->Sup.len : 0) + 2);
appendString(T7_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_160));
appendString(T7_, switch_0);
		result = T7_;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectArg__9cWjALn36XqpUyv43volzuw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((arg ? arg->Sup.len : 0) == 0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = addPrefix__uQmxTBj1ckq1MOOT9c5uRLA(switch_0);
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_158), T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_161, NIM_FALSE);
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__31wM5Ui9c8jnrQ5QD4oPxOQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processCfgPath__1o4k2J9bsj2wWBwUjUj9atgQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* volatile result;
	NimStringDesc* path_2;
	NimStringDesc* basedir;
	NimStringDesc* T8_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T9_;
	NimStringDesc* p;
	TSafePoint TM__brsa2DgNdQAKzy1F0pSZlA_167;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (path ? path->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(path->data[((NI) 0)]) == (NU8)(34));
		LA4_: ;
		if (!T3_) goto LA5_;
		path_2 = nsuUnescape(path, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_166), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_166));
	}
	goto LA1_;
	LA5_: ;
	{
		path_2 = path;
	}
	LA1_: ;
	T8_ = (NimStringDesc*)0;
	T8_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, info.fileIndex);
	nimZeroMem((void*)(&T9_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(T8_, (&T9_));
	basedir = T9_.Field0;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = nosisAbsolute(path_2);
		if (T12_) goto LA13_;
		T12_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(path_2->data, (path_2 ? path_2->Sup.len : 0), 36);
		LA13_: ;
		if (!T12_) goto LA14_;
		p = path_2;
	}
	goto LA10_;
	LA14_: ;
	{
		p = slash___gEyhbzZ1UcxyenWRLJRXNQ(basedir, path_2);
	}
	LA10_: ;
	pushSafePoint(&TM__brsa2DgNdQAKzy1F0pSZlA_167);
	TM__brsa2DgNdQAKzy1F0pSZlA_167.status = _setjmp(TM__brsa2DgNdQAKzy1F0pSZlA_167.context);
	if (TM__brsa2DgNdQAKzy1F0pSZlA_167.status == 0) {
	result = pathSubs__paMedXIWX6si307wASTsQQ(conf, p, basedir);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
			NimStringDesc* T19_;
			TM__brsa2DgNdQAKzy1F0pSZlA_167.status = 0;
			T19_ = (NimStringDesc*)0;
			T19_ = rawNewString((p ? p->Sup.len : 0) + 14);
appendString(T19_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_168));
appendString(T19_, p);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_169, NIM_FALSE);
			result = copyString(p);
			popCurrentException();
		}
	}
	if (TM__brsa2DgNdQAKzy1F0pSZlA_167.status != 0) reraiseException();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, processPath__yr9b8Qf5CxXVgMiRouka8Dg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL notRelativeToProj) {
	NimStringDesc* volatile result;
	NimStringDesc* p;
	TSafePoint TM__brsa2DgNdQAKzy1F0pSZlA_170;
	NimStringDesc* T12_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T13_;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nosisAbsolute(path);
		if (T3_) goto LA4_;
		T3_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(path->data, (path ? path->Sup.len : 0), 36);
		LA4_: ;
		if (!T3_) goto LA5_;
		p = path;
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* T10_;
		if (!notRelativeToProj) goto LA8_;
		T10_ = (NimStringDesc*)0;
		T10_ = nosgetCurrentDir();
		p = slash___gEyhbzZ1UcxyenWRLJRXNQ(T10_, path);
	}
	goto LA1_;
	LA8_: ;
	{
		p = slash___gEyhbzZ1UcxyenWRLJRXNQ((*conf).projectPath, path);
	}
	LA1_: ;
	pushSafePoint(&TM__brsa2DgNdQAKzy1F0pSZlA_170);
	TM__brsa2DgNdQAKzy1F0pSZlA_170.status = _setjmp(TM__brsa2DgNdQAKzy1F0pSZlA_170.context);
	if (TM__brsa2DgNdQAKzy1F0pSZlA_170.status == 0) {
	T12_ = (NimStringDesc*)0;
	T12_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, info.fileIndex);
	nimZeroMem((void*)(&T13_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	nossplitFile(T12_, (&T13_));
	result = pathSubs__paMedXIWX6si307wASTsQQ(conf, p, T13_.Field0);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
			NimStringDesc* T16_;
			TM__brsa2DgNdQAKzy1F0pSZlA_170.status = 0;
			T16_ = (NimStringDesc*)0;
			T16_ = rawNewString((p ? p->Sup.len : 0) + 14);
appendString(T16_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_168));
appendString(T16_, p);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_171, NIM_FALSE);
			result = copyString(p);
			popCurrentException();
		}
	}
	if (TM__brsa2DgNdQAKzy1F0pSZlA_170.status != 0) reraiseException();
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__9cWjALn36XqpUyv43volzuw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!!(((arg ? arg->Sup.len : 0) == 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = addPrefix__uQmxTBj1ckq1MOOT9c5uRLA(switch_0);
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_174), T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_175, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf).globalOptions = ((*conf).globalOptions | op);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf).globalOptions = ((*conf).globalOptions & ~ op);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringDesc* T9_;
		T9_ = (NimStringDesc*)0;
		T9_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_178), arg);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_179, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, NimStringDesc* switch_0, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		NimStringDesc* T5_;
		if (!eqStrings(switch_0, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_184))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_185), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_159));
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_186, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T7_ = (NimStringDesc*)0;
		T7_ = addPrefix__uQmxTBj1ckq1MOOT9c5uRLA(switch_0);
		T8_ = (NimStringDesc*)0;
		T8_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_185), T7_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_187, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__iY5h7sfVXAoUjuXGnmW9bAw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc** cmd, NimStringDesc** arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI i;
	unsureAsgnRef((void**) (&(*cmd)), ((NimStringDesc*) NIM_NIL));
	i = ((NI) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i < (switch_0 ? switch_0->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(switch_0->data[i]) == (NU8)(45));
		LA4_: ;
		if (!T3_) goto LA5_;
		i += ((NI) 1);
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (i < (switch_0 ? switch_0->Sup.len : 0));
		if (!(T9_)) goto LA10_;
		T9_ = ((NU8)(switch_0->data[i]) == (NU8)(45));
		LA10_: ;
		if (!T9_) goto LA11_;
		i += ((NI) 1);
	}
	LA11_: ;
	{
		while (1) {
			if (!(i < (switch_0 ? switch_0->Sup.len : 0))) goto LA14;
			switch (((NU8)(switch_0->data[i]))) {
			case 97 ... 122:
			case 65 ... 90:
			case 48 ... 57:
			case 95:
			case 46:
			{
				unsureAsgnRef((void**) (&(*cmd)), addChar((*cmd), switch_0->data[i]));
			}
			break;
			default:
			{
				goto LA13;
			}
			break;
			}
			i += ((NI) 1);
		} LA14: ;
	} LA13: ;
	{
		if (!((switch_0 ? switch_0->Sup.len : 0) <= i)) goto LA19_;
		unsureAsgnRef((void**) (&(*arg)), ((NimStringDesc*) NIM_NIL));
	}
	goto LA17_;
	LA19_: ;
	{
		if (!(((NU8)(switch_0->data[i])) == ((NU8)(58)) || ((NU8)(switch_0->data[i])) == ((NU8)(61)))) goto LA22_;
		unsureAsgnRef((void**) (&(*arg)), substr__iGg0RIKceRvsmvq8FUHOEw(switch_0, (NI)(i + ((NI) 1))));
	}
	goto LA17_;
	LA22_: ;
	{
		if (!((NU8)(switch_0->data[i]) == (NU8)(91))) goto LA25_;
		unsureAsgnRef((void**) (&(*arg)), substr__iGg0RIKceRvsmvq8FUHOEw(switch_0, i));
	}
	goto LA17_;
	LA25_: ;
	{
		invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, pass, switch_0, info);
	}
	LA17_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__7owBQPsmnvBN9cWaUPu9bYcQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename) {
	NimStringDesc* found;
	found = findFile__Jsd6LfkMRIXL9b0vzcHVYOA(conf, filename, NIM_FALSE);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils(found);
		if (!T3_) goto LA4_;
		found = copyString(filename);
	}
	LA4_: ;
	addExternalFileToCompile__VWI2GZGxWbHzjYJHzOr3dA(conf, found);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__jbuLFmyuMzkCVahVfmlYeA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA3_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_218))) goto LA4_;
	goto LA5_;
	LA2_: ;
	{
		(*conf).options = ((*conf).options | op);
	}
	goto LA6_;
	LA3_: ;
	{
		(*conf).options = ((*conf).options & ~ op);
	}
	goto LA6_;
	LA4_: ;
	{
		result = NIM_TRUE;
	}
	goto LA6_;
	LA5_: ;
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_219), arg);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_220, NIM_FALSE);
	}
	LA6_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b) {
	tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__CWgb1wQSxTCKtdHVU5pCYQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ)(NimStringDesc* arg, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw state, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* orig, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* id;
	NI i;
	tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w n;
	NIM_BOOL isBracket;
	NimStringDesc* val;
	NimStringDesc* T51_;
	id = ((NimStringDesc*) NIM_NIL);
	i = ((NI) 0);
	n = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52);
	isBracket = NIM_FALSE;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i < (arg ? arg->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(arg->data[i]) == (NU8)(91));
		LA4_: ;
		if (!T3_) goto LA5_;
		isBracket = NIM_TRUE;
		i += ((NI) 1);
	}
	LA5_: ;
	{
		while (1) {
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = (i < (arg ? arg->Sup.len : 0));
			if (!(T9_)) goto LA10_;
			T9_ = !((((NU8)(arg->data[i])) == ((NU8)(58)) || ((NU8)(arg->data[i])) == ((NU8)(61)) || ((NU8)(arg->data[i])) == ((NU8)(93))));
			LA10_: ;
			if (!T9_) goto LA8;
			id = addChar(id, arg->data[i]);
			i += ((NI) 1);
		} LA8: ;
	}
	{
		if (!isBracket) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = (i < (arg ? arg->Sup.len : 0));
			if (!(T17_)) goto LA18_;
			T17_ = ((NU8)(arg->data[i]) == (NU8)(93));
			LA18_: ;
			if (!T17_) goto LA19_;
			i += ((NI) 1);
		}
		goto LA15_;
		LA19_: ;
		{
			invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, pass, orig, info);
		}
		LA15_: ;
	}
	LA13_: ;
	{
		if (!(i == (arg ? arg->Sup.len : 0))) goto LA24_;
	}
	goto LA22_;
	LA24_: ;
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = (i < (arg ? arg->Sup.len : 0));
		if (!(T27_)) goto LA28_;
		T27_ = (((NU8)(arg->data[i])) == ((NU8)(58)) || ((NU8)(arg->data[i])) == ((NU8)(61)));
		LA28_: ;
		if (!T27_) goto LA29_;
		i += ((NI) 1);
	}
	goto LA22_;
	LA29_: ;
	{
		invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, pass, orig, info);
	}
	LA22_: ;
	{
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w x;
		tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T36_;
		if (!(state == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 121))) goto LA34_;
		T36_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 83));
		x = findStr__ksT2oQUquwtB1u6JxjTCFw(T36_, id, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0));
		{
			if (!!((x == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0)))) goto LA39_;
			n = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (x))));
		}
		goto LA37_;
		LA39_: ;
		{
			NimStringDesc* T42_;
			T42_ = (NimStringDesc*)0;
			T42_ = rawNewString((id ? id->Sup.len : 0) + 14);
appendString(T42_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_221));
appendString(T42_, id);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T42_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_222, NIM_FALSE);
		}
		LA37_: ;
	}
	goto LA32_;
	LA34_: ;
	{
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w x_2;
		tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T44_;
		T44_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51));
		x_2 = findStr__ksT2oQUquwtB1u6JxjTCFw(T44_, id, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0));
		{
			if (!!((x_2 == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0)))) goto LA47_;
			n = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) (((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (x_2))));
		}
		goto LA45_;
		LA47_: ;
		{
			NimStringDesc* T50_;
			T50_ = (NimStringDesc*)0;
			T50_ = rawNewString((id ? id->Sup.len : 0) + 17);
appendString(T50_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_223));
appendString(T50_, id);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T50_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_224, NIM_FALSE);
		}
		LA45_: ;
	}
	LA32_: ;
	T51_ = (NimStringDesc*)0;
	T51_ = substr__iGg0RIKceRvsmvq8FUHOEw(arg, i);
	val = nsuNormalize(T51_);
	{
		if (!((val ? val->Sup.len : 0) == 0)) goto LA54_;
		val = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176));
	}
	LA54_: ;
	{
		NIM_BOOL T58_;
		NimStringDesc* T61_;
		T58_ = (NIM_BOOL)0;
		T58_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem(TM__brsa2DgNdQAKzy1F0pSZlA_225, 2, val);
		if (!!(T58_)) goto LA59_;
		T61_ = (NimStringDesc*)0;
		T61_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_178), arg);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T61_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_226, NIM_FALSE);
	}
	goto LA56_;
	LA59_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = !((((*conf).cmdlineNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))&7U)))!=0));
		if (T63_) goto LA64_;
		T63_ = (pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0));
		LA64_: ;
		if (!T63_) goto LA65_;
		{
			if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA69_;
			(*conf).cmdlineNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] |=(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
		}
		LA69_: ;
		(*conf).modifiedyNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] |=(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
		if (eqStrings(val, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA71_;
		if (eqStrings(val, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA72_;
		goto LA73_;
		LA71_: ;
		{
			{
				if (!(state == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 122))) goto LA78_;
				(*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] |=(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
			}
			goto LA76_;
			LA78_: ;
			{
				(*conf).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] |=(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
				(*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] |=(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
			}
			LA76_: ;
		}
		goto LA74_;
		LA72_: ;
		{
			{
				if (!(state == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 122))) goto LA84_;
				(*conf).warningAsErrors[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] &= ~(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
			}
			goto LA82_;
			LA84_: ;
			{
				(*conf).notes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] &= ~(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
				(*conf).mainPackageNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] &= ~(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
				(*conf).foreignPackageNotes[(NU)((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12))>>3] &= ~(1U<<((((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (n))- 12)&7U));
			}
			LA82_: ;
		}
		goto LA74_;
		LA73_: ;
		{
		}
		LA74_: ;
	}
	goto LA56_;
	LA65_: ;
	LA56_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(arg);
	if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf).options = ((*conf).options | op);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf).options = ((*conf).options & ~ op);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringDesc* T9_;
		T9_ = (NimStringDesc*)0;
		T9_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_178), arg);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_227, NIM_FALSE);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__WMrF6tFDO8y2YcugTwQDgA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass) {
	{
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T5_;
		NimStringDesc* T6_;
		if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T5_[0] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_256));
		T5_[1] = copyString(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*conf).target.hostOS)- 1].Field0);
		T5_[2] = copyString(CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.hostCPU)- 1].Field0);
		T5_[3] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_257));
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_255), T5_, 4);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T6_, 1);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_258), 1);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_259), 1);
		msgQuit__PlZXt6qHCDDk29c9ac4IuLGA(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__WMrF6tFDO8y2YcugTwQDgA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass) {
	{
		NimStringDesc* T5_;
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T6_;
		NimStringDesc* T7_;
		if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		nimZeroMem((void*)T6_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T6_[0] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_256));
		T6_[1] = copyString(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*conf).target.hostOS)- 1].Field0);
		T6_[2] = copyString(CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.hostCPU)- 1].Field0);
		T6_[3] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_257));
		T7_ = (NimStringDesc*)0;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_255), T6_, 4);
		T5_ = rawNewString((T7_ ? T7_->Sup.len : 0) + 10025);
appendString(T5_, T7_);
appendString(T5_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_260));
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T5_, 1);
		msgQuit__PlZXt6qHCDDk29c9ac4IuLGA(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__WMrF6tFDO8y2YcugTwQDgA_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass) {
	{
		NimStringDesc* T5_;
		tyArray__sMpvt1sOxOJ3LFGulnbeMQ T6_;
		NimStringDesc* T7_;
		if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		nimZeroMem((void*)T6_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
		T6_[0] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_256));
		T6_[1] = copyString(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*conf).target.hostOS)- 1].Field0);
		T6_[2] = copyString(CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.hostCPU)- 1].Field0);
		T6_[3] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_257));
		T7_ = (NimStringDesc*)0;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_255), T6_, 4);
		T5_ = rawNewString((T7_ ? T7_->Sup.len : 0) + 11875);
appendString(T5_, T7_);
appendString(T5_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_261));
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T5_, 1);
		msgQuit__PlZXt6qHCDDk29c9ac4IuLGA(((NI8) 0));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCommandLineDesc__ssYZeuyrx9c44xJxPRKx1jQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T2_;
	NimStringDesc* T3_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	nimZeroMem((void*)T2_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_256));
	T2_[1] = copyString(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*conf).target.hostOS)- 1].Field0);
	T2_[2] = copyString(CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.hostCPU)- 1].Field0);
	T2_[3] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_257));
	T3_ = (NimStringDesc*)0;
	T3_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_255), T2_, 4);
	T1_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 1850);
appendString(T1_, T3_);
appendString(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_262));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__WMrF6tFDO8y2YcugTwQDgA_4)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass) {
	{
		NimStringDesc* T5_;
		if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = getCommandLineDesc__ssYZeuyrx9c44xJxPRKx1jQ(conf);
		msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T5_, 1);
		msgQuit__PlZXt6qHCDDk29c9ac4IuLGA(((NI8) 0));
	}
	LA3_: ;
}
static N_INLINE(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename, NI line, NI col) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
	NI32 T1_;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA(conf, filename);
	result = newLineInfo__NPagzbOMpGo9aqJmfnDrITg(T1_, line, col);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, track__HHQbKxjjZZnOezuSelLvtA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	NI line;
	NI column;
	a = nsuSplitChar(arg, 44, ((NI) -1));
	{
		NI T3_;
		T3_ = (a ? a->Sup.len : 0);
		if (!!((T3_ == ((NI) 3)))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_269), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_270, NIM_FALSE);
	}
	LA4_: ;
	line = (NI)0;
	column = (NI)0;
	{
		NI T8_;
		NimStringDesc* T11_;
		T8_ = (NI)0;
		T8_ = npuParseInt(a->data[((NI) 1)], (&line), ((NI) 0));
		if (!(T8_ <= ((NI) 0))) goto LA9_;
		T11_ = (NimStringDesc*)0;
		T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_271), a->data[((NI) 1)]);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_272, NIM_FALSE);
	}
	LA9_: ;
	{
		NI T14_;
		NimStringDesc* T17_;
		T14_ = (NI)0;
		T14_ = npuParseInt(a->data[((NI) 2)], (&column), ((NI) 0));
		if (!(T14_ <= ((NI) 0))) goto LA15_;
		T17_ = (NimStringDesc*)0;
		T17_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_271), a->data[((NI) 2)]);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T17_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_273, NIM_FALSE);
	}
	LA15_: ;
	(*conf).m.trackPos = newLineInfo__q6yS31W9c9bTxOv5YvOB1n7gmsgs(conf, a->data[((NI) 0)], line, column);
}
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__HHQbKxjjZZnOezuSelLvtA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a;
	NI line;
	NI column;
	NI32 dirtyOriginalIdx;
	a = nsuSplitChar(arg, 44, ((NI) -1));
	{
		NI T3_;
		T3_ = (a ? a->Sup.len : 0);
		if (!!((T3_ == ((NI) 4)))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_274), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_275, NIM_FALSE);
	}
	LA4_: ;
	line = (NI)0;
	column = (NI)0;
	{
		NI T8_;
		NimStringDesc* T11_;
		T8_ = (NI)0;
		T8_ = npuParseInt(a->data[((NI) 2)], (&line), ((NI) 0));
		if (!(T8_ <= ((NI) 0))) goto LA9_;
		T11_ = (NimStringDesc*)0;
		T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_271), a->data[((NI) 1)]);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_276, NIM_FALSE);
	}
	LA9_: ;
	{
		NI T14_;
		NimStringDesc* T17_;
		T14_ = (NI)0;
		T14_ = npuParseInt(a->data[((NI) 3)], (&column), ((NI) 0));
		if (!(T14_ <= ((NI) 0))) goto LA15_;
		T17_ = (NimStringDesc*)0;
		T17_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_271), a->data[((NI) 2)]);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T17_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_277, NIM_FALSE);
	}
	LA15_: ;
	dirtyOriginalIdx = fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA(conf, a->data[((NI) 1)]);
	{
		if (!(((NI32) 0) <= dirtyOriginalIdx)) goto LA20_;
		setDirtyFile__fHp3umDqKLlqmAGYAQvEUA(conf, dirtyOriginalIdx, a->data[((NI) 0)]);
	}
	LA20_: ;
	(*conf).m.trackPos = newLineInfo__NPagzbOMpGo9aqJmfnDrITg(dirtyOriginalIdx, line, column);
}
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__9cWjALn36XqpUyv43volzuw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA3_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		inclDynlibOverride__mKOqGVEJPH4IP05mQ0BZkA(conf, arg);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__t8RT1Qk4s0rBX8YbKQ0DBQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = (*conf).projectName; (*conf).projectName = copyStringRC1(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_313));
	if (T1_) nimGCunrefNoCycle(T1_);
	T2_ = (NimStringDesc*)0;
	T2_ = (*conf).projectFull; (*conf).projectFull = copyStringRC1((*conf).projectName);
	if (T2_) nimGCunrefNoCycle(T2_);
	asgnRef((void**) (&(*conf).projectPath), nosgetCurrentDir());
	(*conf).projectIsStdin = NIM_TRUE;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils((*conf).outDir);
		if (!T5_) goto LA6_;
		asgnRef((void**) (&(*conf).outDir), getNimcacheDir__oltK69akg0xLqkR2ITKbomg_2(conf));
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* key;
	NimStringDesc* val;
	NimStringDesc* T1_;
{	key = (NimStringDesc*)0;
	val = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(switch_0);
	switch (hashString(T1_) & 255) {
	case 0: 
if (eqStrings(T1_, ((NimStringDesc*) NIM_NIL))) goto LA136_;
break;
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_9))) goto LA4_;
break;
	case 3: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_115))) goto LA94_;
break;
	case 6: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_49))) goto LA36_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_89))) goto LA71_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_112))) goto LA91_;
break;
	case 11: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_53))) goto LA40_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_152))) goto LA130_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_18))) goto LA12_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_35))) goto LA24_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_73))) goto LA59_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_41))) goto LA29_;
break;
	case 17: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_28))) goto LA18_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_83))) goto LA67_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_26))) goto LA17_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_54))) goto LA41_;
break;
	case 24: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_37))) goto LA26_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_51))) goto LA38_;
break;
	case 27: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_44))) goto LA31_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_145))) goto LA123_;
break;
	case 28: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_135))) goto LA113_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_32))) goto LA22_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_29))) goto LA19_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_42))) goto LA29_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_75))) goto LA60_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_50))) goto LA37_;
break;
	case 40: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_109))) goto LA89_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_155))) goto LA133_;
break;
	case 43: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_127))) goto LA105_;
break;
	case 46: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_103))) goto LA84_;
break;
	case 47: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_132))) goto LA110_;
break;
	case 50: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_134))) goto LA112_;
break;
	case 51: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_106))) goto LA87_;
break;
	case 52: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_15))) goto LA9_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_97))) goto LA79_;
break;
	case 54: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_133))) goto LA111_;
break;
	case 55: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_96))) goto LA78_;
break;
	case 57: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_92))) goto LA74_;
break;
	case 60: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_43))) goto LA30_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_84))) goto LA68_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_142))) goto LA120_;
break;
	case 61: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_141))) goto LA119_;
break;
	case 65: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_153))) goto LA131_;
break;
	case 66: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_74))) goto LA59_;
break;
	case 68: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_56))) goto LA43_;
break;
	case 71: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_98))) goto LA80_;
break;
	case 73: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_27))) goto LA17_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_47))) goto LA34_;
break;
	case 76: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_7))) goto LA3_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_78))) goto LA63_;
break;
	case 77: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_71))) goto LA57_;
break;
	case 83: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_52))) goto LA39_;
break;
	case 86: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_150))) goto LA128_;
break;
	case 87: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_57))) goto LA44_;
break;
	case 89: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_34))) goto LA23_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_114))) goto LA93_;
break;
	case 90: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_10))) goto LA5_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_45))) goto LA32_;
break;
	case 93: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_36))) goto LA25_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_122))) goto LA100_;
break;
	case 94: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_21))) goto LA14_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_55))) goto LA42_;
break;
	case 97: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_139))) goto LA117_;
break;
	case 99: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_39))) goto LA27_;
break;
	case 100: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_64))) goto LA50_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_77))) goto LA62_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_94))) goto LA76_;
break;
	case 103: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_120))) goto LA98_;
break;
	case 104: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_48))) goto LA35_;
break;
	case 105: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_100))) goto LA82_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_154))) goto LA132_;
break;
	case 108: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_129))) goto LA107_;
break;
	case 109: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_149))) goto LA127_;
break;
	case 110: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_151))) goto LA129_;
break;
	case 112: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_104))) goto LA85_;
break;
	case 113: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_65))) goto LA51_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_102))) goto LA83_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_156))) goto LA134_;
break;
	case 115: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_90))) goto LA72_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_124))) goto LA102_;
break;
	case 117: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_23))) goto LA15_;
break;
	case 119: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_93))) goto LA75_;
break;
	case 120: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_148))) goto LA126_;
break;
	case 122: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_70))) goto LA56_;
break;
	case 127: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_14))) goto LA8_;
break;
	case 129: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_58))) goto LA45_;
break;
	case 132: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_19))) goto LA13_;
break;
	case 133: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_25))) goto LA16_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_86))) goto LA69_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_130))) goto LA108_;
break;
	case 139: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_137))) goto LA115_;
break;
	case 141: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_143))) goto LA121_;
break;
	case 142: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_16))) goto LA10_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_131))) goto LA109_;
break;
	case 143: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_113))) goto LA92_;
break;
	case 144: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_13))) goto LA8_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_157))) goto LA135_;
break;
	case 146: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_22))) goto LA15_;
break;
	case 148: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_140))) goto LA118_;
break;
	case 150: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_72))) goto LA58_;
break;
	case 155: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_20))) goto LA13_;
break;
	case 156: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_12))) goto LA7_;
break;
	case 158: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_33))) goto LA23_;
break;
	case 165: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_68))) goto LA54_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_88))) goto LA70_;
break;
	case 167: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_108))) goto LA88_;
break;
	case 169: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_67))) goto LA53_;
break;
	case 170: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_118))) goto LA97_;
break;
	case 172: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_138))) goto LA116_;
break;
	case 173: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_40))) goto LA28_;
break;
	case 174: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_119))) goto LA97_;
break;
	case 178: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_95))) goto LA77_;
break;
	case 179: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_46))) goto LA33_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_63))) goto LA49_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_126))) goto LA104_;
break;
	case 181: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_4))) goto LA2_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_60))) goto LA46_;
break;
	case 182: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_11))) goto LA6_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_24))) goto LA16_;
break;
	case 183: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_116))) goto LA95_;
break;
	case 184: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_6))) goto LA3_;
break;
	case 190: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_79))) goto LA64_;
break;
	case 197: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_82))) goto LA66_;
break;
	case 198: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_146))) goto LA124_;
break;
	case 200: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_62))) goto LA48_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_80))) goto LA65_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_81))) goto LA65_;
break;
	case 202: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_123))) goto LA101_;
break;
	case 206: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_66))) goto LA52_;
break;
	case 207: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_85))) goto LA68_;
break;
	case 208: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_147))) goto LA125_;
break;
	case 210: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_99))) goto LA81_;
break;
	case 213: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_107))) goto LA87_;
break;
	case 216: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_144))) goto LA122_;
break;
	case 218: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_61))) goto LA47_;
break;
	case 219: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_17))) goto LA11_;
break;
	case 223: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_69))) goto LA55_;
break;
	case 226: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_101))) goto LA82_;
break;
	case 228: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_105))) goto LA86_;
break;
	case 229: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_59))) goto LA45_;
break;
	case 234: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_111))) goto LA90_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_117))) goto LA96_;
break;
	case 236: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_110))) goto LA90_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_121))) goto LA99_;
break;
	case 237: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_31))) goto LA21_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_136))) goto LA114_;
break;
	case 238: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_38))) goto LA26_;
break;
	case 239: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_128))) goto LA106_;
break;
	case 240: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_30))) goto LA20_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_125))) goto LA103_;
break;
	case 246: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_76))) goto LA61_;
break;
	case 248: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_87))) goto LA69_;
break;
	case 249: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_5))) goto LA2_;
break;
	case 254: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_8))) goto LA4_;
break;
	case 255: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_91))) goto LA73_;
break;
	}
	goto LA137_;
	LA2_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* path;
			NimStringDesc* pl;
			path = (NimStringDesc*)0;
			pl = nsuToLowerAsciiStr(arg);
			{
				NIM_BOOL T143_;
				T143_ = (NIM_BOOL)0;
				T143_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(pl, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_163));
				if (T143_) goto LA144_;
				T143_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(pl, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_164));
				LA144_: ;
				if (!T143_) goto LA145_;
				{
					NI i;
					NI colontmp_;
					NI T148_;
					NI res;
					i = (NI)0;
					colontmp_ = (NI)0;
					T148_ = ((*conf).nimblePaths ? (*conf).nimblePaths->Sup.len : 0);
					colontmp_ = (NI)(T148_ - ((NI) 1));
					res = colontmp_;
					{
						while (1) {
							NimStringDesc* nimblePath;
							tyArray__sMpvt1sOxOJ3LFGulnbeMQ T151_;
							NimStringDesc* T152_;
							if (!(((NI) 0) <= res)) goto LA150;
							i = res;
							nimblePath = removeTrailingDirSep__nbuWUOJELn5idXbWiYOmOA((*conf).nimblePaths->data[i]);
							nimZeroMem((void*)T151_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
							T151_[0] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_6));
							T151_[1] = copyString(nimblePath);
							T151_[2] = copyString(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_165));
							T151_[3] = copyString(nimblePath);
							path = nsuFormatOpenArray(arg, T151_, 4);
							T152_ = (NimStringDesc*)0;
							{
								if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2))) goto LA155_;
								T152_ = processCfgPath__1o4k2J9bsj2wWBwUjUj9atgQ(conf, path, info);
							}
							goto LA153_;
							LA155_: ;
							{
								T152_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, path, info, NIM_FALSE);
							}
							LA153_: ;
							addPath__yQoptEnH9cvj9cZKgjcndthg(conf, T152_, info);
							res -= ((NI) 1);
						} LA150: ;
					}
				}
			}
			goto LA141_;
			LA145_: ;
			{
				NimStringDesc* T159_;
				path = arg;
				T159_ = (NimStringDesc*)0;
				{
					if (!(pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2))) goto LA162_;
					T159_ = processCfgPath__1o4k2J9bsj2wWBwUjUj9atgQ(conf, path, info);
				}
				goto LA160_;
				LA162_: ;
				{
					T159_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, path, info, NIM_FALSE);
				}
				LA160_: ;
				addPath__yQoptEnH9cvj9cZKgjcndthg(conf, T159_, info);
			}
			LA141_: ;
		}
	}
	goto LA138_;
	LA3_: ;
	{
		{
			NIM_BOOL T168_;
			NimStringDesc* path_2;
			NimStringDesc* nimbleDir;
			T168_ = (NIM_BOOL)0;
			T168_ = ((6 &((NU8)1<<((NU)(pass)&7U)))!=0);
			if (!(T168_)) goto LA169_;
			T168_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 37))&63U)))!=0));
			LA169_: ;
			if (!T168_) goto LA170_;
			expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
			path_2 = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_TRUE);
			nimbleDir = getEnv__hhED57tMl0Iaa5bOg9cJaig(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_172), ((NimStringDesc*) NIM_NIL));
			{
				NIM_BOOL T174_;
				NIM_BOOL T175_;
				T174_ = (NIM_BOOL)0;
				T175_ = (NIM_BOOL)0;
				T175_ = isEmpty__ZNWb41IwBSHCUIjlqlGoxgpathutils(nimbleDir);
				T174_ = !(T175_);
				if (!(T174_)) goto LA176_;
				T174_ = (pass == ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 2));
				LA176_: ;
				if (!T174_) goto LA177_;
				path_2 = slash___0U8YTiSB6NvFwgvyimFN2Q(nimbleDir, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_173));
			}
			LA177_: ;
			nimblePath__yQoptEnH9cvj9cZKgjcndthg_2(conf, path_2, info);
		}
		LA170_: ;
	}
	goto LA138_;
	LA4_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		disableNimblePath__CQGypz7djD4eDZIXokhWpg(conf);
	}
	goto LA138_;
	LA5_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		clearNimblePath__CQGypz7djD4eDZIXokhWpg_2(conf);
	}
	goto LA138_;
	LA6_: ;
	{
		NimStringDesc* path_3;
		NI posX60gensym83_;
		NI posX60gensym86_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		path_3 = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_FALSE);
		posX60gensym83_ = ((NI) 0);
		{
			NI iX60gensym83_;
			NI colontmp__2;
			NI T183_;
			NI i_2;
			iX60gensym83_ = (NI)0;
			colontmp__2 = (NI)0;
			T183_ = ((*conf).searchPaths ? (*conf).searchPaths->Sup.len : 0);
			colontmp__2 = T183_;
			i_2 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* it;
					if (!(i_2 < colontmp__2)) goto LA185;
					iX60gensym83_ = i_2;
					it = (*conf).searchPaths->data[iX60gensym83_];
					{
						NIM_BOOL T188_;
						T188_ = (NIM_BOOL)0;
						T188_ = eqeq___RkPToIJrmXtRS03VT1CneA(it, path_3);
						if (!!(T188_)) goto LA189_;
						{
							if (!!((posX60gensym83_ == iX60gensym83_))) goto LA193_;
							asgnRef((void**) (&(*conf).searchPaths->data[posX60gensym83_]), (*conf).searchPaths->data[iX60gensym83_]);
						}
						LA193_: ;
						posX60gensym83_ += ((NI) 1);
					}
					LA189_: ;
					i_2 += ((NI) 1);
				} LA185: ;
			}
		}
		asgnRef((void**) (&(*conf).searchPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(&((*conf).searchPaths)->Sup, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) (posX60gensym83_))));
		posX60gensym86_ = ((NI) 0);
		{
			NI iX60gensym86_;
			NI colontmp__3;
			NI T196_;
			NI i_3;
			iX60gensym86_ = (NI)0;
			colontmp__3 = (NI)0;
			T196_ = ((*conf).lazyPaths ? (*conf).lazyPaths->Sup.len : 0);
			colontmp__3 = T196_;
			i_3 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* it_2;
					if (!(i_3 < colontmp__3)) goto LA198;
					iX60gensym86_ = i_3;
					it_2 = (*conf).lazyPaths->data[iX60gensym86_];
					{
						NIM_BOOL T201_;
						T201_ = (NIM_BOOL)0;
						T201_ = eqeq___RkPToIJrmXtRS03VT1CneA(it_2, path_3);
						if (!!(T201_)) goto LA202_;
						{
							if (!!((posX60gensym86_ == iX60gensym86_))) goto LA206_;
							asgnRef((void**) (&(*conf).lazyPaths->data[posX60gensym86_]), (*conf).lazyPaths->data[iX60gensym86_]);
						}
						LA206_: ;
						posX60gensym86_ += ((NI) 1);
					}
					LA202_: ;
					i_3 += ((NI) 1);
				} LA198: ;
			}
		}
		asgnRef((void**) (&(*conf).lazyPaths), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(&((*conf).lazyPaths)->Sup, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) (posX60gensym86_))));
	}
	goto LA138_;
	LA7_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		asgnRef((void**) (&(*conf).nimcacheDir), processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_TRUE));
	}
	goto LA138_;
	LA8_: ;
	{
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg f;
		NimStringDesc* T210_;
		NimStringDesc* T211_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		nimZeroMem((void*)(&f), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		T210_ = (NimStringDesc*)0;
		T210_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_TRUE);
		nossplitFile(T210_, (&f));
		T211_ = (NimStringDesc*)0;
		T211_ = rawNewString((f.Field1 ? f.Field1->Sup.len : 0) + (f.Field2 ? f.Field2->Sup.len : 0) + 0);
appendString(T211_, f.Field1);
appendString(T211_, f.Field2);
		asgnRef((void**) (&(*conf).outFile), T211_);
		asgnRef((void**) (&(*conf).outDir), toAbsoluteDir__jHVASw8gMU0B9bVk9atXU77g(f.Field0));
	}
	goto LA138_;
	LA9_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		asgnRef((void**) (&(*conf).outDir), processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_TRUE));
	}
	goto LA138_;
	LA10_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 8192, arg, pass, info);
	}
	goto LA138_;
	LA11_: ;
	{
		NimStringDesc* T215_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		T215_ = (NimStringDesc*)0;
		T215_ = (*conf).docSeeSrcUrl; (*conf).docSeeSrcUrl = copyStringRC1(arg);
		if (T215_) nimGCunrefNoCycle(T215_);
	}
	goto LA138_;
	LA12_: ;
	{
		{
			NimStringDesc* T221_;
			if (!((arg ? arg->Sup.len : 0) == ((NI) 0))) goto LA219_;
			T221_ = (NimStringDesc*)0;
			T221_ = (*conf).docRoot; (*conf).docRoot = copyStringRC1(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_180));
			if (T221_) nimGCunrefNoCycle(T221_);
		}
		goto LA217_;
		LA219_: ;
		{
			NimStringDesc* T223_;
			T223_ = (NimStringDesc*)0;
			T223_ = (*conf).docRoot; (*conf).docRoot = copyStringRC1(arg);
			if (T223_) nimGCunrefNoCycle(T223_);
		}
		LA217_: ;
	}
	goto LA138_;
	LA13_: ;
	{
		tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
		NimStringDesc* T225_;
		tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g T226_;
		T225_ = (NimStringDesc*)0;
		T225_ = nsuNormalize(arg);
		T226_ = (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g)0;
		backend = parseEnum__EKag4hBbNgjEXLqLxqglTQ(T225_, T226_);
		{
			tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g T229_;
			NimStringDesc* T232_;
			T229_ = (tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g)0;
			if (!(backend == T229_)) goto LA230_;
			T232_ = (NimStringDesc*)0;
			T232_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_181), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T232_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_182, NIM_FALSE);
		}
		LA230_: ;
		(*conf).backend = backend;
	}
	goto LA138_;
	LA14_: ;
	{
		NimStringDesc* T234_;
		T234_ = (NimStringDesc*)0;
		T234_ = (*conf).docCmd; (*conf).docCmd = copyStringRC1(arg);
		if (T234_) nimGCunrefNoCycle(T234_);
	}
	goto LA138_;
	LA15_: ;
	{
	}
	goto LA138_;
	LA16_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NIM_BOOL T239_;
			T239_ = (NIM_BOOL)0;
			T239_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ(arg, TM__brsa2DgNdQAKzy1F0pSZlA_183);
			if (!T239_) goto LA240_;
			splitSwitch__iY5h7sfVXAoUjuXGnmW9bAw(conf, arg, (&key), (&val), pass, info);
			{
				NI T244_;
				T244_ = (NI)0;
				T244_ = nsuCmpIgnoreStyle(key, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_188));
				if (!(T244_ == ((NI) 0))) goto LA245_;
				(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4);
			}
			LA245_: ;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, key, val);
		}
		goto LA237_;
		LA240_: ;
		{
			{
				NI T250_;
				T250_ = (NI)0;
				T250_ = nsuCmpIgnoreStyle(arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_188));
				if (!(T250_ == ((NI) 0))) goto LA251_;
				(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4);
			}
			LA251_: ;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		LA237_: ;
	}
	goto LA138_;
	LA17_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, arg);
	}
	goto LA138_;
	LA18_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
	}
	goto LA138_;
	LA19_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA258_;
			processCompile__7owBQPsmnvBN9cWaUPu9bYcQ(conf, arg);
		}
		LA258_: ;
	}
	goto LA138_;
	LA20_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA263_;
			addExternalFileToLink__VWI2GZGxWbHzjYJHzOr3dA_2(conf, arg);
		}
		LA263_: ;
	}
	goto LA138_;
	LA21_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 64, arg, pass, info);
	}
	goto LA138_;
	LA22_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 268435456, arg, pass, info);
	}
	goto LA138_;
	LA23_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 16, arg, pass, info);
	}
	goto LA138_;
	LA24_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 32, arg, pass, info);
	}
	goto LA138_;
	LA25_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 1048576, arg, pass, info);
	}
	goto LA138_;
	LA26_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 2, arg, pass, info);
	}
	goto LA138_;
	LA27_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(8724152320), arg, pass, info);
	}
	goto LA138_;
	LA28_: ;
	{
		{
			NIM_BOOL T275_;
			T275_ = (NIM_BOOL)0;
			T275_ = ((*conf).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3));
			if (T275_) goto LA276_;
			T275_ = eqStrings((*conf).command, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_190));
			LA276_: ;
			if (!T275_) goto LA277_;
			goto BeforeRet_;
		}
		LA277_: ;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T283_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA281_;
			T283_ = (NimStringDesc*)0;
			T283_ = nsuNormalize(arg);
			switch (hashString(T283_) & 15) {
			case 1: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_191))) goto LA284_;
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_194))) goto LA287_;
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_200))) goto LA292_;
break;
			case 2: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_195))) goto LA288_;
break;
			case 3: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_201))) goto LA293_;
break;
			case 6: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_198))) goto LA290_;
break;
			case 7: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_199))) goto LA291_;
break;
			case 9: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_197))) goto LA289_;
break;
			case 10: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_202))) goto LA293_;
break;
			case 11: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_193))) goto LA286_;
break;
			case 13: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_196))) goto LA288_;
break;
			case 14: 
if (eqStrings(T283_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_192))) goto LA285_;
break;
			}
			goto LA294_;
			LA284_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 2);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_203), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 26)) & 63);
			}
			goto LA295_;
			LA285_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 8);
			}
			goto LA295_;
			LA286_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_204), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_205, NIM_FALSE);
			}
			goto LA295_;
			LA287_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 6);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_206), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			}
			goto LA295_;
			LA288_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 4);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_207), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_208), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40)) & 63);
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41)) & 63);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA303_;
					defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_209), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
					defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_210), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				}
				LA303_: ;
			}
			goto LA295_;
			LA289_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 5);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_207), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_211), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40)) & 63);
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41)) & 63);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA308_;
					defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_209), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
					defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_210), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				}
				LA308_: ;
			}
			goto LA295_;
			LA290_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 7);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_212), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40)) & 63);
				processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(1099511627776), arg, pass, info);
				{
					if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA313_;
					defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_209), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
				}
				LA313_: ;
			}
			goto LA295_;
			LA291_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_213), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			}
			goto LA295_;
			LA292_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 1);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_214), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			}
			goto LA295_;
			LA293_: ;
			{
				(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 3);
				defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_215), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			}
			goto LA295_;
			LA294_: ;
			{
				NimStringDesc* T319_;
				T319_ = (NimStringDesc*)0;
				T319_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_216), arg);
				liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T319_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_217, NIM_FALSE);
			}
			LA295_: ;
		}
		LA281_: ;
	}
	goto LA138_;
	LA29_: ;
	{
		{
			NIM_BOOL T323_;
			T323_ = (NIM_BOOL)0;
			T323_ = processOnOffSwitchOrList__jbuLFmyuMzkCVahVfmlYeA(conf, 8192, arg, pass, info);
			if (!T323_) goto LA324_;
			listWarnings__O9arH9bYenXLOr27ZSmcQnEw(conf);
		}
		LA324_: ;
	}
	goto LA138_;
	LA30_: ;
	{
		processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ(arg, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 120), pass, info, switch_0, conf);
	}
	goto LA138_;
	LA31_: ;
	{
		processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ(arg, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 121), pass, info, switch_0, conf);
	}
	goto LA138_;
	LA32_: ;
	{
		processSpecificNote__B59avMINa9cm5CFqefE9bgZIQ(arg, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 122), pass, info, switch_0, conf);
	}
	goto LA138_;
	LA33_: ;
	{
		{
			NIM_BOOL T332_;
			T332_ = (NIM_BOOL)0;
			T332_ = processOnOffSwitchOrList__jbuLFmyuMzkCVahVfmlYeA(conf, 16384, arg, pass, info);
			if (!T332_) goto LA333_;
			listHints__O9arH9bYenXLOr27ZSmcQnEw_2(conf);
		}
		LA333_: ;
	}
	goto LA138_;
	LA34_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 16777216, arg, pass, info);
	}
	goto LA138_;
	LA35_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 131072, arg, pass, info);
	}
	goto LA138_;
	LA36_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 262144, arg, pass, info);
	}
	goto LA138_;
	LA37_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(2147483648), arg, pass, info);
	}
	goto LA138_;
	LA38_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 524288, arg, pass, info);
	}
	goto LA138_;
	LA39_: ;
	{
		NimStringDesc* T341_;
		T341_ = (NimStringDesc*)0;
		T341_ = nsuNormalize(arg);
		if (eqStrings(T341_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA342_;
		if (eqStrings(T341_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_228))) goto LA342_;
		if (eqStrings(T341_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_229))) goto LA342_;
		if (eqStrings(T341_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA343_;
		goto LA344_;
		LA342_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6)) & 63);
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12)) & 31);
		}
		goto LA345_;
		LA343_: ;
		{
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6)) & 63));
		}
		goto LA345_;
		LA344_: ;
		{
			NimStringDesc* T349_;
			T349_ = (NimStringDesc*)0;
			T349_ = rawNewString((arg ? arg->Sup.len : 0) + 37);
appendString(T349_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_230));
appendString(T349_, arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T349_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_231, NIM_FALSE);
		}
		LA345_: ;
	}
	goto LA138_;
	LA40_: ;
	{
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6)) & 63);
		(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12)) & 31);
	}
	goto LA138_;
	LA41_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 2097152, arg, pass, info);
		{
			if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 21))&31U)))!=0)) goto LA354_;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_54), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA352_;
		LA354_: ;
		{
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_54));
		}
		LA352_: ;
	}
	goto LA138_;
	LA42_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 16777216, arg, pass, info);
		{
			if (!(((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 24))&31U)))!=0)) goto LA360_;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_55), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA358_;
		LA360_: ;
		{
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_55));
		}
		LA358_: ;
	}
	goto LA138_;
	LA43_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(274877906944), arg, pass, info);
		{
			NIM_BOOL T366_;
			T366_ = (NIM_BOOL)0;
			T366_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w(conf);
			if (!T366_) goto LA367_;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_56), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_232), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			{
				NIM_BOOL T371_;
				T371_ = (NIM_BOOL)0;
				T371_ = isVSCompatible__nRr0tdRhl8rTyvIdRrQiFA(conf);
				if (!T371_) goto LA372_;
				addCompileOptionCmd__siPDo9a2eQzwubdmcIGchWg(conf, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_233));
			}
			LA372_: ;
		}
		goto LA364_;
		LA367_: ;
		{
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_56));
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_232));
		}
		LA364_: ;
	}
	goto LA138_;
	LA44_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 33554432, arg, pass, info);
	}
	goto LA138_;
	LA45_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 3518, arg, pass, info);
	}
	goto LA138_;
	LA46_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 384, arg, pass, info);
	}
	goto LA138_;
	LA47_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 256, arg, pass, info);
	}
	goto LA138_;
	LA48_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 128, arg, pass, info);
	}
	goto LA138_;
	LA49_: ;
	{
	}
	goto LA138_;
	LA50_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 2, arg, pass, info);
	}
	goto LA138_;
	LA51_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 4, arg, pass, info);
	}
	goto LA138_;
	LA52_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 8, arg, pass, info);
	}
	goto LA138_;
	LA53_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 16, arg, pass, info);
	}
	goto LA138_;
	LA54_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 64, arg, pass, info);
	}
	goto LA138_;
	LA55_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 32, arg, pass, info);
	}
	goto LA138_;
	LA56_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 512, arg, pass, info);
	}
	goto LA138_;
	LA57_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 1024, arg, pass, info);
	}
	goto LA138_;
	LA58_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 4096, arg, pass, info);
	}
	goto LA138_;
	LA59_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 2048, arg, pass, info);
	}
	goto LA138_;
	LA60_: ;
	{
	}
	goto LA138_;
	LA61_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 4194304, arg, pass, info);
	}
	goto LA138_;
	LA62_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 67108864, arg, pass, info);
	}
	goto LA138_;
	LA63_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 33554432, arg, pass, info);
	}
	goto LA138_;
	LA64_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 4194304, arg, pass, info);
	}
	goto LA138_;
	LA65_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 8388608, arg, pass, info);
	}
	goto LA138_;
	LA66_: ;
	{
		NimStringDesc* T398_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		T398_ = (NimStringDesc*)0;
		T398_ = nsuNormalize(arg);
		if (eqStrings(T398_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_234))) goto LA399_;
		if (eqStrings(T398_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_235))) goto LA400_;
		if (eqStrings(T398_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_200))) goto LA401_;
		goto LA402_;
		LA399_: ;
		{
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31);
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31));
		}
		goto LA403_;
		LA400_: ;
		{
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31));
			(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31);
		}
		goto LA403_;
		LA401_: ;
		{
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31));
			(*conf).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31));
		}
		goto LA403_;
		LA402_: ;
		{
			NimStringDesc* T408_;
			T408_ = (NimStringDesc*)0;
			T408_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_236), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T408_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_237, NIM_FALSE);
		}
		LA403_: ;
	}
	goto LA138_;
	LA67_: ;
	{
		NimStringDesc* T410_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		T410_ = (NimStringDesc*)0;
		T410_ = nsuNormalize(arg);
		if (eqStrings(T410_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_238))) goto LA411_;
		if (eqStrings(T410_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_239))) goto LA412_;
		if (eqStrings(T410_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_121))) goto LA413_;
		if (eqStrings(T410_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_240))) goto LA414_;
		goto LA415_;
		LA411_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9)) & 63);
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_241), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_242), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA416_;
		LA412_: ;
		{
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9)) & 63));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_241), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_243), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA416_;
		LA413_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7)) & 63);
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9)) & 63));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_244), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_245), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA416_;
		LA414_: ;
		{
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 8)) & 63);
			(*conf).globalOptions &= ~(((NU64)1) << ((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9)) & 63));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_244), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_240), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		goto LA416_;
		LA415_: ;
		{
			NimStringDesc* T422_;
			T422_ = (NimStringDesc*)0;
			T422_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_246), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T422_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_247, NIM_FALSE);
		}
		LA416_: ;
	}
	goto LA138_;
	LA68_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA426_;
			addCompileOptionCmd__siPDo9a2eQzwubdmcIGchWg(conf, arg);
		}
		LA426_: ;
	}
	goto LA138_;
	LA69_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA431_;
			addLinkOptionCmd__siPDo9a2eQzwubdmcIGchWg_2(conf, arg);
		}
		LA431_: ;
	}
	goto LA138_;
	LA70_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T438_;
			NI T439_;
			NimStringDesc* T440_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA436_;
			T438_ = (NimStringDesc*)0;
			T438_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_FALSE);
			asgnRef((void**) (&(*conf).cIncludes), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cIncludes), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T439_ = (*conf).cIncludes->Sup.len++;
			T440_ = (NimStringDesc*)0;
			T440_ = (*conf).cIncludes->data[T439_]; (*conf).cIncludes->data[T439_] = copyStringRC1(T438_);
			if (T440_) nimGCunrefNoCycle(T440_);
		}
		LA436_: ;
	}
	goto LA138_;
	LA71_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T446_;
			NI T447_;
			NimStringDesc* T448_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA444_;
			T446_ = (NimStringDesc*)0;
			T446_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_FALSE);
			asgnRef((void**) (&(*conf).cLibs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cLibs), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T447_ = (*conf).cLibs->Sup.len++;
			T448_ = (NimStringDesc*)0;
			T448_ = (*conf).cLibs->data[T447_]; (*conf).cLibs->data[T447_] = copyStringRC1(T446_);
			if (T448_) nimGCunrefNoCycle(T448_);
		}
		LA444_: ;
	}
	goto LA138_;
	LA72_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T454_;
			NI T455_;
			NimStringDesc* T456_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA452_;
			T454_ = (NimStringDesc*)0;
			T454_ = processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_FALSE);
			asgnRef((void**) (&(*conf).cLinkedLibs), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).cLinkedLibs), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T455_ = (*conf).cLinkedLibs->Sup.len++;
			T456_ = (NimStringDesc*)0;
			T456_ = (*conf).cLinkedLibs->data[T455_]; (*conf).cLinkedLibs->data[T455_] = copyStringRC1(T454_);
			if (T456_) nimGCunrefNoCycle(T456_);
		}
		LA452_: ;
	}
	goto LA138_;
	LA73_: ;
	{
		{
			NimStringDesc* T462_;
			if (!!((conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL)))) goto LA460_;
			T462_ = (NimStringDesc*)0;
			T462_ = (*conf).headerFile; (*conf).headerFile = copyStringRC1(arg);
			if (T462_) nimGCunrefNoCycle(T462_);
		}
		LA460_: ;
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 27)) & 63);
	}
	goto LA138_;
	LA74_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 134217728, arg, pass, info);
	}
	goto LA138_;
	LA75_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T469_;
			NimStringDesc* T470_;
			NI T471_;
			NimStringDesc* T472_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA467_;
			T469_ = (NimStringDesc*)0;
			T469_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, info.fileIndex);
			T470_ = (NimStringDesc*)0;
			T470_ = findModule__Y3iZ4DSoNguudlBW9cSwa2A(conf, arg, T469_);
			asgnRef((void**) (&(*conf).implicitImports), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).implicitImports), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T471_ = (*conf).implicitImports->Sup.len++;
			T472_ = (NimStringDesc*)0;
			T472_ = (*conf).implicitImports->data[T471_]; (*conf).implicitImports->data[T471_] = copyStringRC1(T470_);
			if (T472_) nimGCunrefNoCycle(T472_);
		}
		LA467_: ;
	}
	goto LA138_;
	LA76_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			NimStringDesc* T478_;
			NimStringDesc* T479_;
			NI T480_;
			NimStringDesc* T481_;
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA476_;
			T478_ = (NimStringDesc*)0;
			T478_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, info.fileIndex);
			T479_ = (NimStringDesc*)0;
			T479_ = findModule__Y3iZ4DSoNguudlBW9cSwa2A(conf, arg, T478_);
			asgnRef((void**) (&(*conf).implicitIncludes), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).implicitIncludes), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T480_ = (*conf).implicitIncludes->Sup.len++;
			T481_ = (NimStringDesc*)0;
			T481_ = (*conf).implicitIncludes->data[T480_]; (*conf).implicitIncludes->data[T480_] = copyStringRC1(T479_);
			if (T481_) nimGCunrefNoCycle(T481_);
		}
		LA476_: ;
	}
	goto LA138_;
	LA77_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 8, arg, pass, info);
	}
	goto LA138_;
	LA78_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(35184372088832), arg, pass, info);
	}
	goto LA138_;
	LA79_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 2048, arg, pass, info);
	}
	goto LA138_;
	LA80_: ;
	{
		tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ theOS;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		theOS = nameToOS__iaKZ3jKfqDIiIRvch1tYwg(arg);
		{
			NimStringDesc* osList;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T490_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T491_;
			NimStringDesc* T492_;
			if (!(theOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 0))) goto LA488_;
			T490_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
			T490_ = listOSnames__WnkSGhffTY6oNw2hLBbKUQ();
			osList = nsuJoinSep(T490_->data, (T490_ ? T490_->Sup.len : 0), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_248));
			nimZeroMem((void*)T491_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T491_[0] = copyString(arg);
			T491_[1] = copyString(osList);
			T492_ = (NimStringDesc*)0;
			T492_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_249), T491_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T492_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_250, NIM_FALSE);
		}
		goto LA486_;
		LA488_: ;
		{
			setTarget__08masX9a9bS9a9b87wx8moDG9aQ((&(*conf).target), theOS, (*conf).target.targetCPU);
		}
		LA486_: ;
	}
	goto LA138_;
	LA81_: ;
	{
		tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag cpu;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		cpu = nameToCPU__xntkVpXHPIZMT9cuNDXtepg(arg);
		{
			NimStringDesc* cpuList;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* T499_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T500_;
			NimStringDesc* T501_;
			if (!(cpu == ((tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag) 0))) goto LA497_;
			T499_ = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
			T499_ = listCPUnames__WnkSGhffTY6oNw2hLBbKUQ_2();
			cpuList = nsuJoinSep(T499_->data, (T499_ ? T499_->Sup.len : 0), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_248));
			nimZeroMem((void*)T500_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T500_[0] = copyString(arg);
			T500_[1] = copyString(cpuList);
			T501_ = (NimStringDesc*)0;
			T501_ = nsuFormatOpenArray(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_251), T500_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T501_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_252, NIM_FALSE);
		}
		goto LA495_;
		LA497_: ;
		{
			setTarget__08masX9a9bS9a9b87wx8moDG9aQ((&(*conf).target), (*conf).target.targetOS, cpu);
		}
		LA495_: ;
	}
	goto LA138_;
	LA82_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 4096, arg, pass, info);
	}
	goto LA138_;
	LA83_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		(*conf).maxLoopIterationsVM = nsuParseInt(arg);
	}
	goto LA138_;
	LA84_: ;
	{
		NI ret;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		ret = nsuParseInt(arg);
		{
			if (!(ret == ((NI) 0))) goto LA508_;
			(*conf).errorMax = ((NI) 2147483647);
		}
		goto LA506_;
		LA508_: ;
		{
			(*conf).errorMax = ret;
		}
		LA506_: ;
	}
	goto LA138_;
	LA85_: ;
	{
		NI verbosity;
		tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg verb;
		NI T517_;
		NI T518_;
		NI T519_;
		tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg T520_;
		tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg T521_;
		NI T522_;
		NI T523_;
		tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg T524_;
		tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg T525_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		verbosity = nsuParseInt(arg);
		{
			NimStringDesc* T516_;
			if (!!((verbosity >= ((NI) 0) && verbosity <= ((NI) 3)))) goto LA514_;
			T516_ = (NimStringDesc*)0;
			T516_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_253), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T516_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_254, NIM_FALSE);
		}
		LA514_: ;
		(*conf).verbosity = verbosity;
		nimZeroMem((void*)verb, sizeof(tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg));
		nimCopyMem((void*)verb, (NIM_CONST void*)NotesVerbosity__DnFX9bU018gdYu1P77fbdxQ[((*conf).verbosity)- 0], 9);
		T517_ = (NI)0;
		T518_ = (NI)0;
		T519_ = (NI)0;
		for (T519_ = 0; T519_ < 9; T519_++) 
  T520_[T519_] = (*conf).modifiedyNotes[T519_] & (*conf).notes[T519_];
		for (T518_ = 0; T518_ < 9; T518_++) 
  T521_[T518_] = T520_[T518_] | verb[T518_];
		T522_ = (NI)0;
		T523_ = (NI)0;
		for (T523_ = 0; T523_ < 9; T523_++) 
  T524_[T523_] = (*conf).modifiedyNotes[T523_] & verb[T523_];
		for (T522_ = 0; T522_ < 9; T522_++) 
  T525_[T522_] = T524_[T522_] & ~ (*conf).notes[T522_];
		for (T517_ = 0; T517_ < 9; T517_++) 
  (*conf).notes[T517_] = T521_[T517_] & ~ T525_[T517_];
		nimCopyMem((void*)(*conf).mainPackageNotes, (NIM_CONST void*)(*conf).notes, 9);
	}
	goto LA138_;
	LA86_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		(*conf).numberOfProcessors = nsuParseInt(arg);
	}
	goto LA138_;
	LA87_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		writeVersionInfo__WMrF6tFDO8y2YcugTwQDgA(conf, pass);
	}
	goto LA138_;
	LA88_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		writeAdvancedUsage__WMrF6tFDO8y2YcugTwQDgA_2(conf, pass);
	}
	goto LA138_;
	LA89_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		writeFullhelp__WMrF6tFDO8y2YcugTwQDgA_3(conf, pass);
	}
	goto LA138_;
	LA90_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		helpOnError__WMrF6tFDO8y2YcugTwQDgA_4(conf, pass);
	}
	goto LA138_;
	LA91_: ;
	{
	}
	goto LA138_;
	LA92_: ;
	{
		NimStringDesc* T533_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_263), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_264, NIM_FALSE);
		T533_ = (NimStringDesc*)0;
		T533_ = nsuNormalize(arg);
		if (eqStrings(T533_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_176))) goto LA534_;
		if (eqStrings(T533_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA535_;
		if (eqStrings(T533_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_265))) goto LA536_;
		if (eqStrings(T533_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_266))) goto LA537_;
		if (eqStrings(T533_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_193))) goto LA538_;
		goto LA539_;
		LA534_: ;
		{
			(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 3);
		}
		goto LA540_;
		LA535_: ;
		{
			(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 0);
		}
		goto LA540_;
		LA536_: ;
		{
			(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 1);
		}
		goto LA540_;
		LA537_: ;
		{
			(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 2);
		}
		goto LA540_;
		LA538_: ;
		{
			(*conf).symbolFiles = ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 3);
		}
		goto LA540_;
		LA539_: ;
		{
			NimStringDesc* T547_;
			T547_ = (NimStringDesc*)0;
			T547_ = rawNewString((arg ? arg->Sup.len : 0) + 34);
appendString(T547_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_267));
appendString(T547_, arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T547_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_268, NIM_FALSE);
		}
		LA540_: ;
	}
	goto LA138_;
	LA93_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 65536, arg, pass, info);
	}
	goto LA138_;
	LA94_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 131072, arg, pass, info);
	}
	goto LA138_;
	LA95_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 262144, arg, pass, info);
	}
	goto LA138_;
	LA96_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 524288, arg, pass, info);
	}
	goto LA138_;
	LA97_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 1024, arg, pass, info);
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 16, arg, pass, info);
	}
	goto LA138_;
	LA98_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 2097152, arg, pass, info);
	}
	goto LA138_;
	LA99_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		asgnRef((void**) (&(*conf).libpath), processPath__yr9b8Qf5CxXVgMiRouka8Dg(conf, arg, info, NIM_TRUE));
	}
	goto LA138_;
	LA100_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		splitSwitch__iY5h7sfVXAoUjuXGnmW9bAw(conf, arg, (&key), (&val), pass, info);
		putEnv__YVZCqlK3fKyVR367JpYgKA(key, val);
	}
	goto LA138_;
	LA101_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		setCC__Ep9cdURuQvSQKtNomcBwdFQ(conf, arg, info);
	}
	goto LA138_;
	LA102_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		track__HHQbKxjjZZnOezuSelLvtA(conf, arg, info);
	}
	goto LA138_;
	LA103_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		trackDirty__HHQbKxjjZZnOezuSelLvtA_2(conf, arg, info);
	}
	goto LA138_;
	LA104_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1);
	}
	goto LA138_;
	LA105_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 3);
	}
	goto LA138_;
	LA106_: ;
	{
		NimStringDesc* T562_;
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		T562_ = (NimStringDesc*)0;
		T562_ = (*conf).evalExpr; (*conf).evalExpr = copyStringRC1(arg);
		if (T562_) nimGCunrefNoCycle(T562_);
	}
	goto LA138_;
	LA107_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 2);
	}
	goto LA138_;
	LA108_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		(*conf).ideCmd = ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 4);
	}
	goto LA138_;
	LA109_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, 8388608, arg, pass, info);
	}
	goto LA138_;
	LA110_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(68719476736), arg, pass, info);
	}
	goto LA138_;
	LA111_: ;
	{
		dynlibOverride__9cWjALn36XqpUyv43volzuw_3(conf, switch_0, arg, pass, info);
	}
	goto LA138_;
	LA112_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(549755813888), arg, pass, info);
	}
	goto LA138_;
	LA113_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
	}
	goto LA138_;
	LA114_: ;
	{
		{
			if (!((arg ? arg->Sup.len : 0) == ((NI) 0))) goto LA573_;
			(*conf).features = ((*conf).features | 15);
		}
		goto LA571_;
		LA573_: ;
		{
			TSafePoint TM__brsa2DgNdQAKzy1F0pSZlA_278;
			tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ T576_;
			pushSafePoint(&TM__brsa2DgNdQAKzy1F0pSZlA_278);
			TM__brsa2DgNdQAKzy1F0pSZlA_278.status = _setjmp(TM__brsa2DgNdQAKzy1F0pSZlA_278.context);
			if (TM__brsa2DgNdQAKzy1F0pSZlA_278.status == 0) {
			T576_ = (tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ)0;
			T576_ = parseEnum__qIaeVZYC2IcNaPaw4CHbjg(arg);
			(*conf).features |= ((NU16)1)<<((T576_) & 15);
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
					TM__brsa2DgNdQAKzy1F0pSZlA_278.status = 0;
					liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_279), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_280, NIM_FALSE);
					popCurrentException();
				}
			}
			if (TM__brsa2DgNdQAKzy1F0pSZlA_278.status != 0) reraiseException();
		}
		LA571_: ;
	}
	goto LA138_;
	LA115_: ;
	{
		TSafePoint TM__brsa2DgNdQAKzy1F0pSZlA_281;
		tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA T580_;
		pushSafePoint(&TM__brsa2DgNdQAKzy1F0pSZlA_281);
		TM__brsa2DgNdQAKzy1F0pSZlA_281.status = _setjmp(TM__brsa2DgNdQAKzy1F0pSZlA_281.context);
		if (TM__brsa2DgNdQAKzy1F0pSZlA_281.status == 0) {
		T580_ = (tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA)0;
		T580_ = parseEnum__JiBTkh7mRNMhfnA62LJ6xA(arg);
		(*conf).legacyFeatures |= ((NU8)1)<<((T580_) & 7);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
				TM__brsa2DgNdQAKzy1F0pSZlA_281.status = 0;
				liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_282), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_283, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__brsa2DgNdQAKzy1F0pSZlA_281.status != 0) reraiseException();
	}
	goto LA138_;
	LA116_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 0);
		defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_284), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
	}
	goto LA138_;
	LA117_: ;
	{
		NimStringDesc* T585_;
		T585_ = (NimStringDesc*)0;
		T585_ = nsuNormalize(arg);
		if (eqStrings(T585_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_285))) goto LA586_;
		if (eqStrings(T585_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_286))) goto LA587_;
		if (eqStrings(T585_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_287))) goto LA588_;
		if (eqStrings(T585_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_288))) goto LA589_;
		goto LA590_;
		LA586_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2);
		}
		goto LA591_;
		LA587_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 1);
		}
		goto LA591_;
		LA588_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4);
		}
		goto LA591_;
		LA589_: ;
		{
			(*conf).exc = ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3);
		}
		goto LA591_;
		LA590_: ;
		{
			NimStringDesc* T597_;
			T597_ = (NimStringDesc*)0;
			T597_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_289), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T597_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_290, NIM_FALSE);
		}
		LA591_: ;
	}
	goto LA138_;
	LA118_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		{
			if (!!((conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL)))) goto LA601_;
			cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ(conf, arg);
		}
		LA601_: ;
	}
	goto LA138_;
	LA119_: ;
	{
		expectNoArg__9cWjALn36XqpUyv43volzuw_2(conf, switch_0, arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA606_;
			{
				if (!!(!((conf == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL))))) goto LA610_;
				failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_291));
			}
			LA610_: ;
			(*conf).features |= ((NU16)1)<<((((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 4)) & 15);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41)) & 63);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42)) & 63);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40)) & 63);
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_210), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			(*conf).selectedGC = ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 7);
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_212), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_209), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_292), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		LA606_: ;
	}
	goto LA138_;
	LA120_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(1099511627776), arg, pass, info);
		{
			if (!((6 &((NU8)1<<((NU)(pass)&7U)))!=0)) goto LA615_;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_209), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		LA615_: ;
	}
	goto LA138_;
	LA121_: ;
	{
		NimStringDesc* T618_;
		T618_ = (NimStringDesc*)0;
		T618_ = nsuNormalize(arg);
		if (eqStrings(T618_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_177))) goto LA619_;
		if (eqStrings(T618_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_44))) goto LA620_;
		if (eqStrings(T618_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_293))) goto LA621_;
		goto LA622_;
		LA619_: ;
		{
			(*conf).globalOptions = ((*conf).globalOptions & ~ 49152);
		}
		goto LA623_;
		LA620_: ;
		{
			(*conf).globalOptions = (((*conf).globalOptions | 16384) & ~ 32768);
		}
		goto LA623_;
		LA621_: ;
		{
			(*conf).globalOptions = ((*conf).globalOptions | 32768);
		}
		goto LA623_;
		LA622_: ;
		{
			NimStringDesc* T628_;
			T628_ = (NimStringDesc*)0;
			T628_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_294), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T628_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_295, NIM_FALSE);
		}
		LA623_: ;
	}
	goto LA138_;
	LA122_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(4294967296), arg, pass, info);
	}
	goto LA138_;
	LA123_: ;
	{
		{
			NimStringDesc* T635_;
			if (!(((NI) 0) < (arg ? arg->Sup.len : 0))) goto LA633_;
			T635_ = (NimStringDesc*)0;
			T635_ = (*conf).cppCustomNamespace; (*conf).cppCustomNamespace = copyStringRC1(arg);
			if (T635_) nimGCunrefNoCycle(T635_);
		}
		goto LA631_;
		LA633_: ;
		{
			NimStringDesc* T637_;
			T637_ = (NimStringDesc*)0;
			T637_ = (*conf).cppCustomNamespace; (*conf).cppCustomNamespace = copyStringRC1(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_296));
			if (T637_) nimGCunrefNoCycle(T637_);
		}
		LA631_: ;
		defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_297), (*conf).cppCustomNamespace);
	}
	goto LA138_;
	LA124_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(17179869184), arg, pass, info);
	}
	goto LA138_;
	LA125_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(8796093022208), arg, pass, info);
	}
	goto LA138_;
	LA126_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		nstPut((*conf).macrosToExpand, arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_298));
	}
	goto LA138_;
	LA127_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		nstPut((*conf).arcToExpand, arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_298));
	}
	goto LA138_;
	LA128_: ;
	{
		expectArg__9cWjALn36XqpUyv43volzuw(conf, switch_0, arg, pass, info);
		if (eqStrings(arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_299))) goto LA643_;
		if (eqStrings(arg, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_300))) goto LA644_;
		goto LA645_;
		LA643_: ;
		{
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_301), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_302));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_303), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_304));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_305), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_306));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_307), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
			undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_308));
			eqTypeFlags__9aJCM4BDGbCJ8tj1Vz9bDB7g = (eqTypeFlags__9aJCM4BDGbCJ8tj1Vz9bDB7g & ~ 130);
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 47)) & 63);
		}
		goto LA646_;
		LA644_: ;
		{
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_301), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_302));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_303), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_309));
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_305), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_306));
			(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 48)) & 63);
		}
		goto LA646_;
		LA645_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_310), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_311, NIM_FALSE);
		}
		LA646_: ;
	}
	goto LA138_;
	LA129_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(17592186044416), arg, pass, info);
	}
	goto LA138_;
	LA130_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(1125899906842624), arg, pass, info);
	}
	goto LA138_;
	LA131_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 67108864, arg, pass, info);
	}
	goto LA138_;
	LA132_: ;
	{
		processOnOffSwitch__VMQAniczUnWYds9c2odmwlQ(conf, 134217728, arg, pass, info);
	}
	goto LA138_;
	LA133_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(70368744177664), arg, pass, info);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 46))&63U)))!=0)) goto LA657_;
			defineSymbol__znuJizGq3isbcihOOtUY0A((*conf).symbols, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_312), ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_189));
		}
		LA657_: ;
	}
	goto LA138_;
	LA134_: ;
	{
		(*conf).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 49)) & 63);
		(*conf).options |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12)) & 31);
	}
	goto LA138_;
	LA135_: ;
	{
		processOnOffSwitchG__TlFXfZy3Ea2iEuUktBOwLA(conf, IL64(2251799813685248), arg, pass, info);
	}
	goto LA138_;
	LA136_: ;
	{
		handleStdinInput__t8RT1Qk4s0rBX8YbKQ0DBQ(conf);
	}
	goto LA138_;
	LA137_: ;
	{
		{
			NI T665_;
			T665_ = (NI)0;
			T665_ = nsuFindChar(switch_0, 46, ((NI) 0), ((NI) 0));
			if (!(((NI) 0) <= T665_)) goto LA666_;
			setConfigVar__6QeR1iJ9b9aIgKE4A0vKaYTQ(conf, switch_0, arg);
		}
		goto LA663_;
		LA666_: ;
		{
			invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, pass, switch_0, info);
		}
		LA663_: ;
	}
	LA138_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__dV5jwz9cYCLeNjAX40tnQHw)(tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA pass, tyObject_OptParser__l9cyoK9aLLTUH7LBRIbLqETg* p, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	NI bracketLe;
	bracketLe = nsuFindChar((*p).key, 91, ((NI) 0), ((NI) 0));
	{
		NimStringDesc* key;
		NimStringDesc* val;
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(((NI) 0) <= bracketLe)) goto LA3_;
		key = substr__2yh9cer0ymNRHlOOg8P7IuA((*p).key, ((NI) 0), (NI)(bracketLe - ((NI) 1)));
		T5_ = (NimStringDesc*)0;
		T6_ = (NimStringDesc*)0;
		T6_ = substr__iGg0RIKceRvsmvq8FUHOEw((*p).key, bracketLe);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + ((*p).val ? (*p).val->Sup.len : 0) + 1);
appendString(T5_, T6_);
appendChar(T5_, 58);
appendString(T5_, (*p).val);
		val = T5_;
		processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA(key, val, pass, gCmdLineInfo__yhfh3fjBy4h9bf6keLoh9aXQ, config);
	}
	goto LA1_;
	LA3_: ;
	{
		processSwitch__DS57z9bPOnpy1Lyf6Fyb2vA((*p).key, (*p).val, pass, gCmdLineInfo__yhfh3fjBy4h9bf6keLoh9aXQ, config);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeCommandLineUsage__t8RT1Qk4s0rBX8YbKQ0DBQ_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = getCommandLineDesc__ssYZeuyrx9c44xJxPRKx1jQ(conf);
	msgWriteln__PO49anyWCbe63GYNOs9cVuvg(conf, T1_, 1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__9bbrBm0brnGO9cOW9coVJSCaQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(switch_0);
	switch (hashString(T1_) & 63) {
	case 1: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_58))) goto LA16_;
break;
	case 2: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_74))) goto LA30_;
break;
	case 6: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_49))) goto LA11_;
break;
	case 8: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_62))) goto LA19_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_112))) goto LA32_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_80))) goto LA38_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_81))) goto LA38_;
break;
	case 9: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_47))) goto LA9_;
break;
	case 12: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_78))) goto LA35_;
break;
	case 13: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_71))) goto LA28_;
break;
	case 14: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_35))) goto LA4_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_66))) goto LA23_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_73))) goto LA30_;
break;
	case 16: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_41))) goto LA7_;
break;
	case 19: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_52))) goto LA13_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_54))) goto LA14_;
break;
	case 22: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_72))) goto LA29_;
break;
	case 23: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_57))) goto LA40_;
break;
	case 24: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_37))) goto LA6_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_51))) goto LA12_;
break;
	case 25: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_34))) goto LA3_;
break;
	case 26: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_61))) goto LA18_;
break;
	case 29: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_36))) goto LA5_;
break;
	case 30: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_33))) goto LA3_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_55))) goto LA15_;
break;
	case 31: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_69))) goto LA26_;
break;
	case 32: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_42))) goto LA7_;
break;
	case 34: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_101))) goto LA31_;
break;
	case 36: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_64))) goto LA21_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_77))) goto LA36_;
break;
	case 37: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_59))) goto LA16_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_68))) goto LA25_;
break;
	case 39: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_50))) goto LA39_;
break;
	case 40: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_48))) goto LA10_;
break;
	case 41: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_67))) goto LA24_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_100))) goto LA31_;
break;
	case 42: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_118))) goto LA33_;
break;
	case 45: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_31))) goto LA2_;
break;
	case 46: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_38))) goto LA6_;
break;
	case 49: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_65))) goto LA22_;
break;
	case 51: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_46))) goto LA8_;
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_63))) goto LA20_;
break;
	case 53: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_60))) goto LA17_;
break;
	case 54: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_76))) goto LA34_;
break;
	case 58: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_70))) goto LA27_;
break;
	case 62: 
if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_79))) goto LA37_;
break;
	}
	goto LA41_;
	LA2_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6))&63U)))!=0);
	}
	goto LA42_;
	LA3_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 4))&63U)))!=0);
	}
	goto LA42_;
	LA4_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 5))&63U)))!=0);
	}
	goto LA42_;
	LA5_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 20))&63U)))!=0);
	}
	goto LA42_;
	LA6_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 1))&63U)))!=0);
	}
	goto LA42_;
	LA7_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 13))&31U)))!=0);
	}
	goto LA42_;
	LA8_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 14))&31U)))!=0);
	}
	goto LA42_;
	LA9_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 24))&63U)))!=0);
	}
	goto LA42_;
	LA10_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0);
	}
	goto LA42_;
	LA11_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 18))&31U)))!=0);
	}
	goto LA42_;
	LA12_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 19))&31U)))!=0);
	}
	goto LA42_;
	LA13_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6))&63U)))!=0);
	}
	goto LA42_;
	LA14_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 21))&31U)))!=0);
	}
	goto LA42_;
	LA15_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 24))&31U)))!=0);
	}
	goto LA42_;
	LA16_: ;
	{
		result = (((*conf).options & 3518) == 3518);
	}
	goto LA42_;
	LA17_: ;
	{
		result = (((*conf).options & 384) == 384);
	}
	goto LA42_;
	LA18_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 8))&31U)))!=0);
	}
	goto LA42_;
	LA19_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 7))&31U)))!=0);
	}
	goto LA42_;
	LA20_: ;
	{
		result = NIM_FALSE;
	}
	goto LA42_;
	LA21_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 1))&31U)))!=0);
	}
	goto LA42_;
	LA22_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 2))&31U)))!=0);
	}
	goto LA42_;
	LA23_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 3))&31U)))!=0);
	}
	goto LA42_;
	LA24_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0);
	}
	goto LA42_;
	LA25_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 6))&31U)))!=0);
	}
	goto LA42_;
	LA26_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0);
	}
	goto LA42_;
	LA27_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 9))&31U)))!=0);
	}
	goto LA42_;
	LA28_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 10))&31U)))!=0);
	}
	goto LA42_;
	LA29_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0);
	}
	goto LA42_;
	LA30_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 11))&31U)))!=0);
	}
	goto LA42_;
	LA31_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 12))&63U)))!=0);
	}
	goto LA42_;
	LA32_: ;
	{
		result = !(((*conf).symbolFiles == ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 0)));
	}
	goto LA42_;
	LA33_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 10))&63U)))!=0);
	}
	goto LA42_;
	LA34_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 22))&63U)))!=0);
	}
	goto LA42_;
	LA35_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 25))&63U)))!=0);
	}
	goto LA42_;
	LA36_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 26))&63U)))!=0);
	}
	goto LA42_;
	LA37_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 22))&31U)))!=0);
	}
	goto LA42_;
	LA38_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 23))&31U)))!=0);
	}
	goto LA42_;
	LA39_: ;
	{
		result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 31))&63U)))!=0);
	}
	goto LA42_;
	LA40_: ;
	{
		result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0);
	}
	goto LA42_;
	LA41_: ;
	{
		invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0), switch_0, info);
	}
	LA42_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__Wd9alT05EZZXVF7dib5G9cYg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* switch_0, NimStringDesc* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NIM_BOOL result;
	NimStringDesc* T1_;
	result = (NIM_BOOL)0;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuNormalize(switch_0);
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_40))) goto LA2_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_82))) goto LA3_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_104))) goto LA4_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_83))) goto LA5_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_133))) goto LA6_;
	if (eqStrings(T1_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_139))) goto LA7_;
	goto LA8_;
	LA2_: ;
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = nsuNormalize(arg);
		switch (hashString(T11_) & 15) {
		case 1: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_191))) goto LA12_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_194))) goto LA15_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_200))) goto LA21_;
break;
		case 2: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_195))) goto LA17_;
break;
		case 3: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_201))) goto LA22_;
break;
		case 6: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_198))) goto LA19_;
break;
		case 7: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_199))) goto LA20_;
break;
		case 9: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_197))) goto LA18_;
break;
		case 10: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_314))) goto LA16_;
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_202))) goto LA22_;
break;
		case 11: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_193))) goto LA14_;
break;
		case 13: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_196))) goto LA17_;
break;
		case 14: 
if (eqStrings(T11_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_192))) goto LA13_;
break;
		}
		goto LA23_;
		LA12_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 2));
		}
		goto LA24_;
		LA13_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 8));
		}
		goto LA24_;
		LA14_: ;
		{
			result = NIM_FALSE;
		}
		goto LA24_;
		LA15_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 6));
		}
		goto LA24_;
		LA16_: ;
		{
			result = NIM_FALSE;
		}
		goto LA24_;
		LA17_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 4));
		}
		goto LA24_;
		LA18_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 5));
		}
		goto LA24_;
		LA19_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 7));
		}
		goto LA24_;
		LA20_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10));
		}
		goto LA24_;
		LA21_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 1));
		}
		goto LA24_;
		LA22_: ;
		{
			result = ((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 3));
		}
		goto LA24_;
		LA23_: ;
		{
			NimStringDesc* T37_;
			T37_ = (NimStringDesc*)0;
			T37_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_216), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T37_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_315, NIM_FALSE);
		}
		LA24_: ;
	}
	goto LA9_;
	LA3_: ;
	{
		NimStringDesc* T39_;
		T39_ = (NimStringDesc*)0;
		T39_ = nsuNormalize(arg);
		if (eqStrings(T39_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_234))) goto LA40_;
		if (eqStrings(T39_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_235))) goto LA41_;
		if (eqStrings(T39_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_200))) goto LA42_;
		goto LA43_;
		LA40_: ;
		{
			result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15))&31U)))!=0);
		}
		goto LA44_;
		LA41_: ;
		{
			result = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16))&31U)))!=0);
		}
		goto LA44_;
		LA42_: ;
		{
			result = (((*conf).options & 98304) == 0);
		}
		goto LA44_;
		LA43_: ;
		{
			NimStringDesc* T49_;
			T49_ = (NimStringDesc*)0;
			T49_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_236), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T49_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_316, NIM_FALSE);
		}
		LA44_: ;
	}
	goto LA9_;
	LA4_: ;
	{
		NimStringDesc* T51_;
		T51_ = (NimStringDesc*)0;
		T51_ = nimIntToStr((*conf).verbosity);
		result = eqStrings(T51_, arg);
	}
	goto LA9_;
	LA5_: ;
	{
		NimStringDesc* T53_;
		T53_ = (NimStringDesc*)0;
		T53_ = nsuNormalize(arg);
		if (eqStrings(T53_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_238))) goto LA54_;
		if (eqStrings(T53_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_239))) goto LA55_;
		if (eqStrings(T53_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_121))) goto LA56_;
		if (eqStrings(T53_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_240))) goto LA57_;
		goto LA58_;
		LA54_: ;
		{
			result = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0);
		}
		goto LA59_;
		LA55_: ;
		{
			result = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0));
		}
		goto LA59_;
		LA56_: ;
		{
			NIM_BOOL T63_;
			T63_ = (NIM_BOOL)0;
			T63_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7))&63U)))!=0);
			if (!(T63_)) goto LA64_;
			T63_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0));
			LA64_: ;
			result = T63_;
		}
		goto LA59_;
		LA57_: ;
		{
			NIM_BOOL T66_;
			T66_ = (NIM_BOOL)0;
			T66_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 8))&63U)))!=0);
			if (!(T66_)) goto LA67_;
			T66_ = !((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0));
			LA67_: ;
			result = T66_;
		}
		goto LA59_;
		LA58_: ;
		{
			NimStringDesc* T69_;
			T69_ = (NimStringDesc*)0;
			T69_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_246), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T69_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_317, NIM_FALSE);
		}
		LA59_: ;
	}
	goto LA9_;
	LA6_: ;
	{
		result = isDynlibOverride__jYnZYpCgdCpukBZK9bxcw9bQ(conf, arg);
	}
	goto LA9_;
	LA7_: ;
	{
		NimStringDesc* T72_;
		T72_ = (NimStringDesc*)0;
		T72_ = nsuNormalize(arg);
		if (eqStrings(T72_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_285))) goto LA73_;
		if (eqStrings(T72_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_286))) goto LA74_;
		if (eqStrings(T72_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_287))) goto LA75_;
		if (eqStrings(T72_, ((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_288))) goto LA76_;
		goto LA77_;
		LA73_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2));
		}
		goto LA78_;
		LA74_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 1));
		}
		goto LA78_;
		LA75_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4));
		}
		goto LA78_;
		LA76_: ;
		{
			result = ((*conf).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3));
		}
		goto LA78_;
		LA77_: ;
		{
			NimStringDesc* T84_;
			T84_ = (NimStringDesc*)0;
			T84_ = nsuFormatSingleElem(((NimStringDesc*) &TM__brsa2DgNdQAKzy1F0pSZlA_289), arg);
			liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T84_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__brsa2DgNdQAKzy1F0pSZlA_318, NIM_FALSE);
		}
		LA78_: ;
	}
	goto LA9_;
	LA8_: ;
	{
		invalidCmdLineOption__gts4XaBLyIp5Ol3MuJOvVg(conf, ((tyEnum_TCmdLinePass__IiBn9cB6WYIMDHOT44O82wA) 0), switch_0, info);
	}
	LA9_: ;
	return result;
}
