/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw;
typedef struct tySequence__1I3cxybVrOXM64KW2dfERQ tySequence__1I3cxybVrOXM64KW2dfERQ;
typedef struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw;
typedef struct tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w;
typedef struct tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg;
typedef struct tySequence__ZySnRyYriVjDpNDRyzJyGg tySequence__ZySnRyYriVjDpNDRyzJyGg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__EFqgCXJ4d8PgqOdFJmldsQ tyTuple__EFqgCXJ4d8PgqOdFJmldsQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__ImmlCByLdDIzmbcHsV583w tyTuple__ImmlCByLdDIzmbcHsV583w;

/* section: NIM_merge_TYPES */
struct tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A {
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* stateVarSym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmpResultSym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* unrollFinallySym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* curExcSym;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* states;
NI blockLevel;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* stateLoopLabel;
NI exitStateIdx;
NI tempVarId;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tempVars;
tySequence__qwqHTkRvwhrRyENtudHQ7g* exceptionTable;
NIM_BOOL hasExceptions;
NI curExcHandlingState;
NI nearestFinally;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw {
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* finallys;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tySequence__1I3cxybVrOXM64KW2dfERQ* blocks;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NI Field1;
};
struct tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg {
tySequence__ZySnRyYriVjDpNDRyzJyGg* data;
NI counter;
};
struct tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w {
tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg tab;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
struct tyTuple__EFqgCXJ4d8PgqOdFJmldsQ {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field1;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__T6RKPw8xfAeNaoei9aZGzXg[3];
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__ImmlCByLdDIzmbcHsV583w {
NI Field0;
NI Field1;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field2;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__1I3cxybVrOXM64KW2dfERQ {
  TGenericSeq Sup;
  tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__ZySnRyYriVjDpNDRyzJyGg {
  TGenericSeq Sup;
  tyTuple__ImmlCByLdDIzmbcHsV583w data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getEnvParam__0hs55xLsSn1sbFSXWwel1A)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createClosureIterStateType__YeSbRn4y243XNGGtCU6V6g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ)(tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, pop__jgHhw9bd9a38Xqyz0a3Aayngsystem)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_INLINE(void, pop__a3o7Gd9bszZC7VGVXhfyU9cAsystem)(tySequence__1I3cxybVrOXM64KW2dfERQ** s, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result);
static N_INLINE(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*, X5BX5D___svveXaS3ABkzCpulkevY7wsystem)(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, initTable__6C9a3DhzPC9cpjLGyCT2dFSw)(NI initialSize, tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg* Result);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVars__22z9chy834h1bLajhPJAYFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getOrDefault__uCG5IIVbEioYnAZb0kv7NQ)(tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, copySym__lIu8wX6Beq6dBJgESOFFjg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___mhf9c59bdwLow303OTY9aqDsw)(tyObject_Table__bBTYOvhK9cfU3hC9aEhb2BYg* t, NI key, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, toStmtList__BSqD59bZdLojBsNEMT9aVzXw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, newState__KR326D2V0A9c8rAN3F9amGLQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntLit__TuFlkTIoJNHT6fCcycYtSw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI64 value);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL* needsSplit);
N_LIB_PRIVATE N_NIMCALL(void, exprToStmtList__GrcFG9bOeET47xEWduCWw0g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyTuple__EFqgCXJ4d8PgqOdFJmldsQ* Result);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, add__VtZAvh3FTvs4RsUIdDz79aQ)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** y, NI yLen_0);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newTempVar__9crPEzQBTT3GMtBXwq7HxMg)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newEnvVar__33upYIjNEK4gS1UIzFj0Qw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NimStringDesc* name, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, addVar__qOCBdprWtK4hxer73SEdQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addUniqueField__CLL3aqLIY5XbgRQPQDI3cw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, addExprAssgn__so3YwDvudPgOjZgj88h9a1g)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* output, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* input, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exprBody, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* res);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNotCall__qb0UTd3LRTRUDLaWZGAI3w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysSym__9bvw79ck1FDiWpnBYh88rEfw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasYields__SoLjz0OznJM6S0ACeFDkTg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreaksAndContinuesInWhile__PPKdLcsjHM2xtTQ57VQRdQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* before, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* after);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreaksInBlock__U5wYjNmg2Tmx1BJW2OE3eA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* label, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* after);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, collectExceptState__eyQv3n2M3569coxZwjgCbIwclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callCodegenProc__6cD4vACMYqPEkcqC9cypTrw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg1, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg2, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg3, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* optionalArgs);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newOr__lX4ijAVTzsRg8N1Lp9atJqQclosureiters)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNullifyCurExc__FlUh1Xo9bXJFuG43AoVOEVw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCurExcAccess__cqBE2u681LMwPlL6VXs4dA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getFinallyNode__oib8dpvzVeiy5KmNWs9ajBw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTmpResultAccess__cqBE2u681LMwPlL6VXs4dA_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEndFinallyNode__FlUh1Xo9bXJFuG43AoVOEVw_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getClosureIterResult__9coyF0wpG1VqYcJq7Zk1fgQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, addElseToExcept__ZQwdGiE9bcxShuJtHMjr5sQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, deleteEmptyStates__EtZNQZ9ahFW9aGXseKeYzr0Q)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipStmtList__aKHUfk8lGnMfwXRkkphHzQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipThroughEmptyStates__oib8dpvzVeiy5KmNWs9ajBw_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NI, skipEmptyStates__Pi4UWe7a9cL5b9cA6VgWjduw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NI stateIdx);
N_LIB_PRIVATE N_NIMCALL(void, delete__erP7uc8MMOTSdwsQSiTshg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, NI i);
N_LIB_PRIVATE N_NIMCALL(void, delete__g2oR0TynFEFPrKXixkkfzA)(tySequence__qwqHTkRvwhrRyENtudHQ7g** x, NI i);
N_LIB_PRIVATE N_NIMCALL(void, del__erP7uc8MMOTSdwsQSiTshg_2)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformStateAssignments__oib8dpvzVeiy5KmNWs9ajBw_4)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAssgn__Mi9crg20nwOahuXiRT6sVew)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NI stateNo);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAssgn__AWbFLel9cjt8d7ZAwfIyCdA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* toValue);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAccess__cqBE2u681LMwPlL6VXs4dA_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getStateField__UJpIDWVzs220Reaf7HOAmw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(NI, stateFromGotoState__mq9bimW9b7LrVw9b9a6qcSmGUA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapIntoStateLoop__oib8dpvzVeiy5KmNWs9ajBw_5)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapIntoTryExcept__eyQv3n2M3569coxZwjgCbIw_2closureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCatchBody__MnQ8Kzhxn5rtRo9btObf9b9bgclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createExceptionTable__MszPr5bFWBE4wcbymAi00gclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newArrayType__642gHRMR9a1eZ1whzH7tKfQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_2, ":state", 6);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_3, ":stateLoop", 10);
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
extern TNimType NTI__1I3cxybVrOXM64KW2dfERQ_;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_4, "unsupported control flow: \'finally: ... raise\' duplicated becau"
"se of \'break\'", 76);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_6, "/home/runner/work/nightlies/nightlies/nim/compiler/closureiters"
".nim", 67);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_5 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 1325),
((NI) 14)}
;
extern TNimType NTI__qwqHTkRvwhrRyENtudHQ7g_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_7, "lowerStmtListExprs: constr typ.isNil", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_8 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 464),
((NI) 35)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_9, ":tmpSlLower", 11);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_10, "lowerStmtListExpr(nkIf): ", 25);
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_11 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 542),
((NI) 23)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_12, "lowerStmtListExpr(nkTryStmt): ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_13 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 572),
((NI) 25)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_14, "lowerStmtListExpr(nkCaseStmt): ", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_15 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 604),
((NI) 25)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_16, "not", 3);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_17, "true", 4);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_18, "yield in expr not lowered", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_19 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 1406),
((NI) 17)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_20, "transformClosureIteratorBody != s", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_21 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 878),
((NI) 23)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_22, "of", 2);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_23, "getCurrentException", 19);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_24, "or", 2);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_25, ":curExc", 7);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_26, ":unrollFinally", 14);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_27, ":tmpResult", 10);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_28, "==", 2);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_29, "closureIterSetupExc", 19);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_30, "transformReturnsInTry != tryBody", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_31 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 987),
((NI) 21)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_32, "transformClosureIteratorBody != tryBody", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_33 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 989),
((NI) 21)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_34, "transformReturnsInTry != exceptBody", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_35 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 994),
((NI) 21)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_36, "transformClosureIteratorBody != exceptBody", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_37 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 996),
((NI) 21)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_38, "transformClosureIteratorBody != finallyBody", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_39 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 1001),
((NI) 21)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_40, "closure iter ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__slVvvIjx75ivXdMpHiE9c9aQ_41 = {((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_6),
((NI) 1004),
((NI) 17)}
;
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_42, "<", 1);
STRING_LITERAL(TM__slVvvIjx75ivXdMpHiE9c9aQ_43, "-", 1);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, pop__jgHhw9bd9a38Xqyz0a3Aayngsystem)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI L;
	NI T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (L))));
	return result;
}
static N_INLINE(void, pop__a3o7Gd9bszZC7VGVXhfyU9cAsystem)(tySequence__1I3cxybVrOXM64KW2dfERQ** s, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result) {
	NI L;
	NI T1_;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), (*s)->data[L].Field0);
	(*Result).Field1 = (*s)->data[L].Field1;
	unsureAsgnRef((void**) (&(*s)), (tySequence__1I3cxybVrOXM64KW2dfERQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__1I3cxybVrOXM64KW2dfERQ_), ((NI) (L))));
}
static N_INLINE(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*, X5BX5D___svveXaS3ABkzCpulkevY7wsystem)(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* s, NI sLen_0, NI i) {
	tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* result;
	result = (tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVars__22z9chy834h1bLajhPJAYFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x;
		x = getOrDefault__uCG5IIVbEioYnAZb0kv7NQ((*c).tab, (*(*n)._kind_4.sym).Sup.id);
		{
			if (!(x == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA4_;
			result = n;
		}
		goto LA2_;
		LA4_: ;
		{
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(x, (*n).info);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = n;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	{
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA12;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idefs;
							if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA15_;
							idefs = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(it);
							{
								NI v;
								NI colontmp__2;
								NI T18_;
								NI res;
								v = (NI)0;
								colontmp__2 = (NI)0;
								T18_ = (NI)0;
								T18_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								colontmp__2 = (NI)(T18_ - ((NI) 3));
								res = ((NI) 0);
								{
									while (1) {
										if (!(res <= colontmp__2)) goto LA20;
										v = res;
										{
											tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x_2;
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
											if (!((*(*it)._kind_6.sons->data[v]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA23_;
											x_2 = copySym__lIu8wX6Beq6dBJgESOFFjg((*(*it)._kind_6.sons->data[v])._kind_4.sym);
											X5BX5Deq___mhf9c59bdwLow303OTY9aqDsw((&(*c).tab), (*(*(*it)._kind_6.sons->data[v])._kind_4.sym).Sup.id, x_2);
											T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
											T25_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(x_2);
											add__P8dDSotTW25BkfbyspojGg(idefs, T25_);
										}
										goto LA21_;
										LA23_: ;
										{
											add__P8dDSotTW25BkfbyspojGg(idefs, (*it)._kind_6.sons->data[v]);
										}
										LA21_: ;
										res += ((NI) 1);
									} LA20: ;
								}
							}
							{
								NI rest;
								NI colontmp__3;
								NI colontmp__4;
								NI T28_;
								NI i_3;
								rest = (NI)0;
								colontmp__3 = (NI)0;
								colontmp__4 = (NI)0;
								T28_ = (NI)0;
								T28_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								colontmp__3 = (NI)(T28_ - ((NI) 2));
								colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(it);
								i_3 = colontmp__3;
								{
									while (1) {
										if (!(i_3 < colontmp__4)) goto LA30;
										rest = i_3;
										add__P8dDSotTW25BkfbyspojGg(idefs, (*it)._kind_6.sons->data[rest]);
										i_3 += ((NI) 1);
									} LA30: ;
								}
							}
							add__P8dDSotTW25BkfbyspojGg(result, idefs);
						}
						goto LA13_;
						LA15_: ;
						{
							add__P8dDSotTW25BkfbyspojGg(result, it);
						}
						LA13_: ;
						i_2 += ((NI) 1);
					} LA12: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*c).config, (*c).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_4), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__slVvvIjx75ivXdMpHiE9c9aQ_5, NIM_FALSE);
	}
	break;
	default:
	{
		result = n;
		{
			NI i_4;
			NI colontmp__5;
			NI i_5;
			i_4 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_5 = ((NI) 0);
			{
				while (1) {
					if (!(i_5 < colontmp__5)) goto LA36;
					i_4 = i_5;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_4]), freshVars__22z9chy834h1bLajhPJAYFA((*n)._kind_6.sons->data[i_4], c));
					i_5 += ((NI) 1);
				} LA36: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ)(tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f;
		f = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
			NI T7_;
			if (!((*f).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA4_;
			T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T6_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(f);
			unsureAsgnRef((void**) (&(*c).finallys), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*c).finallys), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
			T7_ = (*c).finallys->Sup.len++;
			asgnRef((void**) (&(*c).finallys->data[T7_]), T6_);
		}
		LA4_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
			if (!((*f).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA13_;
			T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T15_ = pop__jgHhw9bd9a38Xqyz0a3Aayngsystem((&(*c).finallys));
			(void)(T15_);
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	{
		tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw T17_;
		NI T18_;
		NI T19_;
		tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw T23_;
		nimZeroMem((void*)(&T17_), sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw));
		T17_.Field0 = n;
		T18_ = ((*c).finallys ? (*c).finallys->Sup.len : 0);
		T17_.Field1 = T18_;
		unsureAsgnRef((void**) (&(*c).blocks), (tySequence__1I3cxybVrOXM64KW2dfERQ*) incrSeqV3((TGenericSeq*)((*c).blocks), (&NTI__1I3cxybVrOXM64KW2dfERQ_)));
		T19_ = (*c).blocks->Sup.len++;
		asgnRef((void**) (&(*c).blocks->data[T19_].Field0), T17_.Field0);
		(*c).blocks->data[T19_].Field1 = T17_.Field1;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA22;
					i_3 = i_4;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_3]), preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ(c, (*n)._kind_6.sons->data[i_3]));
					i_4 += ((NI) 1);
				} LA22: ;
			}
		}
		nimZeroMem((void*)(&T23_), sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw));
		pop__a3o7Gd9bszZC7VGVXhfyU9cAsystem((&(*c).blocks), (&T23_));
		(void)(T23_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		{
			NI T27_;
			T27_ = ((*c).blocks ? (*c).blocks->Sup.len : 0);
			if (!(T27_ == ((NI) 0))) goto LA28_;
		}
		goto LA25_;
		LA28_: ;
		{
			NI fin;
			fin = ((NI) -1);
			{
				tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* T35_;
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA33_;
				T35_ = (tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw*)0;
				T35_ = X5BX5D___svveXaS3ABkzCpulkevY7wsystem((*c).blocks->data, ((*c).blocks ? (*c).blocks->Sup.len : 0), ((NI) 1));
				fin = (*T35_).Field1;
			}
			goto LA31_;
			LA33_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA37_;
				{
					NI i_5;
					NI colontmp__3;
					NI T40_;
					NI res;
					i_5 = (NI)0;
					colontmp__3 = (NI)0;
					T40_ = (((*c).blocks ? (*c).blocks->Sup.len : 0)-1);
					colontmp__3 = T40_;
					res = colontmp__3;
					{
						while (1) {
							if (!(((NI) 0) <= res)) goto LA42;
							i_5 = res;
							{
								NIM_BOOL T45_;
								NIM_BOOL T46_;
								T45_ = (NIM_BOOL)0;
								T46_ = (NIM_BOOL)0;
								T46_ = ((*(*c).blocks->data[i_5].Field0).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112));
								if (!(T46_)) goto LA47_;
								T46_ = ((*(*(*c).blocks->data[i_5].Field0)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
								LA47_: ;
								T45_ = T46_;
								if (!(T45_)) goto LA48_;
								T45_ = ((*(*(*c).blocks->data[i_5].Field0)._kind_6.sons->data[((NI) 0)])._kind_4.sym == (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
								LA48_: ;
								if (!T45_) goto LA49_;
								fin = (*c).blocks->data[i_5].Field1;
								goto LA39;
							}
							LA49_: ;
							res -= ((NI) 1);
						} LA42: ;
					}
				} LA39: ;
			}
			goto LA31_;
			LA37_: ;
			LA31_: ;
			{
				if (!(((NI) 0) <= fin)) goto LA53_;
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
				{
					NI i_6;
					NI colontmp__4;
					NI T56_;
					NI res_2;
					i_6 = (NI)0;
					colontmp__4 = (NI)0;
					T56_ = (((*c).finallys ? (*c).finallys->Sup.len : 0)-1);
					colontmp__4 = T56_;
					res_2 = colontmp__4;
					{
						while (1) {
							tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w vars;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T59_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
							if (!(fin <= res_2)) goto LA58;
							i_6 = res_2;
							nimZeroMem((void*)(&vars), sizeof(tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w));
							nimZeroMem((void*)(&vars), sizeof(tyObject_FreshVarsContext__BITJ25TBEN8CE4NK59coN0w));
							initTable__6C9a3DhzPC9cpjLGyCT2dFSw(((NI) 32), (&vars.tab));
							vars.config = (*c).config;
							vars.info = (*n).info;
							T59_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T59_ = preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ(c, (*c).finallys->data[i_6]);
							T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T60_ = freshVars__22z9chy834h1bLajhPJAYFA(T59_, (&vars));
							add__P8dDSotTW25BkfbyspojGg(result, T60_);
							res_2 -= ((NI) 1);
						} LA58: ;
					}
				}
				add__P8dDSotTW25BkfbyspojGg(result, n);
			}
			LA53_: ;
		}
		LA25_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	default:
	{
		{
			NI i_7;
			NI colontmp__5;
			NI i_8;
			i_7 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_8 = ((NI) 0);
			{
				while (1) {
					if (!(i_8 < colontmp__5)) goto LA65;
					i_7 = i_8;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_7]), preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ(c, (*n)._kind_6.sons->data[i_7]));
					i_8 += ((NI) 1);
				} LA65: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, toStmtList__BSqD59bZdLojBsNEMT9aVzXw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126)))) goto LA3_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, n);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, newState__KR326D2V0A9c8rAN3F9amGLQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut) {
	NI result;
	NI T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resLit;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
	NI T2_;
	NI T3_;
	result = (NI)0;
	T1_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
	result = T1_;
	resLit = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, (*n).info, ((NI64) (result)));
	s = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 157), (*n).info);
	add__P8dDSotTW25BkfbyspojGg(s, resLit);
	add__P8dDSotTW25BkfbyspojGg(s, n);
	unsureAsgnRef((void**) (&(*ctx).states), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*ctx).states), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
	T2_ = (*ctx).states->Sup.len++;
	asgnRef((void**) (&(*ctx).states->data[T2_]), s);
	unsureAsgnRef((void**) (&(*ctx).exceptionTable), (tySequence__qwqHTkRvwhrRyENtudHQ7g*) incrSeqV3((TGenericSeq*)((*ctx).exceptionTable), (&NTI__qwqHTkRvwhrRyENtudHQ7g_)));
	T3_ = (*ctx).exceptionTable->Sup.len++;
	(*ctx).exceptionTable->data[T3_] = (*ctx).curExcHandlingState;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		if (!!((gotoOut == 0))) goto LA6_;
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, (*gotoOut).info, ((NI64) (result)));
		add__P8dDSotTW25BkfbyspojGg(gotoOut, T8_);
	}
	LA6_: ;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, exprToStmtList__GrcFG9bOeET47xEWduCWw0g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyTuple__EFqgCXJ4d8PgqOdFJmldsQ* Result) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).Field0), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info));
	if ((*(*Result).Field0)._kind_6.sons) { nimGCunrefNoCycle((*(*Result).Field0)._kind_6.sons); (*(*Result).Field0)._kind_6.sons = NIM_NIL; }
	n_2 = n;
	{
		while (1) {
			NI T3_;
			NI T4_;
			if (!((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA2;
			add__VtZAvh3FTvs4RsUIdDz79aQ((&(*(*Result).Field0)._kind_6.sons), (*n_2)._kind_6.sons->data, ((*n_2)._kind_6.sons ? (*n_2)._kind_6.sons->Sup.len : 0));
			T3_ = (NI)0;
			T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*Result).Field0);
			asgnRef((void**) (&(*(*Result).Field0)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*(*Result).Field0)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(T3_ - ((NI) 1))))));
			T4_ = (NI)0;
			T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
			n_2 = (*n_2)._kind_6.sons->data[(NI)(T4_ - ((NI) 1))];
		} LA2: ;
	}
	unsureAsgnRef((void**) (&(*Result).Field1), n_2);
}
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newEnvVar__33upYIjNEK4gS1UIzFj0Qw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NimStringDesc* name, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*ctx).g).cache, name);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T1_, (*ctx).fn, (*(*ctx).fn).info, 0);
	asgnRef((void**) (&(*result).typ), typ);
	{
		if (!!(((*ctx).stateVarSym == 0))) goto LA4_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
			if (!((*ctx).tempVars == 0)) goto LA8_;
			unsureAsgnRef((void**) (&(*ctx).tempVars), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*(*ctx).fn).info));
			T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T10_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result);
			addVar__qOCBdprWtK4hxer73SEdQA((*ctx).tempVars, T10_);
		}
		LA8_: ;
	}
	goto LA2_;
	LA4_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* envParam;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
		envParam = getEnvParam__0hs55xLsSn1sbFSXWwel1A((*ctx).fn);
		T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T12_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*envParam).typ);
		result = addUniqueField__CLL3aqLIY5XbgRQPQDI3cw(T12_, result, (*(*ctx).g).cache);
	}
	LA2_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newTempVar__9crPEzQBTT3GMtBXwq7HxMg)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = nimIntToStr((*ctx).tempVarId);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 11);
appendString(T1_, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_9));
appendString(T1_, T2_);
	result = newEnvVar__33upYIjNEK4gS1UIzFj0Qw(ctx, T1_, typ);
	(*ctx).tempVarId += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!((*ctx).stateVarSym == 0)) goto LA3_;
		T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T5_ = getEnvParam__0hs55xLsSn1sbFSXWwel1A((*ctx).fn);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T5_);
		result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(T6_, s, (*(*ctx).fn).info);
	}
	goto LA1_;
	LA3_: ;
	{
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T1_[0] = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw(ctx, s);
	T1_[1] = v;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), T1_, 2);
	(*result).info = (*v).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addExprAssgn__so3YwDvudPgOjZgj88h9a1g)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* output, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* input, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	{
		tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!((*input).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
		exprToStmtList__GrcFG9bOeET47xEWduCWw0g(input, (&T5_));
		st = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		st = T5_.Field0;
		res = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		res = T5_.Field1;
		add__P8dDSotTW25BkfbyspojGg(output, st);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg(ctx, sym, res);
		add__P8dDSotTW25BkfbyspojGg(output, T6_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg(ctx, sym, input);
		add__P8dDSotTW25BkfbyspojGg(output, T8_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exprBody, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* res) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*exprBody).info);
	addExprAssgn__so3YwDvudPgOjZgj88h9a1g(ctx, result, exprBody, res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNotCall__qb0UTd3LRTRUDLaWZGAI3w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, (*e).info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_16), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96));
	T1_[0] = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T2_, (*e).info);
	T1_[1] = e;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T1_, 2);
	asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*e).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL* needsSplit) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		NIM_BOOL ns;
		ns = NIM_FALSE;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i], (&ns)));
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
		{
			tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T10_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex;
			if (!ns) goto LA8_;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			nimZeroMem((void*)(&T10_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
			exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T10_));
			st = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			st = T10_.Field0;
			ex = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			ex = T10_.Field1;
			add__P8dDSotTW25BkfbyspojGg(result, st);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex);
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA8_: ;
		(*needsSplit) = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		NIM_BOOL ns_2;
		ns_2 = NIM_FALSE;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA14;
					i_3 = i_4;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_3], (&ns_2)));
					i_4 += ((NI) 1);
				} LA14: ;
			}
		}
		{
			if (!ns_2) goto LA17_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
			{
				if (!((*n).typ == 0)) goto LA21_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_7), TM__slVvvIjx75ivXdMpHiE9c9aQ_8);
			}
			LA21_: ;
			asgnRef((void**) (&(*result).typ), (*n).typ);
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA25;
						i_5 = i_6;
						switch ((*(*n)._kind_6.sons->data[i_5]).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34):
						{
							{
								tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T31_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_2;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_2;
								if (!((*(*(*n)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA29_;
								nimZeroMem((void*)(&T31_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
								exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*(*n)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)], (&T31_));
								st_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								st_2 = T31_.Field0;
								ex_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								ex_2 = T31_.Field1;
								add__P8dDSotTW25BkfbyspojGg(result, st_2);
								asgnRef((void**) (&(*(*n)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)]), ex_2);
							}
							LA29_: ;
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
						{
							tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T33_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_3;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_3;
							nimZeroMem((void*)(&T33_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
							exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[i_5], (&T33_));
							st_3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							st_3 = T33_.Field0;
							ex_3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							ex_3 = T33_.Field1;
							add__P8dDSotTW25BkfbyspojGg(result, st_3);
							asgnRef((void**) (&(*n)._kind_6.sons->data[i_5]), ex_3);
						}
						break;
						default:
						{
						}
						break;
						}
						i_6 += ((NI) 1);
					} LA25: ;
				}
			}
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		NIM_BOOL ns_3;
		ns_3 = NIM_FALSE;
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_8 = ((NI) 0);
			{
				while (1) {
					if (!(i_8 < colontmp__4)) goto LA38;
					i_7 = i_8;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_7]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_7], (&ns_3)));
					i_8 += ((NI) 1);
				} LA38: ;
			}
		}
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmp;
			NIM_BOOL isExpr;
			NIM_BOOL T43_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* curS;
			if (!ns_3) goto LA41_;
			(*needsSplit) = NIM_TRUE;
			tmp = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T43_ = (NIM_BOOL)0;
			T43_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			isExpr = !(T43_);
			{
				if (!isExpr) goto LA46_;
				tmp = newTempVar__9crPEzQBTT3GMtBXwq7HxMg(ctx, (*n).typ);
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
				asgnRef((void**) (&(*result).typ), (*n).typ);
			}
			goto LA44_;
			LA46_: ;
			{
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			}
			LA44_: ;
			curS = result;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				branch = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i_9;
					NI colontmp__5;
					NI i_10;
					i_9 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__5 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					i_10 = ((NI) 0);
					{
						while (1) {
							if (!(i_10 < colontmp__5)) goto LA52;
							i_9 = i_10;
							branch = (*n)._kind_6.sons->data[i_9];
							switch ((*branch).kind) {
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 50):
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
							{
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchBody;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newBranch;
									tyArray__jlWPjgtbdjE069arIWHC9c9bg T58_;
									if (!isExpr) goto LA56_;
									branchBody = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*branch).info);
									addExprAssgn__so3YwDvudPgOjZgj88h9a1g((&(*ctx)), branchBody, (*branch)._kind_6.sons->data[((NI) 0)], tmp);
									nimZeroMem((void*)T58_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
									T58_[0] = branchBody;
									newBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), T58_, 1);
									add__P8dDSotTW25BkfbyspojGg(curS, newBranch);
								}
								goto LA54_;
								LA56_: ;
								{
									add__P8dDSotTW25BkfbyspojGg(curS, branch);
								}
								LA54_: ;
							}
							break;
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 49):
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newBranch_2;
								newBranch_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								{
									tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T65_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_4;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBody;
									tyArray__jlWPjgtbdjE069arIWHC9c9bg T66_;
									tyArray__AB6yfoUgfWM2NtGe9bzkCmw T67_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newIf;
									tyArray__jlWPjgtbdjE069arIWHC9c9bg T68_;
									if (!((*(*branch)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA63_;
									nimZeroMem((void*)(&T65_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
									exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*branch)._kind_6.sons->data[((NI) 0)], (&T65_));
									st_4 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									st_4 = T65_.Field0;
									res = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									res = T65_.Field1;
									nimZeroMem((void*)T66_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
									T66_[0] = st_4;
									elseBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T66_, 1);
									nimZeroMem((void*)T67_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
									T67_[0] = res;
									T67_[1] = (*branch)._kind_6.sons->data[((NI) 1)];
									newBranch_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T67_, 2);
									nimZeroMem((void*)T68_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
									T68_[0] = newBranch_2;
									newIf = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T68_, 1);
									add__P8dDSotTW25BkfbyspojGg(elseBody, newIf);
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newElse;
										if (!((*curS).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92))) goto LA71_;
										newElse = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), (*branch).info);
										add__P8dDSotTW25BkfbyspojGg(newElse, elseBody);
										add__P8dDSotTW25BkfbyspojGg(curS, newElse);
									}
									goto LA69_;
									LA71_: ;
									{
										add__P8dDSotTW25BkfbyspojGg(curS, elseBody);
									}
									LA69_: ;
									curS = newIf;
								}
								goto LA61_;
								LA63_: ;
								{
									newBranch_2 = branch;
									{
										if (!((*curS).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92))) goto LA77_;
										add__P8dDSotTW25BkfbyspojGg(curS, newBranch_2);
									}
									goto LA75_;
									LA77_: ;
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newIf_2;
										tyArray__jlWPjgtbdjE069arIWHC9c9bg T80_;
										nimZeroMem((void*)T80_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
										T80_[0] = newBranch_2;
										newIf_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T80_, 1);
										add__P8dDSotTW25BkfbyspojGg(curS, newIf_2);
										curS = newIf_2;
									}
									LA75_: ;
								}
								LA61_: ;
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchBody_2;
									if (!isExpr) goto LA83_;
									branchBody_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*(*branch)._kind_6.sons->data[((NI) 1)]).info);
									addExprAssgn__so3YwDvudPgOjZgj88h9a1g((&(*ctx)), branchBody_2, (*branch)._kind_6.sons->data[((NI) 1)], tmp);
									asgnRef((void**) (&(*newBranch_2)._kind_6.sons->data[((NI) 1)]), branchBody_2);
								}
								LA83_: ;
							}
							break;
							default:
							{
								NimStringDesc* T86_;
								T86_ = (NimStringDesc*)0;
								T86_ = rawNewString((reprEnum((NI)(*branch).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*branch).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 25);
appendString(T86_, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_10));
appendString(T86_, reprEnum((NI)(*branch).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T86_, TM__slVvvIjx75ivXdMpHiE9c9aQ_11);
							}
							break;
							}
							i_10 += ((NI) 1);
						} LA52: ;
					}
				}
			}
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T91_;
				if (!isExpr) goto LA89_;
				T91_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T91_ = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp);
				add__P8dDSotTW25BkfbyspojGg(result, T91_);
			}
			LA89_: ;
		}
		LA41_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		NIM_BOOL ns_4;
		ns_4 = NIM_FALSE;
		{
			NI i_11;
			NI colontmp__6;
			NI i_12;
			i_11 = (NI)0;
			colontmp__6 = (NI)0;
			colontmp__6 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_12 = ((NI) 0);
			{
				while (1) {
					if (!(i_12 < colontmp__6)) goto LA95;
					i_11 = i_12;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_11]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_11], (&ns_4)));
					i_12 += ((NI) 1);
				} LA95: ;
			}
		}
		{
			NIM_BOOL isExpr_2;
			NIM_BOOL T100_;
			if (!ns_4) goto LA98_;
			(*needsSplit) = NIM_TRUE;
			T100_ = (NIM_BOOL)0;
			T100_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			isExpr_2 = !(T100_);
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmp_2;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T117_;
				if (!isExpr_2) goto LA103_;
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
				asgnRef((void**) (&(*result).typ), (*n).typ);
				tmp_2 = newTempVar__9crPEzQBTT3GMtBXwq7HxMg(ctx, (*n).typ);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A((&(*ctx)), (*n)._kind_6.sons->data[((NI) 0)], tmp_2));
				{
					NI i_13;
					NI colontmp__7;
					NI i_14;
					i_13 = (NI)0;
					colontmp__7 = (NI)0;
					colontmp__7 = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_14 = ((NI) 1);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch_2;
							if (!(i_14 < colontmp__7)) goto LA107;
							i_13 = i_14;
							branch_2 = (*n)._kind_6.sons->data[i_13];
							switch ((*branch_2).kind) {
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87):
							{
								{
									if (!((*(*branch_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4))) goto LA111_;
									asgnRef((void**) (&(*branch_2)._kind_6.sons->data[((NI) 1)]), convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A((&(*ctx)), (*branch_2)._kind_6.sons->data[((NI) 1)], tmp_2));
								}
								goto LA109_;
								LA111_: ;
								{
									asgnRef((void**) (&(*branch_2)._kind_6.sons->data[((NI) 0)]), convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A((&(*ctx)), (*branch_2)._kind_6.sons->data[((NI) 0)], tmp_2));
								}
								LA109_: ;
							}
							break;
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107):
							{
							}
							break;
							default:
							{
								NimStringDesc* T116_;
								T116_ = (NimStringDesc*)0;
								T116_ = rawNewString((reprEnum((NI)(*branch_2).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*branch_2).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 30);
appendString(T116_, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_12));
appendString(T116_, reprEnum((NI)(*branch_2).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T116_, TM__slVvvIjx75ivXdMpHiE9c9aQ_13);
							}
							break;
							}
							i_14 += ((NI) 1);
						} LA107: ;
					}
				}
				add__P8dDSotTW25BkfbyspojGg(result, n);
				T117_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T117_ = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp_2);
				add__P8dDSotTW25BkfbyspojGg(result, T117_);
			}
			LA103_: ;
		}
		LA98_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		NIM_BOOL ns_5;
		ns_5 = NIM_FALSE;
		{
			NI i_15;
			NI colontmp__8;
			NI i_16;
			i_15 = (NI)0;
			colontmp__8 = (NI)0;
			colontmp__8 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_16 = ((NI) 0);
			{
				while (1) {
					if (!(i_16 < colontmp__8)) goto LA121;
					i_15 = i_16;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_15]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_15], (&ns_5)));
					i_16 += ((NI) 1);
				} LA121: ;
			}
		}
		{
			NIM_BOOL isExpr_3;
			NIM_BOOL T126_;
			if (!ns_5) goto LA124_;
			(*needsSplit) = NIM_TRUE;
			T126_ = (NIM_BOOL)0;
			T126_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			isExpr_3 = !(T126_);
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmp_3;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T145_;
				if (!isExpr_3) goto LA129_;
				tmp_3 = newTempVar__9crPEzQBTT3GMtBXwq7HxMg(ctx, (*n).typ);
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
				asgnRef((void**) (&(*result).typ), (*n).typ);
				{
					tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T135_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_5;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_4;
					if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA133_;
					nimZeroMem((void*)(&T135_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
					exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T135_));
					st_5 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					st_5 = T135_.Field0;
					ex_4 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					ex_4 = T135_.Field1;
					add__P8dDSotTW25BkfbyspojGg(result, st_5);
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex_4);
				}
				LA133_: ;
				{
					NI i_17;
					NI colontmp__9;
					NI i_18;
					i_17 = (NI)0;
					colontmp__9 = (NI)0;
					colontmp__9 = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_18 = ((NI) 1);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch_3;
							if (!(i_18 < colontmp__9)) goto LA138;
							i_17 = i_18;
							branch_3 = (*n)._kind_6.sons->data[i_17];
							switch ((*branch_3).kind) {
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
							{
								NI T140_;
								NI T141_;
								T140_ = (NI)0;
								T140_ = len__P89cqdlERShb9alU3iC0yj8wast(branch_3);
								T141_ = (NI)0;
								T141_ = len__P89cqdlERShb9alU3iC0yj8wast(branch_3);
								asgnRef((void**) (&(*branch_3)._kind_6.sons->data[(NI)(T140_ - ((NI) 1))]), convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A((&(*ctx)), (*branch_3)._kind_6.sons->data[(NI)(T141_ - ((NI) 1))], tmp_3));
							}
							break;
							case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
							{
								asgnRef((void**) (&(*branch_3)._kind_6.sons->data[((NI) 0)]), convertExprBodyToAsgn__8iK2FV1BxkbejgFIhd9an1A((&(*ctx)), (*branch_3)._kind_6.sons->data[((NI) 0)], tmp_3));
							}
							break;
							default:
							{
								NimStringDesc* T144_;
								T144_ = (NimStringDesc*)0;
								T144_ = rawNewString((reprEnum((NI)(*branch_3).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*branch_3).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 31);
appendString(T144_, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_14));
appendString(T144_, reprEnum((NI)(*branch_3).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T144_, TM__slVvvIjx75ivXdMpHiE9c9aQ_15);
							}
							break;
							}
							i_18 += ((NI) 1);
						} LA138: ;
					}
				}
				add__P8dDSotTW25BkfbyspojGg(result, n);
				T145_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T145_ = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp_3);
				add__P8dDSotTW25BkfbyspojGg(result, T145_);
			}
			LA129_: ;
		}
		LA124_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	{
		NIM_BOOL ns_6;
		ns_6 = NIM_FALSE;
		{
			NI i_19;
			NI colontmp__10;
			NI i_20;
			i_19 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_20 = ((NI) 0);
			{
				while (1) {
					if (!(i_20 < colontmp__10)) goto LA149;
					i_19 = i_20;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_19]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_19], (&ns_6)));
					i_20 += ((NI) 1);
				} LA149: ;
			}
		}
		{
			NIM_BOOL isExpr_4;
			NIM_BOOL T154_;
			if (!ns_6) goto LA152_;
			(*needsSplit) = NIM_TRUE;
			T154_ = (NIM_BOOL)0;
			T154_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			isExpr_4 = !(T154_);
			{
				if (!isExpr_4) goto LA157_;
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
				asgnRef((void**) (&(*result).typ), (*n).typ);
			}
			goto LA155_;
			LA157_: ;
			{
				result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			}
			LA155_: ;
			{
				NIM_BOOL T162_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmp_4;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T171_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* check;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBody;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T181_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBranch;
				tyArray__AB6yfoUgfWM2NtGe9bzkCmw T182_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifNode;
				tyArray__jlWPjgtbdjE069arIWHC9c9bg T183_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T184_;
				T162_ = (NIM_BOOL)0;
				T162_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T162_)) goto LA163_;
				T162_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109) || (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110));
				LA163_: ;
				if (!T162_) goto LA164_;
				cond = (*n)._kind_6.sons->data[((NI) 1)];
				{
					tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T170_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_6;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_5;
					if (!((*cond).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA168_;
					nimZeroMem((void*)(&T170_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
					exprToStmtList__GrcFG9bOeET47xEWduCWw0g(cond, (&T170_));
					st_6 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					st_6 = T170_.Field0;
					ex_5 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					ex_5 = T170_.Field1;
					add__P8dDSotTW25BkfbyspojGg(result, st_6);
					cond = ex_5;
				}
				LA168_: ;
				tmp_4 = newTempVar__9crPEzQBTT3GMtBXwq7HxMg(ctx, (*cond).typ);
				T171_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T171_ = newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg((&(*ctx)), tmp_4, cond);
				add__P8dDSotTW25BkfbyspojGg(result, T171_);
				check = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp_4);
				{
					if (!((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110))) goto LA174_;
					check = newNotCall__qb0UTd3LRTRUDLaWZGAI3w((*ctx).g, check);
				}
				LA174_: ;
				cond = (*n)._kind_6.sons->data[((NI) 2)];
				ifBody = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*cond).info);
				{
					tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T180_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_7;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_6;
					if (!((*cond).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA178_;
					nimZeroMem((void*)(&T180_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
					exprToStmtList__GrcFG9bOeET47xEWduCWw0g(cond, (&T180_));
					st_7 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					st_7 = T180_.Field0;
					ex_6 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					ex_6 = T180_.Field1;
					add__P8dDSotTW25BkfbyspojGg(ifBody, st_7);
					cond = ex_6;
				}
				LA178_: ;
				T181_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T181_ = newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg((&(*ctx)), tmp_4, cond);
				add__P8dDSotTW25BkfbyspojGg(ifBody, T181_);
				nimZeroMem((void*)T182_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
				T182_[0] = check;
				T182_[1] = ifBody;
				ifBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T182_, 2);
				nimZeroMem((void*)T183_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
				T183_[0] = ifBranch;
				ifNode = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T183_, 1);
				add__P8dDSotTW25BkfbyspojGg(result, ifNode);
				T184_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T184_ = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp_4);
				add__P8dDSotTW25BkfbyspojGg(result, T184_);
			}
			goto LA160_;
			LA164_: ;
			{
				{
					NI i_21;
					NI colontmp__11;
					NI i_22;
					i_21 = (NI)0;
					colontmp__11 = (NI)0;
					colontmp__11 = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_22 = ((NI) 0);
					{
						while (1) {
							if (!(i_22 < colontmp__11)) goto LA188;
							i_21 = i_22;
							{
								tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T193_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_8;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_7;
								if (!((*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA191_;
								nimZeroMem((void*)(&T193_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
								exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[i_21], (&T193_));
								st_8 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								st_8 = T193_.Field0;
								ex_7 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								ex_7 = T193_.Field1;
								add__P8dDSotTW25BkfbyspojGg(result, st_8);
								asgnRef((void**) (&(*n)._kind_6.sons->data[i_21]), ex_7);
							}
							LA191_: ;
							{
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmp_5;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T198_;
								if (!((*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*(*n)._kind_6.sons->data[i_21]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA196_;
								tmp_5 = newTempVar__9crPEzQBTT3GMtBXwq7HxMg(ctx, (*(*n)._kind_6.sons->data[i_21]).typ);
								T198_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T198_ = newEnvVarAsgn__DGZgiXKrd7mdarKGWpCBJg((&(*ctx)), tmp_5, (*n)._kind_6.sons->data[i_21]);
								add__P8dDSotTW25BkfbyspojGg(result, T198_);
								asgnRef((void**) (&(*n)._kind_6.sons->data[i_21]), newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), tmp_5));
							}
							LA196_: ;
							i_22 += ((NI) 1);
						} LA188: ;
					}
				}
				add__P8dDSotTW25BkfbyspojGg(result, n);
			}
			LA160_: ;
		}
		LA152_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
			c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_23;
				NI colontmp__12;
				NI i_24;
				i_23 = (NI)0;
				colontmp__12 = (NI)0;
				colontmp__12 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_24 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSect;
						NIM_BOOL ns_7;
						NI T204_;
						NI T205_;
						if (!(i_24 < colontmp__12)) goto LA203;
						i_23 = i_24;
						c = (*n)._kind_6.sons->data[i_23];
						varSect = newNodeI__vokyXY9cZDshCSxFKChhG9bg((*n).kind, (*n).info);
						add__P8dDSotTW25BkfbyspojGg(varSect, c);
						ns_7 = NIM_FALSE;
						T204_ = (NI)0;
						T204_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
						T205_ = (NI)0;
						T205_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
						asgnRef((void**) (&(*c)._kind_6.sons->data[(NI)(T204_ - ((NI) 1))]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*c)._kind_6.sons->data[(NI)(T205_ - ((NI) 1))], (&ns_7)));
						{
							NI T210_;
							tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T211_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_9;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_8;
							NI T212_;
							if (!ns_7) goto LA208_;
							(*needsSplit) = NIM_TRUE;
							T210_ = (NI)0;
							T210_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
							nimZeroMem((void*)(&T211_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
							exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*c)._kind_6.sons->data[(NI)(T210_ - ((NI) 1))], (&T211_));
							st_9 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							st_9 = T211_.Field0;
							ex_8 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							ex_8 = T211_.Field1;
							add__P8dDSotTW25BkfbyspojGg(result, st_9);
							T212_ = (NI)0;
							T212_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
							asgnRef((void**) (&(*c)._kind_6.sons->data[(NI)(T212_ - ((NI) 1))]), ex_8);
						}
						LA208_: ;
						add__P8dDSotTW25BkfbyspojGg(result, varSect);
						i_24 += ((NI) 1);
					} LA203: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		NIM_BOOL ns_8;
		ns_8 = NIM_FALSE;
		{
			NI i_25;
			NI colontmp__13;
			NI i_26;
			i_25 = (NI)0;
			colontmp__13 = (NI)0;
			colontmp__13 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_26 = ((NI) 0);
			{
				while (1) {
					if (!(i_26 < colontmp__13)) goto LA216;
					i_25 = i_26;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_25]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_25], (&ns_8)));
					i_26 += ((NI) 1);
				} LA216: ;
			}
		}
		{
			tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T221_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_10;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_9;
			if (!ns_8) goto LA219_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			nimZeroMem((void*)(&T221_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
			exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T221_));
			st_10 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			st_10 = T221_.Field0;
			ex_9 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			ex_9 = T221_.Field1;
			add__P8dDSotTW25BkfbyspojGg(result, st_10);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex_9);
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA219_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		NIM_BOOL ns_9;
		ns_9 = NIM_FALSE;
		{
			NI i_27;
			NI colontmp__14;
			NI colontmp__15;
			NI i_28;
			i_27 = (NI)0;
			colontmp__14 = (NI)0;
			colontmp__15 = (NI)0;
			colontmp__14 = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61));
			colontmp__15 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_28 = colontmp__14;
			{
				while (1) {
					if (!(i_28 < colontmp__15)) goto LA225;
					i_27 = i_28;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_27]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_27], (&ns_9)));
					i_28 += ((NI) 1);
				} LA225: ;
			}
		}
		{
			NI T230_;
			tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T231_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_11;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_10;
			NI T232_;
			if (!ns_9) goto LA228_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
			asgnRef((void**) (&(*result).typ), (*n).typ);
			T230_ = (NI)0;
			T230_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			nimZeroMem((void*)(&T231_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
			exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[(NI)(T230_ - ((NI) 1))], (&T231_));
			st_11 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			st_11 = T231_.Field0;
			ex_10 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			ex_10 = T231_.Field1;
			add__P8dDSotTW25BkfbyspojGg(result, st_11);
			T232_ = (NI)0;
			T232_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T232_ - ((NI) 1))]), ex_10);
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA228_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		NIM_BOOL ns_10;
		ns_10 = NIM_FALSE;
		{
			NI i_29;
			NI colontmp__16;
			NI i_30;
			i_29 = (NI)0;
			colontmp__16 = (NI)0;
			colontmp__16 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_30 = ((NI) 0);
			{
				while (1) {
					if (!(i_30 < colontmp__16)) goto LA236;
					i_29 = i_30;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_29]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_29], (&ns_10)));
					i_30 += ((NI) 1);
				} LA236: ;
			}
		}
		{
			if (!ns_10) goto LA239_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			{
				tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T245_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_12;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_11;
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA243_;
				nimZeroMem((void*)(&T245_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
				exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T245_));
				st_12 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				st_12 = T245_.Field0;
				ex_11 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ex_11 = T245_.Field1;
				add__P8dDSotTW25BkfbyspojGg(result, st_12);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex_11);
			}
			LA243_: ;
			{
				tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T250_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_13;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_12;
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA248_;
				nimZeroMem((void*)(&T250_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
				exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 1)], (&T250_));
				st_13 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				st_13 = T250_.Field0;
				ex_12 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ex_12 = T250_.Field1;
				add__P8dDSotTW25BkfbyspojGg(result, st_13);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), ex_12);
			}
			LA248_: ;
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA239_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		NIM_BOOL lhsNeedsSplit;
		NIM_BOOL rhsNeedsSplit;
		lhsNeedsSplit = NIM_FALSE;
		rhsNeedsSplit = NIM_FALSE;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 0)], (&lhsNeedsSplit)));
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 1)], (&rhsNeedsSplit)));
		{
			NIM_BOOL T254_;
			T254_ = (NIM_BOOL)0;
			T254_ = lhsNeedsSplit;
			if (T254_) goto LA255_;
			T254_ = rhsNeedsSplit;
			LA255_: ;
			if (!T254_) goto LA256_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
			{
				tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T262_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_14;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_13;
				if (!lhsNeedsSplit) goto LA260_;
				nimZeroMem((void*)(&T262_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
				exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T262_));
				st_14 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				st_14 = T262_.Field0;
				ex_13 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ex_13 = T262_.Field1;
				add__P8dDSotTW25BkfbyspojGg(result, st_14);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex_13);
			}
			LA260_: ;
			{
				tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T267_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_15;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_14;
				if (!rhsNeedsSplit) goto LA265_;
				nimZeroMem((void*)(&T267_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
				exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 1)], (&T267_));
				st_15 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				st_15 = T267_.Field0;
				ex_14 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ex_14 = T267_.Field1;
				add__P8dDSotTW25BkfbyspojGg(result, st_15);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), ex_14);
			}
			LA265_: ;
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA256_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		NIM_BOOL condNeedsSplit;
		NIM_BOOL bodyNeedsSplit;
		condNeedsSplit = NIM_FALSE;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 0)], (&condNeedsSplit)));
		bodyNeedsSplit = NIM_FALSE;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 1)], (&bodyNeedsSplit)));
		{
			NIM_BOOL T271_;
			T271_ = (NIM_BOOL)0;
			T271_ = condNeedsSplit;
			if (T271_) goto LA272_;
			T271_ = bodyNeedsSplit;
			LA272_: ;
			if (!T271_) goto LA273_;
			(*needsSplit) = NIM_TRUE;
			{
				tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T279_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_16;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_15;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* brk;
				tyArray__jlWPjgtbdjE069arIWHC9c9bg T280_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch_4;
				tyArray__AB6yfoUgfWM2NtGe9bzkCmw T281_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* check_2;
				tyArray__jlWPjgtbdjE069arIWHC9c9bg T282_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newBody;
				tyArray__T6RKPw8xfAeNaoei9aZGzXg T283_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T284_;
				if (!condNeedsSplit) goto LA277_;
				nimZeroMem((void*)(&T279_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
				exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T279_));
				st_16 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				st_16 = T279_.Field0;
				ex_15 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ex_15 = T279_.Field1;
				nimZeroMem((void*)T280_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
				T280_[0] = (*(*ctx).g).emptyNode;
				brk = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110), T280_, 1);
				nimZeroMem((void*)T281_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
				T281_[0] = newNotCall__qb0UTd3LRTRUDLaWZGAI3w((*ctx).g, ex_15);
				T281_[1] = brk;
				branch_4 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T281_, 2);
				nimZeroMem((void*)T282_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
				T282_[0] = branch_4;
				check_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T282_, 1);
				nimZeroMem((void*)T283_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
				T283_[0] = st_16;
				T283_[1] = check_2;
				T283_[2] = (*n)._kind_6.sons->data[((NI) 1)];
				newBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T283_, 3);
				T284_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T284_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*ctx).g, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_17));
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T284_));
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newBody);
			}
			LA277_: ;
		}
		LA273_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		NIM_BOOL ns_11;
		ns_11 = NIM_FALSE;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 0)], (&ns_11)));
		{
			tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T290_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_17;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_16;
			if (!ns_11) goto LA288_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
			asgnRef((void**) (&(*result).typ), (*n).typ);
			nimZeroMem((void*)(&T290_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
			exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 0)], (&T290_));
			st_17 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			st_17 = T290_.Field0;
			ex_16 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			ex_16 = T290_.Field1;
			add__P8dDSotTW25BkfbyspojGg(result, st_17);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ex_16);
			add__P8dDSotTW25BkfbyspojGg(result, n);
		}
		LA288_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		NIM_BOOL ns_12;
		ns_12 = NIM_FALSE;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[((NI) 1)], (&ns_12)));
		{
			tyTuple__EFqgCXJ4d8PgqOdFJmldsQ T296_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* st_18;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex_17;
			if (!ns_12) goto LA294_;
			(*needsSplit) = NIM_TRUE;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info);
			asgnRef((void**) (&(*result).typ), (*n).typ);
			nimZeroMem((void*)(&T296_), sizeof(tyTuple__EFqgCXJ4d8PgqOdFJmldsQ));
			exprToStmtList__GrcFG9bOeET47xEWduCWw0g((*n)._kind_6.sons->data[((NI) 1)], (&T296_));
			st_18 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			st_18 = T296_.Field0;
			ex_17 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			ex_17 = T296_.Field1;
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 112));
			asgnRef((void**) (&(*n).typ), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), st_18);
			add__P8dDSotTW25BkfbyspojGg(result, n);
			add__P8dDSotTW25BkfbyspojGg(result, ex_17);
		}
		LA294_: ;
	}
	break;
	default:
	{
		{
			NI i_31;
			NI colontmp__17;
			NI i_32;
			i_31 = (NI)0;
			colontmp__17 = (NI)0;
			colontmp__17 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_32 = ((NI) 0);
			{
				while (1) {
					if (!(i_32 < colontmp__17)) goto LA300;
					i_31 = i_32;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_31]), lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ(ctx, (*n)._kind_6.sons->data[i_31], needsSplit));
					i_32 += ((NI) 1);
				} LA300: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasYields__SoLjz0OznJM6S0ACeFDkTg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
			c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA7;
						i = i_2;
						c = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T10_;
							T10_ = (NIM_BOOL)0;
							T10_ = hasYields__SoLjz0OznJM6S0ACeFDkTg_2(c);
							if (!T10_) goto LA11_;
							result = NIM_TRUE;
							goto LA4;
						}
						LA11_: ;
						i_2 += ((NI) 1);
					} LA7: ;
				}
			}
		} LA4: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			if (!T5_) goto LA6_;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
				c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA11;
							i = i_2;
							c = (*n)._kind_6.sons->data[i];
							{
								NIM_BOOL T14_;
								T14_ = (NIM_BOOL)0;
								T14_ = hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg(c);
								if (!T14_) goto LA15_;
								result = NIM_TRUE;
								goto BeforeRet_;
							}
							LA15_: ;
							i_2 += ((NI) 1);
						} LA11: ;
					}
				}
			}
		}
		goto LA3_;
		LA6_: ;
		{
			result = hasYields__SoLjz0OznJM6S0ACeFDkTg_2(n);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA21;
					i_3 = i_4;
					{
						NIM_BOOL T24_;
						T24_ = (NIM_BOOL)0;
						T24_ = hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg((*n)._kind_6.sons->data[i_3]);
						if (!T24_) goto LA25_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA25_: ;
					i_4 += ((NI) 1);
				} LA21: ;
			}
		}
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c_2;
			c_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA31;
						i_5 = i_6;
						c_2 = (*n)._kind_6.sons->data[i_5];
						{
							NIM_BOOL T34_;
							T34_ = (NIM_BOOL)0;
							T34_ = hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg(c_2);
							if (!T34_) goto LA35_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA35_: ;
						i_6 += ((NI) 1);
					} LA31: ;
				}
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = toStmtList__BSqD59bZdLojBsNEMT9aVzXw(n);
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		T3_ = (T4_ == ((NI) 0));
		if (T3_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		T3_ = !(((*(*result)._kind_6.sons->data[(NI)(T6_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156)));
		LA5_: ;
		if (!T3_) goto LA7_;
		add__P8dDSotTW25BkfbyspojGg(result, gotoOut);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreaksAndContinuesInWhile__PPKdLcsjHM2xtTQ57VQRdQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* before, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* after) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111):
	{
		result = before;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	{
		(*ctx).blockLevel += ((NI) 1);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), transformBreaksAndContinuesInWhile__PPKdLcsjHM2xtTQ57VQRdQ(ctx, (*result)._kind_6.sons->data[((NI) 1)], before, after));
		(*ctx).blockLevel -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		{
			if (!((*ctx).blockLevel == ((NI) 0))) goto LA8_;
			result = after;
		}
		LA8_: ;
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), transformBreaksAndContinuesInWhile__PPKdLcsjHM2xtTQ57VQRdQ(ctx, (*n)._kind_6.sons->data[i], before, after));
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreaksInBlock__U5wYjNmg2Tmx1BJW2OE3eA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* label, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* after) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		(*ctx).blockLevel += ((NI) 1);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), transformBreaksInBlock__U5wYjNmg2Tmx1BJW2OE3eA(ctx, (*result)._kind_6.sons->data[((NI) 1)], label, after));
		(*ctx).blockLevel -= ((NI) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA6_;
			{
				if (!((*ctx).blockLevel == ((NI) 0))) goto LA10_;
				result = after;
			}
			LA10_: ;
		}
		goto LA4_;
		LA6_: ;
		{
			{
				NIM_BOOL T15_;
				T15_ = (NIM_BOOL)0;
				T15_ = ((*label).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T15_)) goto LA16_;
				T15_ = ((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym == (*label)._kind_4.sym);
				LA16_: ;
				if (!T15_) goto LA17_;
				result = after;
			}
			LA17_: ;
		}
		LA4_: ;
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA22;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), transformBreaksInBlock__U5wYjNmg2Tmx1BJW2OE3eA(ctx, (*n)._kind_6.sons->data[i], label, after));
					i_2 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	break;
	}
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newOr__lX4ijAVTzsRg8N1Lp9atJqQclosureiters)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyArray__T6RKPw8xfAeNaoei9aZGzXg T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, (*a).info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_24), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110));
	T1_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T2_);
	T1_[1] = a;
	T1_[2] = b;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T1_, 3);
	asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*a).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	(*result).info = (*a).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCurExcAccess__cqBE2u681LMwPlL6VXs4dA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!((*ctx).curExcSym == 0)) goto LA3_;
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw((*ctx).g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_23), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		unsureAsgnRef((void**) (&(*ctx).curExcSym), newEnvVar__33upYIjNEK4gS1UIzFj0Qw(ctx, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_25), (*T5_).typ));
	}
	LA3_: ;
	result = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), (*ctx).curExcSym);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNullifyCurExc__FlUh1Xo9bXJFuG43AoVOEVw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* curExc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nilnode;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	curExc = newCurExcAccess__cqBE2u681LMwPlL6VXs4dA(ctx);
	(*curExc).info = info;
	nilnode = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	asgnRef((void**) (&(*nilnode).typ), (*curExc).typ);
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T1_[0] = curExc;
	T1_[1] = nilnode;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T1_, 2);
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, collectExceptState__eyQv3n2M3569coxZwjgCbIwclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifStmt;
	tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	ifStmt = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), (*n).info);
	g = (*ctx).g;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
		c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					c = (*n)._kind_6.sons->data[i];
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBranch;
						NI T32_;
						if (!((*c).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87))) goto LA7_;
						ifBranch = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						{
							NI T11_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond;
							T11_ = (NI)0;
							T11_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
							if (!(((NI) 1) < T11_)) goto LA12_;
							cond = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							{
								NI i_3;
								NI colontmp__2;
								NI T15_;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								T15_ = (NI)0;
								T15_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
								colontmp__2 = (NI)(T15_ - ((NI) 1));
								i_4 = ((NI) 0);
								{
									while (1) {
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nextCond;
										tyArray__T6RKPw8xfAeNaoei9aZGzXg T18_;
										tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T19_;
										if (!(i_4 < colontmp__2)) goto LA17;
										i_3 = i_4;
										nimZeroMem((void*)T18_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
										T19_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
										T19_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, (*c).info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_22), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 15));
										T18_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T19_);
										T18_[1] = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_23), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
										T18_[2] = (*c)._kind_6.sons->data[i_3];
										nextCond = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T18_, 3);
										asgnRef((void**) (&(*nextCond).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, (*c).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
										(*nextCond).info = (*c).info;
										{
											if (!(cond == 0)) goto LA22_;
											cond = nextCond;
										}
										goto LA20_;
										LA22_: ;
										{
											cond = newOr__lX4ijAVTzsRg8N1Lp9atJqQclosureiters(g, cond, nextCond);
										}
										LA20_: ;
										i_4 += ((NI) 1);
									} LA17: ;
								}
							}
							ifBranch = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), (*c).info);
							add__P8dDSotTW25BkfbyspojGg(ifBranch, cond);
						}
						goto LA9_;
						LA12_: ;
						{
							{
								NI T28_;
								T28_ = (NI)0;
								T28_ = len__P89cqdlERShb9alU3iC0yj8wast(ifStmt);
								if (!(T28_ == ((NI) 0))) goto LA29_;
								ifStmt = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*c).info);
								ifBranch = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*c).info);
							}
							goto LA26_;
							LA29_: ;
							{
								ifBranch = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), (*c).info);
							}
							LA26_: ;
						}
						LA9_: ;
						T32_ = (NI)0;
						T32_ = len__P89cqdlERShb9alU3iC0yj8wast(c);
						add__P8dDSotTW25BkfbyspojGg(ifBranch, (*c)._kind_6.sons->data[(NI)(T32_ - ((NI) 1))]);
						add__P8dDSotTW25BkfbyspojGg(ifStmt, ifBranch);
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		NI T35_;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T38_;
		T35_ = (NI)0;
		T35_ = len__P89cqdlERShb9alU3iC0yj8wast(ifStmt);
		if (!!((T35_ == ((NI) 0)))) goto LA36_;
		nimZeroMem((void*)T38_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T38_[0] = newNullifyCurExc__FlUh1Xo9bXJFuG43AoVOEVw(ctx, (*n).info);
		T38_[1] = ifStmt;
		result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T38_, 2);
	}
	goto LA33_;
	LA36_: ;
	{
		result = (*(*ctx).g).emptyNode;
	}
	LA33_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getFinallyNode__oib8dpvzVeiy5KmNWs9ajBw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	result = (*n)._kind_6.sons->data[(NI)(T1_ - ((NI) 1))];
	{
		if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA4_;
		result = (*result)._kind_6.sons->data[((NI) 0)];
	}
	goto LA2_;
	LA4_: ;
	{
		result = (*(*ctx).g).emptyNode;
	}
	LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		if (!((*ctx).unrollFinallySym == 0)) goto LA3_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
		unsureAsgnRef((void**) (&(*ctx).unrollFinallySym), newEnvVar__33upYIjNEK4gS1UIzFj0Qw(ctx, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_26), T5_));
	}
	LA3_: ;
	result = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), (*ctx).unrollFinallySym);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTmpResultAccess__cqBE2u681LMwPlL6VXs4dA_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*ctx).tmpResultSym == 0)) goto LA3_;
		unsureAsgnRef((void**) (&(*ctx).tmpResultSym), newEnvVar__33upYIjNEK4gS1UIzFj0Qw(ctx, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_27), (*(*(*ctx).fn).typ).sons->data[((NI) 0)]));
	}
	LA3_: ;
	result = newEnvVarAccess__7rupMNyLb9cZQT0jVrPTGUw((&(*ctx)), (*ctx).tmpResultSym);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* goto_1;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T17_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgn;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
			asgn = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info);
			T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T3_ = newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2(ctx, (*n).info);
			add__P8dDSotTW25BkfbyspojGg(asgn, T3_);
			T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T4_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
			T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T5_ = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(1), T4_);
			add__P8dDSotTW25BkfbyspojGg(asgn, T5_);
			add__P8dDSotTW25BkfbyspojGg(result, asgn);
		}
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgnTmpResult;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA8_;
			asgnTmpResult = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info);
			T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T10_ = newTmpResultAccess__cqBE2u681LMwPlL6VXs4dA_2(ctx);
			add__P8dDSotTW25BkfbyspojGg(asgnTmpResult, T10_);
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74))) goto LA13_;
				x = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
			}
			goto LA11_;
			LA13_: ;
			{
				x = (*n)._kind_6.sons->data[((NI) 0)];
			}
			LA11_: ;
			add__P8dDSotTW25BkfbyspojGg(asgnTmpResult, x);
			add__P8dDSotTW25BkfbyspojGg(result, asgnTmpResult);
		}
		LA8_: ;
		T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T16_ = newNullifyCurExc__FlUh1Xo9bXJFuG43AoVOEVw(ctx, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T16_);
		nimZeroMem((void*)T17_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T17_[0] = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, (*n).info, ((NI64) ((*ctx).nearestFinally)));
		goto_1 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), T17_, 1);
		add__P8dDSotTW25BkfbyspojGg(result, goto_1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA22;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2(ctx, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA22: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEndFinallyNode__FlUh1Xo9bXJFuG43AoVOEVw_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* curExc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nilnode;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cmp;
	tyArray__T6RKPw8xfAeNaoei9aZGzXg T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgn;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T3_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T4_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* retStmt;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T5_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T6_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nullifyExc;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T7_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T8_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* raiseStmt;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T9_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T10_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T11_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBody;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T12_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elifBranch;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T13_;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T14_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	curExc = newCurExcAccess__cqBE2u681LMwPlL6VXs4dA(ctx);
	nilnode = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	asgnRef((void**) (&(*nilnode).typ), (*curExc).typ);
	nimZeroMem((void*)T1_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*ctx).g, info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_28), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 87));
	T1_[0] = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T2_, info);
	T1_[1] = curExc;
	T1_[2] = nilnode;
	cmp = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T1_, 3);
	asgnRef((void**) (&(*cmp).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	nimZeroMem((void*)T3_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T4_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T4_ = getClosureIterResult__9coyF0wpG1VqYcJq7Zk1fgQ_2((*ctx).g, (*ctx).fn);
	T3_[0] = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T4_, info);
	T3_[1] = newTmpResultAccess__cqBE2u681LMwPlL6VXs4dA_2(ctx);
	asgn = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), T3_, 2);
	nimZeroMem((void*)T5_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T5_[0] = asgn;
	retStmt = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109), T5_, 1);
	nimZeroMem((void*)T6_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T6_[0] = cmp;
	T6_[1] = retStmt;
	branch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T6_, 2);
	nimZeroMem((void*)T7_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T8_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T8_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*ctx).g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_29));
	T7_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T8_);
	T7_[1] = nilnode;
	nullifyExc = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T7_, 2);
	(*nullifyExc).info = info;
	nimZeroMem((void*)T9_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T9_[0] = curExc;
	raiseStmt = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108), T9_, 1);
	(*raiseStmt).info = info;
	nimZeroMem((void*)T10_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	nimZeroMem((void*)T11_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T11_[0] = nullifyExc;
	T11_[1] = raiseStmt;
	T10_[0] = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T11_, 2);
	elseBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), T10_, 1);
	nimZeroMem((void*)T12_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T12_[0] = branch;
	T12_[1] = elseBranch;
	ifBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T12_, 2);
	nimZeroMem((void*)T13_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T13_[0] = newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2(ctx, info);
	T13_[1] = ifBody;
	elifBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T13_, 2);
	(*elifBranch).info = info;
	nimZeroMem((void*)T14_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T14_[0] = elifBranch;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T14_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addElseToExcept__ZQwdGiE9bcxShuJtHMjr5sQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchBody;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T20_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 1)]);
		T3_ = !(((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[(NI)(T7_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88)));
		LA6_: ;
		if (!T3_) goto LA8_;
		branchBody = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		{
			tyArray__AB6yfoUgfWM2NtGe9bzkCmw T11_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
			nimZeroMem((void*)T11_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
			T11_[0] = newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2(ctx, (*n).info);
			T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T12_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
			T11_[1] = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(1), T12_);
			T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T13_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T11_, 2);
			add__P8dDSotTW25BkfbyspojGg(branchBody, T13_);
		}
		{
			tyArray__AB6yfoUgfWM2NtGe9bzkCmw T15_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
			nimZeroMem((void*)T15_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
			T15_[0] = newCurExcAccess__cqBE2u681LMwPlL6VXs4dA(ctx);
			T15_[1] = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw((*ctx).g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_23), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T16_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T15_, 2);
			add__P8dDSotTW25BkfbyspojGg(branchBody, T16_);
		}
		{
			tyArray__jlWPjgtbdjE069arIWHC9c9bg T18_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
			nimZeroMem((void*)T18_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
			T18_[0] = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, (*n).info, ((NI64) ((*ctx).nearestFinally)));
			T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T19_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), T18_, 1);
			add__P8dDSotTW25BkfbyspojGg(branchBody, T19_);
		}
		nimZeroMem((void*)T20_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T20_[0] = branchBody;
		elseBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), T20_, 1);
		add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 1)], elseBranch);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		result = addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg(result, gotoOut);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					{
						NIM_BOOL T8_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* go;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
						NI T14_;
						T8_ = (NIM_BOOL)0;
						T8_ = hasYields__SoLjz0OznJM6S0ACeFDkTg_2((*n)._kind_6.sons->data[i]);
						if (!T8_) goto LA9_;
						go = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), (*(*n)._kind_6.sons->data[i]).info);
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*n)._kind_6.sons->data[i], go));
						s = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*(*n)._kind_6.sons->data[(NI)(i + ((NI) 1))]).info);
						{
							NI j;
							NI colontmp__2;
							NI colontmp__3;
							NI i_3;
							j = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__2 = (NI)(i + ((NI) 1));
							colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
							i_3 = colontmp__2;
							{
								while (1) {
									if (!(i_3 < colontmp__3)) goto LA13;
									j = i_3;
									add__P8dDSotTW25BkfbyspojGg(s, (*n)._kind_6.sons->data[j]);
									i_3 += ((NI) 1);
								} LA13: ;
							}
						}
						asgnRef((void**) (&(*n)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*n)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(i + ((NI) 1))))));
						T14_ = (NI)0;
						T14_ = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, s, go);
						(void)(T14_);
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
							T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T17_ = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, s, gotoOut);
							if (!!((T17_ == s))) goto LA18_;
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_20), TM__slVvvIjx75ivXdMpHiE9c9aQ_21);
						}
						LA18_: ;
						goto LA3;
					}
					LA9_: ;
					i_2 += ((NI) 1);
				} LA5: ;
			}
		} LA3: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, n);
		add__P8dDSotTW25BkfbyspojGg(result, gotoOut);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 50):
	{
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg((*result)._kind_6.sons->data[((NI) 0)], gotoOut));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*result)._kind_6.sons->data[((NI) 0)], gotoOut));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 49):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
	{
		NI T23_;
		NI T24_;
		NI T25_;
		NI T26_;
		T23_ = (NI)0;
		T23_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		T24_ = (NI)0;
		T24_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		asgnRef((void**) (&(*result)._kind_6.sons->data[(NI)(T23_ - ((NI) 1))]), addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg((*result)._kind_6.sons->data[(NI)(T24_ - ((NI) 1))], gotoOut));
		T25_ = (NI)0;
		T25_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		T26_ = (NI)0;
		T26_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		asgnRef((void**) (&(*result)._kind_6.sons->data[(NI)(T25_ - ((NI) 1))]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*result)._kind_6.sons->data[(NI)(T26_ - ((NI) 1))], gotoOut));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		{
			NI i_4;
			NI colontmp__4;
			NI i_5;
			i_4 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_5 = ((NI) 0);
			{
				while (1) {
					if (!(i_5 < colontmp__4)) goto LA30;
					i_4 = i_5;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_4]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*n)._kind_6.sons->data[i_4], gotoOut));
					i_5 += ((NI) 1);
				} LA30: ;
			}
		}
		{
			NI T33_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch;
			tyArray__jlWPjgtbdjE069arIWHC9c9bg T36_;
			T33_ = (NI)0;
			T33_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!(((*(*n)._kind_6.sons->data[(NI)(T33_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88)))) goto LA34_;
			nimZeroMem((void*)T36_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
			T36_[0] = gotoOut;
			elseBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), T36_, 1);
			add__P8dDSotTW25BkfbyspojGg(n, elseBranch);
		}
		LA34_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s_2;
		NI T38_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifNode;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elifBranch;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch_2;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T39_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), (*n).info);
		s_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		T38_ = (NI)0;
		T38_ = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, s_2, result);
		(void)(T38_);
		ifNode = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), (*n).info);
		elifBranch = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(elifBranch, (*n)._kind_6.sons->data[((NI) 0)]);
		body = addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg((*n)._kind_6.sons->data[((NI) 1)], result);
		body = transformBreaksAndContinuesInWhile__PPKdLcsjHM2xtTQ57VQRdQ(ctx, body, result, gotoOut);
		body = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, body, result);
		add__P8dDSotTW25BkfbyspojGg(elifBranch, body);
		add__P8dDSotTW25BkfbyspojGg(ifNode, elifBranch);
		nimZeroMem((void*)T39_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T39_[0] = gotoOut;
		elseBranch_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), T39_, 1);
		add__P8dDSotTW25BkfbyspojGg(ifNode, elseBranch_2);
		add__P8dDSotTW25BkfbyspojGg(s_2, ifNode);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	{
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), addGotoOut__uiricCrNr2Dq4G7jk4l9b9cg((*result)._kind_6.sons->data[((NI) 1)], gotoOut));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), transformBreaksInBlock__U5wYjNmg2Tmx1BJW2OE3eA(ctx, (*result)._kind_6.sons->data[((NI) 1)], (*result)._kind_6.sons->data[((NI) 0)], gotoOut));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*result)._kind_6.sons->data[((NI) 1)], gotoOut));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tryBody;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptBody;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* finallyBody;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T42_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
		NI tryIdx;
		NI T44_;
		NI exceptIdx;
		NI finallyIdx;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* outToFinally;
		(*ctx).hasExceptions = NIM_TRUE;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), (*n).info);
		tryBody = toStmtList__BSqD59bZdLojBsNEMT9aVzXw((*n)._kind_6.sons->data[((NI) 0)]);
		exceptBody = collectExceptState__eyQv3n2M3569coxZwjgCbIwclosureiters(ctx, n);
		nimZeroMem((void*)T42_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T42_[0] = getFinallyNode__oib8dpvzVeiy5KmNWs9ajBw(ctx, n);
		finallyBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T42_, 1);
		finallyBody = transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2(ctx, finallyBody);
		T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T43_ = newEndFinallyNode__FlUh1Xo9bXJFuG43AoVOEVw_3(ctx, (*finallyBody).info);
		add__P8dDSotTW25BkfbyspojGg(finallyBody, T43_);
		T44_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
		tryIdx = T44_;
		exceptIdx = (NI)0;
		finallyIdx = (NI)0;
		{
			if (!!(((*exceptBody).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA47_;
			exceptIdx = ((NI32)-((NI)(tryIdx + ((NI) 1))));
			finallyIdx = (NI)(tryIdx + ((NI) 2));
		}
		goto LA45_;
		LA47_: ;
		{
			exceptIdx = (NI)(tryIdx + ((NI) 1));
			finallyIdx = (NI)(tryIdx + ((NI) 1));
		}
		LA45_: ;
		outToFinally = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), (*finallyBody).info);
		{
			NI oldExcHandlingState;
			NI realTryIdx;
			NI realFinallyIdx;
			oldExcHandlingState = (*ctx).curExcHandlingState;
			(*ctx).curExcHandlingState = exceptIdx;
			realTryIdx = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, tryBody, result);
			{
				NI realExceptIdx;
				if (!!(((*exceptBody).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA53_;
				(*ctx).curExcHandlingState = finallyIdx;
				realExceptIdx = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, exceptBody, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			}
			LA53_: ;
			(*ctx).curExcHandlingState = oldExcHandlingState;
			realFinallyIdx = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, finallyBody, outToFinally);
		}
		{
			NI oldNearestFinally;
			NI oldExcHandlingState_2;
			oldNearestFinally = (*ctx).nearestFinally;
			(*ctx).nearestFinally = finallyIdx;
			oldExcHandlingState_2 = (*ctx).curExcHandlingState;
			(*ctx).curExcHandlingState = exceptIdx;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T58_;
				T58_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T58_ = transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2(ctx, tryBody);
				if (!!((T58_ == tryBody))) goto LA59_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_30), TM__slVvvIjx75ivXdMpHiE9c9aQ_31);
			}
			LA59_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T63_;
				T63_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T63_ = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, tryBody, outToFinally);
				if (!!((T63_ == tryBody))) goto LA64_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_32), TM__slVvvIjx75ivXdMpHiE9c9aQ_33);
			}
			LA64_: ;
			(*ctx).curExcHandlingState = finallyIdx;
			addElseToExcept__ZQwdGiE9bcxShuJtHMjr5sQ(ctx, exceptBody);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T68_;
				T68_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T68_ = transformReturnsInTry__oib8dpvzVeiy5KmNWs9ajBw_2(ctx, exceptBody);
				if (!!((T68_ == exceptBody))) goto LA69_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_34), TM__slVvvIjx75ivXdMpHiE9c9aQ_35);
			}
			LA69_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T73_;
				T73_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T73_ = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, exceptBody, outToFinally);
				if (!!((T73_ == exceptBody))) goto LA74_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_36), TM__slVvvIjx75ivXdMpHiE9c9aQ_37);
			}
			LA74_: ;
			(*ctx).curExcHandlingState = oldExcHandlingState_2;
			(*ctx).nearestFinally = oldNearestFinally;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T78_;
				T78_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T78_ = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, finallyBody, gotoOut);
				if (!!((T78_ == finallyBody))) goto LA79_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_38), TM__slVvvIjx75ivXdMpHiE9c9aQ_39);
			}
			LA79_: ;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	{
		NimStringDesc* T82_;
		T82_ = (NimStringDesc*)0;
		T82_ = rawNewString((reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 13);
appendString(T82_, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_40));
appendString(T82_, reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*ctx).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T82_, TM__slVvvIjx75ivXdMpHiE9c9aQ_41);
	}
	break;
	default:
	{
		{
			NI i_6;
			NI colontmp__5;
			NI i_7;
			i_6 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_7 = ((NI) 0);
			{
				while (1) {
					if (!(i_7 < colontmp__5)) goto LA86;
					i_6 = i_7;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_6]), transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw(ctx, (*n)._kind_6.sons->data[i_6], gotoOut));
					i_7 += ((NI) 1);
				} LA86: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipStmtList__aKHUfk8lGnMfwXRkkphHzQ)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA2;
			{
				NI T5_;
				T5_ = (NI)0;
				T5_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
				if (!(T5_ == ((NI) 0))) goto LA6_;
				result = (*(*ctx).g).emptyNode;
				goto BeforeRet_;
			}
			LA6_: ;
			result = (*result)._kind_6.sons->data[((NI) 0)];
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, skipEmptyStates__Pi4UWe7a9cL5b9cA6VgWjduw)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NI stateIdx) {
	NI result;
	NI maxJumps;
	NI T1_;
	NI stateIdx_2;
	result = (NI)0;
	T1_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
	maxJumps = T1_;
	stateIdx_2 = stateIdx;
	{
		while (1) {
			NI label;
			NI newLabel;
			label = stateIdx_2;
			{
				if (!(label == (*ctx).exitStateIdx)) goto LA6_;
				goto LA2;
			}
			LA6_: ;
			newLabel = label;
			{
				if (!(label == ((NI) -1))) goto LA10_;
				newLabel = (*ctx).exitStateIdx;
			}
			goto LA8_;
			LA10_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fs;
				fs = skipStmtList__aKHUfk8lGnMfwXRkkphHzQ(ctx, (*(*ctx).states->data[label])._kind_6.sons->data[((NI) 1)]);
				{
					if (!((*fs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156))) goto LA15_;
					newLabel = ((NI) ((*(*fs)._kind_6.sons->data[((NI) 0)])._kind_1.intVal));
				}
				LA15_: ;
			}
			LA8_: ;
			{
				if (!(label == newLabel)) goto LA19_;
				goto LA2;
			}
			LA19_: ;
			stateIdx_2 = newLabel;
			maxJumps -= ((NI) 1);
			{
				if (!(maxJumps == ((NI) 0))) goto LA23_;
			}
			LA23_: ;
		}
	} LA2: ;
	result = ((NI) ((*(*(*ctx).states->data[stateIdx_2])._kind_6.sons->data[((NI) 0)])._kind_1.intVal));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipThroughEmptyStates__oib8dpvzVeiy5KmNWs9ajBw_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	{
		NI T3_;
		result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		T3_ = (NI)0;
		T3_ = skipEmptyStates__Pi4UWe7a9cL5b9cA6VgWjduw((&(*ctx)), ((NI) ((*(*result)._kind_6.sons->data[((NI) 0)])._kind_1.intVal)));
		(*(*result)._kind_6.sons->data[((NI) 0)])._kind_1.intVal = ((NI64) (T3_));
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), skipThroughEmptyStates__oib8dpvzVeiy5KmNWs9ajBw_3(ctx, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, deleteEmptyStates__EtZNQZ9ahFW9aGXseKeYzr0Q)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* goOut;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T1_;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T2_;
	NI iValid;
	NI i_5;
	nimZeroMem((void*)T1_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	T1_[0] = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, T2_, IL64(-1));
	goOut = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), T1_, 1);
	(*ctx).exitStateIdx = newState__KR326D2V0A9c8rAN3F9amGLQ(ctx, goOut, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	iValid = ((NI) 0);
	{
		NI i;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
		NI i_2;
		NI L;
		NI T4_;
		i = (NI)0;
		s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		i_2 = ((NI) 0);
		T4_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
		L = T4_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
				if (!(i_2 < L)) goto LA6;
				i = i_2;
				s = (*ctx).states->data[i_2];
				body = skipStmtList__aKHUfk8lGnMfwXRkkphHzQ((&(*ctx)), (*s)._kind_6.sons->data[((NI) 1)]);
				{
					NIM_BOOL T9_;
					NIM_BOOL T10_;
					NI T12_;
					T9_ = (NIM_BOOL)0;
					T10_ = (NIM_BOOL)0;
					T10_ = ((*body).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156));
					if (!(T10_)) goto LA11_;
					T12_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
					T10_ = !((i == (NI)(T12_ - ((NI) 1))));
					LA11_: ;
					T9_ = T10_;
					if (!(T9_)) goto LA13_;
					T9_ = !((i == ((NI) 0)));
					LA13_: ;
					if (!T9_) goto LA14_;
					(*(*s)._kind_6.sons->data[((NI) 0)])._kind_1.intVal = IL64(-1);
				}
				goto LA7_;
				LA14_: ;
				{
					(*(*s)._kind_6.sons->data[((NI) 0)])._kind_1.intVal = ((NI64) (iValid));
					iValid += ((NI) 1);
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA6: ;
		}
	}
	{
		NI i_3;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s_2;
		NI i_4;
		NI L_2;
		NI T18_;
		i_3 = (NI)0;
		s_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		i_4 = ((NI) 0);
		T18_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
		L_2 = T18_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body_2;
				if (!(i_4 < L_2)) goto LA20;
				i_3 = i_4;
				s_2 = (*ctx).states->data[i_4];
				body_2 = skipStmtList__aKHUfk8lGnMfwXRkkphHzQ((&(*ctx)), (*s_2)._kind_6.sons->data[((NI) 1)]);
				{
					NIM_BOOL T23_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
					NI excHandlState;
					T23_ = (NIM_BOOL)0;
					T23_ = !(((*body_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156)));
					if (T23_) goto LA24_;
					T23_ = (i_3 == ((NI) 0));
					LA24_: ;
					if (!T23_) goto LA25_;
					T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T27_ = skipThroughEmptyStates__oib8dpvzVeiy5KmNWs9ajBw_3(ctx, s_2);
					(void)(T27_);
					excHandlState = (*ctx).exceptionTable->data[i_3];
					{
						NI T32_;
						if (!(excHandlState < ((NI) 0))) goto LA30_;
						T32_ = (NI)0;
						T32_ = skipEmptyStates__Pi4UWe7a9cL5b9cA6VgWjduw((&(*ctx)), ((NI32)-(excHandlState)));
						(*ctx).exceptionTable->data[i_3] = ((NI32)-(T32_));
					}
					goto LA28_;
					LA30_: ;
					{
						if (!!((excHandlState == ((NI) 0)))) goto LA34_;
						(*ctx).exceptionTable->data[i_3] = skipEmptyStates__Pi4UWe7a9cL5b9cA6VgWjduw((&(*ctx)), excHandlState);
					}
					goto LA28_;
					LA34_: ;
					LA28_: ;
				}
				LA25_: ;
				i_4 += ((NI) 1);
			} LA20: ;
		}
	}
	i_5 = ((NI) 0);
	{
		while (1) {
			NI T38_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fs;
			T38_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
			if (!(i_5 < (NI)(T38_ - ((NI) 1)))) goto LA37;
			fs = skipStmtList__aKHUfk8lGnMfwXRkkphHzQ((&(*ctx)), (*(*ctx).states->data[i_5])._kind_6.sons->data[((NI) 1)]);
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = ((*fs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156));
				if (!(T41_)) goto LA42_;
				T41_ = !((i_5 == ((NI) 0)));
				LA42_: ;
				if (!T41_) goto LA43_;
				delete__erP7uc8MMOTSdwsQSiTshg((&(*ctx).states), ((NI) (i_5)));
				delete__g2oR0TynFEFPrKXixkkfzA((&(*ctx).exceptionTable), ((NI) (i_5)));
			}
			goto LA39_;
			LA43_: ;
			{
				i_5 += ((NI) 1);
			}
			LA39_: ;
		} LA37: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAccess__cqBE2u681LMwPlL6VXs4dA_3)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		if (!((*ctx).stateVarSym == 0)) goto LA3_;
		T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T5_ = getEnvParam__0hs55xLsSn1sbFSXWwel1A((*ctx).fn);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T5_);
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = getStateField__UJpIDWVzs220Reaf7HOAmw((*ctx).g, (*ctx).fn);
		result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(T6_, T7_, (*(*ctx).fn).info);
	}
	goto LA1_;
	LA3_: ;
	{
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*ctx).stateVarSym);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAssgn__AWbFLel9cjt8d7ZAwfIyCdA)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* toValue) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T1_[0] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
	T1_[1] = toValue;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T1_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStateAssgn__Mi9crg20nwOahuXiRT6sVew)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, NI stateNo) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, T1_, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T3_ = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(((NI64) (stateNo)), T2_);
	result = newStateAssgn__AWbFLel9cjt8d7ZAwfIyCdA(ctx, T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, stateFromGotoState__mq9bimW9b7LrVw9b9a6qcSmGUA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	result = ((NI) ((*(*n)._kind_6.sons->data[((NI) 0)])._kind_1.intVal));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformStateAssignments__oib8dpvzVeiy5KmNWs9ajBw_4)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			NIM_BOOL T4_;
			NI T5_;
			NI T9_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* retStmt;
			T4_ = (NIM_BOOL)0;
			T5_ = (NI)0;
			T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T4_ = !((T5_ == ((NI) 0)));
			if (!(T4_)) goto LA6_;
			T4_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104));
			LA6_: ;
			if (!T4_) goto LA7_;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
			T9_ = (NI)0;
			T9_ = stateFromGotoState__mq9bimW9b7LrVw9b9a6qcSmGUA((*n)._kind_6.sons->data[((NI) 1)]);
			T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T10_ = newStateAssgn__Mi9crg20nwOahuXiRT6sVew(ctx, T9_);
			add__P8dDSotTW25BkfbyspojGg(result, T10_);
			retStmt = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109), (*n).info);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* retVal;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T15_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
				if (!!(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA13_;
				a = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).info);
				retVal = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
				T15_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T15_ = getClosureIterResult__9coyF0wpG1VqYcJq7Zk1fgQ_2((*ctx).g, (*ctx).fn);
				T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T16_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T15_);
				add__P8dDSotTW25BkfbyspojGg(a, T16_);
				add__P8dDSotTW25BkfbyspojGg(a, retVal);
				add__P8dDSotTW25BkfbyspojGg(retStmt, a);
			}
			goto LA11_;
			LA13_: ;
			{
				add__P8dDSotTW25BkfbyspojGg(retStmt, (*(*ctx).g).emptyNode);
			}
			LA11_: ;
			add__P8dDSotTW25BkfbyspojGg(result, retStmt);
		}
		goto LA2_;
		LA7_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA21;
						i = i_2;
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), transformStateAssignments__oib8dpvzVeiy5KmNWs9ajBw_4(ctx, (*n)._kind_6.sons->data[i]));
						i_2 += ((NI) 1);
					} LA21: ;
				}
			}
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T24_ = newStateAssgn__Mi9crg20nwOahuXiRT6sVew(ctx, ((NI) -1));
		add__P8dDSotTW25BkfbyspojGg(result, T24_);
		add__P8dDSotTW25BkfbyspojGg(result, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	{
		NI T26_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* breakState;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
		T26_ = (NI)0;
		T26_ = stateFromGotoState__mq9bimW9b7LrVw9b9a6qcSmGUA(n);
		T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T27_ = newStateAssgn__Mi9crg20nwOahuXiRT6sVew(ctx, T26_);
		add__P8dDSotTW25BkfbyspojGg(result, T27_);
		breakState = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110), (*n).info);
		T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T28_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*ctx).stateLoopLabel);
		add__P8dDSotTW25BkfbyspojGg(breakState, T28_);
		add__P8dDSotTW25BkfbyspojGg(result, breakState);
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA32;
					i_3 = i_4;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), transformStateAssignments__oib8dpvzVeiy5KmNWs9ajBw_4(ctx, (*n)._kind_6.sons->data[i_3]));
					i_4 += ((NI) 1);
				} LA32: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newArrayType__642gHRMR9a1eZ1whzH7tKfQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rng;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), owner);
	rng = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), owner);
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T1_[0] = newIntLit__TuFlkTIoJNHT6fCcycYtSw(g, (*owner).info, IL64(0));
	T1_[1] = newIntLit__TuFlkTIoJNHT6fCcycYtSw(g, (*owner).info, ((NI64) (n)));
	asgnRef((void**) (&(*rng).n), newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), T1_, 2));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(rng, t, NIM_TRUE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, rng, NIM_TRUE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, t, NIM_TRUE);
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createExceptionTable__MszPr5bFWBE4wcbymAi00gclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*(*ctx).fn).info);
	T1_ = ((*ctx).exceptionTable ? (*ctx).exceptionTable->Sup.len : 0);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, (*(*ctx).fn).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33));
	asgnRef((void**) (&(*result).typ), newArrayType__642gHRMR9a1eZ1whzH7tKfQ((*ctx).g, T1_, T2_, (*ctx).fn));
	{
		NI* i;
		NI i_2;
		NI L;
		NI T4_;
		i = (NI*)0;
		i_2 = ((NI) 0);
		T4_ = ((*ctx).exceptionTable ? (*ctx).exceptionTable->Sup.len : 0);
		L = T4_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elem;
				if (!(i_2 < L)) goto LA6;
				i = (&(*ctx).exceptionTable->data[i_2]);
				elem = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) ((*i))));
				asgnRef((void**) (&(*elem).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, (*(*ctx).fn).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33)));
				add__P8dDSotTW25BkfbyspojGg(result, elem);
				i_2 += ((NI) 1);
			} LA6: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCatchBody__MnQ8Kzhxn5rtRo9btObf9b9bgclosureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intTyp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boolTyp;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), info);
	intTyp = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	boolTyp = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*ctx).g, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* getNextState;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T2_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
		nimZeroMem((void*)T2_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T2_[0] = createExceptionTable__MszPr5bFWBE4wcbymAi00gclosureiters(ctx);
		T2_[1] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
		getNextState = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), T2_, 2);
		asgnRef((void**) (&(*getNextState).typ), intTyp);
		T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T3_ = newStateAssgn__AWbFLel9cjt8d7ZAwfIyCdA(ctx, getNextState);
		add__P8dDSotTW25BkfbyspojGg(result, T3_);
	}
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond;
		tyArray__T6RKPw8xfAeNaoei9aZGzXg T5_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* raiseStmt;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBranch;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T8_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifStmt;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T9_;
		nimZeroMem((void*)T5_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
		T6_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T6_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*ctx).g, info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_28), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 70));
		T5_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T6_);
		T5_[1] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
		T5_[2] = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(0), intTyp);
		cond = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T5_, 3);
		asgnRef((void**) (&(*cond).typ), boolTyp);
		nimZeroMem((void*)T7_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T7_[0] = (*(*ctx).g).emptyNode;
		raiseStmt = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108), T7_, 1);
		nimZeroMem((void*)T8_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T8_[0] = cond;
		T8_[1] = raiseStmt;
		ifBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T8_, 2);
		nimZeroMem((void*)T9_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T9_[0] = ifBranch;
		ifStmt = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T9_, 1);
		add__P8dDSotTW25BkfbyspojGg(result, ifStmt);
	}
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond_2;
		tyArray__T6RKPw8xfAeNaoei9aZGzXg T11_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgn;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T13_;
		nimZeroMem((void*)T11_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
		T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T12_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*ctx).g, info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_42), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 72));
		T11_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T12_);
		T11_[1] = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(0), intTyp);
		T11_[2] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
		cond_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T11_, 3);
		asgnRef((void**) (&(*cond_2).typ), boolTyp);
		nimZeroMem((void*)T13_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T13_[0] = newUnrollFinallyAccess__FlUh1Xo9bXJFuG43AoVOEVw_2(ctx, info);
		T13_[1] = cond_2;
		asgn = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T13_, 2);
		add__P8dDSotTW25BkfbyspojGg(result, asgn);
	}
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cond_3;
		tyArray__T6RKPw8xfAeNaoei9aZGzXg T15_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T16_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* negateState;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T17_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T18_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifBranch_2;
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T19_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifStmt_2;
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T20_;
		nimZeroMem((void*)T15_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
		T16_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T16_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*ctx).g, info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_42), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 72));
		T15_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T16_);
		T15_[1] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
		T15_[2] = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(0), intTyp);
		cond_3 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T15_, 3);
		asgnRef((void**) (&(*cond_3).typ), boolTyp);
		nimZeroMem((void*)T17_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T18_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T18_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg((*ctx).g, info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_43), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93));
		T17_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T18_);
		T17_[1] = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
		negateState = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T17_, 2);
		asgnRef((void**) (&(*negateState).typ), intTyp);
		nimZeroMem((void*)T19_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T19_[0] = cond_3;
		T19_[1] = newStateAssgn__AWbFLel9cjt8d7ZAwfIyCdA(ctx, negateState);
		ifBranch_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), T19_, 2);
		nimZeroMem((void*)T20_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T20_[0] = ifBranch_2;
		ifStmt_2 = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), T20_, 1);
		add__P8dDSotTW25BkfbyspojGg(result, ifStmt_2);
	}
	{
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T22_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T23_;
		nimZeroMem((void*)T22_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T22_[0] = newCurExcAccess__cqBE2u681LMwPlL6VXs4dA(ctx);
		T22_[1] = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw((*ctx).g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_23), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		T23_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T23_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), T22_, 2);
		add__P8dDSotTW25BkfbyspojGg(result, T23_);
	}
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapIntoTryExcept__eyQv3n2M3569coxZwjgCbIw_2closureiters)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* setupExc;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tryBody;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T3_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptBranch;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T4_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T5_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*ctx).g, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_29));
	T1_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T2_);
	T1_[1] = newCurExcAccess__cqBE2u681LMwPlL6VXs4dA(ctx);
	setupExc = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T1_, 2);
	nimZeroMem((void*)T3_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T3_[0] = setupExc;
	T3_[1] = n;
	tryBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T3_, 2);
	nimZeroMem((void*)T4_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T4_[0] = newCatchBody__MnQ8Kzhxn5rtRo9btObf9b9bgclosureiters(ctx, (*(*ctx).fn).info);
	exceptBranch = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87), T4_, 1);
	nimZeroMem((void*)T5_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T5_[0] = tryBody;
	T5_[1] = exceptBranch;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106), T5_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapIntoStateLoop__oib8dpvzVeiy5KmNWs9ajBw_5)(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A* ctx, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* localVars;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* blockStmt;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gs;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
	NI T14_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* blockBody;
	tyArray__T6RKPw8xfAeNaoei9aZGzXg T16_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	loopBody = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	nimZeroMem((void*)T1_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*ctx).g, (*n).info, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_17));
	T1_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T2_);
	T1_[1] = loopBody;
	result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96), T1_, 2);
	(*result).info = (*n).info;
	localVars = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSect;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
		if (!!(((*ctx).stateVarSym == 0))) goto LA5_;
		varSect = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
		T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T7_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*ctx).stateVarSym);
		addVar__qOCBdprWtK4hxer73SEdQA(varSect, T7_);
		add__P8dDSotTW25BkfbyspojGg(localVars, varSect);
		{
			if (!!(((*ctx).tempVars == 0))) goto LA10_;
			add__P8dDSotTW25BkfbyspojGg(localVars, (*ctx).tempVars);
		}
		LA10_: ;
	}
	LA5_: ;
	blockStmt = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112), (*n).info);
	T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T12_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*ctx).stateLoopLabel);
	add__P8dDSotTW25BkfbyspojGg(blockStmt, T12_);
	gs = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), (*n).info);
	T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T13_ = newStateAccess__cqBE2u681LMwPlL6VXs4dA_3(ctx);
	add__P8dDSotTW25BkfbyspojGg(gs, T13_);
	T14_ = ((*ctx).states ? (*ctx).states->Sup.len : 0);
	T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T15_ = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*ctx).g, (*n).info, ((NI64) ((NI)(T14_ - ((NI) 1)))));
	add__P8dDSotTW25BkfbyspojGg(gs, T15_);
	nimZeroMem((void*)T16_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
	T16_[0] = gs;
	T16_[1] = localVars;
	T16_[2] = n;
	blockBody = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T16_, 3);
	{
		if (!(*ctx).hasExceptions) goto LA19_;
		blockBody = wrapIntoTryExcept__eyQv3n2M3569coxZwjgCbIw_2closureiters(ctx, blockBody);
	}
	LA19_: ;
	add__P8dDSotTW25BkfbyspojGg(blockStmt, blockBody);
	add__P8dDSotTW25BkfbyspojGg(loopBody, blockStmt);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformClosureIterator__pOvzY9bL6Z9bAquTmdZOUhVg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A ctx;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T7_;
	tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw pc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
	NI T9_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gotoOut;
	tyArray__jlWPjgtbdjE069arIWHC9c9bg T10_;
	NIM_BOOL ns;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&ctx), sizeof(tyObject_Ctx__Sws9awoFPhDR7PA2lS1LQ5A));
	ctx.g = g;
	ctx.fn = fn;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T3_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T6_;
		T3_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T3_ = getEnvParam__0hs55xLsSn1sbFSXWwel1A(fn);
		if (!(T3_ == 0)) goto LA4_;
		T6_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T6_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*ctx.g).cache, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_2));
		ctx.stateVarSym = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T6_, fn, (*fn).info, 0);
		asgnRef((void**) (&(*ctx.stateVarSym).typ), createClosureIterStateType__YeSbRn4y243XNGGtCU6V6g(g, fn));
	}
	LA4_: ;
	T7_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T7_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*ctx.g).cache, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_3));
	ctx.stateLoopLabel = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22), T7_, fn, (*fn).info, 0);
	nimZeroMem((void*)(&pc), sizeof(tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw));
	nimZeroMem((void*)(&pc), sizeof(tyObject_PreprocessContext__ATjkivkWYrBstrMNxiy9cNw));
	pc.finallys = NIM_NIL;
	pc.config = (*g).config;
	T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T8_ = toStmtList__BSqD59bZdLojBsNEMT9aVzXw(n);
	n_2 = preprocess__9aCtw9bmmWcjV9crnPaXp5CIQ((&pc), T8_);
	T9_ = (NI)0;
	T9_ = newState__KR326D2V0A9c8rAN3F9amGLQ((&ctx), n_2, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	(void)(T9_);
	nimZeroMem((void*)T10_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
	T10_[0] = newIntLit__TuFlkTIoJNHT6fCcycYtSw(g, (*n_2).info, IL64(-1));
	gotoOut = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156), T10_, 1);
	ns = NIM_FALSE;
	n_2 = lowerStmtListExprs__07BK9ckM1VeGOvUAxlv1trQ((&ctx), n_2, (&ns));
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = hasYieldsInExpressions__SoLjz0OznJM6S0ACeFDkTg(n_2);
		if (!T13_) goto LA14_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*ctx.g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__slVvvIjx75ivXdMpHiE9c9aQ_18), TM__slVvvIjx75ivXdMpHiE9c9aQ_19);
	}
	LA14_: ;
	T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T16_ = transformClosureIteratorBody__k5LaXCtaUIFKCXefatVZPw((&ctx), n_2, gotoOut);
	(void)(T16_);
	deleteEmptyStates__EtZNQZ9ahFW9aGXseKeYzr0Q((&ctx));
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n_2).info);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s;
		NI i;
		NI L;
		NI T18_;
		s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		i = ((NI) 0);
		T18_ = (ctx.states ? ctx.states->Sup.len : 0);
		L = T18_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
				if (!(i < L)) goto LA20;
				s = &ctx.states->data[i];
				body = (*(*s))._kind_6.sons->data[((NI) 1)];
				del__erP7uc8MMOTSdwsQSiTshg_2((&(*(*s))._kind_6.sons), ((NI) 1));
				add__P8dDSotTW25BkfbyspojGg(result, (*s));
				add__P8dDSotTW25BkfbyspojGg(result, body);
				i += ((NI) 1);
			} LA20: ;
		}
	}
	result = transformStateAssignments__oib8dpvzVeiy5KmNWs9ajBw_4((&ctx), result);
	result = wrapIntoStateLoop__oib8dpvzVeiy5KmNWs9ajBw_5((&ctx), result);
	return result;
}
