/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tySequence__SHVxAqOYtIy7teT1q4s0zQ tySequence__SHVxAqOYtIy7teT1q4s0zQ;
typedef struct tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow;
typedef struct tyObject_Table__6nOsw5R7jH72bux7HSST9bg tyObject_Table__6nOsw5R7jH72bux7HSST9bg;
typedef struct tySequence__diqJJ1bWuFP7M6rQDS9cBLQ tySequence__diqJJ1bWuFP7M6rQDS9cBLQ;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA;
typedef struct tySequence__sII3pVVRkIdBZ2HDPdZddA tySequence__sII3pVVRkIdBZ2HDPdZddA;
typedef struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A;
typedef struct tySequence__WPcy3bORPBFlmk2KIq2pbQ tySequence__WPcy3bORPBFlmk2KIq2pbQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q;
typedef struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A;
typedef struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q tySequence__vhmj4KkIKPinmRXny9c2Q6Q;
typedef struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ;
typedef struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ tySequence__XUL1TrMU0tgXmaMFCIYgFQ;
typedef struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__KjgUMUjT3LUKOFIK4xt5ug tySequence__KjgUMUjT3LUKOFIK4xt5ug;
typedef struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg tySequence__WwUFq9cJ2xKRlsAWVEHyPRg;
typedef struct tySequence__oUyaggHmIX9bpJcMeoG6lpA tySequence__oUyaggHmIX9bpJcMeoG6lpA;
typedef struct tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TBlock__GFhahvekTq3dDOkWyhchMA tyObject_TBlock__GFhahvekTq3dDOkWyhchMA;
typedef struct tyTuple__FxkU4d1VDodDMc9ah6Mbagw tyTuple__FxkU4d1VDodDMc9ah6Mbagw;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyTuple__Iz0jrTw3w7v6sMzjrqs0nA tyTuple__Iz0jrTw3w7v6sMzjrqs0nA;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__5L3fCt9bX0gyEcO30ervPLw tyTuple__5L3fCt9bX0gyEcO30ervPLw;
typedef struct tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg;
typedef struct tyTuple__yByxe8FSFNTgs4tcAkTYag tyTuple__yByxe8FSFNTgs4tcAkTYag;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ tySequence__shxop0zPIs5Ec3k71aCLuQ;
typedef struct tyTuple__nsNHL3sm0TZE9bootw2pEXw tyTuple__nsNHL3sm0TZE9bootw2pEXw;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tySequence__sno9c9bXUVS2CqhtWOJadaCw tySequence__sno9c9bXUVS2CqhtWOJadaCw;
typedef struct tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyTuple__UpiOGlu5Ux6DLM73wSrdpg;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__4keOEuB8uAwYehpErwqI9ag tyTuple__4keOEuB8uAwYehpErwqI9ag;
typedef struct tyTuple__wROVfG5RQYpjEAhvO3LqdQ tyTuple__wROVfG5RQYpjEAhvO3LqdQ;
typedef struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA tyTuple__a1QJSSO0LTGR9bFH59c2xGCA;
typedef struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg;
typedef struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_Table__6nOsw5R7jH72bux7HSST9bg {
tySequence__diqJJ1bWuFP7M6rQDS9cBLQ* data;
NI counter;
};
struct tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainModProcs;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainModInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* otherModsInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainDatInit;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mapping;
tySequence__SHVxAqOYtIy7teT1q4s0zQ* modules;
tySequence__SHVxAqOYtIy7teT1q4s0zQ* modulesClosed;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* forwardedProcs;
tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* generatedHeader;
tyObject_Table__6nOsw5R7jH72bux7HSST9bg typeInfoMarker;
tyObject_Table__6nOsw5R7jH72bux7HSST9bg typeInfoMarkerV2;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
NI strVersion;
NI seqVersion;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nimtv;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* nimtvDeps;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg nimtvDeclared;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__pujFC2IN5RzE4MXkqaMD9aQ[20];
typedef NU8 tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA {
tySequence__sII3pVVRkIdBZ2HDPdZddA* data;
NI counter;
};
struct tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A {
tySequence__WPcy3bORPBFlmk2KIq2pbQ* data;
NI counter;
};
struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A {
NI counter;
tySequence__vhmj4KkIKPinmRXny9c2Q6Q* data;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__MxT2Arb3Nlp7V9bRITO3dvg[10];
struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ {
tySequence__XUL1TrMU0tgXmaMFCIYgFQ* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw {
NIM_BOOL enabled;
FILE* f;
NimStringDesc* buf;
NimStringDesc* filename;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* syms;
};
struct tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyArray__pujFC2IN5RzE4MXkqaMD9aQ s;
tySet_tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q flags;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
NimStringDesc* filename;
NimStringDesc* cfilename;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpBase;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeCache;
tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A typeABICache;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA forwTypeCache;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg declaredThings;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg declaredProtos;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* headerFiles;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeInfoMarker;
tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA typeInfoMarkerV2;
tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* initProc;
tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* preInitProc;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* hcrCreateTypeInfosProc;
NIM_BOOL inHcrInitGuard;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeStack;
tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A dataCache;
NI typeNodes;
NI nimTypes;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typeNodesName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nimTypesName;
NI labels;
tyArray__MxT2Arb3Nlp7V9bRITO3dvg extensionLoaders;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* injectStmt;
tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ sigConflicts;
tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g;
tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw ndi;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ;
struct tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg {
tySequence__jwzrUFjG9akTIJTBBFvvqxw* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
tySet_tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ flags;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q currLineInfo;
tySequence__KjgUMUjT3LUKOFIK4xt5ug* nestedTryStmts;
tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* finallySafePoints;
NI labels;
tySequence__oUyaggHmIX9bpJcMeoG6lpA* blocks;
NI breakIdx;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* module;
NI withinLoop;
NI splitDecls;
NI withinTryWithExcept;
NI withinBlockLeaveActions;
tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg sigConflicts;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ;
typedef NU8 tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q;
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__c9b9aKKmyKnqxZD8lAny45jg[3];
struct tyObject_TBlock__GFhahvekTq3dDOkWyhchMA {
NI id;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* label;
tyArray__c9b9aKKmyKnqxZD8lAny45jg sections;
NIM_BOOL isLoop;
NI16 nestedTryStmts;
NI16 nestedExceptStmts;
NI16 frameLen;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__JiWwrsTRC6xqNlGcBthSVA[1];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__qTjAvTvKF9anytN1At69aJMQ[1];
typedef NU8 tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg;
struct tyTuple__FxkU4d1VDodDMc9ah6Mbagw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NIM_BOOL Field1;
NI Field2;
};
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
typedef NU8 tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ;
struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA {
tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path;
};
typedef NU8 tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg;
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef NU8 tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__mrugoXXRZUEeG9bEXo9auBKw[2];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__duFhZXIIlrbrM62cWjNekg[5];
typedef NimStringDesc* tyArray__t1sx1FVcaX4m77XqENedIQ[11];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__wqYjTJU9ab2ZgEFMaQc3vNA[3];
typedef NU8 tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw;
typedef NU8 tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw;
struct tyTuple__Iz0jrTw3w7v6sMzjrqs0nA {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NU8 tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg;
struct tyTuple__5L3fCt9bX0gyEcO30ervPLw {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
tySet_tyEnum_TInfoOSProp__thetQwB9agpeQ13qFmAcWhg Field12;
};
typedef tyTuple__5L3fCt9bX0gyEcO30ervPLw tyArray__geAxQ09aiJ4i2plLZEkYDpg[31];
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__dNfZYyzVYdaWfURv4pxodA[6];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__f7nG5LD47BH5K9c6mASit3g[4];
struct tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg {
tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
NimStringDesc* visitorFrmt;
};
typedef NU8 tySet_tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg;
struct tyTuple__yByxe8FSFNTgs4tcAkTYag {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
NimStringDesc* Field12;
NimStringDesc* Field13;
NimStringDesc* Field14;
NimStringDesc* Field15;
NimStringDesc* Field16;
NimStringDesc* Field17;
NimStringDesc* Field18;
NimStringDesc* Field19;
NimStringDesc* Field20;
tySet_tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg Field21;
};
typedef tyTuple__yByxe8FSFNTgs4tcAkTYag tyArray__sa9aJ6U8e9b7Bj4Yq8itsR8w[11];
typedef NU8 tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__YcHYlgE5mhtkt9a3rnoucVg[7];
typedef NU8 tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw;
typedef NU8 tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw;
typedef NU8 tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw;
typedef NU8 tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg;
typedef NimStringDesc* tyArray__Sjq0yxKksnvb1U6tEMqzYg[14];
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ;
struct tyTuple__nsNHL3sm0TZE9bootw2pEXw {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field1;
};
typedef NU8 tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NimStringDesc* tyArray__ttGk45MsSAdGt9ciYdRA8VQ[4];
typedef NimStringDesc* tyArray__rJSOG9bfI5wi9aqXvYJsFCWA[7];
typedef NimStringDesc* tyArray__cqX2jO1YLR9bYjA09bx8BZVg[2];
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NimStringDesc* tyArray__B06a0PrPRpY9aXtMPObCiCA[5];
typedef NU8 tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
struct tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA {
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA Field0;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw {
  RootObj Sup;
NI colonstate_;
tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m1;
};
typedef struct {
N_NIMCALL_PTR(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, ClP_0) (NimStringDesc* handle, NimStringDesc* name, void* ClE_0);
void* ClE_0;
} tyProc__G7yv7dCrMxuDBcXNy2RR1w;
typedef N_CLOSURE_PTR(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, TM__MQdRN7fpbG7rPm4JpVVAhA_846) (NimStringDesc* handle, NimStringDesc* name);
typedef N_CLOSURE_PTR(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, TM__MQdRN7fpbG7rPm4JpVVAhA_850) (NimStringDesc* handle, NimStringDesc* name);
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
typedef NU8 tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg;
struct tyTuple__UpiOGlu5Ux6DLM73wSrdpg {
NimStringDesc* Field0;
NI Field1;
tyEnum_TEndian__bQ3yFYQJojZPNYsZnS7Zjg Field2;
NI Field3;
NI Field4;
};
typedef tyTuple__UpiOGlu5Ux6DLM73wSrdpg tyArray__8d8P9caia9cszVjIJKsQGMQA[25];
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__4keOEuB8uAwYehpErwqI9ag {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyTuple__Iz0jrTw3w7v6sMzjrqs0nA Field2;
};
struct tyTuple__wROVfG5RQYpjEAhvO3LqdQ {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field2;
};
struct tyTuple__a1QJSSO0LTGR9bFH59c2xGCA {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
};
struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg {
NI h;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
NI val;
};
struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg {
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field0;
NI Field1;
};
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
NimStringDesc* Field0;
NI Field1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__SHVxAqOYtIy7teT1q4s0zQ {
  TGenericSeq Sup;
  tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* data[SEQ_DECL_SIZE];
};
struct tySequence__oUyaggHmIX9bpJcMeoG6lpA {
  TGenericSeq Sup;
  tyObject_TBlock__GFhahvekTq3dDOkWyhchMA data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__WwUFq9cJ2xKRlsAWVEHyPRg {
  TGenericSeq Sup;
  tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data[SEQ_DECL_SIZE];
};
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  TGenericSeq Sup;
  NU8 data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__shxop0zPIs5Ec3k71aCLuQ {
  TGenericSeq Sup;
  NIM_BOOL data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__sno9c9bXUVS2CqhtWOJadaCw {
  TGenericSeq Sup;
  tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA data[SEQ_DECL_SIZE];
};
struct tySequence__KjgUMUjT3LUKOFIK4xt5ug {
  TGenericSeq Sup;
  tyTuple__FxkU4d1VDodDMc9ah6Mbagw data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__diqJJ1bWuFP7M6rQDS9cBLQ {
  TGenericSeq Sup;
  tyTuple__4keOEuB8uAwYehpErwqI9ag data[SEQ_DECL_SIZE];
};
struct tySequence__sII3pVVRkIdBZ2HDPdZddA {
  TGenericSeq Sup;
  tyTuple__wROVfG5RQYpjEAhvO3LqdQ data[SEQ_DECL_SIZE];
};
struct tySequence__WPcy3bORPBFlmk2KIq2pbQ {
  TGenericSeq Sup;
  tyTuple__a1QJSSO0LTGR9bFH59c2xGCA data[SEQ_DECL_SIZE];
};
struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q {
  TGenericSeq Sup;
  tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg data[SEQ_DECL_SIZE];
};
struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ {
  TGenericSeq Sup;
  tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  TGenericSeq Sup;
  tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*, newModuleList__pKl1ntXN7hbkEFOmcSlHSg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, newModule__S73dIOk2nN4g6ZKuvNB9ceA)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, rawNewModule__S73dIOk2nN4g6ZKuvNB9ceA_2)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, rawNewModule__a8P0HPhDv3Sesns79bJU0jA)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___0A9bslyIJ49bWrftLGh13rvg)(tyArray__qtqsWM5aXmcpMIVmvq3kAA u);
N_LIB_PRIVATE N_NIMCALL(void, hashOwner__mSn9a9aX0NBzWqerwPW0qRww_4)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, initTable__ZudPzqPNlpthuJgNIdX3jA)(NI initialSize, tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__9apu9bmxB0tG2KjdEWuGfVPg)(NI initialSize, tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q*, newProc__r9c9cj4fW68RhY7ht9btSvB8w)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* module);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, initProcOptions__qttThLa3xHNEeApwU61sZA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, initNodeTable__RsAJjlvhLCgVyd9cZJtMRoQ)(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTempName__ao6gUnuVfQLtZ89c4kaIKfg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___ShdZ6VrAQkY0nWR9a39b9bGdQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__KOisMGxcPhz6CcSmxgwEQQ)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeCfilePath__VmrjcznbGOrooG3SBIdEFQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* cfile, NIM_BOOL createSubDir);
N_LIB_PRIVATE N_NIMCALL(void, open__jmWVcl5Qp9atJWCEkvq1SfA)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, NimStringDesc* filename, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_INLINE(NIM_BOOL, skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__jkXTnxDf8MX1Pmks3s0XxA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformStmt__o9bTtoSsaDmuiyVzV15dOyg_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__a2BRACVCGIuooKjHNmoLsA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__UhPXgqyDuuU9cKcS8FM883w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__fTdzF9aUiQk4rKtSH3doafQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL* inInitGuard);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__0dpuY9coTlraj8JXIe2BzVw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___KxpxlR6eqq3gRIOYTfR67w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___IFeEbVhQpPGgxkLehuSiBA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BYiowJAm8zF7RBRISElaLg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__12ZfBiPs9cA29axtp2bvV6zg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* blockEnd);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, blockBody__tMtK9ba4LBR5bZYSR9avbIag)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZkZcMxwzInnijXy5kz1K3A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, s__kOyJGmZMM2tMgCKSrvUE3gcgendata)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg s);
static N_INLINE(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA*, X5BX5D___VZz2UCb3YWId9ctIYs8ikogsystem)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, indentLine__5PupwEBrKjp65kTtpnAp9bQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(void, prepend__IM4kcMNkkOLJtqdEqSxR8A_2)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__1ygdb876UM9astcNUXtgUBQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(void, genStmts__QrTB5DOwbDX9bKAW7PNbuJA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(void, expr__8mAL9ckajemzgfLPfeZVNoQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, fillLoc__o49bXuxJYpCizOgQ54UViIg)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleName__RaNE9b8A430I9bfpgZmdrC1w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangle__GxzvEIRbrShQbyJNboTw7A)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, idOrSig__sKAFwdXn9cKHxc9cdaovk69cA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* currentModule, tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* sigCollisions);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, useHeader__TAVDUakAwQnRHDK9cFe6L7g_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStr__P2DOsHG6Jk4Siab3L2qwUg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(void, includeHeader__G5jzmdnwglHVk5qfDcXonA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* this_0, NimStringDesc* header);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q)(NimStringDesc** result, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__bilAk8nY4d5fxUpVg9bnphQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ)(NimStringDesc** result, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDesc__iIMq9aNL1HScA9cVz83avtdg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origTyp, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__IafZhvqpthq9b9c13SFhzAOw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(void, hashType__UdooXLclXL8uld7qLI5JRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_ConsiderFlag__9a9az8WnKmq9bvt8EXoSUES7g flags, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypePre__zLenRlTUJy0Mn9b8JKwzEcQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NimStringDesc* literal);
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__V25kMWfh1jWVNQQI5BNfLg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__TIX0sFuRf3uBpOBltYp7bw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, cgsym__arLmPq9aJc9b7GpWTbo6dvHg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, genProc__HbYPOpwLApFuBkISFGrmEQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__FP3Xc9c0yhzvB6NLyfQJkYw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__HbYPOpwLApFuBkISFGrmEQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__HbYPOpwLApFuBkISFGrmEQ_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, findPendingModule__Dhy9cmzSsJkQqlfDq047WUA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__HbYPOpwLApFuBkISFGrmEQ_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProcHeader__OWG529cW3RTHLgDJuQoIH8A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL asPtr);
N_LIB_PRIVATE N_NIMCALL(void, add__yG4AKzsBRS1W4MANDlXQeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__bilAk8nY4d5fxUpVg9bnphQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__uApDq1rn2zPxULBMpTSrxQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** rettype, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** params, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NIM_BOOL declareEnvironment, NIM_BOOL weakDep);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rettype);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapType__pNoigHLHIPJ32RkjLRvhAQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__vCG1GF2Iu043oALVyuJfOw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nr9cP9b0OL9cabygV9bo19cJgZA_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NIM_BOOL, isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPureObject__IVXYI9cxSeivThgKCncHRnA_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___G9aA37gQrW88KHzpCAwhgjQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___PoDv5ydEvGdd9aiIF9cOiAPw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleParamName__RaNE9b8A430I9bfpgZmdrC1w_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__plkNLyLwnwkMYELCfG4Gxw)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* w);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__RafAVeUVSno4B47UdPqNlg)(tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg s, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw, paramStorageLoc__lQqiacOo5FnwNzTrDjiPvw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccgIntroducedPtr__W9aw79b629bysnh3DDOpE3OTg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, cacheGetType__2wgznvEs9bt7XaKJgVohBCw)(tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA tab, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getOrDefault__tD8SQMueXhdfvpBnagcsKg)(tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___Z7W1o5nPSc3ExfO5f7j1Gg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, typeName__qvCJ9bux56nS82Shxh5hLNg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA)(tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* val);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__IafZhvqpthq9b9c13SFhzAOw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* structOrUnion, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typename_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vzbf0XksfaFTXNoTT6BCwA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___lQVSDPkAFXHNoa1N7jYrNw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, structOrUnion__TLFDupRCidtMx8175pusWQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, pushType__4q3XOfd3NI3C8cSNkaF9cWA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, X5BX5D___KricVWBSqqSbgxpQ5up3Ig)(tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, seqStar__hiFj6GH2C6Qv8bI0r9caT5A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___6d8an6hdqiIrRjPW1wEh5Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gMbiWAc0IjihIq46IYhmAw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xQvB9bmOgLpiXXbaCWxYbRg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uHsu7fLXac4OhMNd79bSJwA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapReturnType__K9aceyVl15zb9aYN9b6YJ8TnA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3WM9b4PeyDKoIDFMvYcQX3w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___4cYKitaHx6RQ9azRtQsZp6w)(NimStringDesc* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___p4LhaCxKpUERrq9cB9b8Mp9cw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA)(NimStringDesc* frmt, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBody__ocxOgPRHWfivNZELIhOv7w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, easyResultAsgn__oKhRC9bEKTxG5epdNiNWZ0w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, localVarDecl__NYI5fC69aIqZGRakncXv9cNQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleLocalName__VpV5Cmis02zaNlTmLYJNfQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
static N_INLINE(void, shallow__cnzwaZQQIa73ryXE31wijQsystem)(NimStringDesc** s);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__9bK0jMctS3Kpz9aVaHPQI4gA)(tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg t, NimStringDesc* key, NI default_0);
N_LIB_PRIVATE N_NIMCALL(void, inc__cue4X8ebEalt3pWXvkS49cw)(tyObject_CountTable__chlLjy9bvnFM9b9bSZfiIkyGg* t, NimStringDesc* key, NI val);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___iaEKHmIC9bNRZLxBqSNX0Sg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result);
N_LIB_PRIVATE N_NIMCALL(void, initLoc__qlujIAW86QclHYUVxlHRiQ)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdLoc__xidyzuHqIciXbQyEOKahDg)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TbMwXzwNL7txOQADiTjwKA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__UtJx89cn0a8CNSWWmaj6raA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__EpeofNfMJPurx0duaALCaA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, NIM_BOOL immediateAsgn);
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__Q4oQMHZIwSi4nGkYAuAC8A)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* loc, NIM_BOOL isTemp);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, t__XNOXh7uniWNgiq58C9bW49awcgen)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
static N_INLINE(NIM_BOOL, isComplexValueType__Fl17jclCP5VEr9a7Ycym1awcgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, addrLoc__9b8NbhHc4w1oBKAy127l3xQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__UANnSFbuKD1BS6RrMbZs2A)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg section, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw mode);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw, analyseObjectWithTypeField__Pldxz9alDV6810oJzh2Apog)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, getOrDefault__qISsmXPGy0MStH2gg2BcOA)(tyObject_Table__6nOsw5R7jH72bux7HSST9bg t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyTuple__Iz0jrTw3w7v6sMzjrqs0nA* Result);
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__xfVyTYRVyjtacYdjZK1hbA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* str, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ownerModule);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___DJoMxkeDQMwm5cCmPzoZHw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YPFmrJyah8E9bXydasNTQNQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getModuleDllPath__ao6gUnuVfQLtZ89c4kaIKfg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__z7B4FbwzX3Y0L1EA2lLGXw)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCFile__bmANOnd5oQhXRrTCn9a8S4g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, withPackageName__9bhgFqdEZM7DoX7p3U69bQEg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeCString__vQJydtKy4Nf6bXPYtbmjtg)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9bbJ4OU0MjtzdlRG6xkqTGQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xrQqS5W45hHcYilJqzdwVg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___e9czpY4GXpbU9cznliOfqQ1Q)(tyObject_Table__6nOsw5R7jH72bux7HSST9bg* t, tyArray__qtqsWM5aXmcpMIVmvq3kAA key, tyTuple__Iz0jrTw3w7v6sMzjrqs0nA val);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__TDEOLqqwXHVFJ9cWxDq6Nww)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yhAwz5hzwMQ7qDzJyZYHDA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genHook__oupeNBgikmhXuZ8U9c35Zlg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op);
static N_INLINE(NIM_BOOL, isTrivialProc__0ARm8KufT2VWgot8ref79bwcgen)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yEs78NnVWc9b8GOXpzPn49aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nlZFDYB4M9bmBbYqEropRVw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* base, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LV4C1L0tZJJrAPLOvOYIWQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canFormAcycle__IVXYI9cxSeivThgKCncHRnA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___fIR1FG0QPRsKvEYKq4tJUQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jADQs38xm62v1oxF2cSvEw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___DZV83DjWnQ9a19atC2oeswXg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___E0nDsXp7tY4mC1BnrrjWmA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sfvTjNjtOC86mU9bHczF6ow)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4OTrYJoAayXfDUrtxFShhg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, fakeClosureType__OVHn4Lx3T69a1BHJ0KreWYw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createObj__vpIcmDdKH7ed0dcs37b1GQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__DVDUKxJo5CvrWtAaM2iHCw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jadqNPnY9aM3oxYK6jarLrA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__8W0lvt5dkO9cVIIfffRji9cQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LvsIDF8olc08xBiqCYIUog)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___6Tfa1iP1ENVlWbe89cSELSQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hKg2Id9cvzE5Dgl9cU31c4Vw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___H3xXuIFdbz4MNb5T6BSfcQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ELXFo0GedkhGYj9bocTHZAg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9aLrcjgzGJE3f9ab2uR37jog)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3Q9c5iS9btBDBXZVoQktb1XQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MALQXTKXJv7x9a9c247satLQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTraverseProc__6ja22UmHW9bFsLaOtztGpHQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origTyp, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0nBiBCva6YS9a9bSV2Vr7Zxw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yyhPPkMkLJqWG6p8HGn9aoA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___t8gRNGR1flvaCNlBxuLn1A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__LXrm7ZbTiXTVtbB5E60yIA)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, getTemp__VjOFVqypINqQv5C3ECnxbw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, NIM_BOOL needsInit);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lodeTyp__Zo4XKVi6BmwOZE51Yogqwg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xQaqlAwFuwxqBFixw7ewLg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lenExpr__Xfvxpx3W1zkiCqENsur9ckg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2SWcbuU7RHQR0b8y9aJ9a5VQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lenField__3AsTOpq9crZUYBL9aD1lXBng)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(NI, len__9b0YRltzV3kNSE9aQTsG82wg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lengthOrd__hjogdnp59cMX1rwmjikBhqw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__JXx3ANPSFqQ9c8gmnEaNQ9cA)(NimStringDesc** result, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value);
N_LIB_PRIVATE N_NIMCALL(void, addInt128__IvecK4CF4vhXBu6XHFt6sg)(NimStringDesc** result, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, parentObj__uBOaBBiKguvub019cPppbOQcgen)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gSgutt9b7GMWVGBkCt0UHAQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__ZF8ePl9bsRxWXLu7Z2MFifQ)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getRecordFields__1Yw0f9bM6njBLDchKVMziZw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NimStringDesc* unionPrefix);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleField__IekjVhJd9bZAI9cs9bWYUDsTA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___mZ66tEveFIQokq3arf8Klw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Vcuq0AWiVDndx4UH9cJ9cBRg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___wbZBBJwMkBeW6eH9agO9boag)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zgEKWXsZtT6lqQ6XlgfrsA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uXZ30k0oJEqGPZW57O3dwg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bfOZxc58jjogwT5CgzlLmw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tTI9aMQiBZdiEeBIVh7QtYA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, elemType__PfgI9ap7WOnsRfFV4znQ27w_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4kat3SB2isO6k5GNDb6IOA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gMpJKF837tUhGu2KjcYLFA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jw4Sb0OSpKH1T5cLz7iyzA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__KUz7NJSCXeUWRl4foF5zfg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0RQ2PINB4t8FjFlNUM6N9cQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genLiteral__qifZy01sZ5OX01eT5FP76w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, intLiteral__kQA0lBUvzOSZAw7DHC4Fjg)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LQ9bGxpANW8yeg5P9c0UYAaQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___f8tdlskieCnWysl9c9blzqZg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___KbFpNe1pZ7hIuQi7dp1dSQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nunbo9aB0HmmYQJ3InIBEzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___RBxLok7DyUB0aHl9bxPIl9bQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, int64Literal__kQA0lBUvzOSZAw7DHC4Fjg_2)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, uint64Literal__ldwzpLT4KWF9c4XGru9cpC1A)(NU64 i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___M2d4UEGH9cZOvte6rEhvUTQ)(NU64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NARRjCd1x5Fr7NTTcoPRrw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q)(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key, NI val);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NlLLwmZHOiJUpZfuk00AWA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gs4odkn83z9bVJ76dC1J9ciQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genNilStringLiteral__mf9bJ50BK9auefXIgup7r1CQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteral__SO73hKlDdl5sMaSHTbOJLw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV1__SO73hKlDdl5sMaSHTbOJLw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralDataOnlyV1__wg9bxyc8oC9b9ahuYUo9bM4FJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___mF9aI9b3hDjj53TD2C2gTrHA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g)(NimStringDesc** result, NI64 value);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV2__Cfuh3qIr16gdBtlWztnjAQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__vp7GP3wlFybjCJ5ExVrrhg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* s, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Q63d9bGPwQ9ae1XrP9b7wHM3w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bgV9a1wkKJUW9aAfeUrmhalQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg)(NF f, NimStringDesc* literalPostfix);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___f8NIixSwWrk6SXQ3BFamWw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TTRh79a14hh1gb0owIP1Y6Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TmeCjGna9cPfiHHcfqmKXjw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___FsfRVuOOBePjn9cQ9aK7Vh1w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___paA0sar8RKZqiwEaDfWo2A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jr9cXNQhhlLDfFJH4RSjeZg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, dataField__3AsTOpq9crZUYBL9aD1lXBng_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___EnzikEr9bDhOR6GYxWuYSwQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QqzUiJcAEZE2azDhIWHrgg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___20ZujjIFPkyqvS2OmenEAA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Vxo9ayk1xB18if39aZ1TBnKA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NtQEfuK9bXszNTfYU57z19bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__TiBDnY33G5Ca1p0Z3BOA9bg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__TiBDnY33G5Ca1p0Z3BOA9bg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AKNexo4CH8G2vDeWW34Vpg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__b5mr3rjXEwHVfmNLJr4cBA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___W2wbDjPGDCaBwLQM6yLUQg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__TiBDnY33G5Ca1p0Z3BOA9bg_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LE3oWAmB5YDSDHm3LNHhCg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___W83I2xs7lC32PrMs9bq4P2w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JKMGBJtXtDvc0NwxujFmZQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TA8WFV49atYpIneJatQWALw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nPenDL3j2Q6A1an1Cl3oCA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TNkzce2Sd9bck2QRtketc8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__DVDUKxJo5CvrWtAaM2iHCw_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__TSbjDRI5MCd36QpIuSTshg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* expr, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, discriminatorTableName__WpGsd0DJejVIze0ZXr8L3g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BKnrQUIV2xGn2MO0RK09aUw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SCyrk9acEm3vLZhXCV1fGNg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___erDe9aYc2BNxzH9brKlmtEBg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, plus___hiijuMqvH9aC9aKmwIYuqUAA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA onError);
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HSAgkeH84eiEd8MfKIuBQA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, openArrayToTuple__iIYhRDohWfkp5IdYSl7LXw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, add__9a8CdZqChTyqzq5bpSL3TzA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__hi0Gu9bcBd9a9cO4KStt3d7iw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1AD3Wp47Hcdfg6PO2ac0NQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UZliz9cVEMzhwBoSNLm44vQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__8mAL9ckajemzgfLPfeZVNoQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bJpxHYPJaxWBQn6QxwBA4w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* optionalType);
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ*, toBitSet__Ccp5iPnBYFcoF9aTCBpla6A)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRawSetData__P8T6oQDSZlTI5UtVVMB9c9aw)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NU64, bitSetToWord__7N9cVgZTBxAgp9c0RZ0w0l9cg)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSeqV2__qmtU7fqvjfQZWR4m4R9aU1g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___rouofEnBX1ok9aMXmOsKdHg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___C3GQZbey70223GyG307UFg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSeq__qmtU7fqvjfQZWR4m4R9aU1g_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yxmLIVRKySYknm2wSBp9cpg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8u7UPO7ZpaMkWoJRtZLlYQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xXT7cKE1NTiL4U2MdlA2yQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___44q9ak51X9b9bmuZ9cK4LsFWOg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getClosureType__lWDfUH9cj8K8DjyEqo9cmP3A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Msid9awGKVeVe7p3v7WfNQA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xyRsdWsGY1DVVispyn0Xeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSimpleList__zuhkXYLhosH9cERvaWpRX2w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstTuple__GW9c7sQFGd9bbwGh59aVTyShQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tup);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Tfa6nw2rjNPTLpiEa4Xzvw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstObjConstr__zuhkXYLhosH9cERvaWpRX2w_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__Fl6EeAE3i9aDp1Z4U9aU6eLg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constOrNil, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__bDGkqDlpSTLF19cHOigiRwA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constOrNil, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NI, caseObjDefaultBranch__E9aJksCVNSVSpIoSEOSPgZQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_Int128__9a9axPfb75jdWY25AamJewkA branch);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___7c5Zw7H31uJfWmmhZe9aEqw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getDefaultValue__6MJ4xodlafi9aSG537L79bpw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dnB3So2xw9c189c09a9cc9b4hxA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV2Const__Cfuh3qIr16gdBtlWztnjAQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___r2gXVULKoAtQjkgjf0Z4wg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__BtucsTdHw7orsXIL75hNVg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags);
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__jdslQ8TsNpkTt8SvBLJjEA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src);
static N_INLINE(NIM_BOOL, usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__b5Hq2LPdi5DP1QFBXQYNdA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL preventInheritance);
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* field, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* Result);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__BtucsTdHw7orsXIL75hNVg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ym0Pr6z8A9ajyOAgotpd9a9bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__jQZhYDteQXOIUBRG4iLXPQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__9aKtDk9aj0NeiT1dC7eBiRKw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NIM_BOOL, reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__r42GKs9beopbtQIPWdYjAkw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cb5f0VvvxoagMath9ay3UuQ)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isException__YPjOkGV9axAnGR3UfLeWZ1g_13)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, fillResult__p9cP79bBkRq6WIT5fOHMaTzQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* param);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___T11tCz9bIGT2CcftAwrDXZw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, assignParam__9aFEJaMCg37I5D9b15sgctsw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType);
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__8o8k31aDRiyxRXKGzZbQIQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg, allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* loc);
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__9cgrUeVA21BOQab6CBAvXRQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__a4Eirucy5vgnjUqFNeFEfw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__PDMGXd7Yn9cB79asQW3arukQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__IroqGJs3T8by0fVw4XMZJg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procBody);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__8gOq38UiI9arVxZ9at35m22Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, NimStringDesc* filename, NI line, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___lS9bA1j3Ue6pp7sCliDsT8g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, makeSingleLineCString__rMRFcrOdLs9cBLwxpf0jLag)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, isNoReturn__wKa9aVgc3t9a9atx3OlQKTJyQcgen)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, initFrame__hSB0mXJGcFil9bvrhp0Qm5g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BBAyGuVoK6QA7nXfPUIYKA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, deinitFrame__3AsTOpq9crZUYBL9aD1lXBng_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___g9b9arp3BWCGRHDe21SJso6w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___09aVguRR64dWfw4b6fKBcqg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getProcTypeCast__kjPRfLdGk3b78KhSOOjbOA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tgUnLdPVK0vRqC0pWxMClQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__SYG8r9a6ANje3aBM5rYzaeg)(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib);
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__Q3RS49c6kF7OS9bmwvFHRQJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___FBNsdfF5FNrY4P9cYQIfvZQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, libCandidates__TEY9aqiaMWVK2l0NzZy7BwQ)(NimStringDesc* s, tySequence__sM4lkSb7zS6F7OVMvW9cffQ** dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___cB7zULPbG5vWWdCukRjdqg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dpzmcz9a6kXbhFacdElIMOw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AWFBEodxoi9a61KDUc9aiw1w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__TAVDUakAwQnRHDK9cFe6L7g_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vHbYzYlzLPcurSm0Hu8InQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__t9a9a9bxmaOztYOfsfhQUOXXw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__wDT42Iy4l3KGL9cd8rMjKRA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isExtern);
static N_INLINE(NIM_BOOL, emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nzT6Rke9c7tkW9b3XMmld2LA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9cCc2iMcL3MEBZTTL3LCW1w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__Mns9bHWQy2Dza12fE8Mjw9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** res, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, excl__jENnK9c9bPE73pKmo2vYjpqg_2)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__KCQ2E6mQfCiuCUy6v2RUPw)(tyObject_HashSet__LWqBPbJi8sAUtgObUDu34A* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA key);
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__SaA9bA11X42SNop9bW9cVLmng)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name);
N_LIB_PRIVATE N_NIMCALL(void, addTypeHeader__EyWxAbFrjBhTQTF47MkGkA)(NimStringDesc** result, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__45fPtFhY4FavRaYwDhRfuA)(NimStringDesc** s, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CSMWu6VMLe6j6b1nzeZ5iA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getOpenArrayDesc__u9b36BB6lubIrq9aZ0T9bYwKg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZtuswTdSNk5KTSSCYKvEYQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___XI9awM9a9aQ9cB9bcS7uDRsa1Rw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9cWNaGuyEpBbdBlD9b5nY1ug)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___6P67I9czJ9aa9aZzVyYWUiGlw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___S4jE5dFDtcCC8ODzxaJk6A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___EPABzhs2B9atAvHV4CUTw2Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__1szweXXq3RBN50owrYu2Xw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2MhCcipNmSHgcDtN4cr8ng)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__YRbO0Zq30XmyAQjpf1Mi6g)(NimStringDesc* pat, NI* cursor, NI* outIdx, NI* outStars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__2yh9cer0ymNRHlOOg8P7IuA)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, resolveStarsInCppType__dTa9cSuyNlFVdzNe1dV0rag)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NI idx, NI stars);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getRecordDesc__HJhu9cCeHNnnn2AMyLicEaw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0ul9cDZYl7YkH1RhZBTd9c6A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QFf4DPoOk6Jy59cL2OASJzw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7yDHbEsisDNKcqQHIRgOuQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GwVmUG4AZCEAP8dBk4TGHg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTupleDesc__HJhu9cCeHNnnn2AMyLicEaw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___q7DaQZqCe0lRO0rhBWzM0w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hGIvKp3CGssDQ2vSvfksxQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9c1P82lz6H9anMKDbz1vYNpg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dbg9bsMENUwtF9aO45wEGG3Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
static N_INLINE(NIM_BOOL, requiresExternC__axmagSzN10JTkqlmiAFoqQcgen)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA s);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__y9bTRtTAknVsv9apXKbpJYJA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__6NyA5DzsDGY17BhjidN65Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s);
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__ARtcpl8G0t9cQCPr2Np8Srw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__POVv0myAK3ae9cYA55o72Fw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___eMtcjnP5EASsGpHWzVmIXA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ptz4AXVYEvsEioVLNYw0bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0Wha51b9br4aUzohTFPS9boA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___VsLzrOz1nS9cRBBz9ccZfETQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__T7FeUoHVfLrGm0JydrFabA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__4xOIY9bgIMy9bAzg2ZyIieBw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tRSKshYob5uzZE3eBVe59cg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, potentialValueInit__ZPEw9bE7bf9b89ciOwNlnaiIg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__NAlbw3fU59aFdo7L5aQtmkw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__yX9bZpeKIzp3RLrjnzlc0NQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value);
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vcbf2lEZaiSjbAHwgt9aKXw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8aeHBTewuDsR3u9akMPiPqQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTraverseProc__V1atRcoAv09bVdrCPNlvW8Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTraverseProcForGlobal__N6PVM8zp2L2vM3WsaTEaJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__IpGUPLhMYizrVHs0OdHySA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sb2NV56uvmvOtYkgVsaVQQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7STLi75js8HXlmFg7Abt9bQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5O50gePV9adn3wgFGWjlOLQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9a3Y7eeGNXkOCLUktwxzN9ag)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__BwxixSWhJWbQ369cJZeckHA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* traverseProc);
static N_INLINE(NIM_BOOL, isAssignedImmediately__udBNoPxZaHjsWUNp37jAdwcgen)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsHiddenPointer__IVXYI9cxSeivThgKCncHRnA_5)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Ng8dczn37bLzoM9bsVdPwjQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__7ClJaTgavvBeZEMW4B6fYA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOtherArg__9a86z5oGsAZjkB52zPdLZJQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArgNoParam__idr0athfhAF2aTg9arX9bWAg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL needsTmp);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArgStringToCString__6LeXitLQkjwfrebQPKcpoAcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL needsTmp);
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, NIM_BOOL needsTmp, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___boICAAvO1zkTlYDOuEaj6g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LeuvM3mIc6pSNktpm9cHSVw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___mxQQ2vwZhwfDagj5SEXeHA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___x2NKZw9brJpylbwEtLfx9a9bg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(void, loadInto__vkEx8Dn9aiGOI04WjvQIHIwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a);
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__HKkL9adNEIcNHeJ0iZ6uitg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__iRZAnpxF4CwuSQ4C7wQilQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
static N_INLINE(NIM_BOOL, notYetAlive__4MUa2M7mDMhaGJLAFrkWDw_2cgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getRoot__QppXrRxPfamDSGF2rYPMlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__HKkL9adNEIcNHeJ0iZ6uitg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genParams__KMtRYhmblciqOHa6LfFLDw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tySequence__shxop0zPIs5Ec3k71aCLuQ*, newSeq__rt1It5NRu1MxMaCLDXp0Ew)(NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipTrivialIndirections__oKhRC9bEKTxG5epdNiNWZ0w_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__VM9crKDs5ctG1rw9aot9a4zEQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* potentialWrites);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ, instrTargets__w1KaHRCZ7rX9a4bWRvZGRmQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* insloc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loc);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, getPotentialReads__1E9ailIhVU2zHYmHnsdAukQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__VtZAvh3FTvs4RsUIdDz79aQ)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** y, NI yLen_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL mutate);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArg__NyG7NHKT5F2mihfTt1JRVA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, NIM_BOOL needsTmp);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, openArrayLoc__6mPoivdljN39aZZDBAbjmIw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formalType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg, getMagic__4W1ZJaFiusqlhViRx9cbM9bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArraySlice__OgTjHQyQeIgTGpsUfPmxRQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* q, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formalType, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* destType, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result);
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__Hw9c2IcxFuX7vhYGTZsoSPA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA arr, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, intLiteral__0L2LUBpuDvHdOo5Bdh2tRw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdCharLoc__xidyzuHqIciXbQyEOKahDg_2)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TmT2Gs9cB7RN9cmo9c9cBpfKsA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lastOrd__hjogdnp59cMX1rwmjikBhqw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9b9cGfmDPAxEWXZ4v4mdlErQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CvKvzmiW59auxFBRDFxCJSQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___02C88mFwGG7GLN49c9cza4CQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___mR3c5JSpBB2VsIXEipMwMA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7KIiDutBmiUJL6kpESJ8ZA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___j7I7KYCBLEVOBnBFpLQp4A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___btjbbzpOIPgksCcMaA2TQg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___fzzklE4aYpRPohWGI2Uilg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LzOSzuN9b2AE9bvskk0YuAww)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___L3AeZ1n9aK4C1jsBCeaCmlQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ebmRHYtM9cCbYF6WvKDfQ9cg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qE1JtEDDOvP6J49a9cv9aK1Dg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ctvQ2lU9b9bnVVpNP4GhIo2Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__Y9bFh7BmZkh729bS2kZ5kwnQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__qAerQ9bftuf70QDk42UIFXg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__qAerQ9bftuf70QDk42UIFXg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__VzIhhB7jFivZ9c6NgOwxU1Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w, isPartOf__1otDDZAmvFsmbqPyFytXFg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__fKz9bDGxeJtVdl9bZW9aX2KFA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, NIM_BOOL inTryStmt);
static N_INLINE(NIM_BOOL, hasNoInit__XO14mevzEVVwQTyfj9cMewwcgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8bHx2qDxS2yWIId1X52mqg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, addComma__WAlh7NpO6KFA22Kxnp9aoaw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___kTDR7D9c9aomjcaUQOmKJ9csg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__0dpuY9coTlraj8JXIe2BzVw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
static N_INLINE(tyTuple__FxkU4d1VDodDMc9ah6Mbagw*, X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem)(tyTuple__FxkU4d1VDodDMc9ah6Mbagw* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__4h2Oud7u5jWCpkY1i8QUDg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, NIM_BOOL canRaise, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1tj59chZC08k4TWYeZiqDnQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___533QKY9a8quvLM1SsLE1JfQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__HKkL9adNEIcNHeJ0iZ6uitg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genPatternCall__n9aN0vqKCBL7B9cV6pjBnGNg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NimStringDesc* pat, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uFJUSitn9c1Tw6cF9cZf6x6Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___G8iCcDovsaw25PkF7wHs0g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genThisArg__9a86z5oGsAZjkB52zPdLZJQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddrDeref__vMC9cau6W2PcQ0Z0zO9cDXMA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* node);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SY4U2QvmoQxocaG8MOmyHA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__5AieZFwkpMkLKPnkORd7Cw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* callee, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bhkFYKbURxGcJnKpswdr2Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__17YlQRjV7sYeIVr87qv2GA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value);
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__9azKdI6vAayTOFEcJtCTo1g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___lTsL0bi6njxzDh9c8A32r2w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___k4VEB3kaBL72FRQN8buzSg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YbQIA9cHUESCyYT1WEeIVbA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___66KauNYQRukYNgmb6bVXEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___S550SlHmWbDpD7rs0J2lrA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__HKkL9adNEIcNHeJ0iZ6uitg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
static N_INLINE(void, postStmtActions__hU2pQ4yYkske4uOCGEGfMwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, astdef__PBkjYIaAGbtrZ8DiUArHcw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__fYECstGN5jPehhn5p8Iclg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__TU9cJnldbmGa9bZDxaR6I4tg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__yX5yxw6c9agMF4ZvIHKAZvg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getLabel__3AsTOpq9crZUYBL9aD1lXBng_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sGnLi1DjaBomQ9c9a6MOCA5g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bEKtSmboScaCP8PPnlOWqw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* labl);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZpwWwpfBXgcQ6xoLOH4CJw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__TU9cJnldbmGa9bZDxaR6I4tg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GHW5yjG8N9c2BQBun6aBJzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QXMcmOst45ThYFLo9cOKDiQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Yup67SPGRVcwMdmZwc9cSag)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ec65mR1N7BSL9cmUa3z9czvA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ibyK70G44kCK9cN8nAkxyGA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___H9b69aGZGrLOiKWQdd30yQ9bg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__yX5yxw6c9agMF4ZvIHKAZvg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__TU9cJnldbmGa9bZDxaR6I4tg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Te7bvH18PbGe5siNJ9aDTTA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MUaBvSw0MHw3qQi9bYavAmg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bWYxjLMocXEvYgQQcC63rw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZpcNBrQMfioSvQNxKHhu9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gywCjjjPZobIva6liQWNLQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___6PDHoyz05lEjxGNE0k0ikw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AXGsBlGV5DoEOwPJSl9bdJw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ygzR9aJ6oM1bZTq4Z2lNO3Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uYVc6UX8hcaEdrHosUQAOw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AlV8xJkjCXujAUesHxezgw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___L9asecuKwevQN2h9cWzyv6oA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nZD9cadh12dcqTFsXBHbCRg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dz1JHdrf1p9bPB9ad2dZBtYw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0MUu7DVBoaLHTVUZe9bKoIA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___29aIWEGnJW0wnITIeSKWfFg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___n2CigWG38YNInkiL4n8g7A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bb3v9bDRLv9c9bcQzGH9c5H4Gw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tkJq8W3gQVDjuu9aT3THC6Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___oyQkqbRkRzo43y6iRevkaA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YuphtPwdJHG6BUJOVa9bX3w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___EQxs5xa4FNWtMfcvmFZ9cMA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5YbjRZxm0g3SrdnL73aQaw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4JrnABFfF3UTQ3nO9a6mXzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bkAwkKoaz09cAQo9arQjGA0A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7N9bV9cjVBHs9ciAhz7vgdI9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QX9cU2fNK0jJrZNDQKnAycA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__BKdMcfvryaJLplX0oFPcAQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vTbVjc6faJqdBrTckFLLWQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___v4k9cDtOUzGyUHJbnJ7kQKg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0ym49cR6ES8k9bYWsnh1fELA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRepr__BKdMcfvryaJLplX0oFPcAQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__Faz6su3hXrHmiSECd9c9a6Pg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__BKdMcfvryaJLplX0oFPcAQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__BKdMcfvryaJLplX0oFPcAQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isFinal__YPjOkGV9axAnGR3UfLeWZ1g_5)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdMType__JrPFcJ0c8lx7StUeWoJrrQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** nilCheck, NIM_BOOL enforceV1);
N_LIB_PRIVATE N_NIMCALL(void, genSwap__BKdMcfvryaJLplX0oFPcAQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__UtJx89cn0a8CNSWWmaj6raA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__FWB0HmRDLgoWdgSy9bfL9b5w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NimStringDesc* op);
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__BKdMcfvryaJLplX0oFPcAQ_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, strLoc__09c8G9aj7c6ktd6DIBLVcdnw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__vxeaiXjty5M8JXT1fo429aQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NimStringDesc* cpname);
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__BKdMcfvryaJLplX0oFPcAQ_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeAddr__oKhRC9bEKTxG5epdNiNWZ0w_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__W0UItHZuQBLie8iFE3EjmA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(void, genCall__BKdMcfvryaJLplX0oFPcAQ_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__BKdMcfvryaJLplX0oFPcAQ_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__SrOtkNNSJNR1CbG2n3nFcg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result);
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__BKdMcfvryaJLplX0oFPcAQ_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__BKdMcfvryaJLplX0oFPcAQ_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__BKdMcfvryaJLplX0oFPcAQ_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, genEnumToStrProc__1dNAvAAONCZJhs8N6saOAw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, genOf__8mAL9ckajemzgfLPfeZVNoQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genOf__uDNhebNf5Eggw4ZZsc4T9cg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Jx78R9a9anGvjjocCaP8YgIg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOfHelper__syG9ah9cBD4IpDknTLKkLglQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___s0lnM9cZDB9bOREa4Fx1leBw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___aT7p9bNEmP3LxrK3OhspnSw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNew__X9cSqNhqEboci9cdmwBMNcBw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* sizeExpr, NIM_BOOL needsInit);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___mV75vMLuQ8rrQEUzNz6llA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jhVz7tKuf0heLM2D3nL0gw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__X9cSqNhqEboci9cdmwBMNcBw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__X9cSqNhqEboci9cdmwBMNcBw_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__Ri3gLeBVOaUltgSIU2SrQQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* length, NIM_BOOL lenIsZero);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__BKdMcfvryaJLplX0oFPcAQ_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___c4YKWXetPKpaUUF7Qft2gA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9a4eEIrTth9cYD1nB3M11LRQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___lXaYcLcHHuQ46VvpH6Qr2A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__BKdMcfvryaJLplX0oFPcAQ_14)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___duX6hgjmpJtFFdvJVuoafg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GNSb4l0oRsR1gu66azz1LQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LGbUtKnsZL8FcQiQN7sWEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___e8Xf9ajw9cRlpuqnFnlEuSpA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BDuDfIpocbuOrxKmsugV6Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrd__BKdMcfvryaJLplX0oFPcAQ_15)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__TU9cJnldbmGa9bZDxaR6I4tg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nVQhtKHyPC8pvPbUAUBU7A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__BKdMcfvryaJLplX0oFPcAQ_16)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__BKdMcfvryaJLplX0oFPcAQ_17)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__TU9cJnldbmGa9bZDxaR6I4tg_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9bI5GhokFUA9bgO9av819cgdBg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qTicKO8EMC9cWGOyybIz4WQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yZHx0qMqBvbhmZ0fMuAP6A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YQzyPnY5vKAqE2RyLX0cew)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___cIILAsA6BeRrvHfloZIscg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___IwDTuHqkGn7wW16ga2ktSg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___lbkoHJP5AIgE86vP7MmlKw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9b84wNYrm79cLYfx9bsPNHjPQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___K5ihI3kW9cFBh6sKlfEpJwg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInOp__BKdMcfvryaJLplX0oFPcAQ_18)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__vBGSIpCyq29bEZNYsVP3V6w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nEiBK88oEGnvYfkiei9cyJA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Psy1qActyEYmIhrRo2KkJA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__9cclvr8sbqtJj8irRbQQpqQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* b, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9cZzkwYphs086zWiuLotXLA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___kPsYd8d9cco3hhqO7CEAFeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BbOsdTh4ZRNKmiISHDyg3A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Py40oiVtYdIelNuiQQjpjw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QzVlk7tEXgagMWC19aLvbkg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qxufH5vUl9aY2l9cFq39bnVwA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jiTCvQQpgMU0bTrdVuECiw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___n4OrLXC1r9a83k5wz2NoWxQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDefault__8mAL9ckajemzgfLPfeZVNoQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genReset__UtJx89cn0a8CNSWWmaj6raA_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genEcho__UtJx89cn0a8CNSWWmaj6raA_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__8mAL9ckajemzgfLPfeZVNoQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__8mAL9ckajemzgfLPfeZVNoQ_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__edSekmjUCfSNOPSuXdUClg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spawnExpr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftParallel__ndOOzgg7N9cEw3E9bRfkcIDw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__jdslQ8TsNpkTt8SvBLJjEA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src);
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__UtJx89cn0a8CNSWWmaj6raA_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__oKhRC9bEKTxG5epdNiNWZ0w_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genMove__8mAL9ckajemzgfLPfeZVNoQ_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__UtJx89cn0a8CNSWWmaj6raA_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genSlice__BKdMcfvryaJLplX0oFPcAQ_19)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSetNode__NYI5fC69aIqZGRakncXv9cNQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__BKdMcfvryaJLplX0oFPcAQ_20)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___fOn9b5Ij3ytw2Ui9a2CPI5zw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zJU3FoYOdJ9bmuODPmqtgdQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimInt64ToStr)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1MXpJAdeOMc2XMg5H7t9aSg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___VNAv31sqVgxrd9aXeFF5wYw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MULS9c8dKz2mJ1U9a9cMyTCYw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__8mAL9ckajemzgfLPfeZVNoQ_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__8mAL9ckajemzgfLPfeZVNoQ_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__3euU5r9bcG0Rnz4QchCOUyw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genClosure__8mAL9ckajemzgfLPfeZVNoQ_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
static N_INLINE(NIM_BOOL, isConstClosure__4MUa2M7mDMhaGJLAFrkWDw_3cgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__8mAL9ckajemzgfLPfeZVNoQ_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5TB09c2Iz60T0YagbSbI5RQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__BKdMcfvryaJLplX0oFPcAQ_21)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupFieldAgain__x9bTneajlTd1ibxrXw5m2Pw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** resTyp);
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__9bUUELnkXphPuPspD3YnKHQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genFieldDefect__NFvxltQN2CgyfP8SjDTS1g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disc);
N_LIB_PRIVATE N_NIMCALL(void, genCast__BKdMcfvryaJLplX0oFPcAQ_22)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NIzUqj4Mr1E3EKy0AkJaXQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yQdCkIARIVr9aqI8oVxi9cQw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genConv__BKdMcfvryaJLplX0oFPcAQ_23)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameBackendType__n70Tq9c0HITdaYm9cT8YLryw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y);
N_LIB_PRIVATE N_NIMCALL(void, genAddr__BKdMcfvryaJLplX0oFPcAQ_24)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
static N_INLINE(NIM_BOOL, isCppRef__Rt7PF9bsOeNWjGFhSpqAlTwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__8mAL9ckajemzgfLPfeZVNoQ_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___7c5Zw7H31uJfWmmhZe9aEqw_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__BCJD8YW9ak7zQIm4nTPgpMQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__BCJD8YW9ak7zQIm4nTPgpMQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__BKdMcfvryaJLplX0oFPcAQ_25)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___WYvjnWcyRjjjI0lasIi1YA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDeref__BKdMcfvryaJLplX0oFPcAQ_26)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__BKdMcfvryaJLplX0oFPcAQ_27)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__O8nIPJbfEFU0FjR77WG5eA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hR4oq6WdDjEl0JIvQtvUlg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__BKdMcfvryaJLplX0oFPcAQ_28)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__8mAL9ckajemzgfLPfeZVNoQ_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__8mAL9ckajemzgfLPfeZVNoQ_14)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, initFrameNoDebug__pzdwBzdMmIm0ZmOmWB6yqA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frame, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename, NI line);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___84GQPNcrIJtbrzuA7JnMPw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, deinitFrameNoDebug__i9b8wSa9cUkrnf3r9bmZ8OzfA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frame);
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__UtJx89cn0a8CNSWWmaj6raA_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genIf__8mAL9ckajemzgfLPfeZVNoQ_15)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SqZEI7bxySjmJX4GsXyvKw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___c1f569aWpTd825BTnv9bq4Xg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, downConv__8mAL9ckajemzgfLPfeZVNoQ_16)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(void, upConv__8mAL9ckajemzgfLPfeZVNoQ_17)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__kCP6QlI8uS4X0pOQUdr7tg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___THj7TLQ2KRJ59bBAfaCkUxA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__8mAL9ckajemzgfLPfeZVNoQ_18)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__8mAL9ckajemzgfLPfeZVNoQ_19)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__8mAL9ckajemzgfLPfeZVNoQ_20)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__QrTB5DOwbDX9bKAW7PNbuJA_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stmtsContainPragma__QPJXGOVirAPBlaL8RY5bwA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w);
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__UtJx89cn0a8CNSWWmaj6raA_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, flattenStmts__qsyX8NJX39ctdwAi4rC8W1g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___xL5gyZrjbGMarSdRAXOo9ag_3)(NI64 a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ibl3qMPOrpGT2x8X7vmbeQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___bBcuDHMXr6Kz1tr7BzD9aKw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___aDvifvZOUmduC6Unfm69bKA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5kuxCbMO8PVJc9aJbXScUOQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Uu9cBz7dxPVDFhF9aLzWecyQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___WWt3il4CHPiYP10KdNLrWw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, assignLabel__mIFKIo7g6Echd7EokLhQegcgen)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* b);
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__UtJx89cn0a8CNSWWmaj6raA_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__9c6v9b6B8RZkui111YH4cbEw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__9c6v9b6B8RZkui111YH4cbEw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__UtJx89cn0a8CNSWWmaj6raA_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowerTupleUnpacking__8A4G64HByteFanrMUexmNw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__sno9c9bXUVS2CqhtWOJadaCw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, genCase__re1pwmyeR32ikwnOC3vvzQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__re1pwmyeR32ikwnOC3vvzQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__v2qC0V55wqa9bmqc7eHTz8A)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__P8OJ6tb5bbr0Tp2llps5Rw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA e, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* labl, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** branches, NI branchesLen_0);
N_LIB_PRIVATE N_NIMCALL(NI64, hashString__9acplCwsZ5kwBbm0f7S7DNw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hc7hMh137dtaNdd3qw28EQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___XWz49cQA2QiZaLkqHBU5L3g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NI labId, NI until);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Au81R9a68Rv3gwlPtvDarPg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__8mAL9ckajemzgfLPfeZVNoQ_21)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__ACGHJp9bbmHaRpjqO8LXrqA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseStmt);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Yw741acxvsUs9cOX9cuiDj9bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__8mAL9ckajemzgfLPfeZVNoQ_22)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__sCIDQrEETdL3XXbX8Uzgrg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__FtWqvDVdWg4sJ9aFlt4ZdKg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___T9caGByKkBhaXSZ6fCJLIdQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JmTWN8YiVKTZuvCYW2XNZA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__QrTB5DOwbDX9bKAW7PNbuJA_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, NI howManyTrys, NI howManyExcepts);
N_LIB_PRIVATE N_NIMCALL(tySequence__KjgUMUjT3LUKOFIK4xt5ug*, newSeq__uReleM9aRnQZRzdaRfwc5xQ)(NI len);
static N_INLINE(void, pop__Y36bTNxSoXinCwCTSTCSTgsystem)(tySequence__KjgUMUjT3LUKOFIK4xt5ug** s, tyTuple__FxkU4d1VDodDMc9ah6Mbagw* Result);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, X5BX5D___TZRG9c19bQX0slkSQAmDzJZAsystem)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Kbv8OIo8zpawh7SNMbfgkA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__QrTB5DOwbDX9bKAW7PNbuJA_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
static N_INLINE(void, cow__od9bAwM0gKRf4yeR2rVpdZQcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__9ap9b3IFVLSL9b9akVbfMyRxlA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, NIM_BOOL fastAsgn);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscriminantField__OTZyO2oJpdYpHVBZuRXuRQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__X9cSqNhqEboci9cdmwBMNcBw_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__c1s9cEnyLNclmLP8bBuHmDg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, discriminatorTableDecl__WpGsd0DJejVIze0ZXr8L3g_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* d);
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__QrTB5DOwbDX9bKAW7PNbuJA_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genAsmOrEmitStmt__53Pwv51Dxuia7o9bQN4K9agw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, NIM_BOOL isAsmStmt);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__re1pwmyeR32ikwnOC3vvzQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___22ELRKd9bDuNug6qvIihS3A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__Y9bFh7BmZkh729bS2kZ5kwnQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__re1pwmyeR32ikwnOC3vvzQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xr7e1yaPtCde5qS79c5DFzg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__dZW9czpRSiiVl9cyT6tyk84A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__re1pwmyeR32ikwnOC3vvzQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__QrTB5DOwbDX9bKAW7PNbuJA_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__0dpuY9coTlraj8JXIe2BzVw_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p);
static N_INLINE(void, genSimpleBlock__RH6PUsmPRE4ftBMagpWhBQcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stmts);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ddrHnMlEhcHznkXv27msmQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___B0OBOTOJQENvDd71LJ9b19bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__t9a9a9bxmaOztYOfsfhQUOXXw_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genPragma__UtJx89cn0a8CNSWWmaj6raA_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genEmit__QrTB5DOwbDX9bKAW7PNbuJA_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg, determineSection__3f2MBweHSQI3C7jDZiYA2Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__QrTB5DOwbDX9bKAW7PNbuJA_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yhJ9aDxHfJqHvWO0i6N9bukQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MLJpsW0DAZYB8lAgq09cUjg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genState__UtJx89cn0a8CNSWWmaj6raA_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__UtJx89cn0a8CNSWWmaj6raA_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8tWfSjtTOlDafxpQPvChAA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xKLwwPkFSVy2Dtn9cuJ78xw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hdRijZdoPR3UGq9aUw2zFDQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__8mAL9ckajemzgfLPfeZVNoQ_23)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZjQc8bFVF8ePFYxjN0iVVg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SiqB8gWmdYKb4vtgqYrrMA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, generateMethodDispatchers__7t0GJlNQwZyLt0Kz3RhRdw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__PBGOqkExHgxzX6Rn0nJkYg)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g);
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s);
N_LIB_PRIVATE N_NIMCALL(void, writeModule__ZCCFqS1YhEjeMHLdSMM8xg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NIM_BOOL pending);
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__7ll08CGQoDzh9cxhZCroU4w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getInitName__ao6gUnuVfQLtZ89c4kaIKfg_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSomeInitName__E8VUcJLPfNp8S9aZKgHijew)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSomeNameForModule__JBd7XGjgK9ab0QMtKIFvb8Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2Ixv9aZ9bvpNaVAVzYBJlUPg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HoXSbgR7plMG7Fef0fcy9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___H1Ma2EXqegHnMqzJZ4SA1g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jpXTCDNVjIi5r4hbHN5SVQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSectionStart__otaTb0ytiYCWgsXTIvijfg)(tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg ps, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2)(tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg ps, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Mb9ccCVvEQ2RaqUK5tbPQ2w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4L62Yp9bLO2ZDcvBG9bSvP9bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MCSdS9cTdQvttqiM9azLzkDg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getHcrInitName__ao6gUnuVfQLtZ89c4kaIKfg_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, hcrGetProcLoadCode__uWPA1lTRrPufWdliMF9aGrg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* sym, NimStringDesc* prefix, NimStringDesc* handle, NimStringDesc* getProcFunc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___E9bSTz8DQ4tgiLV9avQjFgFA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3CQpPXVDiNqC3jKO8Juliw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___w50CkyHBltcyR8rWxttZCg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__7ll08CGQoDzh9cxhZCroU4w_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getDatInitName__ao6gUnuVfQLtZ89c4kaIKfg_6)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSectionStart__KYNwN8RXzjqIkzxFSwHsxw)(tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg fs, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2)(tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg fs, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___fmEfDTfNDkVDxWi9c0O6D2g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__9aldr9cciNpmwLn9bc4Nq2PGQ)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___k9bgPIs43oLgxnk1l4TNQaw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5MqeIopvDuA9aozxL79cQ88g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(NI, rawGet__QnNqXOulpiE3rTDm0rj6bgtables)(tyObject_Table__fdKWDDO1P17zvuQPReVgRA t, NI32 key, NI* hc);
static N_INLINE(NI, hash__ixIcN23Rzgwj4rjH9cMHDWQhashes)(NI32 x);
static N_INLINE(NI, hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes)(NU64 x);
static N_INLINE(NU64, hiXorLo__wWqo9alrSZddOyokrApfNaQhashes)(NU64 a, NU64 b);
static N_INLINE(NU64, hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes)(NU64 a, NU64 b);
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode);
static N_INLINE(NI, nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables)(NI h, NI maxHash);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Zp9bMZDO5tEkvVLTxiKsBkA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___j5FZyaqnqjc2dcsUkAp28Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___EbvvG9awBeRKzx8xuBIb7TA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, sigHash__mSn9a9aX0NBzWqerwPW0qRww_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyArray__qtqsWM5aXmcpMIVmvq3kAA Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9a8besSQa09cOOt9b9cgdVwY9aQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___oVKF7oq59cRGAaMpvWzNWbw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7ru3bwKuSx4Sc8ilsBmX3g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___MDIdJXTVckPj57aO7LMVgw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vQDE0VOBftnrpkVsM9cme4w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9bmR9bM9b0qqEqU0QJKnmLQnA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___88tWbH31SmOWJjgJ7RnfHA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___t1CB59bEwlxfHZhNwNNz1bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YbLM7ZajsWOFLl4iSo0Krg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___rH7Ns9bqAnnfkukwBIlz9bKg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zx9ctq3Ffe9aysjoWhZOzevQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___T9a21DAzFCa3OqRooKKtkqw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__7ll08CGQoDzh9cxhZCroU4w_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__MFyPdYFFCqzDX9cGGcC0rbA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check);
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__7ll08CGQoDzh9cxhZCroU4w_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
static N_NIMCALL(void, Marker_tyRef__UjwNQwrGjW3X9ahveEH9bnWA)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, loadLib__NbMtJSxAjvelhGqZMFvydw)(NimStringDesc* handle, NimStringDesc* name, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, closeNamespaceNim__EBP36f89alKNeO11l19ca8RQ)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, openNamespaceNim__h7k639c1gj2MLT300oN1wwg)(NimStringDesc* namespace_0);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__7ll08CGQoDzh9cxhZCroU4w_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Y4DThr9bpMbmoKpvgT1rYwg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toObjFile__GMjJ0d3khWrmxAqhh9anEsw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genModule__EFwkiA59cPQJZpsz0yL8eHQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getFileHeader__t9c9byVBpvEfissxdPQCEZLw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getCopyright__t9c9byVBpvEfissxdPQCEZLw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___j6hWzb1y4ej13yZg5WynCQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___7GaivGwvdxlAsVH2IdyT2Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCompileCFileCmd__uOCPoEVtEQdC7k9cm7JeVsw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile, NIM_BOOL isMainFile, NIM_BOOL produceOutput);
static N_INLINE(void, addNimDefines__jVBximZchOMC4kzSRdtvHgcgen)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YfbBxPLyPvVS6F2y9bSUFIA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genMergeInfo__T0VHRXp9cMnXMqYxgPwvmXw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__7ll08CGQoDzh9cxhZCroU4w_6)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___OBvl4G6evYkvK9b9bClFGqNw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__7ll08CGQoDzh9cxhZCroU4w_7)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceChar)(NimStringDesc* s, NIM_CHAR sub, NIM_CHAR by);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___pHsLkkx9bTDctZjmJqwCYRA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ksH6NowTz9bh4eMOdyaiR1w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__H4aCBrBgfkxUNX78oimi1g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalsFile__Wiam9c8x73Mtmbj0r4Ppikg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRope__LLRRC42xWBSkxzV9bsPu7lA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* head, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileNewer)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(void, addFileToCompile__0nANBPjKLpImf3GNXBeQ2Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, mergeRequired__X8MaNNxDVB7fxLVXrvJcFw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, mergeFiles__l8sH9bHsXY4q3tbS3srelEw)(NimStringDesc* cfilename, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(void, close__yy9bzEsQhd9bXopz79cWnxXdw)(tyObject_NdiFile__9cEuXfAnHp9bnWFK409cMtsEw* f, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, writeMapping__LBHXhYTVO2vldQU4a5LZ9aQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* symbolMapping);
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__7ll08CGQoDzh9cxhZCroU4w_8)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___y39ant8iE9bjKB0kbkRCAibQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___RKXvZR1cmZW5dfjtFQCG3g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___nEA33x9cMfuJw3ZiGbn25iw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0xK6HolrLvVFWil73hZYbA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Z2c9cvs0wVVVqTEZ3Qwe9bfw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);

/* section: NIM_merge_DATA */
extern TNimType NTI__NkKlBfvvsMUW70DxvxLVIg_;
extern TNimType NTI__9cG6VsX22pOhho6kxyhFVow_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_2, "TM", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_3, "_", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_4, "ndi", 3);
extern TNimType NTI__SHVxAqOYtIy7teT1q4s0zQ_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_5, ".h", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_6, "nimBackendAssumesChange", 23);
extern TNimType NTI__oUyaggHmIX9bpJcMeoG6lpA_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_7, "\011", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_8, "if (nim_hcr_do_init_)\012", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_9, "{", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_10, "\012", 1);
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_11, "static", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_12, "extern", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_13, " ", 1);
extern TNimType NTI__WwUFq9cJ2xKRlsAWVEHyPRg_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_14, "cannot generate C type for: ", 28);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_16, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtypes.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_15 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 710),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_18, "void", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_19, "void*", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_20, "nimStrVersion", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_21, "N_LIB_IMPORT ", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_22, "N_LIB_EXPORT ", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_23, "static ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_24, "N_LIB_PRIVATE ", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_25, "ccgtypes.nim(166, 14) `typ.isResolvedUserTypeClass` ", 52);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_26, "ccgtypes.nim(199, 19) `false` mapType", 37);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_27, "ccgtypes.nim(200, 17) `false` mapType", 37);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_28, "genProcParams", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_29 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 462),
((NI) 42)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_30, "_0", 2);
extern TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_31, "getTypeName: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_32 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 142),
((NI) 33)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_33, "union", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_34, "struct", 6);
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_35, "ccgtypes.nim(383, 14) `m.forwTypeCache[sig] == result` ", 55);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_36, "getTypeForward(", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_37 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 384),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_38, "cannot map the empty seq type to a C type", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_39 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 402),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_40, "struct", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_41, "_Content", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_42, "struct ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_43, " {\012  NI len; ", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_44, "_Content* p;\012};\012", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_45, "*", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_46, ", ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_47, "void* ClE_0", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_48, "...", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_49, "void)", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_50, ")", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_51, "(", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_52, "_PTR", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_53, "_actual", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_54, "N_NIMCALL", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_55, "N_STDCALL", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_56, "N_CDECL", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_57, "N_SAFECALL", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_58, "N_SYSCALL", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_59, "N_INLINE", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_60, "N_NOINLINE", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_61, "N_FASTCALL", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_62, "N_THISCALL", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_63, "N_CLOSURE", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_64, "N_NOCONV", 8);
N_LIB_PRIVATE NIM_CONST tyArray__t1sx1FVcaX4m77XqENedIQ CallingConvToStr__A7GdKVVGtI3pvj9cV9adydpw = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_54),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_55),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_56),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_57),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_58),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_59),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_60),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_61),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_62),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_63),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_64)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_65, "(*", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_66, "proc has no result symbol", 25);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_68, "/home/runner/work/nightlies/nightlies/nim/compiler/cgen.nim", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_67 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 1013),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_69, " register", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_70, " volatile", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_71, " NIM_NOALIAS", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_72, " = ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_73, ";", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_74, ".len = 0; ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_75, ".p = NIM_NIL;", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_76, " = (", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_77, ")0;", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_78, "nimZeroMem", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_79, "((void*)", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_80, "(&", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_81, ", sizeof(", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_82, "));", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_83, ".Sup", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_84, ".m_type = ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_85, "TNimTypeV2", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_86, ".nim.cpp", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_87, ".nim.m", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_88, ".nim.c", 6);
extern NIM_CONST tyArray__geAxQ09aiJ4i2plLZEkYDpg OS__Jx0qy9c9bSo4fGkMxUfUaAaw;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_89, "/", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_90, "request for RTTI generation for incomplete object: ", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_91 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1343),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_92, "|", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_93, ".", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_94, "NIM_NIL", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_95, " needs to have the \'nimcall\' calling convention", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_96 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1325),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_97, "TNimType", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_98, "TNimNode", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_99, "0", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_100, "void*", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_101, "nimTypeNames", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_102, "ref object", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_103, "anon ref object from ", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_104, "nimTypeRoot", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_105, "genTypeInfoV1(", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_106 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1449),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_107 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1451),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_108, "0", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_109, "Marker_", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_110, "op", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_111, "T", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_112, ".len", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_113, "len", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_114, "Sup.len", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_115, "for (", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_116, " = 0; ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_117, " < ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_118, "; ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_119, "++) {", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_120, "[", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_121, "]", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_122, "genTraverseProc", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_124, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtrav.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_123 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_124),
((NI) 34),
((NI) 42)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_125, "genRecordFieldsAux", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_126 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 527),
((NI) 40)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_127, "mangleRecFieldName", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_128 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 516),
((NI) 33)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_129, "struct {", 8);
extern NIM_CONST tyArray__sa9aJ6U8e9b7Bj4Yq8itsR8w CC__78I18QZNZFIv9ah7oETc0jg;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_130, "struct __attribute__((__packed__)){", 35);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_131, "genRecordFieldsAux(record case branch)", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_132 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 553),
((NI) 25)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_133, "genRecordFieldsAux()", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_134 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 583),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_135, "genTraverseProc()", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_136 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_124),
((NI) 39),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_137, "ULL", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_138, "((", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_139, "NimStringDesc", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_140, "*) NIM_NIL)", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_141, "*) &", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_142, "TGenericSeq", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_143, "const", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_144, "NimStrPayload", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_145, "NimStringV2", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_146, "cannot determine how to produce code for string literal", 55);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_148, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgliterals."
"nim", 66);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_147 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_148),
((NI) 113),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_149, "f", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_150, "genLiteral(", 11);
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_152, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgexprs.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_151 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 99),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_153 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_124),
((NI) 56),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_154 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_124),
((NI) 58),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_155, ".Field", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_156, "nimGCvisit", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_157, ");", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_158, "nimGCvisitSeq", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_159, ".ClE_0", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_160, ".p->data", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_161, "->data", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_162, "a", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_163, "(*a)", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_164, ", \012", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_165 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1180),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_166, "anonymous obj with discriminator", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_167 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1089),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_168, "genObjectFields", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_169 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1132),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_170, "genObjectFields; nkOfBranch broken", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_171 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1148),
((NI) 23)}
;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Max__zlJMNfqX7LwCYj0PF6ncWQ;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_172, "genObjectFields(nkRecCase)", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_173 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1162),
((NI) 25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_174 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1170),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_175 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1175),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_176 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 1484),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_177, "node has no type", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_178 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 3078),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_179, "{\012", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_180, "0x", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_181, "0123456789abcdef", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_182, ",\012", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_183, "}\012", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_184, "{", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_185, "}", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_186, " struct {", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_187, "  NI cap; ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_188, " data[", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_189, "];", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_190, "} ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_191, " = {", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_192, " | NIM_STRLIT_FLAG, ", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_193, "};", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_194, ", {", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_195, "NIM_CONST", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_196, "  ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_197, " Sup;", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_198, "const openArray expression is not an array construction", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_199 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 3116),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_200, "] = ", 4);
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Zero__1ed0M9aQUqqSQVhLxSQO9bCw;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_201, "._", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_202, "NIM_FALSE", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_203, "0.0", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_204, "NIM_NIL", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_205, "{0, NIM_NIL}", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_206, "{NIM_NIL, NIM_NIL}", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_207, "{NIM_NIL, 0}", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_208, "{}", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_209, "cannot create null element for: ", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_210 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2903),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_211 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2973),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_212, "nimCopyMem", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_213, ", (NIM_CONST void*)&", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_214, "asgnRef", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_215, "((void**) ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_216, "unsureAsgnRef", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_217, ", (NIM_CONST void*)", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_218, "genericShallowAssign", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_219, ", (void*)", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_220, "genericAssign", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_221, "genericSeqAssign", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_222, "copyString", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_223, "copyStringRC1", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_224, "if (", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_225, ") ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_226, "nimGCunrefNoCycle", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_227, "ClE_0", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_228, ".ClP_0 = ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_229, ".ClP_0;", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_230 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 366),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_231, ".Field0 = ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_232, ".Field0; ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_233, ".Field1 = ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_234, ".Field1;", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_235, "Len_0;", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_236, "nimPrepareStrMutationV2", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_237, "cannot handle ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_238 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 302),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_239, "genericAssignOpenArray", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_240, "Len_0, ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_241, "genAssignment: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_242 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 404),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_243, "memTrackerWrite", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_244, "objectInit", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_245, ".name = ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_246, "\011return ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_247, " = 0;", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_248, "specializeResetN", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_250, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgreset.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_249 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_250),
((NI) 25),
((NI) 42)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_251, "specializeResetN()", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_252 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_250),
((NI) 29),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_253 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_250),
((NI) 47),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_254 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_250),
((NI) 49),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_255, "((void**)&", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_256, ", NIM_NIL);", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_257, ".ClE_0, NIM_NIL);", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_258, ".ClP_0 = NIM_NIL;", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_259, " = NIM_NIL;", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_260, "closure generation failed", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_261 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 839),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_262, ", (", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_263, ") ClE_0);", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_264, ") ClE_0;", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_265, "NIM_BOOL* nimErr_;", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_266, "nimErr_ = ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_267, "nimErrorFlag", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_268, "();", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_269, "__declspec(noreturn) ", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_270, "__declspec(naked) ", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_271, " {", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_272, "}\012\012", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_273, "#", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_274, "  define nimfr_(proc, file) \\\012      TFrame FR_; \\\012      FR_.pro"
"cname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; ", 125);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_275, "nimFrame", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_276, "(&FR_);\012\012  ", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_277, "  define nimfrs_(proc, file, slots, length) \\\012      struct {TFr"
"ame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; V"
"arSlot s[slots];} FR_; \\\012      FR_.procname = proc; FR_.filename"
" = file; FR_.line = 0; FR_.len = length; ", 232);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_278, "((TFrame*)&FR_);\012\012  ", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_279, "  define nimln_(n, file) \\\012      FR_.line = n; FR_.filename = f"
"ile;\012  ", 70);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_280, "\011nimfr_(", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_281, "nimProfile", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_282, "popFrame", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_283 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 689),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_284, "||", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_285, "nimLoadLibrary", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_286, "))", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_287, "if (!(", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_288, ")) ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_289, "nimLoadLibraryError", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_290, "))) ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_291, "loadDynamicLib", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_292 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 719),
((NI) 35)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_293, "Dl_$1_", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_294 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 752),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_295, "wrong index: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_296 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 759),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_297, "nimGetProcAddr", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_298, "extern ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_299, "N_LIB_EXPORT_VAR ", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_300, "NIM_THREADVAR ", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_301, "cgsym: ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_302, ": ", 2);
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_303 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 791),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_304, "system module needs: ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_305 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 796),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_306, "NimStringDesc*", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_307, "NCSTRING", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_308, "NIM_BOOL", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_309, "NIM_CHAR", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_310, "NI", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_311, "NI8", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_312, "NI16", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_313, "NI32", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_314, "NI64", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_315, "NF", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_316, "NF32", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_317, "NF64", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_318, "NF128", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_319, "NU", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_320, "NU8", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_321, "NU16", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_322, "NU32", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_323, "NU64", 4);
N_LIB_PRIVATE NIM_CONST tyArray__Sjq0yxKksnvb1U6tEMqzYg NumericalTypeToStr__do7KqFuyalEFiD7s8tBisg = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_310),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_311),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_312),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_313),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_314),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_315),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_316),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_317),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_318),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_319),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_320),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_321),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_322),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_323)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_324, "tyStatic for getSimpleTypeDesc", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_325 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 330),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_326, "checkAbi", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_327, "backend & Nim disagree on size for: ", 36);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_328, "&", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_329, "getTypeDescAux: enum", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_330 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 782),
((NI) 29)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_331, " : ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_332, " data[SEQ_DECL_SIZE];", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_333, "ccgtypes.nim(683, 14) `false` invalid apostrophe type parameter"
" index", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_334 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 863),
((NI) 25)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_335, "<", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_336, " COMMA ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_337, "> ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_338, " __attribute__((__packed__))", 28);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_339, "#pragma pack(push, 1)\012", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_340, "* m_type;", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_341, " : public ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_342, "};\012", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_343, "#pragma pack(pop)\012", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_344, "char dummy;\012", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_345, "getTypeDescAux(", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_346 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_16),
((NI) 929),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_347, "extern \"C\" ", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_348, " __attribute__((naked))", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_349, " __attribute__((noreturn))", 26);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_350, ";\012", 2);
extern TNimType NTI__EtHNvCB0bgfu9bFjzx9cb6aA_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_351, "request to generate code for .compileTime proc: ", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_352 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2664),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_353, "expr: proc not init ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_354 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2668),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_355, "_const", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_356, "\'goto\' target must be a literal value", 37);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_358, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgstmts.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_357 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 271),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_359, "*) ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_360, ".dynlib variables cannot have a value", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_361 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 551),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_362, ".threadvar variables cannot have a value", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_363 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 559),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_364, "NIM_CONST ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_365, " = $#;$n", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_366, ";$n", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_367, "\011NimTV_ = (NimThreadVars*) ", 27);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_368, "GetThreadLocalVars", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_369, "NimTV_->", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_370, "nimRegisterThreadLocalMarker", 28);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_371, "nimRegisterGlobalMarker", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_372, "nimln_(", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_373, "nimToCStringConv", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_374, "wrong argument count", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_376, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgcalls.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_375 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 480),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_377, "hcrRegisterGlobal(", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_378, ", \"", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_379, "\", sizeof(", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_380, "), ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_381, ", (void**)&", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_382, "if (hcrRegisterGlobal(", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_383, "))\012", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_384, "=destroy", 8);
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_385, "-", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_386, " != -1 && ((NU)(", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_387, ") >= (NU)(", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_388, ".Field1) || (NU)(", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_389, ".Field1))){ ", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_390, "raiseIndexError", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_391, "(); ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_392, "goto BeforeRet_;", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_393, "goto LA", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_394, "_;", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_395, "Len_0) || (NU)(", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_396, "Len_0))){ ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_397, " != -1 && (", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_398, " < -1 || ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_399, " || ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_400, " > ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_401, ")){ ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_402, ") >= (NU)", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_403, " || (NU)(", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_404, "openArrayLoc: ", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_405 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 196),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_406 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 248),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_407 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 249),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_408 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 56),
((NI) 13)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_409, "if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;", 44);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_410, "if (NIM_UNLIKELY(*nimErr_)) goto LA", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_411 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 641),
((NI) 17)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__MQdRN7fpbG7rPm4JpVVAhA_412 = {
0x00, 0x00, 0x00, 0x00, 0x88, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_413, "call expression expected for C++ pattern", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_414 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 604),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_415 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 544),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_416, "->", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_417 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 689),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_418, "varargs for objective C method\?", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_419 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_376),
((NI) 709),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_420, "expr: var not init ", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_421 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2689),
((NI) 22)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_422, "expr: temp not init ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_423 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2708),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_424, "expr: param not init ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_425 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2715),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_426, "expr(", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_427, "); unknown symbol", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_428 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2717),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_429, "LA", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_430, " == ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_431, "){ ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_432, "raiseOverflow", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_433, ")(", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_434, "+", 1);
N_LIB_PRIVATE NIM_CONST tyArray__ttGk45MsSAdGt9ciYdRA8VQ opr__jSXnH9c8YRRwSdXyVdSg9acA = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_434),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_89)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_435, " (", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_436, " != ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_437, "raiseFloatInvalidOp", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_438, " != 0.0 && ", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_439, "*0.5 == ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_440, ") { ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_441, "raiseFloatOverflow", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_442, "); ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_443, "%", 1);
N_LIB_PRIVATE NIM_CONST tyArray__rJSOG9bfI5wi9aqXvYJsFCWA opr__UAWyVnvyQoWbplounFNlGg = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_434),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_89),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_443),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_434),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_444, " == 0){ ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_445, "raiseDivByZero", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_446, "nimAddInt64", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_447, "nimSubInt64", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_448, "nimMulInt64", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_449, "nimDivInt64", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_450, "nimModInt64", 11);
N_LIB_PRIVATE NIM_CONST tyArray__rJSOG9bfI5wi9aqXvYJsFCWA prc64__9bTptLAKOOYdunqlEwXM6PQ = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_446),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_447),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_448),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_449),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_450),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_446),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_447)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_451, "nimAddInt", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_452, "nimSubInt", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_453, "nimMulInt", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_454, "nimDivInt", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_455, "nimModInt", 9);
N_LIB_PRIVATE NIM_CONST tyArray__rJSOG9bfI5wi9aqXvYJsFCWA prc__8UqUr1y9abLbrO1vSUF2CqQ = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_451),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_452),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_453),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_454),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_455),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_451),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_452)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_456, ", &", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_457, ")) { ", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_458, "\'repr\' is not available for --newruntime", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_459 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1630),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_460, "reprInt", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_461, "((NI64)", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_462, "reprFloat", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_463, "reprBool", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_464, "reprChar", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_465, "reprEnum", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_466, "((NI)", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_467, "reprStr", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_468, "reprSet", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_469, "genRepr()", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_470 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1664),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_471, "reprOpenArray", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_472, "reprAny", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_473, "\'repr\' doesn\'t support \'void\' type", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_474 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1673),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_475 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1133),
((NI) 39)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_476, "getDynamicTypeInfo", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_477, ".m_type", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_478, "->typeInfoV1", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_479, "binaryStmt", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_480 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 495),
((NI) 34)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_481, "+=", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_482, "-=", 2);
N_LIB_PRIVATE NIM_CONST tyArray__cqX2jO1YLR9bYjA09bx8BZVg opr__O7uP3jzNu3e9auWdRdRa9cJA = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_481),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_482)}
;
N_LIB_PRIVATE NIM_CONST tyArray__cqX2jO1YLR9bYjA09bx8BZVg fun64__fjrbodMqcYB619bEDCGfJsA = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_446),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_447)}
;
N_LIB_PRIVATE NIM_CONST tyArray__cqX2jO1YLR9bYjA09bx8BZVg fun__gOe15RXeJ2duD5In6NwLXA = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_451),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_452)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_483, "appendChar", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_484, " + ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_485, "appendString", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_486, "rawNewString", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_487, "binaryStmtAddr", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_488 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 502),
((NI) 34)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_489, "nimAddCharV1", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_490, "addChar", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_491, "prepareAdd", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_492, "resizeString", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_493, "incrSeqV3", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_494, "((TGenericSeq*)(", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_495, "NI ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_496, "++;", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_497, " == 0)", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_498, "eqStrings", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_499, "cmpStrings", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_500, ") <= 0)", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_501, ") < 0)", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_502, ".ClP_0 == 0)", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_503, "nimIntToStr", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_504, "nimInt64ToStr", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_505, "nimBoolToStr", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_506, "nimCharToStr", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_507, "nimFloatToStr", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_508, "cstrToNimstr", 12);
extern TNimType NTI__MvZmat48bhe9b6x9aUD58D5Q_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_509, "no \'of\' operator available for pure objects", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_510 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1617),
((NI) 15)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_511, ") && (", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_512, "isObj", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_513, ".m_type, ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_514, "Nim_OfCheck_CACHE", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_515, "isObjWithCache", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_516, "nimNewObj", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_517, ", NIM_ALIGNOF(", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_518, "nimNewObjUninit", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_519, "the destructor that is turned into a finalizer needs to have th"
"e \'nimcall\' calling convention", 93);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_520 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1297),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_521, "nimGCunrefRC1", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_522, " = NIM_NIL; }", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_523, "newObj", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_524, "newObjRC1", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_525, ".len = ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_526, ".p = (", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_527, "newSeqPayload", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_528, "), NIM_ALIGNOF(", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_529, "newSeq", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_530, "newSeqRC1", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_531, "nimNewSeqOfCap", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_532, "unknown ast", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_533 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2341),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_534, "Field", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_535, ")-(", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_536, ")+1", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_537, "Len_0-1)", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_538, "Len_0", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_539, ".Field1-1)", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_540, ".Field1", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_541, " \? (", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_542, "nimCStrLen", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_543, ")-1) : -1)", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_544, " \? ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_545, ") : 0)", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_546, "genArrayLen()", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_547 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1769),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_548, "unaryStmt", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_549 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 509),
((NI) 34)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_550, "nimGCref", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_551, "); }", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_552, "nimGCunref", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_553, "setLengthStrV2", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_554, "genSetLengthStr", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_555 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1816),
((NI) 36)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_556, "setLengthStr", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_557, "setLengthSeqV2", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_558, "(&(", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_559, ")->Sup, ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_560, "countBits32", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_561, "countBits64", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_562, "(((", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_563, " & ~ ", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_564, ")==0)&&(", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_565, ")==0)", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_566, " & ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_567, " | ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_568, "genSetOp()", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_569 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1961),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_570, "cardSet", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_571, "++) { ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_572, " = ((", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_573, "] & ~ ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_574, "]) == 0);", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_575, "  if (!", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_576, ") break;}", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_577, "nimCmpMem", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_578, ") != 0);", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_579, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == "
"0);$n  if (!$3) break;}$n", 88);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_580, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == "
"0);$n  if (!$3) break;}$nif ($3) $3 = (#nimCmpMem($4, $5, $2) !="
" 0);$n", 133);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_581, "& ~", 3);
N_LIB_PRIVATE NIM_CONST tyArray__B06a0PrPRpY9aXtMPObCiCA lookupOpr__w7WuexLq9cuXtAtqil9csnVQ = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_579),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_580),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_328),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_92),
((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_581)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_582, "genSetOp", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_583 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2000),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_584 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1105),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_585, ", \"\"", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_586, ", Genode::Cstring(", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_587, "->data, ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_588, "->len)", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_589, "<base/log.h>", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_590, "<util/string.h>", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_591, "Genode::log(\"\"", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_592, "echoBinSafe", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_593, "(NIM_NIL, ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_594, "\'$1\' can only be used in compile-time context", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_595 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2390),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_596, "for --gc:arc|orc \'deepcopy\' support has to be enabled with --de"
"epcopy:on", 72);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_597 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2405),
((NI) 16)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_598, "genericDeepCopy", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_599, "genericSeqDeepCopy", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_600, "genericDeepCopyOpenArray", 24);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_601, "genDeepCopy: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_602 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 454),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_603, ".p != ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_604, ".p) {", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_605, ".len; ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_606, ".p = ", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_607, ".p;", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_608, ".p && !(", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_609, ".p->cap & NIM_STRLIT_FLAG)) {", 29);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_610, "deallocShared", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_611, ".p);", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_612, "dealloc", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_613, "alignedDealloc", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_614, ".p, NIM_ALIGNOF(", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_615, "destructor turned out to be not trivial", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_616 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2205),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_617, "genMagicExpr: ", 14);
extern TNimType NTI__shZhZOdbVC5nnFvcXQAImg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_618 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2422),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_619, "CNSTCLOSURE", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_620, "closure to closure created", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_621 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2502),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_622, ".ClE_0 = ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_623, "genCheckedRecordField", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_624 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 832),
((NI) 33)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_625, "genObjConstr", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_626 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1460),
((NI) 40)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_627, "raiseFieldError", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_628, "union { ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_629, " source; ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_630, " dest; } LOC", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_631, "if ((NU)(", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_632, ") > (NU)(", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_633, "raiseIndexError2", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_634, "raiseIndexError3", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_635, "index out of bounds, the container is empty", 43);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_636, "index ", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_637, " not in ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_638, " .. ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_639 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 929),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_640, "[(", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_641, ")- ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_642, "Len_0)){ ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_643, ",", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_644, "Len_0-1); ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_645, ".Field1)){ ", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_646, ".Field1-1); ", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_647, ".Field0[", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_648, ") > (NU)", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_649, "-1); ", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_650, "genTupleElem", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_651 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 815),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_652, "expr(nkBracketExpr, ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_653 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 1025),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_654, "genDeref ", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_655 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 753),
((NI) 21)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_656, "genRecordFieldAux", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_657 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 799),
((NI) 38)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_658, "genRecordField 3 ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_659 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 849),
((NI) 40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_660 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 894),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_661, "FR", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_662, ".procname = ", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_663, ".filename = ", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_664, ";  ", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_665, ".line = ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_666, ".len = -1; nimFrame(&", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_667, "popFrameOfAddr", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_668, "genIf()", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_669 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 460),
((NI) 23)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_670, "->Sup", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_671, " = &", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_672, " && !", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_673, "raiseObjectConversionError", 26);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_674, "if (!", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_675, " > (", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_676, "raiseRangeErrorNoArgs", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_677, "raiseRangeErrorU", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_678, "raiseRangeErrorF", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_679, "raiseRangeErrorI", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_680, "csize", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_681, "(NI64)", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_682, ") < ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_683, ") > ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_684 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2786),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_685, "case statement must be exhaustive for computed goto", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_686 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 513),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_687, "case statement cannot work on enums with holes for computed got"
"o", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_688 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 517),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_689, "case statement has too many cases for computed goto", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_690 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 521),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_691, "case statement has to start at 0 for computed goto", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_692 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 525),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_693, "no case statement found for computed goto", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_694 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 528),
((NI) 14)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_695, "range notation not available for computed goto", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_696 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 552),
((NI) 18)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_697, "while (1) {", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_698, "genVarTuple", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_699 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 64),
((NI) 40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_700 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 107),
((NI) 44)}
;
N_LIB_PRIVATE TNimType NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
N_LIB_PRIVATE TNimType NTI__sno9c9bXUVS2CqhtWOJadaCw_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_702, "NIM_BOOL ", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_703, " = NIM_FALSE;", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_704, " |= hcrRegisterGlobal(", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_705, ");\012", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_706, "for statement not eliminated", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_707 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2794),
((NI) 29)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_708, ")) goto ", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_709, "switch (", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_710, "hashString", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_711, ") & ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_712, ") {", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_713, " >= ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_714, " && ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_715, " <= ", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_716, ") goto ", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_717 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 484),
((NI) 18)}
;
extern TNimType NTI__KjgUMUjT3LUKOFIK4xt5ug_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_718, "popSafePoint", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_719, "popCurrentException", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_720, ".status != 0) ", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_721, "ccgstmts.nim(684, 13) `sym.loc.k == locOther` ", 46);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_722, "no loop to break", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_723 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 690),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_724, "FieldDiscriminantCheck", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_725, "((NI)(NU)(", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_726, "), (NI)(NU)(", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_727 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 1551),
((NI) 11)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_728, "(void)(", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_729, "\"", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_730, "\\\"", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_731, "\\n\"\012", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_732, "if (NIM_UNLIKELY(*nimErr_)) {", 29);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_733, "_:;", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_734, "*nimErr_ = NIM_FALSE;", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_735, "m_type", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_736, "Sup.m_type", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_737, "nimBorrowCurrentException", 25);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_738, "()->", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_739, "else ", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_740, "NIM_BOOL oldNimErrFin", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_741, "oldNimErrFin", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_742, "_ = *nimErr_; *nimErr_ = NIM_FALSE;", 35);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_743, "*nimErr_ = oldNimErrFin", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_744, "<exception>", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_745, "\011std::exception_ptr T", 21);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_746, "_ = nullptr;", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_747, "try {", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_748, "catch (", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_749, "Exception", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_750, "* T", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_751, "_) {", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_752, "\011TFrame* _nimCurFrame;", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_753, "\011_nimCurFrame = ", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_754, "getFrame", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_755, "setFrame", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_756, "(_nimCurFrame);", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_757, "_ = std::current_exception();", 29);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_758, "else if (", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_759, " = T", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_760, "else throw;", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_761, "catch (...) {", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_762, "& ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_763, "&) {", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_764, "if (T", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_765, "_) std::rethrow_exception(T", 27);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_766, "_);", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_767, "<setjmp.h>", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_768, "TSafePoint", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_769, "pushSafePoint", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_770, "nimStdSetjmp", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_771, ".status = setjmp(", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_772, ".context);", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_773, "nimSigSetjmp", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_774, ".status = sigsetjmp(", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_775, ".context, 0);", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_776, "nimRawSetjmp", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_777, ".status = _setjmp(", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_778, ".status == 0) {", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_779, "else {", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_780, "()) {", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_781, ".status = 0;", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_782, "nimLeaveFinally", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_783, "reraiseException", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_784, "raiseExceptionEx", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_785, "*)", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_786, "/*TYPESECTION*/", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_787, "/*VARSECTION*/", 14);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_788, "/*INCLUDESECTION*/", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_789 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 189),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_790, "STATE", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_791, ": ;", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_792, "STATE", 5);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_793, "); unknown node kind", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_794 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_152),
((NI) 2854),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_795 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_358),
((NI) 1583),
((NI) 17)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_796, "nimTestErrorFlag", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_797, "programResult", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_798, "procAddrError", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_799, "rawWrite", 8);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_800, "initStackBottomWith", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_801, "initThreadVarsEmulation", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_802, "still forwarded: ", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_803 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 2109),
((NI) 19)}
;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_804, "NimMainModule", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_805, "Init000", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_806, "N_LIB_EXPORT", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_807, "N_LIB_PRIVATE", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_808, "generated_not_to_break_here", 27);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_809, "* ", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_810, "\011hcrRegisterGlobal(", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_811, "\", sizeof(TNimNode) * ", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_812, ", NULL, (void**)&", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_813, "\011if (nim_hcr_do_init_) {\012\012", 26);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_814, "\012\011} // nim_hcr_do_init_\012", 24);
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_815, "hcrRegisterProc", 15);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_816, "hcrGetProc", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_817, "hcrRegisterGlobal", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_818, "hcrGetGlobal", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_819, "HcrInit000", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_820, "hcrInit", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_821, "hcrAddModule", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_822, "handle", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_823, "getProcAddr", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_824, "DatInit000", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_825, "stdlib_system", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_826, "stdlib_os", 9);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_827, "\011int* cmd_count;\012", 17);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_828, "\011char*** cmd_line;\012", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_829, "\011*cmd_count = cmdCount;\012", 24);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_830, "\011*cmd_line = cmdLine;\012", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_831, "();\012", 4);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_832, "((void *)&inner);\012", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_833, "\012\012", 2);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_834, "#", 1);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_835, "ifndef ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_836, "_Content_PP\012", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_837, "define ", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_838, "_Content_PP\012struct ", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_839, "_Content { NI cap; ", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_840, " data[SEQ_DECL_SIZE];};\012", 24);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_841, "endif\012\012      ", 13);
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__IDX4istqRyOZp3l6j9aUesw_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
N_LIB_PRIVATE TNimType NTI__UjwNQwrGjW3X9ahveEH9bnWA_;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_843, "\011if (!(", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_844, ")))\012\011\011", 6);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_845, "hcr_handle", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_847, "\011void* rtl_handle;\012", 19);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_848, "rtl_handle", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_849, "nimGC_setStackBottom", 20);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_851, "nimrtl_", 7);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_852, "\011inner = PreMain;\012", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_853, "\011initStackBottomWith_actual((void *)&inner);\012", 45);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_854, "\011(*inner)();\012", 13);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_855, "\011PreMain();\012", 12);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_856, "<windows.h>", 11);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_857, "<libc/component.h>", 18);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_858, "\012N_LIB_PRIVATE void PreMainInner(void) {\012", 41);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_859, "}\012\012N_LIB_PRIVATE int cmdCount;\012N_LIB_PRIVATE char** cmdLine;\012N_"
"LIB_PRIVATE char** gEnv;\012N_LIB_PRIVATE void PreMain(void) {\012\011voi"
"d (*volatile inner)(void);\012\011inner = PreMainInner;\012", 177);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_860, "\011(*inner)();\012}\012\012", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_861, "N_LIB_PRIVATE N_CDECL(void, NimMainInner)(void) {\012", 50);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_862, "}\012\012N_CDECL(void, NimMain)(void) {\012\011void (*volatile inner)(void)"
";\012", 65);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_863, "\011inner = NimMainInner;\012", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_864, "}\012\012N_LIB_EXPORT N_CDECL(void, NimMain)(void) {\012\011void (*volatile"
" inner)(void);\012", 78);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_865, "extern Genode::Env *nim_runtime_env;\012extern void nim_component_"
"construct(Genode::Env*);\012\012N_LIB_PRIVATE N_CDECL(void, NimMainInn"
"er)(void) {\012", 139);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_866, "using namespace ", 16);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_867, "N_STDCALL(int, WinMain)(HINSTANCE hCurInstance, \012              "
"          HINSTANCE hPrevInstance, \012                        LPST"
"R lpCmdLine, int nCmdShow) {\012\011NimMain();\012\011return ", 176);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_868, "nim_program_result;\012}\012\012", 23);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_869, "BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fwdreason, \012     "
"               LPVOID lpvReserved) {\012\011if(fwdreason == DLL_PROCES"
"S_ATTACH) {\012\011NimMain();\012}\012\011return 1;\012}\012\012", 167);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_870, "void Libc::Component::construct(Libc::Env &env) {\012\011// Set Env u"
"sed during runtime initialization\012\011nim_runtime_env = &env;\012\011Libc"
"::with_libc([&] () {\012\011\011// Initialize runtime and globals\012\011NimMai"
"n();\012\011// Call application construct\012\011\011nim_component_construct(&e"
"nv);\012\011});\012}\012\012", 268);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_871, "N_LIB_PRIVATE void NIM_POSIX_INIT NimMainInit(void) {\012\011NimMain("
");\012}\012\012", 69);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_872, "int main(void) {\012\011NimMain();\012\011return 0;\012}\012\012", 43);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_873, "int main(int argc, char** args, char** env) {\012\011cmdLine = args;\012"
"\011cmdCount = argc;\012\011gEnv = env;\012\011NimMain();\012\011return ", 114);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_874, "namespace ", 10);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_875, " {\012", 3);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_876, "1.4.2", 5);
extern NIM_CONST tyArray__8d8P9caia9cszVjIJKsQGMQA CPU__uYXopJX8pM87pQDCtmgWfQ;
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_877, "#define NIM_HOT_CODE_RELOADING\012", 31);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_878, "#define USE_NIM_NAMESPACE ", 26);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_879, "nimEmulateOverflowChecks", 24);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_880, "#define NIM_EmulateOverflowChecks\012", 34);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_881, "\012#include \"nimbase.h\"\012", 22);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_882, "#undef LANGUAGE_C\012#undef MIPSEB\012#undef MIPSEL\012#undef PPC\012#undef"
" R3000\012#undef R4000\012#undef i386\012#undef linux\012#undef mips\012#undef "
"near\012#undef far\012#undef powerpc\012#undef unix\012", 170);
STRING_LITERAL(TM__MQdRN7fpbG7rPm4JpVVAhA_883, "#define nimfr_(x, y)\012#define nimln_(x, y)\012", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_884 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 1962),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_885 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 1970),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_886 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 2013),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_887 = {((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_68),
((NI) 1895),
((NI) 14)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, initProcOptions__qttThLa3xHNEeApwU61sZA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg result;
	tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg opts;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg));
	opts = (*(*(*m).g).config).options;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA3_;
		result = (opts & ~ 131072);
	}
	goto LA1_;
	LA3_: ;
	{
		result = opts;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTempName__ao6gUnuVfQLtZ89c4kaIKfg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*m).labels)));
	result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*m).tmpBase, T1_);
	(*m).labels += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, rawNewModule__a8P0HPhDv3Sesns79bJU0jA)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, NimStringDesc* filename) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* result;
	NimStringDesc* T1_;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA T2_;
	NimStringDesc* T3_;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
	NimStringDesc* ndiName;
	result = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	result = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) newObj((&NTI__NkKlBfvvsMUW70DxvxLVIg_), sizeof(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow));
	(*result).Sup.Sup.m_type = (&NTI__9cG6VsX22pOhho6kxyhFVow_);
	asgnRef((void**) (&(*result).g), g);
	T1_ = (NimStringDesc*)0;
	nimZeroMem((void*)T2_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashOwner__mSn9a9aX0NBzWqerwPW0qRww_4(module, T2_);
	T3_ = (NimStringDesc*)0;
	T3_ = dollar___0A9bslyIJ49bWrftLGh13rvg(T2_);
	T1_ = rawNewString((T3_ ? T3_->Sup.len : 0) + 3);
appendString(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_2));
appendString(T1_, T3_);
appendString(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
	asgnRef((void**) (&(*result).tmpBase), rope__yShmEg9cffWxI7s5XzEKBow(T1_));
	if ((*result).headerFiles) { nimGCunrefNoCycle((*result).headerFiles); (*result).headerFiles = NIM_NIL; }
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).declaredThings));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).declaredProtos));
	T4_ = (NimStringDesc*)0;
	T4_ = (*result).cfilename; (*result).cfilename = copyStringRC1(filename);
	if (T4_) nimGCunrefNoCycle(T4_);
	T5_ = (NimStringDesc*)0;
	T5_ = (*result).filename; (*result).filename = copyStringRC1(filename);
	if (T5_) nimGCunrefNoCycle(T5_);
	initTable__ZudPzqPNlpthuJgNIdX3jA(((NI) 32), (&(*result).typeCache));
	initTable__ZudPzqPNlpthuJgNIdX3jA(((NI) 32), (&(*result).forwTypeCache));
	asgnRef((void**) (&(*result).module), module);
	initTable__ZudPzqPNlpthuJgNIdX3jA(((NI) 32), (&(*result).typeInfoMarker));
	initCountTable__9apu9bmxB0tG2KjdEWuGfVPg(((NI) 32), (&(*result).sigConflicts));
	asgnRef((void**) (&(*result).initProc), newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), result));
	(*(*result).initProc).options = initProcOptions__qttThLa3xHNEeApwU61sZA(result);
	asgnRef((void**) (&(*result).preInitProc), newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), result));
	(*(*result).preInitProc).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 6)) & 7);
	(*(*result).preInitProc).labels = ((NI) 100000);
	initNodeTable__RsAJjlvhLCgVyd9cZJtMRoQ((&(*result).dataCache));
	if ((*result).typeStack) { nimGCunrefNoCycle((*result).typeStack); (*result).typeStack = NIM_NIL; }
	asgnRef((void**) (&(*result).typeNodesName), getTempName__ao6gUnuVfQLtZ89c4kaIKfg(result));
	asgnRef((void**) (&(*result).nimTypesName), getTempName__ao6gUnuVfQLtZ89c4kaIKfg(result));
	{
		if (!(((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA8_;
		(*result).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 0)) & 7);
		(*(*result).preInitProc).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17)) & 31));
	}
	LA8_: ;
	{
		NimStringDesc* T14_;
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 6))&63U)))!=0)) goto LA12_;
		T14_ = (NimStringDesc*)0;
		T14_ = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*g).config, filename, NIM_TRUE);
		ndiName = noschangeFileExt(T14_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_4));
	}
	goto LA10_;
	LA12_: ;
	{
		ndiName = ((NimStringDesc*) NIM_NIL);
	}
	LA10_: ;
	open__jmWVcl5Qp9atJWCEkvq1SfA((&(*result).ndi), ndiName, (*g).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, rawNewModule__S73dIOk2nN4g6ZKuvNB9ceA_2)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* result;
	NimStringDesc* T1_;
	result = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, ((NI32) ((*module).position)));
	result = rawNewModule__a8P0HPhDv3Sesns79bJU0jA(g, module, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, newModule__S73dIOk2nN4g6ZKuvNB9ceA)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* result;
	result = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	result = rawNewModule__S73dIOk2nN4g6ZKuvNB9ceA_2(g, module, conf);
	{
		NI T3_;
		T3_ = ((*g).modules ? (*g).modules->Sup.len : 0);
		if (!(T3_ <= (*module).position)) goto LA4_;
		asgnRef((void**) (&(*g).modules), (tySequence__SHVxAqOYtIy7teT1q4s0zQ*) setLengthSeqV2(&((*g).modules)->Sup, (&NTI__SHVxAqOYtIy7teT1q4s0zQ_), ((NI) ((NI)((*module).position + ((NI) 1))))));
	}
	LA4_: ;
	asgnRef((void**) (&(*g).modules->data[(*module).position]), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__uilCuJJCRRa62GOiz1PPkg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* result;
	tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* T6_;
	result = (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*)0;
	{
		tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* T5_;
		if (!((*graph).backend == ((RootObj*) NIM_NIL))) goto LA3_;
		T5_ = (tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*)0;
		T5_ = newModuleList__pKl1ntXN7hbkEFOmcSlHSg(graph);
		asgnRef((void**) (&(*graph).backend), &T5_->Sup);
	}
	LA3_: ;
	g = (*((tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA**) (&((*graph).backend))));
	T6_ = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	T6_ = newModule__S73dIOk2nN4g6ZKuvNB9ceA(g, module, (*graph).config);
	result = &T6_->Sup;
	{
		NIM_BOOL T9_;
		NimStringDesc* f;
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*(*graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 27))&63U)))!=0);
		if (!(T9_)) goto LA10_;
		T9_ = ((*g).generatedHeader == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL));
		LA10_: ;
		if (!T9_) goto LA11_;
		{
			if (!(((NI) 0) < ((*(*graph).config).headerFile ? (*(*graph).config).headerFile->Sup.len : 0))) goto LA15_;
			f = (*(*graph).config).headerFile;
		}
		goto LA13_;
		LA15_: ;
		{
			f = (*(*graph).config).projectFull;
		}
		LA13_: ;
		T18_ = (NimStringDesc*)0;
		T18_ = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*graph).config, f, NIM_TRUE);
		T19_ = (NimStringDesc*)0;
		T19_ = noschangeFileExt(T18_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_5));
		asgnRef((void**) (&(*g).generatedHeader), rawNewModule__a8P0HPhDv3Sesns79bJU0jA(g, module, T19_));
		(*(*g).generatedHeader).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 3)) & 7);
	}
	LA11_: ;
	return result;
}
static N_INLINE(NIM_BOOL, skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((NI) 0) < (*config).errorCounter);
	return result;
}
static N_INLINE(NIM_BOOL, moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((NI) 0) <= (*module).Sup.id);
	if (T1_) goto LA2_;
	T1_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*graph).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_6));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__a2BRACVCGIuooKjHNmoLsA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*(*m).g).config);
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, blockBody__tMtK9ba4LBR5bZYSR9avbIag)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* b) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = (*b).sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0))- 0];
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!(((NI16) 0) < (*b).frameLen)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*b).frameLen)));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___ZkZcMxwzInnijXy5kz1K3A(T5_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T6_);
	}
	LA3_: ;
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*b).sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1))- 0]);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*b).sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2))- 0]);
	return result;
}
static N_INLINE(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA*, X5BX5D___VZz2UCb3YWId9ctIYs8ikogsystem)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* s, NI sLen_0, NI i) {
	tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* result;
	result = (tyObject_TBlock__GFhahvekTq3dDOkWyhchMA*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, s__kOyJGmZMM2tMgCKSrvUE3gcgendata)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result;
	tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = (tyObject_TBlock__GFhahvekTq3dDOkWyhchMA*)0;
	T1_ = X5BX5D___VZz2UCb3YWId9ctIYs8ikogsystem((*p).blocks->data, ((*p).blocks ? (*p).blocks->Sup.len : 0), ((NI) 1));
	result = &(*T1_).sections[(s)- 0];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, indentLine__5PupwEBrKjp65kTtpnAp9bQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = r;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T5_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
				prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&result, T5_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__12ZfBiPs9cA29axtp2bvV6zg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* blockEnd) {
	NI topBlock;
	NI T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	topBlock = (NI)(T1_ - ((NI) 1));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = blockBody__tMtK9ba4LBR5bZYSR9avbIag((&(*p).blocks->data[topBlock]));
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).blocks->data[(NI)(topBlock - ((NI) 1))].sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2))- 0], T2_);
	asgnRef((void**) (&(*p).blocks), (tySequence__oUyaggHmIX9bpJcMeoG6lpA*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__oUyaggHmIX9bpJcMeoG6lpA_), ((NI) (topBlock))));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, blockEnd);
	add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T4_);
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__0dpuY9coTlraj8JXIe2BzVw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	NI topBlock;
	NI T1_;
	NI16 frameLen;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* blockEnd;
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	topBlock = (NI)(T1_ - ((NI) 1));
	frameLen = (*p).blocks->data[topBlock].frameLen;
	blockEnd = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!(((NI16) 0) < frameLen)) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (frameLen)));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___KxpxlR6eqq3gRIOYTfR67w(T6_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&blockEnd, T7_);
	}
	LA4_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		if (!!(((*p).blocks->data[topBlock].label == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA10_;
		nimZeroMem((void*)T12_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T12_[0] = (*p).blocks->data[topBlock].label;
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = percent___IFeEbVhQpPGgxkLehuSiBA(T12_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&blockEnd, T13_);
	}
	goto LA8_;
	LA10_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		nimZeroMem((void*)T15_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = percent___BYiowJAm8zF7RBRISElaLg(T15_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&blockEnd, T16_);
	}
	LA8_: ;
	endBlock__12ZfBiPs9cA29axtp2bvV6zg(p, blockEnd);
}
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	NI result;
	result = (NI)0;
	{
		tyTuple__FxkU4d1VDodDMc9ah6Mbagw* x;
		NI i;
		NI L;
		NI T2_;
		x = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
		i = ((NI) 0);
		T2_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				x = (&(*p).nestedTryStmts->data[i]);
				{
					if (!(*x).Field1) goto LA7_;
					result += ((NI) 1);
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__1ygdb876UM9astcNUXtgUBQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	NI result;
	NI T1_;
	NI T2_;
	NI T3_;
	result = (NI)0;
	(*p).labels += ((NI) 1);
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	result = T1_;
	asgnRef((void**) (&(*p).blocks), (tySequence__oUyaggHmIX9bpJcMeoG6lpA*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__oUyaggHmIX9bpJcMeoG6lpA_), ((NI) ((NI)(result + ((NI) 1))))));
	(*p).blocks->data[result].id = ((NI) ((*p).labels));
	T2_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	(*p).blocks->data[result].nestedTryStmts = ((NI16) (T2_));
	T3_ = (NI)0;
	T3_ = inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2(p);
	(*p).blocks->data[result].nestedExceptStmts = ((NI16) (T3_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillLoc__o49bXuxJYpCizOgQ54UViIg)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s) {
	{
		if (!((*a).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		(*a).k = k;
		unsureAsgnRef((void**) (&(*a).lode), lode);
		(*a).storage = s;
		{
			if (!((*a).r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA7_;
			unsureAsgnRef((void**) (&(*a).r), r);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleName__RaNE9b8A430I9bfpgZmdrC1w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = (*s).loc.r;
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*s).name).s);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T5_);
		T6_ = (NimStringDesc*)0;
		T6_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*(*m).module).name).s);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = idOrSig__sKAFwdXn9cKHxc9cdaovk69cA(s, T6_, (&(*m).sigConflicts));
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T7_);
		asgnRef((void**) (&(*s).loc.r), result);
		{
			NI T12_;
			if (!(*m).ndi.enabled) goto LA10_;
			asgnRef((void**) (&(*m).ndi.syms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*m).ndi.syms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
			T12_ = (*m).ndi.syms->Sup.len++;
			asgnRef((void**) (&(*m).ndi.syms->data[T12_]), s);
		}
		LA10_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	sym = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!((*sym).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = mangleName__RaNE9b8A430I9bfpgZmdrC1w(m, sym);
		fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 7), n, T5_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useHeader__TAVDUakAwQnRHDK9cFe6L7g_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	{
		NimStringDesc* str;
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 6))&15U)))!=0)) goto LA3_;
		str = getStr__P2DOsHG6Jk4Siab3L2qwUg((*(*sym).annex).path);
		includeHeader__G5jzmdnwglHVk5qfDcXonA(m, str);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q)(NimStringDesc** result, NimStringDesc* value) {
	unsureAsgnRef((void**) (&(*result)), resizeString((*result), (value ? value->Sup.len : 0) + 0));
appendString((*result), value);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__bilAk8nY4d5fxUpVg9bnphQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	if (!(T1_)) goto LA2_;
	T1_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 37))&63U)))!=0));
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem)(tySequence__WwUFq9cJ2xKRlsAWVEHyPRg** s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI L;
	NI T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) setLengthSeqV2(&((*s))->Sup, (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ)(NimStringDesc** result, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value) {
	{
		NimStringDesc* str;
		str = (NimStringDesc*)0;
		{
			tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* stack;
			if (!!((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA4_;
			stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) newSeq((&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), 1);
			asgnRef((void**) (&stack->data[0]), value);
			{
				while (1) {
					NI T8_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* it;
					T8_ = (stack ? stack->Sup.len : 0);
					if (!(((NI) 0) < T8_)) goto LA7;
					it = pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem((&stack));
					{
						while (1) {
							NI T11_;
							if (!!(((*it).left == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA10;
							stack = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) incrSeqV3((TGenericSeq*)(stack), (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_));
							T11_ = stack->Sup.len++;
							asgnRef((void**) (&stack->data[T11_]), (*it).right);
							it = (*it).left;
						} LA10: ;
					}
					str = (*it).data;
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), (str ? str->Sup.len : 0) + 0));
appendString((*result), str);
				} LA7: ;
			}
		}
		LA4_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__IafZhvqpthq9b9c13SFhzAOw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
	result = (NIM_BOOL)0;
	x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(1189055854743137808));
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = !(((*x).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T5_)) goto LA6_;
	T5_ = (((*(*x).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
	LA6_: ;
	T1_ = T5_;
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NimStringDesc* literal) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((*(*t).sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
		LA6_: ;
		if (!T3_) goto LA7_;
		useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, (*t).sym);
		result = (*(*t).sym).loc.r;
	}
	goto LA1_;
	LA7_: ;
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(literal);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__V25kMWfh1jWVNQQI5BNfLg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NI result;
	result = (NI)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* coreX60gensym63_;
		if (!((*(*m).g).strVersion == ((NI) 0))) goto LA3_;
		coreX60gensym63_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*m).g).graph, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_20));
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (coreX60gensym63_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (T7_) goto LA8_;
			T7_ = !(((*coreX60gensym63_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10)));
			LA8_: ;
			if (!T7_) goto LA9_;
			(*(*m).g).strVersion = ((NI) 1);
		}
		goto LA5_;
		LA9_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
			T12_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw((*coreX60gensym63_).ast);
			(*(*m).g).strVersion = toInt__TIX0sFuRf3uBpOBltYp7bw(T12_);
		}
		LA5_: ;
	}
	LA3_: ;
	result = (*(*m).g).strVersion;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__FP3Xc9c0yhzvB6NLyfQJkYw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !(((*prc).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__HbYPOpwLApFuBkISFGrmEQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	NI T1_;
	asgnRef((void**) (&(*(*m).g).forwardedProcs), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*(*m).g).forwardedProcs), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T1_ = (*(*m).g).forwardedProcs->Sup.len++;
	asgnRef((void**) (&(*(*m).g).forwardedProcs->data[T1_]), prc);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*, findPendingModule__Dhy9cmzSsJkQqlfDq047WUA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ms;
	result = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	ms = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
	result = (*(*m).g).modules->data[(*ms).position];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__bilAk8nY4d5fxUpVg9bnphQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	if (!(T1_)) goto LA2_;
	T1_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 37))&63U)))!=0);
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w result;
	NI64 T1_;
	result = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
	T1_ = (NI64)0;
	T1_ = getSize__vCG1GF2Iu043oALVyuJfOw(conf, typ);
	switch (((NI) (T1_))) {
	case ((NI) 1):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 4);
	}
	break;
	case ((NI) 2):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 5);
	}
	break;
	case ((NI) 4):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 6);
	}
	break;
	case ((NI) 8):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 7);
	}
	break;
	default:
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapType__pNoigHLHIPJ32RkjLRvhAQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w result;
{	result = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 0);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 2);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 1);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 20);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		result = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA(conf, typ);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			if (!(kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3))) goto LA9_;
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17);
		}
		goto LA7_;
		LA9_: ;
		{
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 19);
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 19);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
		{
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0))) goto LA17_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_25));
		}
		LA17_: ;
		T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T19_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, T19_, kind);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T21_;
		T21_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T21_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, T21_, kind);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T25_;
			NIM_BOOL T26_;
			T25_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(conf, typ);
			T26_ = (NIM_BOOL)0;
			T26_ = lt___nr9cP9b0OL9cabygV9bo19cJgZA_3(T25_, IL64(0));
			if (!T26_) goto LA27_;
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 6);
		}
		goto LA23_;
		LA27_: ;
		{
			NI64 T30_;
			T30_ = (NI64)0;
			T30_ = getSize__vCG1GF2Iu043oALVyuJfOw(conf, typ);
			switch (((NI) (T30_))) {
			case ((NI) 1):
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 13);
			}
			break;
			case ((NI) 2):
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 14);
			}
			break;
			case ((NI) 4):
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 6);
			}
			break;
			case ((NI) 8):
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 7);
			}
			break;
			default:
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 6);
			}
			break;
			}
		}
		LA23_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	{
		result = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, (*typ).sons->data[((NI) 0)], kind);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T38_;
		T38_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T38_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		base = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T38_, IL64(36134350135273744));
		switch ((*base).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
		{
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 18);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
		{
			{
				tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T43_;
				T43_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
				T43_ = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA(conf, base);
				if (!(T43_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17))) goto LA44_;
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 18);
			}
			goto LA41_;
			LA44_: ;
			{
				result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 20);
			}
			LA41_: ;
		}
		break;
		default:
		{
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 20);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 20);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 22);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			if (!!(((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA53_;
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 23);
		}
		goto LA51_;
		LA53_: ;
		{
			result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 19);
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 21);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 24);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		result = ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) ((NI)((NI)((*typ).kind - ((NI) 31)) + ((NI) 3))));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T64_;
			if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA62_;
			T64_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T64_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
			result = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, T64_, kind);
		}
		goto LA60_;
		LA62_: ;
		{
			{
				if (!NIM_TRUE) goto LA68_;
				failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_26));
			}
			LA68_: ;
		}
		LA60_: ;
	}
	break;
	default:
	{
		{
			if (!NIM_TRUE) goto LA73_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_27));
		}
		LA73_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T4_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T4_ = (NIM_BOOL)0;
	T4_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0);
	if (!(T4_)) goto LA5_;
	T4_ = ((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	LA5_: ;
	T3_ = T4_;
	if (T3_) goto LA6_;
	T3_ = isPureObject__IVXYI9cxSeivThgKCncHRnA_2(typ);
	LA6_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rettype) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(rettype == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA3_: ;
	{
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T6_;
		T6_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T6_ = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, rettype, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
		switch (T6_) {
		case ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
			T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(rettype, IL64(36134350135273744));
			result = !(((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47) || (*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21)));
		}
		break;
		case ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 19):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			NIM_BOOL T16_;
			NIM_BOOL T18_;
			NIM_BOOL T20_;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(rettype, IL64(36134350135273744));
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(rettype);
				if (T12_) goto LA13_;
				T12_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(t);
				LA13_: ;
				if (!T12_) goto LA14_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			LA14_: ;
			T16_ = (NIM_BOOL)0;
			T16_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(t);
			if (T16_) goto LA17_;
			T18_ = (NIM_BOOL)0;
			T18_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			if (!(T18_)) goto LA19_;
			T20_ = (NIM_BOOL)0;
			T20_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(t);
			T18_ = !(T20_);
			LA19_: ;
			T16_ = T18_;
			LA17_: ;
			result = T16_;
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__plkNLyLwnwkMYELCfG4Gxw)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* w) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*w).Sup.id) {
	case ((NI) 222) ... ((NI) 287):
	case ((NI) 4) ... ((NI) 66):
	case ((NI) 143):
	{
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleParamName__RaNE9b8A430I9bfpgZmdrC1w_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = (*s).loc.r;
	{
		NimStringDesc* res;
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		res = mangle__GxzvEIRbrShQbyJNboTw7A((*(*s).name).s);
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (T8_) goto LA9_;
			T8_ = isKeyword__plkNLyLwnwkMYELCfG4Gxw((*s).name);
			LA9_: ;
			T7_ = T8_;
			if (T7_) goto LA10_;
			T7_ = contains__RafAVeUVSno4B47UdPqNlg((*(*(*m).g).config).cppDefines, res);
			LA10_: ;
			if (!T7_) goto LA11_;
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_30));
		}
		LA11_: ;
		result = rope__yShmEg9cffWxI7s5XzEKBow(res);
		asgnRef((void**) (&(*s).loc.r), result);
		{
			NI T17_;
			if (!(*m).ndi.enabled) goto LA15_;
			asgnRef((void**) (&(*m).ndi.syms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*m).ndi.syms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
			T17_ = (*m).ndi.syms->Sup.len++;
			asgnRef((void**) (&(*m).ndi.syms->data[T17_]), s);
		}
		LA15_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw, paramStorageLoc__lQqiacOo5FnwNzTrDjiPvw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param) {
	tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw result;
	result = (tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw)0;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*param).typ, IL64(140737496744192));
		if (!!(((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48)))) goto LA4_;
		result = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccgIntroducedPtr__W9aw79b629bysnh3DDOpE3OTg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* pt;
{	result = (NIM_BOOL)0;
	pt = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s).typ, IL64(36134350135273744));
	{
		if (!(((*pt).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 14))&63U)))!=0)) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(((*pt).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 13))&63U)))!=0)) goto LA6_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	switch ((*pt).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = !(((*(*s).typ).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T11_)) goto LA12_;
			T11_ = (((*(*(*s).typ).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0);
			LA12_: ;
			if (!T11_) goto LA13_;
			result = NIM_TRUE;
		}
		goto LA9_;
		LA13_: ;
		{
			NIM_BOOL T16_;
			NI64 T18_;
			T16_ = (NIM_BOOL)0;
			T16_ = (((*s).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 20))&31U)))!=0);
			if (T16_) goto LA17_;
			T18_ = (NI64)0;
			T18_ = getSize__vCG1GF2Iu043oALVyuJfOw(conf, pt);
			T16_ = (((NI64) ((NI)((*conf).target.floatSize * ((NI) 3)))) < T18_);
			LA17_: ;
			if (!T16_) goto LA19_;
			result = NIM_TRUE;
		}
		goto LA9_;
		LA19_: ;
		{
			NIM_BOOL T22_;
			T22_ = (NIM_BOOL)0;
			T22_ = (((*pt).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0);
			if (!(T22_)) goto LA23_;
			T22_ = ((*pt).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			LA23_: ;
			if (!T22_) goto LA24_;
			result = NIM_FALSE;
		}
		goto LA9_;
		LA24_: ;
		{
			result = NIM_TRUE;
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		NIM_BOOL T28_;
		NI64 T29_;
		T28_ = (NIM_BOOL)0;
		T29_ = (NI64)0;
		T29_ = getSize__vCG1GF2Iu043oALVyuJfOw(conf, pt);
		T28_ = (((NI64) ((NI)((*conf).target.floatSize * ((NI) 3)))) < T29_);
		if (T28_) goto LA30_;
		T28_ = (((*s).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 20))&31U)))!=0);
		LA30_: ;
		result = T28_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	{
		NIM_BOOL T34_;
		NIM_BOOL T35_;
		NIM_BOOL T40_;
		NIM_BOOL T42_;
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T44_;
		T34_ = (NIM_BOOL)0;
		T35_ = (NIM_BOOL)0;
		T35_ = ((*s).position == ((NI) 0));
		if (!(T35_)) goto LA36_;
		T35_ = !((retType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA36_: ;
		T34_ = T35_;
		if (!(T34_)) goto LA37_;
		T34_ = ((*retType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
		LA37_: ;
		if (!T34_) goto LA38_;
		T40_ = (NIM_BOOL)0;
		T40_ = ((*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
		if (T40_) goto LA41_;
		T42_ = (NIM_BOOL)0;
		T42_ = ((*pt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19));
		if (!(T42_)) goto LA43_;
		T44_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T44_ = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA(conf, pt);
		T42_ = (T44_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17));
		LA43_: ;
		T40_ = T42_;
		LA41_: ;
		result = !(T40_);
	}
	LA38_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, cacheGetType__2wgznvEs9bt7XaKJgVohBCw)(tyObject_Table__gZ3EYQdz9coOB7ngN9a1cqwA tab, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = getOrDefault__tD8SQMueXhdfvpBnagcsKg(tab, sig);
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, typeName__qvCJ9bux56nS82Shxh5hLNg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	typ_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(1189055854743137808));
	{
		NIM_BOOL T3_;
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*typ_2).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*typ_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*typ_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NimStringDesc*)0;
		T8_ = (NimStringDesc*)0;
		T8_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*(*typ_2).sym).name).s);
		T7_ = rawNewString((reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + (T8_ ? T8_->Sup.len : 0) + 1);
appendString(T7_, reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T7_, 95);
appendString(T7_, T8_);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	t = typ;
	{
		while (1) {
			{
				NIM_BOOL T5_;
				T5_ = (NIM_BOOL)0;
				T5_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T5_)) goto LA6_;
				T5_ = !(((192 & (*(*t).sym).flags) == 0));
				LA6_: ;
				if (!T5_) goto LA7_;
				result = (*(*t).sym).loc.r;
				goto BeforeRet_;
			}
			LA7_: ;
			{
				if (!((IL64(1189055854743137808) &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA11_;
				t = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			}
			goto LA9_;
			LA11_: ;
			{
				goto LA1;
			}
			LA9_: ;
		}
	} LA1: ;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4) || (*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46) || (*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA16_;
		typ_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
	}
	goto LA14_;
	LA16_: ;
	{
		typ_2 = typ;
	}
	LA14_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		NimStringDesc* T24_;
		if (!((*typ_2).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA21_;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = typeName__qvCJ9bux56nS82Shxh5hLNg(typ_2);
		T24_ = (NimStringDesc*)0;
		T24_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig);
		asgnRef((void**) (&(*typ_2).loc.r), amp___Z7W1o5nPSc3ExfO5f7j1Gg(T23_, T24_));
	}
	goto LA19_;
	LA21_: ;
	{
	}
	LA19_: ;
	result = (*typ_2).loc.r;
	{
		NimStringDesc* T30_;
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA28_;
		T30_ = (NimStringDesc*)0;
		T30_ = rawNewString((reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 13);
appendString(T30_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_31));
appendString(T30_, reprEnum((NI)(*typ_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T30_, TM__MQdRN7fpbG7rPm4JpVVAhA_32);
	}
	LA28_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__IafZhvqpthq9b9c13SFhzAOw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* structOrUnion, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typename_0) {
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = structOrUnion;
		T7_[1] = typename_0;
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___vzbf0XksfaFTXNoTT6BCwA(T7_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 3))- 0], T8_);
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T10_[0] = structOrUnion;
		T10_[1] = typename_0;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = percent___lQVSDPkAFXHNoa1N7jYrNw(T10_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 3))- 0], T11_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, structOrUnion__TLFDupRCidtMx8175pusWQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* cachedUnion;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* cachedStruct;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	cachedUnion = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_33));
	cachedStruct = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_34));
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(70368744177680));
	{
		if (!(((*t_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0)) goto LA3_;
		result = cachedUnion;
	}
	goto LA1_;
	LA3_: ;
	{
		result = cachedStruct;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushType__4q3XOfd3NI3C8cSNkaF9cWA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NI T9_;
{	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*m).typeStack ? (*m).typeStack->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				{
					if (!((*m).typeStack->data[i] == typ)) goto LA7_;
					goto BeforeRet_;
				}
				LA7_: ;
				res += ((NI) 1);
			} LA4: ;
		}
	}
	asgnRef((void**) (&(*m).typeStack), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*m).typeStack), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
	T9_ = (*m).typeStack->Sup.len++;
	asgnRef((void**) (&(*m).typeStack->data[T9_]), typ);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).forwTypeCache, sig);
	{
		if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = getTypePre__zLenRlTUJy0Mn9b8JKwzEcQ(m, typ, sig);
	{
		if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	concrete = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	switch ((*concrete).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, typ, sig);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).forwTypeCache), sig, result);
		{
			NIM_BOOL T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			T12_ = (NIM_BOOL)0;
			T12_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(concrete);
			if (!!(T12_)) goto LA13_;
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = structOrUnion__TLFDupRCidtMx8175pusWQ(typ);
			addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg(m, T15_, result);
		}
		goto LA10_;
		LA13_: ;
		{
			pushType__4q3XOfd3NI3C8cSNkaF9cWA(m, concrete);
		}
		LA10_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T19_;
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T19_ = X5BX5D___KricVWBSqqSbgxpQ5up3Ig((&(*m).forwTypeCache), sig);
			if (!!(((*T19_) == result))) goto LA20_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_35));
		}
		LA20_: ;
	}
	break;
	default:
	{
		NimStringDesc* T23_;
		T23_ = (NimStringDesc*)0;
		T23_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 16);
appendString(T23_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_36));
appendString(T23_, reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T23_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T23_, TM__MQdRN7fpbG7rPm4JpVVAhA_37);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, seqStar__hiFj6GH2C6Qv8bI0r9caT5A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		result = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* etB;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	etB = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
	switch ((*etB).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(etB);
			if (!(T4_)) goto LA5_;
			T4_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
			LA5_: ;
			if (!T4_) goto LA6_;
			result = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, t, check, kind);
		}
		goto LA2_;
		LA6_: ;
		{
			tyArray__qtqsWM5aXmcpMIVmvq3kAA T9_;
			nimZeroMem((void*)T9_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
			hashType__UdooXLclXL8uld7qLI5JRw(t, 2, T9_);
			result = getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2(m, t, T9_);
			pushType__4q3XOfd3NI3C8cSNkaF9cWA(m, t);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
		nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__UdooXLclXL8uld7qLI5JRw(t, 2, sig);
		{
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA13_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
				T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T17_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*etB).sons->data[((NI) 0)], IL64(36134350135273744));
				if (!((*T17_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3))) goto LA18_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_38), TM__MQdRN7fpbG7rPm4JpVVAhA_39);
			}
			LA18_: ;
			result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA22_;
				result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, t, sig);
				{
					NIM_BOOL T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* payload;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
					T26_ = (NIM_BOOL)0;
					T26_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
					if (!!(T26_)) goto LA27_;
					X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).forwTypeCache), sig, result);
					T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T29_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_40));
					addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg(m, T29_, result);
					payload = amp___Z7W1o5nPSc3ExfO5f7j1Gg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_41));
					T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T30_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_40));
					addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg(m, T30_, payload);
				}
				LA27_: ;
			}
			LA22_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
				T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T33_ = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
				if (!(T33_ == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA34_;
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
				res = rawNewString(((NI) 80));
				res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_42));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
				res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_43));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
				res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_44));
				T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T36_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T36_);
			}
			LA34_: ;
		}
		goto LA11_;
		LA13_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			NimStringDesc* T39_;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2(m, t, sig);
			T39_ = (NimStringDesc*)0;
			T39_ = seqStar__hiFj6GH2C6Qv8bI0r9caT5A(m);
			result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T38_, T39_);
		}
		LA11_: ;
		pushType__4q3XOfd3NI3C8cSNkaF9cWA(m, t);
	}
	break;
	default:
	{
		result = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, t, check, kind);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w, mapReturnType__K9aceyVl15zb9aYN9b6YJ8TnA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w result;
	result = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
	result = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__uApDq1rn2zPxULBMpTSrxQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** rettype, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** params, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NIM_BOOL declareEnvironment, NIM_BOOL weakDep) {
	unsureAsgnRef((void**) (&(*params)), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	{
		NIM_BOOL T3_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*m).g).config, (*t).sons->data[((NI) 0)]);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		unsureAsgnRef((void**) (&(*rettype)), percent___G9aA37gQrW88KHzpCAwhgjQ(T7_, 0));
	}
	goto LA1_;
	LA5_: ;
	{
		unsureAsgnRef((void**) (&(*rettype)), getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*t).sons->data[((NI) 0)], check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11)));
	}
	LA1_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*t).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA11;
				i = i_2;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
					tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw T29_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T44_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arr;
					NI j;
					{
						if (!!(((*(*(*t).n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA15_;
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*(*t).n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_28), TM__MQdRN7fpbG7rPm4JpVVAhA_29);
					}
					LA15_: ;
					param = (*(*(*t).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T19_;
						T19_ = (NIM_BOOL)0;
						T19_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*param).typ);
						if (!T19_) goto LA20_;
						goto LA12;
					}
					LA20_: ;
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T26_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
						if (!!(((*params) == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA24_;
						nimZeroMem((void*)T26_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T27_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T26_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T27_);
					}
					LA24_: ;
					T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T28_ = mangleParamName__RaNE9b8A430I9bfpgZmdrC1w_2(m, param);
					T29_ = (tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw)0;
					T29_ = paramStorageLoc__lQqiacOo5FnwNzTrDjiPvw(param);
					fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*param).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 4), (*(*t).n)._kind_6.sons->data[i], T28_, T29_);
					{
						NIM_BOOL T32_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T36_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
						T32_ = (NIM_BOOL)0;
						T32_ = ccgIntroducedPtr__W9aw79b629bysnh3DDOpE3OTg((*(*m).g).config, param, (*t).sons->data[((NI) 0)]);
						if (!T32_) goto LA33_;
						T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T35_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, (*param).typ, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T35_);
						nimZeroMem((void*)T36_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T37_ = percent___6d8an6hdqiIrRjPW1wEh5Q(T36_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T37_);
						(*param).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
						(*param).loc.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
					}
					goto LA30_;
					LA33_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
						if (!weakDep) goto LA39_;
						T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T41_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, (*param).typ, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T41_);
					}
					goto LA30_;
					LA39_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
						T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T43_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*param).typ, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T43_);
					}
					LA30_: ;
					nimZeroMem((void*)T44_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T45_ = percent___gMbiWAc0IjihIq46IYhmAw(T44_, 0);
					add__IM4kcMNkkOLJtqdEqSxR8A(params, T45_);
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T50_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
						if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45))&63U)))!=0)) goto LA48_;
						nimZeroMem((void*)T50_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T51_ = percent___xQvB9bmOgLpiXXbaCWxYbRg(T50_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(params, T51_);
					}
					LA48_: ;
					add__IM4kcMNkkOLJtqdEqSxR8A(params, (*param).loc.r);
					arr = (*param).typ;
					{
						if (!((*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47) || (*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46))) goto LA54_;
						arr = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(arr);
					}
					LA54_: ;
					j = ((NI) 0);
					{
						while (1) {
							tyArray__mrugoXXRZUEeG9bEXo9auBKw T62_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
							if (!((*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA57;
							{
								if (!((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))) goto LA60_;
								(*param).loc.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
							}
							LA60_: ;
							nimZeroMem((void*)T62_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
							T62_[0] = (*param).loc.r;
							T62_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (j)));
							T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T63_ = percent___uHsu7fLXac4OhMNd79bSJwA(T62_, 2);
							add__IM4kcMNkkOLJtqdEqSxR8A(params, T63_);
							j += ((NI) 1);
							arr = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arr).sons->data[((NI) 0)], IL64(70368744177664));
						} LA57: ;
					}
				} LA12: ;
				i_2 += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NIM_BOOL T66_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arr_2;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T82_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
		T66_ = (NIM_BOOL)0;
		T66_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T66_)) goto LA67_;
		T66_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*m).g).config, (*t).sons->data[((NI) 0)]);
		LA67_: ;
		if (!T66_) goto LA68_;
		arr_2 = (*t).sons->data[((NI) 0)];
		{
			if (!!(((*params) == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA72_;
			add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		}
		LA72_: ;
		{
			tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T76_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
			T76_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
			T76_ = mapReturnType__K9aceyVl15zb9aYN9b6YJ8TnA_2((*(*m).g).config, (*t).sons->data[((NI) 0)]);
			if (!!((T76_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17)))) goto LA77_;
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T79_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, arr_2, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			add__IM4kcMNkkOLJtqdEqSxR8A(params, T79_);
			add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
		}
		goto LA74_;
		LA77_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
			T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T81_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, arr_2, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			add__IM4kcMNkkOLJtqdEqSxR8A(params, T81_);
		}
		LA74_: ;
		nimZeroMem((void*)T82_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T83_ = percent___3WM9b4PeyDKoIDFMvYcQX3w(T82_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(params, T83_);
	}
	LA68_: ;
	{
		NIM_BOOL T86_;
		T86_ = (NIM_BOOL)0;
		T86_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		if (!(T86_)) goto LA87_;
		T86_ = declareEnvironment;
		LA87_: ;
		if (!T86_) goto LA88_;
		{
			if (!!(((*params) == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA92_;
			add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		}
		LA92_: ;
		add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_47));
	}
	LA88_: ;
	{
		if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0))&63U)))!=0)) goto LA96_;
		{
			if (!!(((*params) == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA100_;
			add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		}
		LA100_: ;
		add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_48));
	}
	LA96_: ;
	{
		if (!((*params) == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA104_;
		add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_49));
	}
	goto LA102_;
	LA104_: ;
	{
		add__yG4AKzsBRS1W4MANDlXQeg(params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	}
	LA102_: ;
	unsureAsgnRef((void**) (&(*params)), amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51), (*params)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProcHeader__OWG529cW3RTHLgDJuQoIH8A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL asPtr) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* rettype;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* asPtrStr;
	NimStringDesc* T21_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	rettype = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	params = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5))&15U)))!=0)) goto LA3_;
		{
			if (!(((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 3))&7U)))!=0)) goto LA7_;
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_21));
		}
		goto LA5_;
		LA7_: ;
		{
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_22));
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5));
		if (T12_) goto LA13_;
		T12_ = asPtr;
		LA13_: ;
		T11_ = T12_;
		if (T11_) goto LA14_;
		T11_ = isNonReloadable__bilAk8nY4d5fxUpVg9bnphQ_2(m, prc);
		LA14_: ;
		if (!T11_) goto LA15_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
	}
	goto LA1_;
	LA15_: ;
	{
		if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0))) goto LA18_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_24));
	}
	goto LA1_;
	LA18_: ;
	LA1_: ;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T20_ = mangleName__RaNE9b8A430I9bfpgZmdrC1w(m, prc);
	fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*prc).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 7), (*(*prc).ast)._kind_6.sons->data[((NI) 0)], T20_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	genProcParams__uApDq1rn2zPxULBMpTSrxQ(m, (*prc).typ, &rettype, &params, (&check), NIM_TRUE, NIM_FALSE);
	T21_ = (NimStringDesc*)0;
	{
		if (!asPtr) goto LA24_;
		T21_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_52));
	}
	goto LA22_;
	LA24_: ;
	{
		T21_ = ((NimStringDesc*) NIM_NIL);
	}
	LA22_: ;
	asPtrStr = rope__yShmEg9cffWxI7s5XzEKBow(T21_);
	name = (*prc).loc.r;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, prc);
		if (!(T29_)) goto LA30_;
		T29_ = !(asPtr);
		LA30_: ;
		if (!T29_) goto LA31_;
		add__yG4AKzsBRS1W4MANDlXQeg(&name, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_53));
	}
	LA31_: ;
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T37_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
		if (!((*prc).constraint == 0)) goto LA35_;
		nimZeroMem((void*)T37_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T37_[0] = rope__yShmEg9cffWxI7s5XzEKBow(CallingConvToStr__A7GdKVVGtI3pvj9cV9adydpw[((*(*prc).typ).callConv)- 0]);
		T37_[1] = asPtrStr;
		T37_[2] = rettype;
		T37_[3] = name;
		T37_[4] = params;
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T38_ = percent___p4LhaCxKpUERrq9cB9b8Mp9cw(T37_, 5);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T38_);
	}
	goto LA33_;
	LA35_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* asPtrStr_2;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T47_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			if (!asPtr) goto LA42_;
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_65));
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T44_, name);
			asPtrStr_2 = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T45_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		}
		goto LA40_;
		LA42_: ;
		{
			asPtrStr_2 = name;
		}
		LA40_: ;
		nimZeroMem((void*)T47_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T47_[0] = rettype;
		T47_[1] = asPtrStr_2;
		T47_[2] = params;
		result = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA((*(*prc).constraint)._kind_3.strVal, T47_, 3);
	}
	LA33_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag((*n)._kind_6.sons->data[i]);
						if (!T13_) goto LA14_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, easyResultAsgn__oKhRC9bEKTxG5epdNiNWZ0w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		NI i;
		i = ((NI) 0);
		{
			while (1) {
				NIM_BOOL T4_;
				NI T5_;
				T4_ = (NIM_BOOL)0;
				T5_ = (NI)0;
				T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				T4_ = (i < T5_);
				if (!(T4_)) goto LA6_;
				T4_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) || (*(*n)._kind_6.sons->data[i]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) && (*(*n)._kind_6.sons->data[i]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159));
				LA6_: ;
				if (!T4_) goto LA3;
				i += ((NI) 1);
			} LA3: ;
		}
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(i < T9_)) goto LA10_;
			result = easyResultAsgn__oKhRC9bEKTxG5epdNiNWZ0w((*n)._kind_6.sons->data[i]);
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NIM_BOOL T19_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T16_)) goto LA17_;
			T16_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag((*n)._kind_6.sons->data[((NI) 1)]);
			T15_ = !(T19_);
			LA18_: ;
			if (!T15_) goto LA20_;
			(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 15)) & 31);
			result = (*n)._kind_6.sons->data[((NI) 1)];
			goto BeforeRet_;
		}
		LA20_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		{
			NI T25_;
			T25_ = (NI)0;
			T25_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T25_)) goto LA26_;
			result = easyResultAsgn__oKhRC9bEKTxG5epdNiNWZ0w((*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA30_;
				(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 15)) & 31);
			}
			LA30_: ;
		}
		LA26_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, shallow__cnzwaZQQIa73ryXE31wijQsystem)(NimStringDesc** s) {
	TGenericSeq* s_2;
	s_2 = ((TGenericSeq*) ((*s)));
	{
		NimStringDesc* T5_;
		if (!(s_2 == ((TGenericSeq*) NIM_NIL))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = mnewString(((NI) 0));
		s_2 = ((TGenericSeq*) (T5_));
	}
	LA3_: ;
	{
		if (!((NI)((*s_2).reserved & ((NI) 1073741824)) == ((NI) 0))) goto LA8_;
		(*s_2).reserved = (NI)((*s_2).reserved | ((NI) (-2147483647 -1)));
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleLocalName__VpV5Cmis02zaNlTmLYJNfQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = (*s).loc.r;
	{
		NimStringDesc* key;
		NI counter;
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		key = mangle__GxzvEIRbrShQbyJNboTw7A((*(*s).name).s);
		shallow__cnzwaZQQIa73ryXE31wijQsystem((&key));
		counter = getOrDefault__9bK0jMctS3Kpz9aVaHPQI4gA((*p).sigConflicts, key, ((NI) 0));
		result = rope__yShmEg9cffWxI7s5XzEKBow(key);
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5))) goto LA7_;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
				if (!!((counter == ((NI) 0)))) goto LA11_;
				T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T13_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(counter + ((NI) 1)))));
				T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T14_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3), T13_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T14_);
			}
			LA11_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			NIM_BOOL T16_;
			NIM_BOOL T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NIM_BOOL)0;
			T17_ = !((counter == ((NI) 0)));
			if (T17_) goto LA18_;
			T17_ = isKeyword__plkNLyLwnwkMYELCfG4Gxw((*s).name);
			LA18_: ;
			T16_ = T17_;
			if (T16_) goto LA19_;
			T16_ = contains__RafAVeUVSno4B47UdPqNlg((*(*(*(*p).module).g).config).cppDefines, key);
			LA19_: ;
			if (!T16_) goto LA20_;
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(counter + ((NI) 1)))));
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3), T22_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T23_);
		}
		goto LA5_;
		LA20_: ;
		LA5_: ;
		inc__cue4X8ebEalt3pWXvkS49cw((&(*p).sigConflicts), key, ((NI) 1));
		asgnRef((void**) (&(*s).loc.r), result);
		{
			if (!!(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5)))) goto LA26_;
			{
				NI T32_;
				if (!(*(*p).module).ndi.enabled) goto LA30_;
				asgnRef((void**) (&(*(*p).module).ndi.syms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*(*p).module).ndi.syms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
				T32_ = (*(*p).module).ndi.syms->Sup.len++;
				asgnRef((void**) (&(*(*p).module).ndi.syms->data[T32_]), s);
			}
			LA30_: ;
		}
		LA26_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, localVarDecl__NYI5fC69aIqZGRakncXv9cNQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	s = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!((*s).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = mangleLocalName__VpV5Cmis02zaNlTmLYJNfQ(p, s);
		fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*s).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 2), n, T5_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9))) goto LA8_;
			(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 2)) & 15);
		}
		LA8_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T12_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T12_)) goto LA13_;
		T12_ = (((NI) 0) < (*s)._kind_4.alignment);
		LA13_: ;
		if (!T12_) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T16_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*s)._kind_4.alignment)));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = percent___iaEKHmIC9bNRZLxBqSNX0Sg(T16_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T17_);
	}
	LA14_: ;
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*s).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T18_);
	{
		if (!((*s).constraint == 0)) goto LA21_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0)) goto LA25_;
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_69));
		}
		LA25_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0)) goto LA29_;
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_70));
		}
		LA29_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45))&63U)))!=0)) goto LA33_;
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_71));
		}
		LA33_: ;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*s).loc.r);
	}
	goto LA19_;
	LA21_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T36_;
		nimZeroMem((void*)T36_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T36_[0] = result;
		T36_[1] = (*s).loc.r;
		result = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA((*(*s).constraint)._kind_3.strVal, T36_, 2);
	}
	LA19_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLoc__qlujIAW86QclHYUVxlHRiQ)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s) {
	(*result).k = k;
	(*result).storage = s;
	unsureAsgnRef((void**) (&(*result).lode), lode);
	unsureAsgnRef((void**) (&(*result).r), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result) {
	initLoc__qlujIAW86QclHYUVxlHRiQ(result, ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		if (T5_) goto LA6_;
		T5_ = ((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T11_)) goto LA12_;
			T11_ = (((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA12_: ;
			if (!T11_) goto LA13_;
			(*result).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8)) & 15);
		}
		LA13_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		(*result).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8)) & 15);
	}
	LA1_: ;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, e, result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdLoc__xidyzuHqIciXbQyEOKahDg)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = a.r;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0))&15U)))!=0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = result;
		result = percent___TbMwXzwNL7txOQADiTjwKA(T5_, 1);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__UtJx89cn0a8CNSWWmaj6raA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* nl;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* decl;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	{
		if (!(((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0)) goto LA3_;
		nl = ((NimStringDesc*) NIM_NIL);
	}
	goto LA1_;
	LA3_: ;
	{
		nl = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA1_: ;
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = localVarDecl__NYI5fC69aIqZGRakncXv9cNQ(p, n);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T6_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	decl = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T7_, nl);
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, decl);
	add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T9_);
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, t__XNOXh7uniWNgiq58C9bW49awcgen)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*a.lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		result = (*(*a.lode)._kind_4.sym).typ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (*a.lode).typ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isComplexValueType__Fl17jclCP5VEr9a7Ycym1awcgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(49645149017385232));
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19) || (*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t_2).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, addrLoc__9b8NbhHc4w1oBKAy127l3xQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = a.r;
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T6_;
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0))&15U)))!=0));
		if (!(T3_)) goto LA4_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T6_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			if (!((*a.lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA9_;
			T6_ = (*(*a.lode)._kind_4.sym).kind;
		}
		goto LA7_;
		LA9_: ;
		{
			T6_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
		}
		LA7_: ;
		T12_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T12_ = mapType__pNoigHLHIPJ32RkjLRvhAQ(conf, T5_, T6_);
		T3_ = !((T12_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17)));
		LA4_: ;
		if (!T3_) goto LA13_;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80), result);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T15_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getCFile__bmANOnd5oQhXRrTCn9a8S4g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NimStringDesc* result;
	NimStringDesc* ext;
	NimStringDesc* T13_;
	NimStringDesc* T14_;
	result = (NimStringDesc*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		ext = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_86));
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 4));
		if (T8_) goto LA9_;
		T8_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 32))&63U)))!=0);
		LA9_: ;
		if (!T8_) goto LA10_;
		ext = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_87));
	}
	goto LA1_;
	LA10_: ;
	{
		ext = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_88));
	}
	LA1_: ;
	T13_ = (NimStringDesc*)0;
	T13_ = withPackageName__9bhgFqdEZM7DoX7p3U69bQEg_2((*(*m).g).config, (*m).cfilename);
	T14_ = (NimStringDesc*)0;
	T14_ = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*m).g).config, T13_, NIM_TRUE);
	result = noschangeFileExt(T14_, ext);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getModuleDllPath__ao6gUnuVfQLtZ89c4kaIKfg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T2_;
	NimStringDesc* dir;
	NimStringDesc* name;
	NimStringDesc* ext;
	NimStringDesc* filename;
	tyArray__nHXaesL0DJZHyVS07ARPRA T3_;
	NimStringDesc* T4_;
	NimStringDesc* T5_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = getCFile__bmANOnd5oQhXRrTCn9a8S4g(m);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw(T1_, (&T2_));
	dir = (NimStringDesc*)0;
	dir = T2_.Field0;
	name = (NimStringDesc*)0;
	name = T2_.Field1;
	ext = (NimStringDesc*)0;
	ext = T2_.Field2;
	nimZeroMem((void*)T3_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
	T4_ = (NimStringDesc*)0;
	T4_ = rawNewString((name ? name->Sup.len : 0) + (ext ? ext->Sup.len : 0) + 0);
appendString(T4_, name);
appendString(T4_, ext);
	T3_[0] = T4_;
	filename = nsuFormatOpenArray(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*(*(*m).g).config).target.targetOS)- 1].Field2, T3_, 1);
	T5_ = (NimStringDesc*)0;
	T5_ = rawNewString((dir ? dir->Sup.len : 0) + (filename ? filename->Sup.len : 0) + 1);
appendString(T5_, dir);
appendString(T5_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_89));
appendString(T5_, filename);
	result = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T5_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* T1_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
	T1_ = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA(m, s);
	result = getModuleDllPath__ao6gUnuVfQLtZ89c4kaIKfg_2(T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__xfVyTYRVyjtacYdjZK1hbA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* str, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ownerModule) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nr;
	nr = rope__yShmEg9cffWxI7s5XzEKBow(name);
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T6_[0] = str;
		T6_[1] = nr;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___DJoMxkeDQMwm5cCmPzoZHw(T6_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T7_);
		nimZeroMem((void*)T8_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T8_[0] = str;
		T8_[1] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, ownerModule);
		T8_[2] = nr;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___YPFmrJyah8E9bXydasNTQNQ(T8_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T9_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T11_[0] = str;
		T11_[1] = nr;
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___9bbJ4OU0MjtzdlRG6xkqTGQ(T11_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* it;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	res = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_92));
	it = t;
	{
		while (1) {
			if (!!((it == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA2;
			it = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(it, IL64(36275087638268176));
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m_2;
				if (!!(((*it).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA5_;
				m_2 = (*(*it).sym).owner;
				{
					while (1) {
						NIM_BOOL T9_;
						T9_ = (NIM_BOOL)0;
						T9_ = !((m_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T9_)) goto LA10_;
						T9_ = !(((*m_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
						LA10_: ;
						if (!T9_) goto LA8;
						m_2 = (*m_2).owner;
					} LA8: ;
				}
				{
					NIM_BOOL T13_;
					T13_ = (NIM_BOOL)0;
					T13_ = (m_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T13_) goto LA14_;
					T13_ = (((*m_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
					LA14_: ;
					if (!T13_) goto LA15_;
					res = resizeString(res, ((*(*(*it).sym).name).s ? (*(*(*it).sym).name).s->Sup.len : 0) + 0);
appendString(res, (*(*(*it).sym).name).s);
				}
				goto LA11_;
				LA15_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p;
					NimStringDesc* T25_;
					p = (*m_2).owner;
					{
						NIM_BOOL T20_;
						NimStringDesc* T24_;
						T20_ = (NIM_BOOL)0;
						T20_ = !((p == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T20_)) goto LA21_;
						T20_ = ((*p).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 24));
						LA21_: ;
						if (!T20_) goto LA22_;
						T24_ = (NimStringDesc*)0;
						T24_ = rawNewString(((*(*p).name).s ? (*(*p).name).s->Sup.len : 0) + 1);
appendString(T24_, (*(*p).name).s);
appendString(T24_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
						res = resizeString(res, (T24_ ? T24_->Sup.len : 0) + 0);
appendString(res, T24_);
					}
					LA22_: ;
					T25_ = (NimStringDesc*)0;
					T25_ = rawNewString(((*(*m_2).name).s ? (*(*m_2).name).s->Sup.len : 0) + 1);
appendString(T25_, (*(*m_2).name).s);
appendString(T25_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
					res = resizeString(res, (T25_ ? T25_->Sup.len : 0) + 0);
appendString(res, T25_);
					res = resizeString(res, ((*(*(*it).sym).name).s ? (*(*(*it).sym).name).s->Sup.len : 0) + 0);
appendString(res, (*(*(*it).sym).name).s);
				}
				LA11_: ;
			}
			goto LA3_;
			LA5_: ;
			{
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T27_;
				NimStringDesc* T28_;
				nimZeroMem((void*)T27_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__UdooXLclXL8uld7qLI5JRw(it, 2, T27_);
				T28_ = (NimStringDesc*)0;
				T28_ = dollar___0A9bslyIJ49bWrftLGh13rvg(T27_);
				res = resizeString(res, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(res, T28_);
			}
			LA3_: ;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_92));
			it = (*it).sons->data[((NI) 0)];
		} LA2: ;
	}
	result = makeCString__vQJydtKy4Nf6bXPYtbmjtg(res);
	return result;
}
static N_INLINE(NIM_BOOL, isTrivialProc__0ARm8KufT2VWgot8ref79bwcgen)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NI T1_;
	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*s).ast)._kind_6.sons->data[((NI) 6)]);
	result = (T1_ == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genHook__oupeNBgikmhXuZ8U9c35Zlg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* theProc;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	theProc = (*t).attachedOps[(op)- 0];
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((theProc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isTrivialProc__0ARm8KufT2VWgot8ref79bwcgen(theProc);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		{
			NIM_BOOL T10_;
			NimStringDesc* T14_;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*theProc).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			if (T10_) goto LA11_;
			T10_ = !(((*(*theProc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0)));
			LA11_: ;
			if (!T10_) goto LA12_;
			T14_ = (NimStringDesc*)0;
			T14_ = rawNewString(((*(*theProc).name).s ? (*(*theProc).name).s->Sup.len : 0) + 47);
appendString(T14_, (*(*theProc).name).s);
appendString(T14_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_95));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_96, NIM_FALSE);
		}
		LA12_: ;
		genProc__HbYPOpwLApFuBkISFGrmEQ(m, theProc);
		result = (*theProc).loc.r;
	}
	goto LA1_;
	LA6_: ;
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_94));
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_65));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T6_, name);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T7_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	}
	goto LA1_;
	LA4_: ;
	{
		result = name;
	}
	LA1_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* base, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI nimtypeKind;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nameHcr;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* size;
	tyArray__f7nG5LD47BH5K9c6mASit3g T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	NI flags;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
	nimtypeKind = (NI)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(typ);
		if (!T3_) goto LA4_;
		nimtypeKind = ((NI) 18);
	}
	goto LA1_;
	LA4_: ;
	{
		nimtypeKind = (*typ).kind;
	}
	LA1_: ;
	nameHcr = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
	size = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 40))&63U)))!=0)) goto LA9_;
		size = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_100));
	}
	goto LA7_;
	LA9_: ;
	{
		size = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, origType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	}
	LA7_: ;
	nimZeroMem((void*)T12_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T12_[0] = nameHcr;
	T12_[1] = size;
	T12_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (nimtypeKind)));
	T12_[3] = base;
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = percent___LV4C1L0tZJJrAPLOvOYIWQ(T12_, 4);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T13_);
	flags = ((NI) 0);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(typ);
		if (!!(T16_)) goto LA17_;
		flags = (NI)(flags | ((NI) 1));
	}
	LA17_: ;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = canFormAcycle__IVXYI9cxSeivThgKCncHRnA(typ);
		if (!!(T21_)) goto LA22_;
		flags = (NI)(flags | ((NI) 2));
	}
	LA22_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		if (!!((flags == ((NI) 0)))) goto LA26_;
		nimZeroMem((void*)T28_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T28_[0] = nameHcr;
		T28_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (flags)));
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = percent___fIR1FG0QPRsKvEYKq4tJUQ(T28_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T29_);
	}
	LA26_: ;
	T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T30_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
	(void)(T30_);
	{
		NIM_BOOL T33_;
		NimStringDesc* typename_1;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T55_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		T33_ = (NIM_BOOL)0;
		T33_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*m).g).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_101));
		if (!T33_) goto LA34_;
		T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		{
			if (!!(((*origType).typeInst == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA39_;
			T36_ = (*origType).typeInst;
		}
		goto LA37_;
		LA39_: ;
		{
			T36_ = origType;
		}
		LA37_: ;
		typename_1 = typeToString__QlvraUan7WbHowhAbvDvdA(T36_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		{
			NIM_BOOL T44_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
			NimStringDesc* T49_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
			NimStringDesc* T51_;
			T44_ = (NIM_BOOL)0;
			T44_ = eqStrings(typename_1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_102));
			if (!(T44_)) goto LA45_;
			T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T46_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origType, IL64(36275087638268176));
			T44_ = !(((*T46_).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA45_: ;
			if (!T44_) goto LA47_;
			T49_ = (NimStringDesc*)0;
			T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T50_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origType, IL64(36275087638268176));
			T51_ = (NimStringDesc*)0;
			T51_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*m).g).config, (*(*T50_).sym).info);
			T49_ = rawNewString((T51_ ? T51_->Sup.len : 0) + 21);
appendString(T49_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_103));
appendString(T49_, T51_);
			typename_1 = T49_;
		}
		LA47_: ;
		nimZeroMem((void*)T52_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T52_[0] = nameHcr;
		T52_[1] = makeCString__vQJydtKy4Nf6bXPYtbmjtg(typename_1);
		T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T53_ = percent___jADQs38xm62v1oxF2cSvEw(T52_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T53_);
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_104));
		(void)(T54_);
		nimZeroMem((void*)T55_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T55_[0] = nameHcr;
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = percent___DZV83DjWnQ9a19atC2oeswXg(T55_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T56_);
	}
	LA34_: ;
	{
		NIM_BOOL T59_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T62_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T64_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
		T59_ = (NIM_BOOL)0;
		T59_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T59_) goto LA60_;
		nimZeroMem((void*)T62_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T62_[0] = name;
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = percent___E0nDsXp7tY4mC1BnrrjWmA(T62_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T63_);
		nimZeroMem((void*)T64_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T64_[0] = name;
		T64_[1] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*m).module);
		T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T65_ = percent___sfvTjNjtOC86mU9bHczF6ow(T64_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).hcrCreateTypeInfosProc, T65_);
	}
	goto LA57_;
	LA60_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T67_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
		nimZeroMem((void*)T67_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T67_[0] = name;
		T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T68_ = percent___4OTrYJoAayXfDUrtxFShhg(T67_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T68_);
	}
	LA57_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, fakeClosureType__OVHn4Lx3T69a1BHJ0KreWYw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), owner);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26), owner);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T1_, NIM_TRUE);
	r = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), owner);
	obj = createObj__vpIcmDdKH7ed0dcs37b1GQ((*(*m).g).graph, owner, (*owner).info, NIM_FALSE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(r, obj, NIM_TRUE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, r, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = (*m).typeNodesName;
	T1_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*m).typeNodes)));
	result = percent___jadqNPnY9aM3oxYK6jarLrA(T1_, 2);
	(*m).typeNodes += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__8W0lvt5dkO9cVIIfffRji9cQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* size) {
	{
		NIM_BOOL T3_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = name;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___LvsIDF8olc08xBiqCYIUog(T6_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T7_);
		nimZeroMem((void*)T8_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T8_[0] = name;
		T8_[1] = size;
		T8_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*m).module);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___6Tfa1iP1ENVlWbe89cSELSQ(T8_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).hcrCreateTypeInfosProc, T9_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T11_[0] = name;
		T11_[1] = size;
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___hKg2Id9cvzE5Dgl9cU31c4Vw(T11_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__DVDUKxJo5CvrWtAaM2iHCw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* expr;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T27_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
	genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, typ, typ, name, T1_, info);
	expr = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
	{
		NI T4_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		NI T9_;
		NimStringDesc* T10_;
		NI T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T20_;
		NI T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		T4_ = (NI)0;
		T4_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		if (!(((NI) 0) < T4_)) goto LA5_;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T7_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
		T9_ = (NI)0;
		T9_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		T10_ = (NimStringDesc*)0;
		T10_ = nimIntToStr(T9_);
		tmp = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T8_, T10_);
		T11_ = (NI)0;
		T11_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T11_)));
		genTNimNodeArray__8W0lvt5dkO9cVIIfffRji9cQ(m, tmp, T12_);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2;
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T16_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T18_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
					if (!(i_2 < colontmp_)) goto LA15;
					i = i_2;
					a = (*typ).sons->data[i];
					tmp2 = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
					nimZeroMem((void*)T16_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T16_[0] = tmp;
					T16_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
					T16_[2] = tmp2;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = percent___H3xXuIFdbz4MNb5T6BSfcQ(T16_, 3);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T17_);
					nimZeroMem((void*)T18_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					T18_[0] = tmp2;
					T18_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, origType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
					T18_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
					T18_[3] = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, a, info);
					T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T19_ = percent___ELXFo0GedkhGYj9bocTHZAg(T18_, 4);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T19_);
					i_2 += ((NI) 1);
				} LA15: ;
			}
		}
		nimZeroMem((void*)T20_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T20_[0] = expr;
		T21_ = (NI)0;
		T21_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		T20_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T21_)));
		T20_[2] = tmp;
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = percent___9aLrcjgzGJE3f9ab2uR37jog(T20_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T22_);
	}
	goto LA2_;
	LA5_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
		NI T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T24_[0] = expr;
		T25_ = (NI)0;
		T25_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		T24_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T25_)));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = percent___3Q9c5iS9btBDBXZVoQktb1XQ(T24_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T26_);
	}
	LA2_: ;
	nimZeroMem((void*)T27_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T27_[0] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
	T27_[1] = expr;
	T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T28_ = percent___MALQXTKXJv7x9a9c247satLQ(T27_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T28_);
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* base;
	base = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NI T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		T3_ = (((NI) 0) < T4_);
		if (!(T3_)) goto LA5_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		T3_ = !((T6_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA5_: ;
		if (!T3_) goto LA7_;
		x = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		{
			if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA11_;
			x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(x, IL64(36275087638268176));
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NIM_BOOL T19_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
			if (!(T16_)) goto LA17_;
			T16_ = ((*x).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = !(((*x).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T19_)) goto LA20_;
			T19_ = ((1040 & (*(*x).sym).flags) == 16);
			LA20_: ;
			T15_ = T19_;
			LA18_: ;
			if (!T15_) goto LA21_;
			base = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
		}
		goto LA13_;
		LA21_: ;
		{
			base = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, x, info);
		}
		LA13_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		base = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
	}
	LA1_: ;
	genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, typ, origType, name, base, info);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lodeTyp__Zo4XKVi6BmwOZE51Yogqwg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
	asgnRef((void**) (&(*result).typ), t);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getTemp__VjOFVqypINqQv5C3ECnxbw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, NIM_BOOL needsInit) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	(*p).labels += ((NI) 1);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___Z7W1o5nPSc3ExfO5f7j1Gg(T2_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3)));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	res = rawNewString(((NI) 80));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T4_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*result).r);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA7_: ;
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T9_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T10_);
	(*result).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1);
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(t));
	(*result).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
	(*result).flags = 0;
	constructLoc__Q4oQMHZIwSi4nGkYAuAC8A(p, result, !(needsInit));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lenField__3AsTOpq9crZUYBL9aD1lXBng)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T4_) goto LA5_;
		T4_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA5_: ;
		if (!T4_) goto LA6_;
		T1_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_113));
	}
	goto LA2_;
	LA6_: ;
	{
		T1_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_114));
	}
	LA2_: ;
	result = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lenExpr__Xfvxpx3W1zkiCqENsur9ckg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T5_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_112));
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T7_[1] = lenField__3AsTOpq9crZUYBL9aD1lXBng(p);
		result = percent___2SWcbuU7RHQR0b8y9aJ9a5VQ(T7_, 2);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__JXx3ANPSFqQ9c8gmnEaNQ9cA)(NimStringDesc** result, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value) {
	addInt128__IvecK4CF4vhXBu6XHFt6sg(result, value);
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, parentObj__uBOaBBiKguvub019cPppbOQcgen)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T7_[0] = accessor;
		result = percent___gSgutt9b7GMWVGBkCt0UHAQ(T7_, 1);
	}
	goto LA1_;
	LA5_: ;
	{
		result = accessor;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangleField__IekjVhJd9bZAI9cs9bWYUDsTA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = mangle__GxzvEIRbrShQbyJNboTw7A((*name).s);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isKeyword__plkNLyLwnwkMYELCfG4Gxw(name);
		if (!T3_) goto LA4_;
		result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_30));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!!(((192 & (*field).flags) == 0))) goto LA3_;
		result = (*field).loc.r;
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T6_;
		T6_ = (NimStringDesc*)0;
		T6_ = mangleField__IekjVhJd9bZAI9cs9bWYUDsTA(m, (*field).name);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T6_);
	}
	LA1_: ;
	{
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA9_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*field).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_127), TM__MQdRN7fpbG7rPm4JpVVAhA_128);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NimStringDesc* unionPrefix) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T5_ = genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw(m, (*n)._kind_6.sons->data[i], rectype, check, unionPrefix);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T5_);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* unionBody;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA9_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_125), TM__MQdRN7fpbG7rPm4JpVVAhA_126);
		}
		LA9_: ;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw(m, (*n)._kind_6.sons->data[((NI) 0)], rectype, check, unionPrefix);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T11_);
		unionBody = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA14;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* k;
						k = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* structName;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
							NimStringDesc* T23_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a;
							NimStringDesc* T24_;
							NimStringDesc* T25_;
							if (!!(((*k).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA18_;
							T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T20_ = mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA(m, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
							T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T21_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3), T20_);
							T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T22_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T21_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
							T23_ = (NimStringDesc*)0;
							T23_ = nimIntToStr(i_3);
							structName = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T22_, T23_);
							T24_ = (NimStringDesc*)0;
							T25_ = (NimStringDesc*)0;
							T25_ = dollar___mZ66tEveFIQokq3arf8Klw(structName);
							T24_ = rawNewString((unionPrefix ? unionPrefix->Sup.len : 0) + (T25_ ? T25_->Sup.len : 0) + 1);
appendString(T24_, unionPrefix);
appendString(T24_, T25_);
appendString(T24_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
							a = genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw(m, k, rectype, check, T24_);
							{
								tyArray__JiWwrsTRC6xqNlGcBthSVA T42_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
								if (!!((a == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA28_;
								{
									if (!!((((*rectype).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 23))&63U)))!=0))) goto LA32_;
									add__yG4AKzsBRS1W4MANDlXQeg(&unionBody, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_129));
								}
								goto LA30_;
								LA32_: ;
								{
									{
										if (!((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0)) goto LA37_;
										add__yG4AKzsBRS1W4MANDlXQeg(&unionBody, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_130));
									}
									goto LA35_;
									LA37_: ;
									{
										tyArray__qTjAvTvKF9anytN1At69aJMQ T40_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
										nimZeroMem((void*)T40_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
										T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T41_ = percent___Vcuq0AWiVDndx4UH9cJ9cBRg(T40_, 0);
										add__IM4kcMNkkOLJtqdEqSxR8A(&unionBody, T41_);
									}
									LA35_: ;
								}
								LA30_: ;
								add__IM4kcMNkkOLJtqdEqSxR8A(&unionBody, a);
								nimZeroMem((void*)T42_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
								T42_[0] = structName;
								T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T43_ = percent___wbZBBJwMkBeW6eH9agO9boag(T42_, 1);
								add__IM4kcMNkkOLJtqdEqSxR8A(&unionBody, T43_);
								{
									NIM_BOOL T46_;
									tyArray__qTjAvTvKF9anytN1At69aJMQ T50_;
									tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
									T46_ = (NIM_BOOL)0;
									T46_ = (((*rectype).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 23))&63U)))!=0);
									if (!(T46_)) goto LA47_;
									T46_ = !(((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0));
									LA47_: ;
									if (!T46_) goto LA48_;
									nimZeroMem((void*)T50_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
									T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
									T51_ = percent___zgEKWXsZtT6lqQ6XlgfrsA(T50_, 0);
									add__IM4kcMNkkOLJtqdEqSxR8A(&unionBody, T51_);
								}
								LA48_: ;
							}
							LA28_: ;
						}
						goto LA16_;
						LA18_: ;
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
							T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T53_ = genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw(m, k, rectype, check, unionPrefix);
							add__IM4kcMNkkOLJtqdEqSxR8A(&unionBody, T53_);
						}
						LA16_: ;
					}
					break;
					default:
					{
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_131), TM__MQdRN7fpbG7rPm4JpVVAhA_132);
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA14: ;
			}
		}
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			if (!!((unionBody == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA57_;
			nimZeroMem((void*)T59_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T59_[0] = unionBody;
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = percent___uXZ30k0oJEqGPZW57O3dwg(T59_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T60_);
		}
		LA57_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* sname;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA64_;
			goto BeforeRet_;
		}
		LA64_: ;
		sname = mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA(m, field);
		T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T66_ = amp___4cYKitaHx6RQ9azRtQsZp6w(unionPrefix, sname);
		fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*field).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 5), n, T66_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T71_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
			if (!(((NI) 0) < (*field)._kind_4.alignment)) goto LA69_;
			nimZeroMem((void*)T71_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T71_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*field)._kind_4.alignment)));
			T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T72_ = percent___iaEKHmIC9bNRZLxBqSNX0Sg(T71_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T72_);
		}
		LA69_: ;
		{
			NIM_BOOL T75_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* noAlias;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fieldType;
			T75_ = (NIM_BOOL)0;
			T75_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(rectype);
			if (!!(T75_)) goto LA76_;
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T82_;
				if (!(((*field).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45))&63U)))!=0)) goto LA80_;
				nimZeroMem((void*)T82_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				noAlias = percent___bfOZxc58jjogwT5CgzlLmw(T82_, 0);
			}
			goto LA78_;
			LA80_: ;
			{
				noAlias = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
			}
			LA78_: ;
			fieldType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*field).loc.lode).typ, IL64(36134350135273744));
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T88_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T89_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
				if (!((*fieldType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49))) goto LA86_;
				nimZeroMem((void*)T88_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T89_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T89_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(fieldType);
				T88_[0] = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T89_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
				T88_[1] = sname;
				T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T90_ = percent___tTI9aMQiBZdiEeBIVh7QtYA(T88_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T90_);
			}
			goto LA84_;
			LA86_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T94_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T95_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
				if (!((*fieldType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))) goto LA92_;
				nimZeroMem((void*)T94_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T95_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T95_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
				T94_[0] = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, T95_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
				T94_[1] = sname;
				T94_[2] = noAlias;
				T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T96_ = percent___4kat3SB2isO6k5GNDb6IOA(T94_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T96_);
			}
			goto LA84_;
			LA92_: ;
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T100_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T101_;
				NimStringDesc* T102_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
				if (!!(((*field)._kind_4.bitsize == ((NI) 0)))) goto LA98_;
				nimZeroMem((void*)T100_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T101_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T101_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
				T100_[0] = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T101_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
				T100_[1] = sname;
				T102_ = (NimStringDesc*)0;
				T102_ = nimIntToStr((*field)._kind_4.bitsize);
				T100_[2] = rope__yShmEg9cffWxI7s5XzEKBow(T102_);
				T100_[3] = noAlias;
				T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T103_ = percent___gMpJKF837tUhGu2KjcYLFA(T100_, 4);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T103_);
			}
			goto LA84_;
			LA98_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T105_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T106_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
				nimZeroMem((void*)T105_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T106_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T106_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
				T105_[0] = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T106_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
				T105_[1] = sname;
				T105_[2] = noAlias;
				T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T107_ = percent___4kat3SB2isO6k5GNDb6IOA(T105_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T107_);
			}
			LA84_: ;
		}
		LA76_: ;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_133), TM__MQdRN7fpbG7rPm4JpVVAhA_134);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getRecordFields__1Yw0f9bM6njBLDchKVMziZw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = genRecordFieldsAux__4Ai9cgO7hu1LuaSdTl5N9anw(m, (*typ).n, typ, check, ((NimStringDesc*) NIM_NIL));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getRecordFields__1Yw0f9bM6njBLDchKVMziZw(m, typ, (&check));
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, intLiteral__kQA0lBUvzOSZAw7DHC4Fjg)(NI64 i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (IL64(-2147483648) < i);
		if (!(T3_)) goto LA4_;
		T3_ = (i <= IL64(2147483647));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = rope__KOisMGxcPhz6CcSmxgwEQQ(i);
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T10_;
		if (!(i == IL64(-2147483648))) goto LA8_;
		nimZeroMem((void*)T10_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		result = percent___LQ9bGxpANW8yeg5P9c0UYAaQ(T10_, 0);
	}
	goto LA1_;
	LA8_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T14_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i)) goto LA12_;
		nimZeroMem((void*)T14_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T14_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(i);
		result = percent___f8tdlskieCnWysl9c9blzqZg(T14_, 1);
	}
	goto LA1_;
	LA12_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T16_;
		nimZeroMem((void*)T16_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		result = percent___KbFpNe1pZ7hIuQi7dp1dSQ(T16_, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, int64Literal__kQA0lBUvzOSZAw7DHC4Fjg_2)(NI64 i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(i);
		result = percent___f8tdlskieCnWysl9c9blzqZg(T5_, 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T7_;
		nimZeroMem((void*)T7_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		result = percent___KbFpNe1pZ7hIuQi7dp1dSQ(T7_, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, uint64Literal__ldwzpLT4KWF9c4XGru9cpC1A)(NU64 i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = dollar___M2d4UEGH9cZOvte6rEhvUTQ(i);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 3);
appendString(T1_, T2_);
appendString(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_137));
	result = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genNilStringLiteral__mf9bJ50BK9auefXIgup7r1CQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_139));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_140));
	result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralDataOnlyV1__wg9bxyc8oC9b9ahuYUo9bM4FJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_142));
	(void)(T1_);
	result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	nimZeroMem((void*)T2_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T2_[0] = result;
	T2_[1] = makeCString__vQJydtKy4Nf6bXPYtbmjtg(s);
	T2_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((s ? s->Sup.len : 0))));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___mF9aI9b3hDjj53TD2C2gTrHA(T2_, 3);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g)(NimStringDesc** result, NI64 value) {
	addInt__mftMOxbyu0h4yByfs3sqjA(result, value);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV1__SO73hKlDdl5sMaSHTbOJLw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!NIM_FALSE) goto LA3_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_139));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_140));
		result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	goto LA1_;
	LA3_: ;
	{
		NI id;
		id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*m).dataCache), n, ((NI) ((*m).labels)));
		{
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			if (!(id == ((NI) ((*m).labels)))) goto LA9_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_139));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T11_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_141));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = genStringLiteralDataOnlyV1__wg9bxyc8oC9b9ahuYUo9bM4FJQ(m, (*n)._kind_3.strVal);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T12_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			result = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		}
		goto LA7_;
		LA9_: ;
		{
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_139));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T14_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_141));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), (*m).tmpBase);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (id)));
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			result = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		}
		LA7_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__vp7GP3wlFybjCJ5ExVrrhg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* s, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result, NIM_BOOL isConst) {
	tyArray__f7nG5LD47BH5K9c6mASit3g T1_;
	NimStringDesc* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	nimZeroMem((void*)T1_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T1_[0] = result;
	T1_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((s ? s->Sup.len : 0))));
	T1_[2] = makeCString__vQJydtKy4Nf6bXPYtbmjtg(s);
	T2_ = (NimStringDesc*)0;
	{
		if (!isConst) goto LA5_;
		T2_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_143));
	}
	goto LA3_;
	LA5_: ;
	{
		T2_ = ((NimStringDesc*) NIM_NIL);
	}
	LA3_: ;
	T1_[3] = rope__yShmEg9cffWxI7s5XzEKBow(T2_);
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = percent___Q63d9bGPwQ9ae1XrP9b7wHM3w(T1_, 4);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T8_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV2__Cfuh3qIr16gdBtlWztnjAQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI id;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*m).dataCache), n, ((NI) ((*m).labels)));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pureLit;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		if (!(id == ((NI) ((*m).labels)))) goto LA3_;
		pureLit = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		genStringLiteralDataOnlyV2__vp7GP3wlFybjCJ5ExVrrhg(m, (*n)._kind_3.strVal, pureLit, isConst);
		result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_144));
		(void)(T5_);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_145));
		(void)(T6_);
		nimZeroMem((void*)T7_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T7_[0] = result;
		T7_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
		T7_[2] = pureLit;
		T8_ = (NimStringDesc*)0;
		{
			if (!isConst) goto LA11_;
			T8_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_143));
		}
		goto LA9_;
		LA11_: ;
		{
			T8_ = ((NimStringDesc*) NIM_NIL);
		}
		LA9_: ;
		T7_[3] = rope__yShmEg9cffWxI7s5XzEKBow(T8_);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = percent___bgV9a1wkKJUW9aAfeUrmhalQ(T7_, 4);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T14_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__f7nG5LD47BH5K9c6mASit3g T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		NimStringDesc* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		nimZeroMem((void*)T16_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T16_[0] = result;
		T16_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
		T16_[2] = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*m).tmpBase, T17_);
		T18_ = (NimStringDesc*)0;
		{
			if (!isConst) goto LA21_;
			T18_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_143));
		}
		goto LA19_;
		LA21_: ;
		{
			T18_ = ((NimStringDesc*) NIM_NIL);
		}
		LA19_: ;
		T16_[3] = rope__yShmEg9cffWxI7s5XzEKBow(T18_);
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = percent___bgV9a1wkKJUW9aAfeUrmhalQ(T16_, 4);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T24_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteral__SO73hKlDdl5sMaSHTbOJLw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NI)0;
	T1_ = detectStrVersion__V25kMWfh1jWVNQQI5BNfLg(m);
	switch (T1_) {
	case ((NI) 0):
	case ((NI) 1):
	{
		result = genStringLiteralV1__SO73hKlDdl5sMaSHTbOJLw_2(m, n);
	}
	break;
	case ((NI) 2):
	{
		result = genStringLiteralV2__Cfuh3qIr16gdBtlWztnjAQ(m, n, NIM_TRUE);
	}
	break;
	default:
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_146), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_147, NIM_FALSE);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genLiteral__qifZy01sZ5OX01eT5FP76w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k;
		k = (tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag)0;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
			if (!!((ty == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA4_;
			T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(36134350144710928));
			k = (*T6_).kind;
		}
		goto LA2_;
		LA4_: ;
		{
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5):
			{
				k = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
			{
				k = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
			{
				k = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35);
			}
			break;
			default:
			{
				k = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5);
			}
			break;
			}
		}
		LA2_: ;
		switch (k) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg((*n)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
		{
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T18_;
				if (!!(((*n)._kind_1.intVal == IL64(0)))) goto LA16_;
				nimZeroMem((void*)T18_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				result = percent___nunbo9aB0HmmYQJ3InIBEzQ(T18_, 0);
			}
			goto LA14_;
			LA16_: ;
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T20_;
				nimZeroMem((void*)T20_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				result = percent___RBxLok7DyUB0aHl9bxPIl9bQ(T20_, 0);
			}
			LA14_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		{
			result = int64Literal__kQA0lBUvzOSZAw7DHC4Fjg_2((*n)._kind_1.intVal);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		{
			result = uint64Literal__ldwzpLT4KWF9c4XGru9cpC1A(((NU64) ((*n)._kind_1.intVal)));
		}
		break;
		default:
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
			nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T24_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ty, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T24_[1] = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg((*n)._kind_1.intVal);
			result = percent___NARRjCd1x5Fr7NTTcoPRrw(T24_, 2);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k_2;
		{
			if (!(ty == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA28_;
			k_2 = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26);
		}
		goto LA26_;
		LA28_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
			T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T31_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(36134350144710928));
			k_2 = (*T31_).kind;
		}
		LA26_: ;
		{
			NIM_BOOL T34_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
			NI id;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			T34_ = (NIM_BOOL)0;
			T34_ = (k_2 == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T34_)) goto LA35_;
			T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T36_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(36134350144710928));
			T34_ = ((*T36_).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA35_: ;
			if (!T34_) goto LA37_;
			id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
			result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*(*p).module).tmpBase, T39_);
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T44_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
				if (!(id == ((NI) ((*(*p).module).labels)))) goto LA42_;
				(*(*p).module).labels += ((NI) 1);
				nimZeroMem((void*)T44_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T44_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ty, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				T44_[1] = result;
				T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T45_ = percent___NlLLwmZHOiJUpZfuk00AWA(T44_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T45_);
			}
			LA42_: ;
		}
		goto LA32_;
		LA37_: ;
		{
			if (!(k_2 == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26) || k_2 == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5) || k_2 == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25))) goto LA47_;
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_94));
		}
		goto LA32_;
		LA47_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T50_;
			nimZeroMem((void*)T50_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T50_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ty, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			result = percent___gs4odkn83z9bVJ76dC1J9ciQ(T50_, 1);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k_3;
		{
			if (!(ty == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA54_;
			k_3 = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28);
		}
		goto LA52_;
		LA54_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T57_;
			T57_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T57_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(1202566653633669392));
			k_3 = (*T57_).kind;
		}
		LA52_: ;
		switch (k_3) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = genNilStringLiteral__mf9bJ50BK9auefXIgup7r1CQ((*p).module, (*n).info);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		{
			{
				NIM_BOOL T62_;
				NIM_BOOL T63_;
				T62_ = (NIM_BOOL)0;
				T63_ = (NIM_BOOL)0;
				T63_ = (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0) == ((NI) 0));
				if (!(T63_)) goto LA64_;
				T63_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0));
				LA64_: ;
				T62_ = T63_;
				if (!(T62_)) goto LA65_;
				T62_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0));
				LA65_: ;
				if (!T62_) goto LA66_;
				result = genNilStringLiteral__mf9bJ50BK9auefXIgup7r1CQ((*p).module, (*n).info);
			}
			goto LA60_;
			LA66_: ;
			{
				result = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw((*p).module, n);
			}
			LA60_: ;
		}
		break;
		default:
		{
			result = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*n)._kind_3.strVal);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		NimStringDesc* T71_;
		T71_ = (NimStringDesc*)0;
		T71_ = toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg((*n)._kind_2.floatVal, ((NimStringDesc*) NIM_NIL));
		result = rope__yShmEg9cffWxI7s5XzEKBow(T71_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 17):
	{
		NimStringDesc* T73_;
		T73_ = (NimStringDesc*)0;
		T73_ = toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg((*n)._kind_2.floatVal, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_149));
		result = rope__yShmEg9cffWxI7s5XzEKBow(T73_);
	}
	break;
	default:
	{
		NimStringDesc* T75_;
		T75_ = (NimStringDesc*)0;
		T75_ = rawNewString((reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 12);
appendString(T75_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_150));
appendString(T75_, reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
appendChar(T75_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T75_, TM__MQdRN7fpbG7rPm4JpVVAhA_151);
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = genLiteral__qifZy01sZ5OX01eT5FP76w(p, n, (*n).typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__KUz7NJSCXeUWRl4foF5zfg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch) {
	{
		NI j;
		NI colontmp_;
		NI T2_;
		NI i;
		j = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA4;
				j = i;
				{
					if (!((*(*branch)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA7_;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T13_;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T14_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
						if (!((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 0))&7U)))!=0)) goto LA11_;
						T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T13_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T14_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T14_[0] = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, (*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
						T14_[1] = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, (*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]);
						T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T15_ = percent___0RQ2PINB4t8FjFlNUM6N9cQ(T14_, 2);
						T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T13_, T16_);
					}
					goto LA9_;
					LA11_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
						v = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2((*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)]);
						{
							while (1) {
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T20_;
								tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
								if (!((*v)._kind_1.intVal <= (*(*(*branch)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)])._kind_1.intVal)) goto LA19;
								T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
								T20_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
								nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
								T21_[0] = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, v);
								T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T22_ = percent___f8NIixSwWrk6SXQ3BFamWw(T21_, 1);
								T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T23_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T22_);
								add__IM4kcMNkkOLJtqdEqSxR8A(T20_, T23_);
								(*v)._kind_1.intVal += ((NI) 1);
							} LA19: ;
						}
					}
					LA9_: ;
				}
				goto LA5_;
				LA7_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T25_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
					T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T25_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T26_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T26_[0] = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, (*branch)._kind_6.sons->data[j]);
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = percent___f8NIixSwWrk6SXQ3BFamWw(T26_, 1);
					T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T28_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T27_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T25_, T28_);
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__ZF8ePl9bsRxWXLu7Z2MFifQ)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					genTraverseProc__ZF8ePl9bsRxWXLu7Z2MFifQ(c, accessor, (*n)._kind_6.sons->data[i], typ);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disc;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T44_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T45_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_122), TM__MQdRN7fpbG7rPm4JpVVAhA_123);
		}
		LA12_: ;
		p = c.p;
		disc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((*disc).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA16_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*c.p).module, typ);
		}
		LA16_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
			T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T20_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*disc).loc);
			if (!(T20_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA21_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_135), TM__MQdRN7fpbG7rPm4JpVVAhA_136);
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T24_[0] = accessor;
		T24_[1] = (*disc).loc.r;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = percent___jw4Sb0OSpKH1T5cLz7iyzA(T24_, 2);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T26_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T39_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T40_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T41_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					if (!(i_4 < colontmp__2)) goto LA29;
					i_3 = i_4;
					branch = (*n)._kind_6.sons->data[i_3];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA32_;
						genCaseRange__KUz7NJSCXeUWRl4foF5zfg(c.p, branch);
					}
					goto LA30_;
					LA32_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T36_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
						T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T36_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T37_ = percent___TTRh79a14hh1gb0owIP1Y6Q(T36_, 0);
						T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T38_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T37_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T38_);
					}
					LA30_: ;
					T39_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T39_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
					genTraverseProc__ZF8ePl9bsRxWXLu7Z2MFifQ(c, accessor, T39_, typ);
					T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T40_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T41_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T42_ = percent___TmeCjGna9cPfiHHcfqmKXjw(T41_, 0);
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T40_, T43_);
					i_4 += ((NI) 1);
				} LA29: ;
			}
		}
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T44_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T45_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = percent___FsfRVuOOBePjn9cQ9aK7Vh1w(T45_, 0);
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T46_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T44_, T47_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T62_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T64_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA51_;
			goto BeforeRet_;
		}
		LA51_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA55_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*c.p).module, typ);
		}
		LA55_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T59_;
			T59_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T59_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
			if (!(T59_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA60_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_135), TM__MQdRN7fpbG7rPm4JpVVAhA_153);
		}
		LA60_: ;
		nimZeroMem((void*)T62_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T62_[0] = accessor;
		T62_[1] = (*field).loc.r;
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = percent___paA0sar8RKZqiwEaDfWo2A(T62_, 2);
		T64_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T64_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
		genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T63_, T64_);
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c.p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_135), TM__MQdRN7fpbG7rPm4JpVVAhA_154);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
{	{
		if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	p = c.p;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, accessor, T6_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA arraySize;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA i;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* oldCode;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		NI oldLen;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		arraySize = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c.p).module).g).config, (*typ).sons->data[((NI) 0)]);
		nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*c.p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, T8_, (&i), NIM_FALSE);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		oldCode = (*T9_);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_115));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_116));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
		cgFormatValue__JXx3ANPSFqQ9c8gmnEaNQ9cA((&res), arraySize);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_119));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T16_);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		oldLen = len__9b0YRltzV3kNSE9aQTsG82wg((*T17_));
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), accessor);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), i.r);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T18_, (*typ).sons->data[((NI) 1)]);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
			NI T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T25_;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			T22_ = (NI)0;
			T22_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T21_));
			if (!(T22_ == oldLen)) goto LA23_;
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T25_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			unsureAsgnRef((void**) (&(*T25_)), oldCode);
		}
		goto LA19_;
		LA23_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T27_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T27_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T28_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = percent___BYiowJAm8zF7RBRISElaLg(T28_, 0);
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T29_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T27_, T30_);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
					if (!(i_3 < colontmp_)) goto LA34;
					i_2 = i_3;
					x = (*typ).sons->data[i_2];
					{
						if (!!((x == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA37_;
						x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(x, IL64(36275087638268176));
					}
					LA37_: ;
					T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T39_ = parentObj__uBOaBBiKguvub019cPppbOQcgen(accessor, (*c.p).module);
					genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T39_, x);
					i_3 += ((NI) 1);
				} LA34: ;
			}
		}
		{
			if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA42_;
			genTraverseProc__ZF8ePl9bsRxWXLu7Z2MFifQ(c, accessor, (*typ).n, typ);
		}
		LA42_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
		typ_2 = typ;
		{
			NI i_4;
			NI colontmp__2;
			NI i_5;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(typ_2);
			i_5 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* res_3;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
					if (!(i_5 < colontmp__2)) goto LA47;
					i_4 = i_5;
					res_3 = rawNewString(((NI) 80));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), accessor);
					res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_155));
					cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (i_4)));
					T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T48_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
					genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T48_, (*typ_2).sons->data[i_4]);
					i_5 += ((NI) 1);
				} LA47: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T50_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T50_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T51_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_156));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T51_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), accessor);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_4), c.visitorFrmt);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA54_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA54_: ;
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T56_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T50_, T57_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T63_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			if (!!((((*(*(*(*c.p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0))) goto LA61_;
			T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T63_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_5 = rawNewString(((NI) 80));
			T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T64_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_156));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T64_);
			res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), accessor);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_5), c.visitorFrmt);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA67_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA67_: ;
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T69_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T69_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T63_, T70_);
		}
		goto LA59_;
		LA61_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T72_;
			NIM_BOOL T73_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T76_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
			T72_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T72_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
			T73_ = (NIM_BOOL)0;
			T73_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T72_);
			if (!T73_) goto LA74_;
			T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T76_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_6 = rawNewString(((NI) 80));
			T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T77_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_158));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T77_);
			res_6 = resizeString(res_6, 8);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), accessor);
			res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_6), c.visitorFrmt);
			res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA80_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA80_: ;
			T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T82_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T83_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T82_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T76_, T83_);
		}
		goto LA59_;
		LA74_: ;
		LA59_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T89_;
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0))) goto LA87_;
			T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T89_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_7 = rawNewString(((NI) 80));
			T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T90_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_156));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T90_);
			res_7 = resizeString(res_7, 8);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), accessor);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_7), c.visitorFrmt);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA93_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA93_: ;
			T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T95_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
			T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T96_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T95_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T89_, T96_);
		}
		LA87_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T102_;
			NimStringDesc* res_8;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
			NimStringDesc* res_9;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T104_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T109_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T110_;
			if (!((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA100_;
			T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T102_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_8 = rawNewString(((NI) 80));
			T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T103_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_156));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T103_);
			res_8 = resizeString(res_8, 8);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			res_9 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), accessor);
			res_9 = resizeString(res_9, 6);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_159));
			T104_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T104_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T104_);
			res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_8), c.visitorFrmt);
			res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA107_;
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA107_: ;
			T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T109_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
			T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T110_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T109_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T102_, T110_);
		}
		LA100_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, dataField__3AsTOpq9crZUYBL9aD1lXBng_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_160));
	}
	goto LA1_;
	LA3_: ;
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_161));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__LXrm7ZbTiXTVtbB5E60yIA)(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA i;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* oldCode;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T2_;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	NI oldLen;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T7_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	p = c.p;
	nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*c.p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	getTemp__VjOFVqypINqQv5C3ECnxbw(p, T1_, (&i), NIM_FALSE);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T2_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	oldCode = (*T2_);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	a.r = accessor;
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T4_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T4_[0] = i.r;
	T4_[1] = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(c.p, a);
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = percent___xQaqlAwFuwxqBFixw7ewLg(T4_, 2);
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T5_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T6_);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T7_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	oldLen = len__9b0YRltzV3kNSE9aQTsG82wg((*T7_));
	nimZeroMem((void*)T8_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T8_[0] = accessor;
	T8_[1] = i.r;
	T8_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(c.p);
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = percent___jr9cXNQhhlLDfFJH4RSjeZg(T8_, 3);
	genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T9_, (*typ).sons->data[((NI) 0)]);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
		NI T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T16_;
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T13_ = (NI)0;
		T13_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T12_));
		if (!(T13_ == oldLen)) goto LA14_;
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T16_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		unsureAsgnRef((void**) (&(*T16_)), oldCode);
	}
	goto LA10_;
	LA14_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T18_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T18_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T19_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = percent___BYiowJAm8zF7RBRISElaLg(T19_, 0);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T20_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T18_, T21_);
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTraverseProc__6ja22UmHW9bFsLaOtztGpHQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origTyp, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c;
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	NIM_BOOL hcrOn;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* markerName;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* header;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* t;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* generatedProc;
	tyArray__f7nG5LD47BH5K9c6mASit3g T30_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T31_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T32_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T34_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&c), sizeof(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg));
	p = newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), m);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
	result = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_109), T1_);
	hcrOn = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origTyp, IL64(36134350135273744));
	{
		if (!hcrOn) goto LA4_;
		markerName = amp___Z7W1o5nPSc3ExfO5f7j1Gg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_53));
	}
	goto LA2_;
	LA4_: ;
	{
		markerName = result;
	}
	LA2_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T7_[0] = markerName;
	header = percent___0nBiBCva6YS9a9bSV2Vr7Zxw(T7_, 1);
	t = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T9_[0] = t;
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = percent___yyhPPkMkLJqWG6p8HGn9aoA(T9_, 1);
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T10_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T11_);
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
	nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T13_[0] = t;
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = percent___t8gRNGR1flvaCNlBxuLn1A(T13_, 1);
	T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T15_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T14_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T12_, T15_);
	c.p = p;
	c.visitorFrmt = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_110));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))) goto LA18_;
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_162));
		genTraverseProcSeq__LXrm7ZbTiXTVtbB5E60yIA(c, T20_, typ);
	}
	goto LA16_;
	LA18_: ;
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T24_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[((NI) 0)], IL64(36134350135273744));
			if (!((*T24_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16))) goto LA25_;
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_162));
			genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T27_, (*typ).sons->data[((NI) 0)]);
		}
		goto LA22_;
		LA25_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_163));
			genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, T29_, (*typ).sons->data[((NI) 0)]);
		}
		LA22_: ;
	}
	LA16_: ;
	nimZeroMem((void*)T30_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T30_[0] = header;
	T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T31_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	T30_[1] = (*T31_);
	T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T32_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
	T30_[2] = (*T32_);
	T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	T30_[3] = (*T33_);
	generatedProc = percent___EnzikEr9bDhOR6GYxWuYSwQ(T30_, 4);
	nimZeroMem((void*)T34_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T34_[0] = header;
	T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T35_ = percent___QqzUiJcAEZE2azDhIWHrgg(T34_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T35_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], generatedProc);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T40_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T42_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		if (!hcrOn) goto LA38_;
		nimZeroMem((void*)T40_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T40_[0] = result;
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = percent___20ZujjIFPkyqvS2OmenEAA(T40_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T41_);
		nimZeroMem((void*)T42_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T42_[0] = result;
		T42_[1] = markerName;
		T42_[2] = getModuleDllPath__ao6gUnuVfQLtZ89c4kaIKfg_2(m);
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = percent___Vxo9ayk1xB18if39aZ1TBnKA(T42_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T43_);
	}
	LA38_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__TiBDnY33G5Ca1p0Z3BOA9bg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, (*typ).sons->data[((NI) 1)], info);
	genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, typ, typ, name, T1_, info);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__b5mr3rjXEwHVfmNLJr4cBA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(arg);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__TiBDnY33G5Ca1p0Z3BOA9bg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T1_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, typ, typ, name, info);
	tmp = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T1_[0] = tmp;
	T2_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*m).g).config, typ);
	T1_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T2_);
	T1_[2] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___AKNexo4CH8G2vDeWW34Vpg(T1_, 3);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__TiBDnY33G5Ca1p0Z3BOA9bg_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nodePtrs;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	NI T3_;
	NimStringDesc* T4_;
	NI T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* enumNames;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* specialCases;
	NI firstNimNode;
	NIM_BOOL hasHoles;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* enumArray;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* counter;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T30_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T32_;
	NI T33_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
	tyArray__dNfZYyzVYdaWfURv4pxodA T35_;
	NI T36_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
	tyArray__f7nG5LD47BH5K9c6mASit3g T38_;
	NI T39_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
	genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, typ, typ, name, info);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
	T3_ = (NI)0;
	T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T4_ = (NimStringDesc*)0;
	T4_ = nimIntToStr(T3_);
	nodePtrs = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T2_, T4_);
	T5_ = (NI)0;
	T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T5_)));
	genTNimNodeArray__8W0lvt5dkO9cVIIfffRji9cQ(m, nodePtrs, T6_);
	enumNames = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	specialCases = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	firstNimNode = (*m).typeNodes;
	hasHoles = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* elemNode;
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				field = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
				elemNode = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
					if (!((*field).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA12_;
					T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T14_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*field).name).s);
					add__IM4kcMNkkOLJtqdEqSxR8A(&enumNames, T14_);
				}
				goto LA10_;
				LA12_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
					T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T16_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*field).ast)._kind_3.strVal);
					add__IM4kcMNkkOLJtqdEqSxR8A(&enumNames, T16_);
				}
				LA10_: ;
				{
					NI T19_;
					T19_ = (NI)0;
					T19_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
					if (!(i < (NI)(T19_ - ((NI) 1)))) goto LA20_;
					add__yG4AKzsBRS1W4MANDlXQeg(&enumNames, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_164));
				}
				LA20_: ;
				{
					NIM_BOOL T24_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T28_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
					T24_ = (NIM_BOOL)0;
					T24_ = !(((*field).position == i));
					if (T24_) goto LA25_;
					T24_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 5))&63U)))!=0);
					LA25_: ;
					if (!T24_) goto LA26_;
					nimZeroMem((void*)T28_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T28_[0] = elemNode;
					T28_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*field).position)));
					T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T29_ = percent___LE3oWAmB5YDSDHm3LNHhCg(T28_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&specialCases, T29_);
					hasHoles = NIM_TRUE;
				}
				LA26_: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	enumArray = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	counter = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	nimZeroMem((void*)T30_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T30_[0] = counter;
	T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T31_ = percent___W83I2xs7lC32PrMs9bq4P2w(T30_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T31_);
	nimZeroMem((void*)T32_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T32_[0] = enumArray;
	T33_ = (NI)0;
	T33_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T32_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T33_)));
	T32_[2] = enumNames;
	T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T34_ = percent___JKMGBJtXtDvc0NwxujFmZQ(T32_, 3);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T34_);
	nimZeroMem((void*)T35_, sizeof(tyArray__dNfZYyzVYdaWfURv4pxodA));
	T35_[0] = counter;
	T36_ = (NI)0;
	T36_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T35_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T36_)));
	T35_[2] = (*m).typeNodesName;
	T35_[3] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (firstNimNode)));
	T35_[4] = enumArray;
	T35_[5] = nodePtrs;
	T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T37_ = percent___TA8WFV49atYpIneJatQWALw(T35_, 6);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T37_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], specialCases);
	nimZeroMem((void*)T38_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T38_[0] = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
	T39_ = (NI)0;
	T39_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T38_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T39_)));
	T38_[2] = nodePtrs;
	T38_[3] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
	T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T40_ = percent___nPenDL3j2Q6A1an1Cl3oCA(T38_, 4);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T40_);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T45_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		if (!hasHoles) goto LA43_;
		nimZeroMem((void*)T45_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T45_[0] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = percent___TNkzce2Sd9bck2QRtketc8A(T45_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T46_);
	}
	LA43_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, discriminatorTableName__WpGsd0DJejVIze0ZXr8L3g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* d) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype_2;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA T9_;
	NimStringDesc* T10_;
	NimStringDesc* T11_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	objtype_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(objtype, IL64(36275087638309136));
	{
		while (1) {
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T3_;
			T3_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T3_ = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*objtype_2).n, (*d).name);
			if (!(T3_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA2;
			objtype_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*objtype_2).sons->data[((NI) 0)], IL64(36275087638309136));
		} LA2: ;
	}
	{
		if (!((*objtype_2).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA6_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*d).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_166), TM__MQdRN7fpbG7rPm4JpVVAhA_167);
	}
	LA6_: ;
	nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	nimZeroMem((void*)T9_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(objtype_2, 2, T9_);
	T10_ = (NimStringDesc*)0;
	T10_ = dollar___0A9bslyIJ49bWrftLGh13rvg(T9_);
	T8_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T10_);
	T11_ = (NimStringDesc*)0;
	T11_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*d).name).s);
	T8_[1] = rope__yShmEg9cffWxI7s5XzEKBow(T11_);
	result = percent___BKnrQUIV2xGn2MO0RK09aUw(T8_, 2);
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__TSbjDRI5MCd36QpIuSTshg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* expr, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
{	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T4_ == ((NI) 1))) goto LA5_;
			genObjectFields__TSbjDRI5MCd36QpIuSTshg(m, typ, origType, (*n)._kind_6.sons->data[((NI) 0)], expr, info);
		}
		goto LA2_;
		LA5_: ;
		{
			NI T8_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			NI T13_;
			NimStringDesc* T14_;
			NI T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T22_;
			NI T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T8_)) goto LA9_;
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T11_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T14_ = (NimStringDesc*)0;
			T14_ = nimIntToStr(T13_);
			tmp = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T12_, T14_);
			T15_ = (NI)0;
			T15_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T15_)));
			genTNimNodeArray__8W0lvt5dkO9cVIIfffRji9cQ(m, tmp, T16_);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2;
						tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T20_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
						if (!(i_2 < colontmp_)) goto LA19;
						i = i_2;
						tmp2 = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
						nimZeroMem((void*)T20_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
						T20_[0] = tmp;
						T20_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
						T20_[2] = tmp2;
						T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T21_ = percent___H3xXuIFdbz4MNb5T6BSfcQ(T20_, 3);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T21_);
						genObjectFields__TSbjDRI5MCd36QpIuSTshg(m, typ, origType, (*n)._kind_6.sons->data[i], tmp2, info);
						i_2 += ((NI) 1);
					} LA19: ;
				}
			}
			nimZeroMem((void*)T22_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T22_[0] = expr;
			T23_ = (NI)0;
			T23_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T22_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T23_)));
			T22_[2] = tmp;
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = percent___9aLrcjgzGJE3f9ab2uR37jog(T22_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T24_);
		}
		goto LA2_;
		LA9_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T26_;
			NI T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			nimZeroMem((void*)T26_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T26_[0] = expr;
			T27_ = (NI)0;
			T27_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T26_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T27_)));
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = percent___3Q9c5iS9btBDBXZVoQktb1XQ(T26_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T28_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp_2;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA L;
		tyArray__YcHYlgE5mhtkt9a3rnoucVg T39_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T41_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T42_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		field = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		tmp_2 = discriminatorTableName__WpGsd0DJejVIze0ZXr8L3g(m, typ, field);
		L = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*m).g).config, (*field).typ);
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA32_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2(m, typ);
		}
		LA32_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
			T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T36_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
			if (!(T36_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA37_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_168), TM__MQdRN7fpbG7rPm4JpVVAhA_169);
		}
		LA37_: ;
		nimZeroMem((void*)T39_, sizeof(tyArray__YcHYlgE5mhtkt9a3rnoucVg));
		T39_[0] = expr;
		T39_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, origType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		T39_[2] = (*field).loc.r;
		T39_[3] = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, (*field).typ, info);
		T39_[4] = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*field).name).s);
		T39_[5] = tmp_2;
		T39_[6] = rope__b5mr3rjXEwHVfmNLJr4cBA(L);
		T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T40_ = percent___SCyrk9acEm3vLZhXCV1fGNg(T39_, 7);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T40_);
		nimZeroMem((void*)T41_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T41_[0] = tmp_2;
		T42_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(L, IL64(1));
		T41_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T42_);
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = percent___erDe9aYc2BNxzH9brKlmtEBg(T41_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T43_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2_2;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T47_;
					if (!(i_4 < colontmp__2)) goto LA46;
					i_3 = i_4;
					b = (*n)._kind_6.sons->data[i_3];
					tmp2_2 = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
					T47_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T47_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(b);
					genObjectFields__TSbjDRI5MCd36QpIuSTshg(m, typ, origType, T47_, tmp2_2, info);
					switch ((*b).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					{
						{
							NI T51_;
							T51_ = (NI)0;
							T51_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
							if (!(T51_ < ((NI) 2))) goto LA52_;
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*b).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_170), TM__MQdRN7fpbG7rPm4JpVVAhA_171);
						}
						LA52_: ;
						{
							NI j;
							NI colontmp__3;
							NI T55_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T55_ = (NI)0;
							T55_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
							colontmp__3 = (NI)(T55_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA57;
									j = i_5;
									{
										NI x;
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T62_;
										NI y;
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T63_;
										if (!((*(*b)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA60_;
										T62_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										x = toInt__TIX0sFuRf3uBpOBltYp7bw(T62_);
										T63_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										y = toInt__TIX0sFuRf3uBpOBltYp7bw(T63_);
										{
											while (1) {
												tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T66_;
												tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
												if (!(x <= y)) goto LA65;
												nimZeroMem((void*)T66_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
												T66_[0] = tmp_2;
												T66_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (x)));
												T66_[2] = tmp2_2;
												T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
												T67_ = percent___H3xXuIFdbz4MNb5T6BSfcQ(T66_, 3);
												add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T67_);
												x += ((NI) 1);
											} LA65: ;
										}
									}
									goto LA58_;
									LA60_: ;
									{
										tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T69_;
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T70_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
										nimZeroMem((void*)T69_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
										T69_[0] = tmp_2;
										T70_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*b)._kind_6.sons->data[j], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										T69_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T70_);
										T69_[2] = tmp2_2;
										T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T71_ = percent___H3xXuIFdbz4MNb5T6BSfcQ(T69_, 3);
										add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T71_);
									}
									LA58_: ;
									i_5 += ((NI) 1);
								} LA57: ;
							}
						}
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T73_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
						nimZeroMem((void*)T73_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
						T73_[0] = tmp_2;
						T73_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(L);
						T73_[2] = tmp2_2;
						T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T74_ = percent___H3xXuIFdbz4MNb5T6BSfcQ(T73_, 3);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T74_);
					}
					break;
					default:
					{
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_172), TM__MQdRN7fpbG7rPm4JpVVAhA_173);
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA46: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_2;
		field_2 = (*n)._kind_4.sym;
		{
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*field_2).typ);
			if (!T79_) goto LA80_;
			goto BeforeRet_;
		}
		LA80_: ;
		{
			tyArray__duFhZXIIlrbrM62cWjNekg T95_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
			if (!((*field_2)._kind_4.bitsize == ((NI) 0))) goto LA84_;
			{
				if (!((*field_2).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA88_;
				fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2(m, typ);
			}
			LA88_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T92_;
				T92_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T92_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field_2).loc);
				if (!(T92_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA93_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_168), TM__MQdRN7fpbG7rPm4JpVVAhA_174);
			}
			LA93_: ;
			nimZeroMem((void*)T95_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
			T95_[0] = expr;
			T95_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, origType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			T95_[2] = (*field_2).loc.r;
			T95_[3] = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, (*field_2).typ, info);
			T95_[4] = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*field_2).name).s);
			T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T96_ = percent___HSAgkeH84eiEd8MfKIuBQA(T95_, 5);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T96_);
		}
		LA84_: ;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_168), TM__MQdRN7fpbG7rPm4JpVVAhA_175);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__DVDUKxJo5CvrWtAaM2iHCw_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T20_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T11_;
			NimStringDesc* T12_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*typ).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = ((1040 & (*(*typ).sym).flags) == 16);
			LA8_: ;
			if (!T7_) goto LA9_;
			T11_ = (NimStringDesc*)0;
			T12_ = (NimStringDesc*)0;
			T12_ = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 51);
appendString(T11_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_90));
appendString(T11_, T12_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_165, NIM_FALSE);
		}
		LA9_: ;
		genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, typ, origType, name, info);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
		genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, typ, origType, name, T14_, info);
	}
	LA1_: ;
	tmp = getNimNode__ao6gUnuVfQLtZ89c4kaIKfg_3(m);
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(typ);
		if (!!(T17_)) goto LA18_;
		genObjectFields__TSbjDRI5MCd36QpIuSTshg(m, typ, origType, (*typ).n, tmp, info);
	}
	LA18_: ;
	nimZeroMem((void*)T20_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T20_[0] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, name);
	T20_[1] = tmp;
	T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T21_ = percent___MALQXTKXJv7x9a9c247satLQ(T20_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T21_);
	t = (*typ).sons->data[((NI) 0)];
	{
		while (1) {
			if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA23;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36275087638268176));
			(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 5)) & 63);
			t = (*t).sons->data[((NI) 0)];
		} LA23: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, openArrayToTuple__iIYhRDohWfkp5IdYSl7LXw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* p;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), (*t).owner);
	p = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), (*t).owner);
	a = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49), (*t).owner);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
	add__9a8CdZqChTyqzq5bpSL3TzA(a, T1_);
	add__9a8CdZqChTyqzq5bpSL3TzA(p, a);
	add__9a8CdZqChTyqzq5bpSL3TzA(result, p);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*m).g).graph, (*(*t).owner).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	add__9a8CdZqChTyqzq5bpSL3TzA(result, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__hi0Gu9bcBd9a9cO4KStt3d7iw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result) {
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	genProc__HbYPOpwLApFuBkISFGrmEQ(m, s);
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = result;
	T1_[1] = (*s).loc.r;
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = percent___1AD3Wp47Hcdfg6PO2ac0NQ(T1_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T2_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NimStringDesc* prefixTI;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyTuple__Iz0jrTw3w7v6sMzjrqs0nA marker;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T23_;
	NimStringDesc* T24_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T25_;
	tyTuple__Iz0jrTw3w7v6sMzjrqs0nA T36_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	origType = t;
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origType, IL64(1202566653625249296));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		prefixTI = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	}
	goto LA1_;
	LA4_: ;
	{
		prefixTI = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80));
	}
	LA1_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(origType, 2, sig);
	result = getOrDefault__tD8SQMueXhdfvpBnagcsKg((*m).typeInfoMarker, sig);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA9_;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T11_, result);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T12_, T13_);
		goto BeforeRet_;
	}
	LA9_: ;
	nimZeroMem((void*)(&marker), sizeof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA));
	getOrDefault__qISsmXPGy0MStH2gg2BcOA((*(*m).g).typeInfoMarker, sig, (&marker));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		if (!!((marker.Field0 == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA16_;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
		(void)(T18_);
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_98));
		(void)(T19_);
		declareNimType__xfVyTYRVyjtacYdjZK1hbA(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97), marker.Field0, marker.Field1);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeInfoMarker), sig, marker.Field0);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T20_, marker.Field0);
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T21_, T22_);
		goto BeforeRet_;
	}
	LA16_: ;
	nimZeroMem((void*)T23_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T24_ = (NimStringDesc*)0;
	T24_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig);
	T23_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T24_);
	result = percent___nlZFDYB4M9bmBbYqEropRVw(T23_, 1);
	X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeInfoMarker), sig, result);
	T25_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T25_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t_2, IL64(36275087638309136));
	owner = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*T25_).owner);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		if (!!((owner == (*m).module))) goto LA28_;
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*(*m).g).modules->data[(*owner).position], origType, info);
		(void)(T30_);
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
		(void)(T31_);
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_98));
		(void)(T32_);
		declareNimType__xfVyTYRVyjtacYdjZK1hbA(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97), result, owner);
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T33_, result);
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T34_, T35_);
		goto BeforeRet_;
	}
	LA28_: ;
	nimZeroMem((void*)(&T36_), sizeof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA));
	T36_.Field0 = result;
	T36_.Field1 = owner;
	X5BX5Deq___e9czpY4GXpbU9cznliOfqQ1Q((&(*(*m).g).typeInfoMarker), sig, T36_);
	switch ((*t_2).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_99));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
		T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T39_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_99));
		genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, t_2, t_2, result, T39_, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
			if (!!(((*t_2).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA43_;
			T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T45_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
			result = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, T45_, info);
		}
		goto LA41_;
		LA43_: ;
		{
			NimStringDesc* T47_;
			T47_ = (NimStringDesc*)0;
			T47_ = rawNewString((reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 15);
appendString(T47_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_105));
appendString(T47_, reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T47_, 41);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T47_, TM__MQdRN7fpbG7rPm4JpVVAhA_106);
		}
		LA41_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T53_;
		{
			NimStringDesc* argX60gensym813_;
			if (!!((((*t_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0))) goto LA51_;
			argX60gensym813_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_107);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym813_, TM__MQdRN7fpbG7rPm4JpVVAhA_107);
		}
		LA51_: ;
		T53_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T53_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
		result = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, T53_, info);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			if (!!(((*t_2).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA57_;
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_99));
			genTypeInfoAuxBase__7TeHWriUy9a9aRQ1EAhsSN1w(m, t_2, t_2, result, T59_, info);
		}
		goto LA55_;
		LA57_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
			x = fakeClosureType__OVHn4Lx3T69a1BHJ0KreWYw(m, (*t_2).owner);
			genTupleInfo__DVDUKxJo5CvrWtAaM2iHCw(m, x, x, result, info);
		}
		LA55_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, t_2, t_2, result, info);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* markerProc;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			if (!((1856 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0)) goto LA64_;
			markerProc = genTraverseProc__6ja22UmHW9bFsLaOtztGpHQ(m, origType, sig);
			nimZeroMem((void*)T66_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T66_[0] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, result);
			T66_[1] = markerProc;
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = percent___NtQEfuK9bXszNTfYU57z19bw(T66_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T67_);
		}
		LA64_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, t_2, t_2, result, info);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* markerProc_2;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T73_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
			if (!((1856 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0)) goto LA71_;
			markerProc_2 = genTraverseProc__6ja22UmHW9bFsLaOtztGpHQ(m, origType, sig);
			nimZeroMem((void*)T73_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T73_[0] = tiNameForHcr__oXvL9aGYxIh9cO59b845ZGKcA(m, result);
			T73_[1] = markerProc_2;
			T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T74_ = percent___NtQEfuK9bXszNTfYU57z19bw(T73_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T74_);
		}
		LA71_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		genTypeInfoAux__DVDUKxJo5CvrWtAaM2iHCw_2(m, t_2, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		genArrayInfo__TiBDnY33G5Ca1p0Z3BOA9bg(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		genSetInfo__TiBDnY33G5Ca1p0Z3BOA9bg_2(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		genEnumInfo__TiBDnY33G5Ca1p0Z3BOA9bg_3(m, t_2, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		genObjectInfo__DVDUKxJo5CvrWtAaM2iHCw_3(m, t_2, origType, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		genTupleInfo__DVDUKxJo5CvrWtAaM2iHCw(m, t_2, origType, result, info);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x_2;
		x_2 = openArrayToTuple__iIYhRDohWfkp5IdYSl7LXw(m, t_2);
		genTupleInfo__DVDUKxJo5CvrWtAaM2iHCw(m, x_2, origType, result, info);
	}
	break;
	default:
	{
		NimStringDesc* T83_;
		T83_ = (NimStringDesc*)0;
		T83_ = rawNewString((reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 15);
appendString(T83_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_105));
appendString(T83_, reprEnum((NI)(*t_2).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T83_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T83_, TM__MQdRN7fpbG7rPm4JpVVAhA_176);
	}
	break;
	}
	{
		if (!!(((*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA86_;
		genDeepCopyProc__hi0Gu9bcBd9a9cO4KStt3d7iw(m, (*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0], result);
	}
	goto LA84_;
	LA86_: ;
	{
		if (!!(((*origType).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA89_;
		genDeepCopyProc__hi0Gu9bcBd9a9cO4KStt3d7iw(m, (*origType).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0], result);
	}
	goto LA84_;
	LA89_: ;
	LA84_: ;
	{
		NIM_BOOL T93_;
		NIM_BOOL T94_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* v2info;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T99_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
		T93_ = (NIM_BOOL)0;
		T94_ = (NIM_BOOL)0;
		T94_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0);
		if (!(T94_)) goto LA95_;
		T94_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		LA95_: ;
		T93_ = T94_;
		if (!(T93_)) goto LA96_;
		T93_ = !((((*(*t_2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
		LA96_: ;
		if (!T93_) goto LA97_;
		v2info = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg(m, origType, info);
		nimZeroMem((void*)T99_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T99_[0] = v2info;
		T99_[1] = result;
		T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T100_ = percent___UZliz9cVEMzhwBoSNLm44vQ(T99_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T100_);
	}
	LA97_: ;
	T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T101_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
	T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T102_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T101_, result);
	T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T103_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T102_, T103_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__TDEOLqqwXHVFJ9cWxDq6Nww)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typeName_1;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* destroyImpl;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* traceImpl;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* disposeImpl;
	tyArray__dNfZYyzVYdaWfURv4pxodA T17_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	typeName_1 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T11_;
			NimStringDesc* T12_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = ((1040 & (*(*t).sym).flags) == 16);
			LA8_: ;
			if (!T7_) goto LA9_;
			T11_ = (NimStringDesc*)0;
			T12_ = (NimStringDesc*)0;
			T12_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 51);
appendString(T11_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_90));
appendString(T11_, T12_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_91, NIM_FALSE);
		}
		LA9_: ;
		typeName_1 = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg(m, t);
	}
	goto LA1_;
	LA3_: ;
	{
		typeName_1 = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_94));
	}
	LA1_: ;
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85));
	(void)(T14_);
	nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T15_[0] = name;
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = percent___yhAwz5hzwMQ7qDzJyZYHDA(T15_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T16_);
	destroyImpl = genHook__oupeNBgikmhXuZ8U9c35Zlg(m, t, info, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0));
	traceImpl = genHook__oupeNBgikmhXuZ8U9c35Zlg(m, t, info, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 3));
	disposeImpl = genHook__oupeNBgikmhXuZ8U9c35Zlg(m, t, info, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 4));
	nimZeroMem((void*)T17_, sizeof(tyArray__dNfZYyzVYdaWfURv4pxodA));
	T17_[0] = name;
	T17_[1] = destroyImpl;
	T17_[2] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	T17_[3] = typeName_1;
	T17_[4] = traceImpl;
	T17_[5] = disposeImpl;
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = percent___yEs78NnVWc9b8GOXpzPn49aw(T17_, 6);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T18_);
	{
		NIM_BOOL T21_;
		NIM_BOOL T22_;
		NIM_BOOL T23_;
		NI T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		T21_ = (NIM_BOOL)0;
		T22_ = (NIM_BOOL)0;
		T23_ = (NIM_BOOL)0;
		T23_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		if (!(T23_)) goto LA24_;
		T25_ = (NI)0;
		T25_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		T23_ = (((NI) 0) < T25_);
		LA24_: ;
		T22_ = T23_;
		if (!(T22_)) goto LA26_;
		T22_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA26_: ;
		T21_ = T22_;
		if (!(T21_)) goto LA27_;
		T21_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 51))&63U)))!=0);
		LA27_: ;
		if (!T21_) goto LA28_;
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, t, info);
		(void)(T30_);
	}
	LA28_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NimStringDesc* prefixTI;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyTuple__Iz0jrTw3w7v6sMzjrqs0nA marker;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T22_;
	NimStringDesc* T23_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
	tyTuple__Iz0jrTw3w7v6sMzjrqs0nA T34_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	origType = t;
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origType, IL64(1202566653625249296));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		prefixTI = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	}
	goto LA1_;
	LA4_: ;
	{
		prefixTI = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80));
	}
	LA1_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(origType, 2, sig);
	result = getOrDefault__tD8SQMueXhdfvpBnagcsKg((*m).typeInfoMarkerV2, sig);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA9_;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T11_, result);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T12_, T13_);
		goto BeforeRet_;
	}
	LA9_: ;
	nimZeroMem((void*)(&marker), sizeof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA));
	getOrDefault__qISsmXPGy0MStH2gg2BcOA((*(*m).g).typeInfoMarkerV2, sig, (&marker));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		if (!!((marker.Field0 == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA16_;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85));
		(void)(T18_);
		declareNimType__xfVyTYRVyjtacYdjZK1hbA(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85), marker.Field0, marker.Field1);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeInfoMarkerV2), sig, marker.Field0);
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T19_, marker.Field0);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T20_, T21_);
		goto BeforeRet_;
	}
	LA16_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T23_ = (NimStringDesc*)0;
	T23_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig);
	T22_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T23_);
	result = percent___xrQqS5W45hHcYilJqzdwVg(T22_, 1);
	X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeInfoMarkerV2), sig, result);
	T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T24_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t_2, IL64(36275087638309136));
	owner = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*T24_).owner);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		if (!!((owner == (*m).module))) goto LA27_;
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg((*(*m).g).modules->data[(*owner).position], origType, info);
		(void)(T29_);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85));
		(void)(T30_);
		declareNimType__xfVyTYRVyjtacYdjZK1hbA(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85), result, owner);
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T31_, result);
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T32_, T33_);
		goto BeforeRet_;
	}
	LA27_: ;
	nimZeroMem((void*)(&T34_), sizeof(tyTuple__Iz0jrTw3w7v6sMzjrqs0nA));
	T34_.Field0 = result;
	T34_.Field1 = owner;
	X5BX5Deq___e9czpY4GXpbU9cznliOfqQ1Q((&(*(*m).g).typeInfoMarkerV2), sig, T34_);
	genTypeInfoV2Impl__TDEOLqqwXHVFJ9cWxDq6Nww(m, t_2, origType, result, info);
	T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T35_ = rope__yShmEg9cffWxI7s5XzEKBow(prefixTI);
	T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T36_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T35_, result);
	T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T37_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T36_, T37_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU64, bitSetToWord__7N9cVgZTBxAgp9c0RZ0w0l9cg)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s, NI size) {
	NU64 result;
	result = (NU64)0;
	result = 0ULL;
	{
		NI j;
		NI i;
		j = (NI)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < size)) goto LA3;
				j = i;
				{
					NI T6_;
					T6_ = (s ? s->Sup.len : 0);
					if (!(j < T6_)) goto LA7_;
					result = (NU64)(result | (NU64)((NU64)(((NU64) (s->data[j]))) << (NU64)((NI)(j * ((NI) 8)))));
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genRawSetData__P8T6oQDSZlTI5UtVVMB9c9aw)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs, NI size) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* res;
		if (!(((NI) 8) < size)) goto LA3_;
		res = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_179));
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < size)) goto LA7;
					i = i_2;
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_180));
					res = addChar(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_181)->data[(NU8)((NU8)(cs->data[i]) / (NU8)(((NU8) 16)))]);
					res = addChar(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_181)->data[(NU8)((NU8)(cs->data[i]) % (NU8)(((NU8) 16)))]);
					{
						if (!(i < (NI)(size - ((NI) 1)))) goto LA10_;
						{
							if (!((NI)(i % ((NI) 8)) == ((NI) 7))) goto LA14_;
							res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_182));
						}
						goto LA12_;
						LA14_: ;
						{
							res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
						}
						LA12_: ;
					}
					goto LA8_;
					LA10_: ;
					{
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_183));
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	goto LA1_;
	LA3_: ;
	{
		NU64 T19_;
		T19_ = (NU64)0;
		T19_ = bitSetToWord__7N9cVgZTBxAgp9c0RZ0w0l9cg(cs, size);
		result = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (T19_)));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, t, (&check), ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_41));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSeqV2__qmtU7fqvjfQZWR4m4R9aU1g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* payload;
	NimStringDesc* res;
	NimStringDesc* T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
	NI T23_;
	NI T28_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T34_;
	NI T35_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
	base = (*T1_).sons->data[((NI) 0)];
	data = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_184));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T9_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
					if (!(((NI) 0) < i)) goto LA7_;
					nimZeroMem((void*)T9_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T10_ = percent___rouofEnBX1ok9aMXmOsKdHg(T9_, 0);
					add__IM4kcMNkkOLJtqdEqSxR8A(&data, T10_);
				}
				LA7_: ;
				T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T11_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*n)._kind_6.sons->data[i], isConst, base);
				add__IM4kcMNkkOLJtqdEqSxR8A(&data, T11_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&data, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	payload = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
	T12_ = (NimStringDesc*)0;
	{
		if (!isConst) goto LA15_;
		T12_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_143));
	}
	goto LA13_;
	LA15_: ;
	{
		T12_ = ((NimStringDesc*) NIM_NIL);
	}
	LA13_: ;
	cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), T12_);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_186));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA20_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA20_: ;
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_187));
	T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T22_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, base, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T22_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_188));
	T23_ = (NI)0;
	T23_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (T23_)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_189));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA26_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_190));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), payload);
	res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_191));
	T28_ = (NI)0;
	T28_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (T28_)));
	res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_192));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), data);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_193));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA31_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA31_: ;
	T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T33_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T33_);
	nimZeroMem((void*)T34_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T35_ = (NI)0;
	T35_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T34_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T35_)));
	T34_[1] = getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2((*p).module, t);
	T34_[2] = payload;
	result = percent___C3GQZbey70223GyG307UFg(T34_, 3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSeq__qmtU7fqvjfQZWR4m4R9aU1g_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T1_;
	NI T2_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
	NimStringDesc* res;
	NimStringDesc* T19_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
	NI T35_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T45_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T2_ = (NI)0;
	T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T1_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T2_)));
	data = percent___yxmLIVRKySYknm2wSBp9cpg(T1_, 1);
	T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
	base = (*T3_).sons->data[((NI) 0)];
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 0) < T6_)) goto LA7_;
		add__yG4AKzsBRS1W4MANDlXQeg(&data, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_194));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
					if (!(i_2 < colontmp_)) goto LA11;
					i = i_2;
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T16_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
						if (!(((NI) 0) < i)) goto LA14_;
						nimZeroMem((void*)T16_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T17_ = percent___rouofEnBX1ok9aMXmOsKdHg(T16_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&data, T17_);
					}
					LA14_: ;
					T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T18_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*n)._kind_6.sons->data[i], isConst, base);
					add__IM4kcMNkkOLJtqdEqSxR8A(&data, T18_);
					i_2 += ((NI) 1);
				} LA11: ;
			}
		}
		add__yG4AKzsBRS1W4MANDlXQeg(&data, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	LA7_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&data, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
	T19_ = (NimStringDesc*)0;
	{
		if (!isConst) goto LA22_;
		T19_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_195));
	}
	goto LA20_;
	LA22_: ;
	{
		T19_ = ((NimStringDesc*) NIM_NIL);
	}
	LA20_: ;
	cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), T19_);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_186));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA27_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA27_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
	T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T29_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_142));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T29_);
	res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_197));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA32_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA32_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
	T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T34_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, base, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T34_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_188));
	T35_ = (NI)0;
	T35_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (T35_)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_189));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA38_: ;
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_190));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), data);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA42_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA42_: ;
	T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T44_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T44_);
	nimZeroMem((void*)T45_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T45_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	T45_[1] = result;
	result = percent___8u7UPO7ZpaMkWoJRtZLlYQ(T45_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result) {
	initLoc__qlujIAW86QclHYUVxlHRiQ(result, ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, e, result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getClosureType__lWDfUH9cj8K8DjyEqo9cmP3A)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw kind) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* rettype;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* desc;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	rettype = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	desc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	genProcParams__uApDq1rn2zPxULBMpTSrxQ(m, t, &rettype, &desc, (&check), !((kind == ((tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw) 0))), NIM_FALSE);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
		if (!!(T3_)) goto LA4_;
		{
			NIM_BOOL T8_;
			tyArray__f7nG5LD47BH5K9c6mASit3g T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = !(((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)));
			if (T8_) goto LA9_;
			T8_ = !((kind == ((tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw) 2)));
			LA9_: ;
			if (!T8_) goto LA10_;
			nimZeroMem((void*)T12_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T12_[0] = rope__yShmEg9cffWxI7s5XzEKBow(CallingConvToStr__A7GdKVVGtI3pvj9cV9adydpw[((*t).callConv)- 0]);
			T12_[1] = rettype;
			T12_[2] = result;
			T12_[3] = desc;
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = percent___Msid9awGKVeVe7p3v7WfNQA(T12_, 4);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T13_);
		}
		goto LA6_;
		LA10_: ;
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			nimZeroMem((void*)T15_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T15_[0] = result;
			T15_[1] = rettype;
			T15_[2] = desc;
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = percent___xyRsdWsGY1DVVispyn0Xeg(T15_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T16_);
		}
		LA6_: ;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstSimpleList__zuhkXYLhosH9cERvaWpRX2w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_182));
				}
				LA6_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA10_;
					T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T12_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*it)._kind_6.sons->data[((NI) 1)], isConst, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T12_);
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
					T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T14_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, it, isConst, (*it).typ);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T14_);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_183));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstTuple__GW9c7sQFGd9bbwGh59aVTyShQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tup) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_182));
				}
				LA6_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA10_;
					T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T12_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*it)._kind_6.sons->data[((NI) 1)], isConst, (*tup).sons->data[i]);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T12_);
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
					T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T14_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, it, isConst, (*tup).sons->data[i]);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T14_);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_183));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, caseObjDefaultBranch__E9aJksCVNSVSpIoSEOSPgZQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_Int128__9a9axPfb75jdWY25AamJewkA branch) {
	NI result;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(obj);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NI j;
					NI colontmp__2;
					NI T5_;
					NI res;
					j = (NI)0;
					colontmp__2 = (NI)0;
					T5_ = (NI)0;
					T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*obj)._kind_6.sons->data[i]);
					colontmp__2 = (NI)(T5_ - ((NI) 2));
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= colontmp__2)) goto LA7;
							j = res;
							{
								tyObject_Int128__9a9axPfb75jdWY25AamJewkA x;
								tyObject_Int128__9a9axPfb75jdWY25AamJewkA y;
								if (!((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA10_;
								x = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
								y = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
								{
									NIM_BOOL T14_;
									T14_ = (NIM_BOOL)0;
									T14_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(x, branch);
									if (!(T14_)) goto LA15_;
									T14_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(branch, y);
									LA15_: ;
									if (!T14_) goto LA16_;
									result = i;
									goto BeforeRet_;
								}
								LA16_: ;
							}
							goto LA8_;
							LA10_: ;
							{
								tyObject_Int128__9a9axPfb75jdWY25AamJewkA T19_;
								NIM_BOOL T20_;
								T19_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*obj)._kind_6.sons->data[i])._kind_6.sons->data[j], Max__zlJMNfqX7LwCYj0PF6ncWQ);
								T20_ = (NIM_BOOL)0;
								T20_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T19_, branch);
								if (!T20_) goto LA21_;
								result = i;
								goto BeforeRet_;
							}
							goto LA8_;
							LA21_: ;
							LA8_: ;
							res += ((NI) 1);
						} LA7: ;
					}
				}
				{
					NI T25_;
					T25_ = (NI)0;
					T25_ = len__P89cqdlERShb9alU3iC0yj8wast((*obj)._kind_6.sons->data[i]);
					if (!(T25_ == ((NI) 1))) goto LA26_;
					result = i;
					goto BeforeRet_;
				}
				LA26_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getDefaultValue__6MJ4xodlafi9aSG537L79bpw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350136322064));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_202));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_99));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_203));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_204));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA8_;
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_205));
		}
		goto LA6_;
		LA8_: ;
		{
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_204));
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			if (!!(((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA14_;
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_204));
		}
		goto LA12_;
		LA14_: ;
		{
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_206));
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		NI count;
		count = ((NI) 0);
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		getNullValueAuxT__Fl6EeAE3i9aDp1Z4U9aU6eLg(p, t, t, (*t).n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), &result, (&count), NIM_TRUE, info);
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_184));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					if (!(i_2 < colontmp_)) goto LA21;
					i = i_2;
					{
						if (!(((NI) 0) < i)) goto LA24_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					}
					LA24_: ;
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = getDefaultValue__6MJ4xodlafi9aSG537L79bpw(p, (*t).sons->data[i], info);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T26_);
					i_2 += ((NI) 1);
				} LA21: ;
			}
		}
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_184));
		{
			NI i_3;
			NI colontmp__2;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T29_;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T29_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, (*t).sons->data[((NI) 0)]);
			colontmp__2 = toInt__TIX0sFuRf3uBpOBltYp7bw(T29_);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
					if (!(i_4 < colontmp__2)) goto LA31;
					i_3 = i_4;
					{
						if (!(((NI) 0) < i_3)) goto LA34_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					}
					LA34_: ;
					T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T36_ = getDefaultValue__6MJ4xodlafi9aSG537L79bpw(p, (*t).sons->data[((NI) 1)], info);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T36_);
					i_4 += ((NI) 1);
				} LA31: ;
			}
		}
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_207));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T41_;
			T41_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
			T41_ = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA((*(*(*p).module).g).config, t);
			if (!(T41_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17))) goto LA42_;
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_208));
		}
		goto LA39_;
		LA42_: ;
		{
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_99));
		}
		LA39_: ;
	}
	break;
	default:
	{
		NimStringDesc* T46_;
		T46_ = (NimStringDesc*)0;
		T46_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 32);
appendString(T46_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_209));
appendString(T46_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T46_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__MQdRN7fpbG7rPm4JpVVAhA_210, NIM_FALSE);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__bDGkqDlpSTLF19cHOigiRwA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constOrNil, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
{	switch ((*obj).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T3_;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*obj)._kind_6.sons;
			i = ((NI) 0);
			T3_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					if (!(i < L)) goto LA5;
					it = &colontmp_->data[i];
					getNullValueAux__bDGkqDlpSTLF19cHOigiRwA(p, t, (*it), constOrNil, result, count, isConst, info);
					i += ((NI) 1);
				} LA5: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA branch;
		NI selectedBranch;
		NI countB;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		getNullValueAux__bDGkqDlpSTLF19cHOigiRwA(p, t, (*obj)._kind_6.sons->data[((NI) 0)], constOrNil, result, count, isConst, info);
		{
			if (!(((NI) 0) < (*count))) goto LA9_;
			add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		}
		LA9_: ;
		branch = Zero__1ed0M9aQUqqSQVhLxSQO9bCw;
		{
			if (!!((constOrNil == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA13_;
			{
				NI i_2;
				NI colontmp__2;
				NI i_3;
				i_2 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(constOrNil);
				i_3 = ((NI) 1);
				{
					while (1) {
						if (!(i_3 < colontmp__2)) goto LA17;
						i_2 = i_3;
						{
							if (!((*(*constOrNil)._kind_6.sons->data[i_2]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA20_;
							{
								if (!((*(*(*(*(*constOrNil)._kind_6.sons->data[i_2])._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id == (*(*(*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id)) goto LA24_;
								branch = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*constOrNil)._kind_6.sons->data[i_2])._kind_6.sons->data[((NI) 1)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
								goto LA15;
							}
							LA24_: ;
						}
						goto LA18_;
						LA20_: ;
						{
							if (!(i_2 == (*(*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym).position)) goto LA27_;
							branch = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*constOrNil)._kind_6.sons->data[i_2], Max__zlJMNfqX7LwCYj0PF6ncWQ);
							goto LA15;
						}
						goto LA18_;
						LA27_: ;
						LA18_: ;
						i_3 += ((NI) 1);
					} LA17: ;
				}
			} LA15: ;
		}
		LA13_: ;
		selectedBranch = caseObjDefaultBranch__E9aJksCVNSVSpIoSEOSPgZQ(obj, branch);
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		countB = ((NI) 0);
		b = lastSon__UPSW0jLTX5qJL51YMUAHgw((*obj)._kind_6.sons->data[selectedBranch]);
		{
			NIM_BOOL T31_;
			NI T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			NimStringDesc* T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138));
			if (!(T31_)) goto LA32_;
			T33_ = (NI)0;
			T33_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
			T31_ = (((NI) 0) < T33_);
			LA32_: ;
			if (!T31_) goto LA34_;
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA((*p).module, (*(*obj)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_201), T36_);
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T37_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
			T39_ = (NimStringDesc*)0;
			T39_ = nimIntToStr(selectedBranch);
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T38_, T39_);
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T41_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T40_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_191));
			add__IM4kcMNkkOLJtqdEqSxR8A(result, T41_);
			getNullValueAux__bDGkqDlpSTLF19cHOigiRwA(p, t, b, constOrNil, result, (&countB), isConst, info);
			add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		}
		goto LA29_;
		LA34_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA43_;
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA((*p).module, (*b)._kind_4.sym);
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93), T45_);
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T46_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			add__IM4kcMNkkOLJtqdEqSxR8A(result, T47_);
			getNullValueAux__bDGkqDlpSTLF19cHOigiRwA(p, t, b, constOrNil, result, (&countB), isConst, info);
		}
		goto LA29_;
		LA43_: ;
		LA29_: ;
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
		{
			if (!(((NI) 0) < (*count))) goto LA51_;
			add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		}
		LA51_: ;
		(*count) += ((NI) 1);
		field = (*obj)._kind_4.sym;
		{
			if (!!((constOrNil == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA55_;
			{
				NI i_4;
				NI colontmp__3;
				NI i_5;
				i_4 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(constOrNil);
				i_5 = ((NI) 1);
				{
					while (1) {
						if (!(i_5 < colontmp__3)) goto LA59;
						i_4 = i_5;
						{
							if (!((*(*constOrNil)._kind_6.sons->data[i_4]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA62_;
							{
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
								if (!((*(*(*(*(*constOrNil)._kind_6.sons->data[i_4])._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id == (*(*field).name).Sup.id)) goto LA66_;
								T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T68_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*(*constOrNil)._kind_6.sons->data[i_4])._kind_6.sons->data[((NI) 1)], isConst, (*field).typ);
								add__IM4kcMNkkOLJtqdEqSxR8A(result, T68_);
								goto BeforeRet_;
							}
							LA66_: ;
						}
						goto LA60_;
						LA62_: ;
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
							if (!(i_4 == (*field).position)) goto LA70_;
							T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T72_ = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*constOrNil)._kind_6.sons->data[i_4], isConst, (*field).typ);
							add__IM4kcMNkkOLJtqdEqSxR8A(result, T72_);
							goto BeforeRet_;
						}
						goto LA60_;
						LA70_: ;
						LA60_: ;
						i_5 += ((NI) 1);
					} LA59: ;
				}
			}
		}
		LA55_: ;
		T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T73_ = getDefaultValue__6MJ4xodlafi9aSG537L79bpw(p, (*field).typ, info);
		add__IM4kcMNkkOLJtqdEqSxR8A(result, T73_);
	}
	break;
	default:
	{
		NimStringDesc* T75_;
		NimStringDesc* T76_;
		T75_ = (NimStringDesc*)0;
		T76_ = (NimStringDesc*)0;
		T76_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(obj);
		T75_ = rawNewString((T76_ ? T76_->Sup.len : 0) + 32);
appendString(T75_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_209));
appendString(T75_, T76_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T75_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_211, NIM_FALSE);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__Fl6EeAE3i9aDp1Z4U9aU6eLg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constOrNil, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, NI* count, NIM_BOOL isConst, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* oldRes;
	NI oldcount;
	base = (*t).sons->data[((NI) 0)];
	oldRes = (*result);
	oldcount = (*count);
	{
		if (!!((base == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		base = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(base, IL64(36275087638268176));
		getNullValueAuxT__Fl6EeAE3i9aDp1Z4U9aU6eLg(p, orig, base, (*base).n, constOrNil, result, count, isConst, info);
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(t);
		if (!!(T6_)) goto LA7_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA11_;
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg((*p).module, orig, (*obj).info);
			add__IM4kcMNkkOLJtqdEqSxR8A(result, T13_);
		}
		goto LA9_;
		LA11_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, orig, (*obj).info);
			add__IM4kcMNkkOLJtqdEqSxR8A(result, T15_);
		}
		LA9_: ;
		(*count) += ((NI) 1);
	}
	goto LA1_;
	LA7_: ;
	LA1_: ;
	getNullValueAux__bDGkqDlpSTLF19cHOigiRwA(p, t, obj, constOrNil, result, count, isConst, info);
	{
		if (!(oldcount == (*count))) goto LA18_;
		unsureAsgnRef((void**) (&(*result)), oldRes);
	}
	LA18_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genConstObjConstr__zuhkXYLhosH9cERvaWpRX2w_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NI count;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
	count = ((NI) 0);
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA3_;
		getNullValueAuxT__Fl6EeAE3i9aDp1Z4U9aU6eLg(p, t, t, (*t).n, n, &result, (&count), isConst, (*n).info);
	}
	LA3_: ;
	nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T5_[0] = result;
	result = percent___dnB3So2xw9c189c09a9cc9b4hxA(T5_, 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genStringLiteralV2Const__Cfuh3qIr16gdBtlWztnjAQ_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI id;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pureLit;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*m).dataCache), n, ((NI) ((*m).labels)));
	pureLit = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!(id == ((NI) ((*m).labels)))) goto LA3_;
		pureLit = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_144));
		(void)(T5_);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_145));
		(void)(T6_);
		genStringLiteralDataOnlyV2__vp7GP3wlFybjCJ5ExVrrhg(m, (*n)._kind_3.strVal, pureLit, isConst);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
		pureLit = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*m).tmpBase, T8_);
	}
	LA1_: ;
	nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T9_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0))));
	T9_[1] = pureLit;
	result = percent___r2gXVULKoAtQjkgjf0Z4wg(T9_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isConst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* optionalType) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	{
		result = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, (*n)._kind_6.sons->data[((NI) 1)], isConst, (*n).typ);
	}
	break;
	default:
	{
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag ty;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		ty = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0);
		typ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		{
			if (!(optionalType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA5_;
			{
				if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA9_;
				ty = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28);
			}
			goto LA7_;
			LA9_: ;
			{
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_177), TM__MQdRN7fpbG7rPm4JpVVAhA_178);
			}
			LA7_: ;
		}
		goto LA3_;
		LA5_: ;
		{
			typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(optionalType, IL64(1189055854742120720));
			ty = (*typ).kind;
		}
		LA3_: ;
		switch (ty) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
		{
			tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs;
			NI64 T14_;
			cs = toBitSet__Ccp5iPnBYFcoF9aTCBpla6A((*(*(*p).module).g).config, n);
			T14_ = (NI64)0;
			T14_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, (*n).typ);
			result = genRawSetData__P8T6oQDSZlTI5UtVVMB9c9aw(cs, ((NI) (T14_)));
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			{
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA18_;
				result = genConstSeqV2__qmtU7fqvjfQZWR4m4R9aU1g(p, n, typ, isConst);
			}
			goto LA16_;
			LA18_: ;
			{
				result = genConstSeq__qmtU7fqvjfQZWR4m4R9aU1g_2(p, n, typ, isConst);
			}
			LA16_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
		{
			{
				NIM_BOOL T24_;
				NIM_BOOL T25_;
				NI T27_;
				T24_ = (NIM_BOOL)0;
				T25_ = (NIM_BOOL)0;
				T25_ = ((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				if (!(T25_)) goto LA26_;
				T27_ = (NI)0;
				T27_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				T25_ = (((NI) 1) < T27_);
				LA26_: ;
				T24_ = T25_;
				if (!(T24_)) goto LA28_;
				T24_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
				LA28_: ;
				if (!T24_) goto LA29_;
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T35_;
					if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA33_;
					nimZeroMem((void*)T35_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					result = percent___xXT7cKE1NTiL4U2MdlA2yQ(T35_, 0);
				}
				goto LA31_;
				LA33_: ;
				{
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T37_;
					nimZeroMem((void*)(&d), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&d));
					nimZeroMem((void*)T37_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T37_[0] = getClosureType__lWDfUH9cj8K8DjyEqo9cmP3A((*p).module, typ, ((tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw) 1));
					T37_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
					result = percent___44q9ak51X9b9bmuZ9cK4LsFWOg(T37_, 2);
				}
				LA31_: ;
			}
			goto LA22_;
			LA29_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d_2;
				nimZeroMem((void*)(&d_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n, (&d_2));
				result = rdLoc__xidyzuHqIciXbQyEOKahDg(d_2);
			}
			LA22_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		{
			result = genConstSimpleList__zuhkXYLhosH9cERvaWpRX2w(p, n, isConst);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
		{
			result = genConstTuple__GW9c7sQFGd9bbwGh59aVTyShQ(p, n, isConst, typ);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* data;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* payload;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* ctype;
			NI arrLen;
			NimStringDesc* res;
			NimStringDesc* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T57_;
			{
				if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA44_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_198), TM__MQdRN7fpbG7rPm4JpVVAhA_199);
			}
			LA44_: ;
			data = genConstSimpleList__zuhkXYLhosH9cERvaWpRX2w(p, n, isConst);
			payload = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
			ctype = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*typ).sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			arrLen = len__P89cqdlERShb9alU3iC0yj8wast(n);
			res = rawNewString(((NI) 80));
			res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
			T46_ = (NimStringDesc*)0;
			{
				if (!isConst) goto LA49_;
				T46_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_143));
			}
			goto LA47_;
			LA49_: ;
			{
				T46_ = ((NimStringDesc*) NIM_NIL);
			}
			LA47_: ;
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), T46_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), ctype);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), payload);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (arrLen)));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_200));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), data);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA54_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA54_: ;
			T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T56_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T56_);
			nimZeroMem((void*)T57_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T57_[0] = ctype;
			T57_[1] = payload;
			T57_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (arrLen)));
			result = percent___Tfa6nw2rjNPTLpiEa4Xzvw(T57_, 3);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
		{
			result = genConstObjConstr__zuhkXYLhosH9cERvaWpRX2w_2(p, n, isConst);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
		{
			{
				NIM_BOOL T62_;
				NIM_BOOL T63_;
				T62_ = (NIM_BOOL)0;
				T63_ = (NIM_BOOL)0;
				T63_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
				if (!(T63_)) goto LA64_;
				T63_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)));
				LA64_: ;
				T62_ = T63_;
				if (!(T62_)) goto LA65_;
				T62_ = (ty == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
				LA65_: ;
				if (!T62_) goto LA66_;
				result = genStringLiteralV2Const__Cfuh3qIr16gdBtlWztnjAQ_2((*p).module, n, isConst);
			}
			goto LA60_;
			LA66_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d_3;
				nimZeroMem((void*)(&d_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n, (&d_3));
				result = rdLoc__xidyzuHqIciXbQyEOKahDg(d_3);
			}
			LA60_: ;
		}
		break;
		default:
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d_4;
			nimZeroMem((void*)(&d_4), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n, (&d_4));
			result = rdLoc__xidyzuHqIciXbQyEOKahDg(d_4);
		}
		break;
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__8mAL9ckajemzgfLPfeZVNoQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	NI id;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	t = (*n).typ;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T1_);
	id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*(*p).module).tmpBase, T2_);
	fillLoc__o49bXuxJYpCizOgQ54UViIg(d, ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 8), n, T3_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		if (!(id == ((NI) ((*(*p).module).labels)))) goto LA6_;
		(*(*p).module).labels += ((NI) 1);
		nimZeroMem((void*)T8_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T8_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T8_[1] = (*d).r;
		T8_[2] = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, n, NIM_TRUE, t);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___bJpxHYPJaxWBQn6QxwBA4w(T8_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T9_);
	}
	LA6_: ;
}
static N_INLINE(NIM_BOOL, usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 8) <= (*conf).selectedGC);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__jdslQ8TsNpkTt8SvBLJjEA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
		if (!(T4_)) goto LA5_;
		T4_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10)));
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options((*(*(*p).module).g).config);
		T3_ = !(T7_);
		LA6_: ;
		if (!T3_) goto LA8_;
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA15_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA15_: ;
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T17_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T18_);
	}
	goto LA1_;
	LA8_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T22_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		if (!(dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3))) goto LA20_;
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T22_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_214));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T23_);
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T24_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA28_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA28_: ;
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T30_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T22_, T31_);
	}
	goto LA1_;
	LA20_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T34_);
		res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T35_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T36_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA39_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA39_: ;
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T42_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T41_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T42_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags) {
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA10_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA10_: ;
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T12_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T13_);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T15_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
		T15_ = (NIM_BOOL)0;
		T15_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw) 0))&7U)))!=0));
		if (T15_) goto LA16_;
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T18_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T17_, IL64(36134350144710928));
		T15_ = (((*T18_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 6))&63U)))!=0);
		LA16_: ;
		if (!T15_) goto LA19_;
		{
			NIM_BOOL T23_;
			NIM_BOOL T24_;
			NIM_BOOL T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T30_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			T23_ = (NIM_BOOL)0;
			T24_ = (NIM_BOOL)0;
			T24_ = (dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
			if (!(T24_)) goto LA25_;
			T24_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10)));
			LA25_: ;
			T23_ = T24_;
			if (T23_) goto LA26_;
			T27_ = (NIM_BOOL)0;
			T27_ = usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options((*(*(*p).module).g).config);
			T23_ = !(T27_);
			LA26_: ;
			if (!T23_) goto LA28_;
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T30_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T32_);
			res_2 = resizeString(res_2, 19);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_217));
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T33_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T34_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA37_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA37_: ;
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T39_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T30_, T40_);
		}
		goto LA21_;
		LA28_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_218));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T43_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T44_);
			res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T45_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T46_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T46_, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T47_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA50_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA50_: ;
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T53_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T52_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T42_, T53_);
		}
		LA21_: ;
	}
	goto LA1_;
	LA19_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T55_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T59_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
		T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T55_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_220));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T56_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T57_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
		T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T58_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T58_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T59_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T59_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T60_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T59_, (*dest.lode).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T60_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA63_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA63_: ;
		T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T65_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T66_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T65_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T55_, T66_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__b5Hq2LPdi5DP1QFBXQYNdA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T10_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
			T7_ = !(T8_);
			if (T7_) goto LA9_;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T7_ = (T10_ == ((NI) 0));
			LA9_: ;
			if (!T7_) goto LA11_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T15_;
				T15_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T15_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
				if (!((*T15_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))) goto LA16_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA16_: ;
		}
		LA11_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T19_;
		NIM_BOOL T20_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NIM_BOOL)0;
		T20_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0));
		if (!(T20_)) goto LA21_;
		T20_ = ((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
		LA21_: ;
		T19_ = T20_;
		if (!(T19_)) goto LA22_;
		T19_ = (((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0) == ((NI) 0));
		LA22_: ;
		if (!T19_) goto LA23_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA23_: ;
	LA1_: ;
	result = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* field, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* Result) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	(*Result).k = 0;
	(*Result).storage = 0;
	unsureAsgnRef((void**)&(*Result).lode, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).r, NIM_NIL);
	(*Result).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 5);
	(*Result).storage = a.storage;
	unsureAsgnRef((void**) (&(*Result).lode), lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(t));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T1_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
	unsureAsgnRef((void**) (&(*Result).r), amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T2_, field));
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__BtucsTdHw7orsXIL75hNVg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags) {
	tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw newflags;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
	{
		if (!(src.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1))) goto LA3_;
		newflags = (flags | 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		if (!(((*T6_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 6))&63U)))!=0)) goto LA7_;
		newflags = (flags & ~ 1);
	}
	goto LA1_;
	LA7_: ;
	{
		newflags = flags;
	}
	LA1_: ;
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T10_, IL64(36134350135273744));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* field;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T14_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T15_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T16_;
				if (!(i_2 < colontmp_)) goto LA13;
				i = i_2;
				t_2 = (*t).sons->data[i];
				nimZeroMem((void*)T14_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T14_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
				field = percent___ym0Pr6z8A9ajyOAgotpd9a9bw(T14_, 1);
				nimZeroMem((void*)(&T15_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(dest, t_2, field, (&T15_));
				nimZeroMem((void*)(&T16_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(src, t_2, field, (&T16_));
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, T15_, T16_, newflags);
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__jQZhYDteQXOIUBRG4iLXPQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!!((n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		switch ((*n).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
		{
			result = ((NI) 1);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
		{
			result = ((NI) 100);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
		{
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t;
				t = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					i_2 = ((NI) 0);
					{
						while (1) {
							NI T12_;
							if (!(i_2 < colontmp_)) goto LA11;
							i = i_2;
							t = (*n)._kind_6.sons->data[i];
							T12_ = (NI)0;
							T12_ = asgnComplexity__jQZhYDteQXOIUBRG4iLXPQ(t);
							result += T12_;
							i_2 += ((NI) 1);
						} LA11: ;
					}
				}
			}
		}
		break;
		default:
		{
		}
		break;
		}
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__9aKtDk9aj0NeiT1dC7eBiRKw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw newflags;
{	{
		if (!(t == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(src.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1))) goto LA7_;
		newflags = (flags | 1);
	}
	goto LA5_;
	LA7_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
		T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T10_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		if (!(((*T10_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 6))&63U)))!=0)) goto LA11_;
		newflags = (flags & ~ 1);
	}
	goto LA5_;
	LA11_: ;
	{
		newflags = flags;
	}
	LA5_: ;
	switch ((*t).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T19_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T20_;
		field = (*t)._kind_4.sym;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA17_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, typ);
		}
		LA17_: ;
		nimZeroMem((void*)(&T19_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(dest, (*field).typ, (*field).loc.r, (&T19_));
		nimZeroMem((void*)(&T20_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(src, (*field).typ, (*field).loc.r, (&T20_));
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, T19_, T20_, newflags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(t);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA25;
						i = i_2;
						child = (*t)._kind_6.sons->data[i];
						genOptAsgnObject__9aKtDk9aj0NeiT1dC7eBiRKw(p, dest, src, newflags, child, typ);
						i_2 += ((NI) 1);
					} LA25: ;
				}
			}
		}
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (NIM_BOOL)0;
	x = n;
	{
		while (1) {
			if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA2;
			x = (*x)._kind_6.sons->data[((NI) 0)];
		} LA2: ;
	}
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*x)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		LA6_: ;
		if (!T5_) goto LA7_;
		result = NIM_FALSE;
	}
	goto LA3_;
	LA7_: ;
	{
		result = NIM_TRUE;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = a.r;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T7_;
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T13_;
		NIM_BOOL T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0))&15U)))!=0));
		if (!(T4_)) goto LA5_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T7_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			if (!((*a.lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA10_;
			T7_ = (*(*a.lode)._kind_4.sym).kind;
		}
		goto LA8_;
		LA10_: ;
		{
			T7_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
		}
		LA8_: ;
		T13_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T13_ = mapType__pNoigHLHIPJ32RkjLRvhAQ((*(*(*p).module).g).config, T6_, T7_);
		T4_ = !((T13_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17)));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T15_) goto LA16_;
		T15_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA16_: ;
		T3_ = !(T15_);
		LA14_: ;
		if (!T3_) goto LA17_;
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80), result);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T19_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	}
	LA17_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__r42GKs9beopbtQIPWdYjAkw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36275087632017680));
	switch ((*T2_).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			NIM_BOOL T6_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			T6_ = (NIM_BOOL)0;
			T6_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(a.lode);
			if (!T6_) goto LA7_;
			T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_232));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_234));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA16_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA16_: ;
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T18_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T19_);
		}
		goto LA4_;
		LA7_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T23_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T24_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
			res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_235));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA28_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA28_: ;
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T30_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T31_);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T34_);
		res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T35_);
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T36_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T37_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T37_);
		res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T38_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T38_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA41_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA41_: ;
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T44_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T43_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T44_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T46_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T51_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T46_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T47_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
		T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T48_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T48_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T49_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T49_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
		T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T50_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T51_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, T50_);
		T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T52_ = rope__b5mr3rjXEwHVfmNLJr4cBA(T51_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T52_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA55_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA55_: ;
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T58_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T57_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T46_, T58_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* etyp;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T76_;
		NimStringDesc* res_6;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T80_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
		T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T60_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		etyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T60_, IL64(36134350135273744));
		{
			NIM_BOOL T63_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T67_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
			T63_ = (NIM_BOOL)0;
			T63_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T63_)) goto LA64_;
			T63_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
			LA64_: ;
			if (!T63_) goto LA65_;
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T67_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_5 = rawNewString(((NI) 80));
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_236));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T68_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T69_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T69_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA72_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA72_: ;
			T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T74_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T75_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T74_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T67_, T75_);
		}
		LA65_: ;
		T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T76_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_6 = rawNewString(((NI) 80));
		T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T77_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T77_);
		res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
		T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T78_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T78_);
		T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T79_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T79_);
		res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T80_ = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T80_);
		res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
		T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T81_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T81_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA84_;
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA84_: ;
		T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T86_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
		T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T87_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T86_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T76_, T87_);
	}
	break;
	default:
	{
		NimStringDesc* T89_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T90_;
		T89_ = (NimStringDesc*)0;
		T90_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T90_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T89_ = rawNewString((reprEnum((NI)(*T90_).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*T90_).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 14);
appendString(T89_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_237));
appendString(T89_, reprEnum((NI)(*T90_).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*a.lode).info, T89_, TM__MQdRN7fpbG7rPm4JpVVAhA_238);
	}
	break;
	}
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cb5f0VvvxoagMath9ay3UuQ)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs(info);
	{
		if (!(result < ((NI) 0))) goto LA3_;
		result = ((NI) 0);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__BtucsTdHw7orsXIL75hNVg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src, tySet_tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw flags) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
{	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		T3_ = (NIM_BOOL)0;
		T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T4_ = t__XNOXh7uniWNgiq58C9bW49awcgen(src);
		T3_ = !((T4_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA5_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = t__XNOXh7uniWNgiq58C9bW49awcgen(src);
		T3_ = ((*T6_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
		LA5_: ;
		if (!T3_) goto LA7_;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA14_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA14_: ;
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T16_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T17_);
		goto BeforeRet_;
	}
	LA7_: ;
	T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T18_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T18_, IL64(1202566653625280784));
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, dest, src);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA23_;
			genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
		}
		goto LA21_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw) 0))&7U)))!=0));
			if (!(T27_)) goto LA28_;
			T27_ = !((src.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1)));
			LA28_: ;
			T26_ = T27_;
			if (T26_) goto LA29_;
			T26_ = canMove__b5Hq2LPdi5DP1QFBXQYNdA(p, src.lode, dest);
			LA29_: ;
			if (!T26_) goto LA30_;
			genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, dest, src);
		}
		goto LA21_;
		LA30_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_221));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T34_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T35_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T36_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T37_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T37_, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T38_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA41_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA41_: ;
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T43_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T44_);
		}
		LA21_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA48_;
			genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
		}
		goto LA46_;
		LA48_: ;
		{
			NIM_BOOL T51_;
			NIM_BOOL T52_;
			T51_ = (NIM_BOOL)0;
			T52_ = (NIM_BOOL)0;
			T52_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TAssignmentFlag__Kd9aFyBNhxSsWFh1Km9a2hMw) 0))&7U)))!=0));
			if (!(T52_)) goto LA53_;
			T52_ = !((src.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1)));
			LA53_: ;
			T51_ = T52_;
			if (T51_) goto LA54_;
			T51_ = canMove__b5Hq2LPdi5DP1QFBXQYNdA(p, src.lode, dest);
			LA54_: ;
			if (!T51_) goto LA55_;
			genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, dest, src);
		}
		goto LA46_;
		LA55_: ;
		{
			{
				NIM_BOOL T60_;
				NIM_BOOL T61_;
				NIM_BOOL T64_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T67_;
				NimStringDesc* res_3;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
				T60_ = (NIM_BOOL)0;
				T61_ = (NIM_BOOL)0;
				T61_ = (dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
				if (!(T61_)) goto LA62_;
				T61_ = !(((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10)));
				LA62_: ;
				T60_ = T61_;
				if (T60_) goto LA63_;
				T64_ = (NIM_BOOL)0;
				T64_ = usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options((*(*(*p).module).g).config);
				T60_ = !(T64_);
				LA63_: ;
				if (!T60_) goto LA65_;
				T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T67_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_3 = rawNewString(((NI) 80));
				T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T68_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T68_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T69_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_222));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T69_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T70_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T70_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA73_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA73_: ;
				T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T75_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
				T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T76_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T75_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T67_, T76_);
			}
			goto LA58_;
			LA65_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T80_;
				NimStringDesc* res_4;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T92_;
				NimStringDesc* res_5;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
				if (!(dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3))) goto LA78_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, ty, (&tmp), NIM_FALSE);
				T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T80_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_4 = rawNewString(((NI) 80));
				T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T81_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T81_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T82_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T82_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
				T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T83_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T83_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T84_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_223));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T84_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T85_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T85_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA88_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA88_: ;
				T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T90_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
				T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T91_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T90_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T80_, T91_);
				T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T92_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T93_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T93_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T94_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_226));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T94_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T95_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T95_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA98_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA98_: ;
				T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T100_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
				T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T101_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T100_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T92_, T101_);
			}
			goto LA58_;
			LA78_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T103_;
				NimStringDesc* res_6;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T104_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T105_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
				T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T103_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_6 = rawNewString(((NI) 80));
				T104_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T104_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T104_);
				res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
				T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T105_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T105_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T106_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_222));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T106_);
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T107_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T107_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA110_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA110_: ;
				T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T112_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
				T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T113_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T112_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T103_, T113_);
			}
			LA58_: ;
		}
		LA46_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T117_;
			NIM_BOOL T118_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T121_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T122_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T123_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T124_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T125_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T126_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T127_;
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T128_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T129_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T134_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T135_;
			T117_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T117_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T118_ = (NIM_BOOL)0;
			T118_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T117_);
			if (!T118_) goto LA119_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			T121_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T121_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T122_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T122_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_227));
			nimZeroMem((void*)(&T123_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(dest, T121_, T122_, (&T123_));
			nimCopyMem((void*)(&a), (NIM_CONST void*)(&T123_), sizeof(a));
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			T124_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T124_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T125_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T125_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_227));
			nimZeroMem((void*)(&T126_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			optAsgnLoc__BudZ9caWLs3siCMYU9bVcDKw(src, T124_, T125_, (&T126_));
			nimCopyMem((void*)(&b), (NIM_CONST void*)(&T126_), sizeof(b));
			genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, a, b);
			T127_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T127_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_7 = rawNewString(((NI) 80));
			T128_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T128_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T128_);
			res_7 = resizeString(res_7, 9);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_228));
			T129_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T129_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T129_);
			res_7 = resizeString(res_7, 7);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_229));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA132_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA132_: ;
			T134_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T134_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
			T135_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T135_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T134_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T127_, T135_);
		}
		goto LA115_;
		LA119_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T137_;
			NimStringDesc* res_8;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T138_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T139_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T144_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T145_;
			T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T137_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_8 = rawNewString(((NI) 80));
			T138_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T138_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T138_);
			res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T139_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T139_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T139_);
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA142_;
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA142_: ;
			T144_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T144_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
			T145_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T145_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T144_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T137_, T145_);
		}
		LA115_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T149_;
			NIM_BOOL T150_;
			T149_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T149_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T150_ = (NIM_BOOL)0;
			T150_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T149_);
			if (!T150_) goto LA151_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T155_;
				NI T156_;
				T155_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T155_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
				T156_ = (NI)0;
				T156_ = len__5mJADrRYkP3r9auuiuDZN9cQast(T155_);
				if (!(T156_ <= ((NI) 4))) goto LA157_;
				genOptAsgnTuple__BtucsTdHw7orsXIL75hNVg_3(p, dest, src, flags);
			}
			goto LA153_;
			LA157_: ;
			{
				genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
			}
			LA153_: ;
		}
		goto LA147_;
		LA151_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T161_;
			NimStringDesc* res_9;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T162_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T163_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T168_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T169_;
			T161_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T161_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_9 = rawNewString(((NI) 80));
			T162_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T162_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T162_);
			res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T163_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T163_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T163_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA166_;
				res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA166_: ;
			T168_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T168_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
			T169_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T169_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T168_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T161_, T169_);
		}
		LA147_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			NIM_BOOL T173_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T176_;
			NimStringDesc* res_10;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T177_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T178_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T183_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T184_;
			T173_ = (NIM_BOOL)0;
			T173_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(ty);
			if (!T173_) goto LA174_;
			T176_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T176_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_10 = rawNewString(((NI) 80));
			T177_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T177_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T177_);
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T178_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T178_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T178_);
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA181_;
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA181_: ;
			T183_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T183_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
			T184_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T184_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T183_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T176_, T184_);
		}
		goto LA171_;
		LA174_: ;
		{
			NIM_BOOL T186_;
			T186_ = (NIM_BOOL)0;
			T186_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(ty);
			if (!!(T186_)) goto LA187_;
			genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
		}
		goto LA171_;
		LA187_: ;
		{
			NIM_BOOL T190_;
			T190_ = (NIM_BOOL)0;
			T190_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(ty);
			if (!T190_) goto LA191_;
			{
				NIM_BOOL T195_;
				NI T197_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T200_;
				T195_ = (NIM_BOOL)0;
				T195_ = ((*ty).sons->data[((NI) 0)] == 0);
				if (!(T195_)) goto LA196_;
				T197_ = (NI)0;
				T197_ = asgnComplexity__jQZhYDteQXOIUBRG4iLXPQ((*ty).n);
				T195_ = (T197_ <= ((NI) 4));
				LA196_: ;
				if (!T195_) goto LA198_;
				T200_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T200_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ty, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				(void)(T200_);
				{
					NimStringDesc* argX60gensym3406_;
					if (!!(!(((*ty).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))) goto LA203_;
					argX60gensym3406_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_230);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3406_, TM__MQdRN7fpbG7rPm4JpVVAhA_230);
				}
				LA203_: ;
				genOptAsgnObject__9aKtDk9aj0NeiT1dC7eBiRKw(p, dest, src, flags, (*ty).n, ty);
			}
			goto LA193_;
			LA198_: ;
			{
				genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
			}
			LA193_: ;
		}
		goto LA171_;
		LA191_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T207_;
			NimStringDesc* res_11;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T208_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T209_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T214_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T215_;
			T207_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T207_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_11 = rawNewString(((NI) 80));
			T208_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T208_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T208_);
			res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T209_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T209_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T209_);
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA212_;
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA212_: ;
			T214_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T214_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
			T215_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T215_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T214_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T207_, T215_);
		}
		LA171_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		{
			NIM_BOOL T219_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T220_;
			T219_ = (NIM_BOOL)0;
			T220_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T220_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T219_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T220_);
			if (!(T219_)) goto LA221_;
			T219_ = !(((176 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0));
			LA221_: ;
			if (!T219_) goto LA222_;
			genGenericAsgn__BtucsTdHw7orsXIL75hNVg_2(p, dest, src, flags);
		}
		goto LA217_;
		LA222_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T225_;
			NimStringDesc* res_12;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T226_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T227_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T228_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T229_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T230_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T235_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T236_;
			T225_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T225_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_12 = rawNewString(((NI) 80));
			T226_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T226_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T226_);
			res_12 = resizeString(res_12, 8);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T227_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T227_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T227_);
			res_12 = resizeString(res_12, 19);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_217));
			T228_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T228_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T228_);
			res_12 = resizeString(res_12, 9);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
			T229_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T229_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T230_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T230_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T229_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T230_);
			res_12 = resizeString(res_12, 3);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA233_;
				res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA233_: ;
			T235_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T235_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
			T236_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T236_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T235_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T225_, T236_);
		}
		LA217_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			NIM_BOOL T240_;
			T240_ = (NIM_BOOL)0;
			T240_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(dest.lode);
			if (!T240_) goto LA241_;
			genOpenArrayConv__r42GKs9beopbtQIPWdYjAkw(p, dest, src);
		}
		goto LA238_;
		LA241_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T244_;
			NIM_BOOL T245_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T248_;
			NimStringDesc* res_13;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T249_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T250_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T251_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T252_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T253_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T254_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T259_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T260_;
			T244_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T244_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T245_ = (NIM_BOOL)0;
			T245_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T244_);
			if (!T245_) goto LA246_;
			T248_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T248_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_13 = rawNewString(((NI) 80));
			T249_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T249_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_239));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T249_);
			res_13 = resizeString(res_13, 8);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T250_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T250_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T250_);
			res_13 = resizeString(res_13, 9);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
			T251_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T251_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T251_);
			res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T252_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T252_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T252_);
			res_13 = resizeString(res_13, 7);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_240));
			T253_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T253_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T254_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T254_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T253_, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T254_);
			res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA257_;
				res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA257_: ;
			T259_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T259_ = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
			T260_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T260_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T259_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T248_, T260_);
		}
		goto LA238_;
		LA246_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T262_;
			NimStringDesc* res_14;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T263_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T264_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T269_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T270_;
			T262_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T262_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_14 = rawNewString(((NI) 80));
			T263_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T263_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_14), T263_);
			res_14 = resizeString(res_14, 3);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T264_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T264_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_14), T264_);
			res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA267_;
				res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA267_: ;
			T269_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T269_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
			T270_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T270_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T269_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T262_, T270_);
		}
		LA238_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T274_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T277_;
			NimStringDesc* res_15;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T278_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T279_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T280_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T281_;
			NI64 T282_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T287_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T288_;
			T274_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
			T274_ = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA((*(*(*p).module).g).config, ty);
			if (!(T274_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17))) goto LA275_;
			T277_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T277_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_15 = rawNewString(((NI) 80));
			T278_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T278_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T278_);
			res_15 = resizeString(res_15, 8);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T279_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T279_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T279_);
			res_15 = resizeString(res_15, 19);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_217));
			T280_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T280_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T280_);
			res_15 = resizeString(res_15, 2);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T281_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T281_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T282_ = (NI64)0;
			T282_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T281_);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_15), T282_);
			res_15 = resizeString(res_15, 2);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA285_;
				res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA285_: ;
			T287_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T287_ = rope__yShmEg9cffWxI7s5XzEKBow(res_15);
			T288_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T288_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T287_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T277_, T288_);
		}
		goto LA272_;
		LA275_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T290_;
			NimStringDesc* res_16;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T291_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T292_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T297_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T298_;
			T290_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T290_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_16 = rawNewString(((NI) 80));
			T291_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T291_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_16), T291_);
			res_16 = resizeString(res_16, 3);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T292_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T292_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_16), T292_);
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA295_;
				res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA295_: ;
			T297_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T297_ = rope__yShmEg9cffWxI7s5XzEKBow(res_16);
			T298_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T298_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T297_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T290_, T298_);
		}
		LA272_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T300_;
		NimStringDesc* res_17;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T301_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T302_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T307_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T308_;
		T300_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T300_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_17 = rawNewString(((NI) 80));
		T301_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T301_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_17), T301_);
		res_17 = resizeString(res_17, 3);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		T302_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T302_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_17), T302_);
		res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA305_;
			res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA305_: ;
		T307_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T307_ = rope__yShmEg9cffWxI7s5XzEKBow(res_17);
		T308_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T308_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T307_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T300_, T308_);
	}
	break;
	default:
	{
		NimStringDesc* T310_;
		T310_ = (NimStringDesc*)0;
		T310_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 15);
appendString(T310_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_241));
appendString(T310_, reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T310_, TM__MQdRN7fpbG7rPm4JpVVAhA_242);
	}
	break;
	}
	{
		NIM_BOOL T313_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T317_;
		NimStringDesc* res_18;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T318_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T319_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T320_;
		NI64 T321_;
		NimStringDesc* T322_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T323_;
		NI T324_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T329_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T330_;
		T313_ = (NIM_BOOL)0;
		T313_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 24))&31U)))!=0);
		if (!(T313_)) goto LA314_;
		T313_ = ((9 &((NU8)1<<((NU)(dest.storage)&7U)))!=0);
		LA314_: ;
		if (!T313_) goto LA315_;
		T317_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T317_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_18 = rawNewString(((NI) 80));
		T318_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T318_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_243));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_18), T318_);
		res_18 = resizeString(res_18, 8);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
		T319_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T319_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_18), T319_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T320_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T320_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		T321_ = (NI64)0;
		T321_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T320_);
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_18), T321_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T322_ = (NimStringDesc*)0;
		T322_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*(*p).module).g).config, (*p).currLineInfo.fileIndex);
		T323_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T323_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T322_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_18), T323_);
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T324_ = (NI)0;
		T324_ = safeLineNm__cb5f0VvvxoagMath9ay3UuQ((*p).currLineInfo);
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_18), ((NI64) (T324_)));
		res_18 = resizeString(res_18, 2);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA327_;
			res_18 = resizeString(res_18, 1);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA327_: ;
		T329_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T329_ = rope__yShmEg9cffWxI7s5XzEKBow(res_18);
		T330_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T330_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T329_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T317_, T330_);
	}
	LA315_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__UANnSFbuKD1BS6RrMbZs2A)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg section, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw mode) {
	tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw T1_;
	T1_ = (tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw)0;
	T1_ = analyseObjectWithTypeField__Pldxz9alDV6810oJzh2Apog(t);
	switch (T1_) {
	case ((tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw) 0):
	{
	}
	break;
	case ((tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw) 1):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* s;
		r = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T8_;
			if (!(mode == ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 1))) goto LA6_;
			nimZeroMem((void*)T8_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T8_[0] = r;
			r = percent___TbMwXzwNL7txOQADiTjwKA(T8_, 1);
		}
		LA6_: ;
		s = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T11_) goto LA12_;
			T11_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA12_: ;
			if (!!(T11_)) goto LA13_;
			{
				while (1) {
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*s).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
					if (!(T17_)) goto LA18_;
					T17_ = !(((*s).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					LA18_: ;
					if (!T17_) goto LA16;
					add__yG4AKzsBRS1W4MANDlXQeg(&r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
					s = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s).sons->data[((NI) 0)], IL64(36275087638268176));
				} LA16: ;
			}
		}
		LA13_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA21_;
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, section);
			res = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), r);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_84));
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg((*p).module, t, (*(*a).lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T24_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA27_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA27_: ;
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T29_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T30_);
		}
		goto LA19_;
		LA21_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T32_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T32_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, section);
			res_2 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), r);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_84));
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*(*a).lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T33_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA36_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA36_: ;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T38_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T32_, T39_);
		}
		LA19_: ;
	}
	break;
	case ((tyEnum_TTypeFieldResult__aBXTX9cIKT9b0yNlXSu9aPT9cw) 2):
	{
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA43_;
			nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T49_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T50_;
				NimStringDesc* res_3;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
				tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T54_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
				if (!(mode == ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 1))) goto LA47_;
				objType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350139468048));
				T49_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T49_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*(*a).lode).info, objType);
				rawConstExpr__8mAL9ckajemzgfLPfeZVNoQ_2(p, T49_, (&tmp));
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T50_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_3 = rawNewString(((NI) 80));
				T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T51_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T51_);
				res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
				T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T52_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T52_);
				res_3 = resizeString(res_3, 20);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_213));
				T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T53_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T53_);
				res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
				T54_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
				{
					if (!((*(*a).lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA57_;
					T54_ = (*(*(*a).lode)._kind_4.sym).kind;
				}
				goto LA55_;
				LA57_: ;
				{
					T54_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
				}
				LA55_: ;
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, objType, T54_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T60_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA63_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA63_: ;
				T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T65_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
				T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T66_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T65_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T50_, T66_);
			}
			goto LA45_;
			LA47_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T68_;
				T68_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T68_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*(*a).lode).info, t);
				rawConstExpr__8mAL9ckajemzgfLPfeZVNoQ_2(p, T68_, (&tmp));
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*a), tmp, 0);
			}
			LA45_: ;
		}
		goto LA41_;
		LA43_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T75_;
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
			{
				if (!(mode == ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0))) goto LA72_;
				r_2 = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*a));
			}
			goto LA70_;
			LA72_: ;
			{
				r_2 = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
			}
			LA70_: ;
			T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T75_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, section);
			res_4 = rawNewString(((NI) 80));
			T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T76_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_244));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T76_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), r_2);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T77_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*(*a).lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T77_);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA80_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA80_: ;
			T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T82_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T83_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T82_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T75_, T83_);
		}
		LA41_: ;
	}
	break;
	}
	{
		NIM_BOOL T86_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r_3;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* s_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T106_;
		NimStringDesc* res_5;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T107_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
		T86_ = (NIM_BOOL)0;
		T86_ = isException__YPjOkGV9axAnGR3UfLeWZ1g_13(t);
		if (!T86_) goto LA87_;
		r_3 = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T93_;
			if (!(mode == ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 1))) goto LA91_;
			nimZeroMem((void*)T93_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T93_[0] = r_3;
			r_3 = percent___TbMwXzwNL7txOQADiTjwKA(T93_, 1);
		}
		LA91_: ;
		s_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		{
			NIM_BOOL T96_;
			T96_ = (NIM_BOOL)0;
			T96_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T96_) goto LA97_;
			T96_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA97_: ;
			if (!!(T96_)) goto LA98_;
			{
				while (1) {
					NIM_BOOL T102_;
					NIM_BOOL T103_;
					T102_ = (NIM_BOOL)0;
					T103_ = (NIM_BOOL)0;
					T103_ = ((*s_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
					if (!(T103_)) goto LA104_;
					T103_ = !(((*s_2).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					LA104_: ;
					T102_ = T103_;
					if (!(T102_)) goto LA105_;
					T102_ = !(((*(*s_2).sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 264)));
					LA105_: ;
					if (!T102_) goto LA101;
					add__yG4AKzsBRS1W4MANDlXQeg(&r_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
					s_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s_2).sons->data[((NI) 0)], IL64(36275087638268176));
				} LA101: ;
			}
		}
		LA98_: ;
		T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T106_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, section);
		res_5 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), r_3);
		res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_245));
		T107_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T107_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T108_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*(*T107_).sym).name).s);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T108_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA111_;
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA111_: ;
		T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T113_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T114_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T113_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T106_, T114_);
	}
	LA87_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__Q4oQMHZIwSi4nGkYAuAC8A)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* loc, NIM_BOOL isTemp) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	typ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(1189055854742120720));
		T3_ = ((*T5_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28) || (*T5_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_74));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_75));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T16_);
	}
	goto LA1_;
	LA6_: ;
	{
		NIM_BOOL T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		T18_ = (NIM_BOOL)0;
		T18_ = isComplexValueType__Fl17jclCP5VEr9a7Ycym1awcgen(typ);
		if (!!(T18_)) goto LA19_;
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
		res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_76));
		T23_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA26_;
			T23_ = (*(*(*loc).lode)._kind_4.sym).kind;
		}
		goto LA24_;
		LA26_: ;
		{
			T23_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
		}
		LA24_: ;
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, T23_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_77));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA32_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA32_: ;
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T34_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T35_);
	}
	goto LA1_;
	LA19_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T65_;
		{
			NIM_BOOL T39_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T41_;
			T39_ = (NIM_BOOL)0;
			T39_ = !(isTemp);
			if (T39_) goto LA40_;
			T41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T41_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
			T39_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T41_);
			LA40_: ;
			if (!T39_) goto LA42_;
			{
				NIM_BOOL T46_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T49_;
				NimStringDesc* res_3;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
				tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
				T46_ = (NIM_BOOL)0;
				T46_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(typ);
				if (!!(T46_)) goto LA47_;
				T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T49_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_3 = rawNewString(((NI) 80));
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T50_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_78));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T50_);
				res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
				T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T51_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*loc));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T51_);
				res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
				T52_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
				{
					if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA55_;
					T52_ = (*(*(*loc).lode)._kind_4.sym).kind;
				}
				goto LA53_;
				LA55_: ;
				{
					T52_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
				}
				LA53_: ;
				T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T58_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, T52_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T58_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA61_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA61_: ;
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
				T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T64_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T63_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T49_, T64_);
			}
			LA47_: ;
		}
		LA42_: ;
		T65_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T65_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
		genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), T65_, loc, ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__EpeofNfMJPurx0duaALCaA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, NIM_BOOL immediateAsgn) {
	{
		if (!!((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0))) goto LA3_;
		{
			if (!!(immediateAsgn)) goto LA7_;
			constructLoc__Q4oQMHZIwSi4nGkYAuAC8A(p, (&(*v).loc), NIM_FALSE);
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillResult__p9cP79bBkRq6WIT5fOHMaTzQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* param) {
	tyArray__qTjAvTvKF9anytN1At69aJMQ T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	nimZeroMem((void*)T1_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = percent___T11tCz9bIGT2CcftAwrDXZw(T1_, 0);
	fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*(*param)._kind_4.sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 4), param, T2_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
	t = (*(*param)._kind_4.sym).typ;
	{
		NIM_BOOL T5_;
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T6_;
		T5_ = (NIM_BOOL)0;
		T6_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T6_ = mapReturnType__K9aceyVl15zb9aYN9b6YJ8TnA_2(conf, t);
		T5_ = !((T6_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17)));
		if (!(T5_)) goto LA7_;
		T5_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag(conf, t);
		LA7_: ;
		if (!T5_) goto LA8_;
		(*(*param)._kind_4.sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
		(*(*param)._kind_4.sym).loc.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__8o8k31aDRiyxRXKGzZbQIQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param) {
	NimStringDesc* key;
	key = mangle__GxzvEIRbrShQbyJNboTw7A((*(*param).name).s);
	shallow__cnzwaZQQIa73ryXE31wijQsystem((&key));
	inc__cue4X8ebEalt3pWXvkS49cw((&(*p).sigConflicts), key, ((NI) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, assignParam__9aFEJaMCg37I5D9b15sgctsw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType) {
	scopeMangledParam__8o8k31aDRiyxRXKGzZbQIQ(p, s);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg, allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg result;
{	result = (tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg)0;
	result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						result = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(it);
						{
							if (!!((result == ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0)))) goto LA8_;
							goto BeforeRet_;
						}
						LA8_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T13_)) goto LA14_;
			T13_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			LA14_: ;
			if (!T13_) goto LA15_;
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag((*n)._kind_6.sons->data[((NI) 1)]);
				if (!!(T19_)) goto LA20_;
				result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1);
			}
			goto LA17_;
			LA20_: ;
			{
				result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
			}
			LA17_: ;
		}
		goto LA11_;
		LA15_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag(n);
			if (!T24_) goto LA25_;
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
		}
		goto LA11_;
		LA25_: ;
		LA11_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		{
			NI T30_;
			T30_ = (NI)0;
			T30_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T30_)) goto LA31_;
			{
				NIM_BOOL T35_;
				T35_ = (NIM_BOOL)0;
				T35_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
				if (!(T35_)) goto LA36_;
				T35_ = !((result == ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1)));
				LA36_: ;
				if (!T35_) goto LA37_;
				result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
			}
			goto LA33_;
			LA37_: ;
			{
				result = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ((*n)._kind_6.sons->data[((NI) 0)]);
			}
			LA33_: ;
		}
		LA31_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		NIM_BOOL exhaustive;
		exhaustive = NIM_FALSE;
		result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_2;
			it_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg aX60gensym5861_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T57_;
						if (!(i_4 < colontmp__2)) goto LA44;
						i_3 = i_4;
						it_2 = (*n)._kind_6.sons->data[i_3];
						{
							NIM_BOOL T47_;
							NI T48_;
							T47_ = (NIM_BOOL)0;
							T48_ = (NI)0;
							T48_ = len__P89cqdlERShb9alU3iC0yj8wast(it_2);
							T47_ = (T48_ == ((NI) 2));
							if (!(T47_)) goto LA49_;
							T47_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag((*it_2)._kind_6.sons->data[((NI) 0)]);
							LA49_: ;
							if (!T47_) goto LA50_;
							result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
							goto BeforeRet_;
						}
						LA50_: ;
						{
							NI T54_;
							T54_ = (NI)0;
							T54_ = len__P89cqdlERShb9alU3iC0yj8wast(it_2);
							if (!(T54_ == ((NI) 1))) goto LA55_;
							exhaustive = NIM_TRUE;
						}
						LA55_: ;
						T57_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T57_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it_2);
						aX60gensym5861_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(T57_);
						switch (aX60gensym5861_) {
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2):
						{
							result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0):
						{
							result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
						}
						break;
						}
						i_4 += ((NI) 1);
					} LA44: ;
				}
			}
		}
		{
			if (!!(exhaustive)) goto LA63_;
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
		}
		LA63_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		NIM_BOOL exhaustive_2;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T71_;
		{
			NIM_BOOL T68_;
			T68_ = (NIM_BOOL)0;
			T68_ = containsResult__fNMD7OWzxZVWuSQ9cYs2S9ag((*n)._kind_6.sons->data[((NI) 0)]);
			if (!T68_) goto LA69_;
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
			goto BeforeRet_;
		}
		LA69_: ;
		result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1);
		T71_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T71_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710672));
		exhaustive_2 = !(((*T71_).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) && (*T71_).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39) || (*T71_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_3;
					tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg aX60gensym5866_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T75_;
					if (!(i_6 < colontmp__3)) goto LA74;
					i_5 = i_6;
					it_3 = (*n)._kind_6.sons->data[i_5];
					T75_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T75_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it_3);
					aX60gensym5866_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(T75_);
					switch (aX60gensym5866_) {
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2):
					{
						result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0):
					{
						result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
					}
					break;
					}
					{
						if (!((*it_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88))) goto LA81_;
						exhaustive_2 = NIM_TRUE;
					}
					LA81_: ;
					i_6 += ((NI) 1);
				} LA74: ;
			}
		}
		{
			if (!!(exhaustive_2)) goto LA85_;
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
		}
		LA85_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		result = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ((*n)._kind_6.sons->data[((NI) 0)]);
		{
			if (!(result == ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0))) goto LA90_;
			result = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ((*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!(result == ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1))) goto LA94_;
				result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
			}
			LA94_: ;
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 158):
	{
		result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11))) goto LA101_;
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
		}
		LA101_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg aX60gensym5869_;
		result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1);
		aX60gensym5869_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ((*n)._kind_6.sons->data[((NI) 0)]);
		switch (aX60gensym5869_) {
		case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2):
		{
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1):
		{
		}
		break;
		case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0):
		{
			result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
		}
		break;
		}
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_8 = ((NI) 1);
			{
				while (1) {
					if (!(i_8 < colontmp__4)) goto LA109;
					i_7 = i_8;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T114_;
						if (!((*(*n)._kind_6.sons->data[i_7]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA112_;
						T114_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T114_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_7]);
						result = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(T114_);
					}
					goto LA110_;
					LA112_: ;
					{
						tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg aX60gensym5873_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T116_;
						T116_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T116_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_7]);
						aX60gensym5873_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(T116_);
						switch (aX60gensym5873_) {
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2):
						{
							result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0):
						{
							result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
						}
						break;
						}
					}
					LA110_: ;
					i_8 += ((NI) 1);
				} LA109: ;
			}
		}
	}
	break;
	default:
	{
		{
			NI i_9;
			NI colontmp__5;
			NI i_10;
			i_9 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_10 = ((NI) 0);
			{
				while (1) {
					tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg aX60gensym5875_;
					if (!(i_10 < colontmp__5)) goto LA123;
					i_9 = i_10;
					aX60gensym5875_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ((*n)._kind_6.sons->data[i_9]);
					switch (aX60gensym5875_) {
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2):
					{
						result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 2);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0):
					{
						result = ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 0);
					}
					break;
					}
					i_10 += ((NI) 1);
				} LA123: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__a4Eirucy5vgnjUqFNeFEfw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					specializeResetN__a4Eirucy5vgnjUqFNeFEfw(p, accessor, (*n)._kind_6.sons->data[i], typ);
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disc;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T44_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T45_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T48_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_248), TM__MQdRN7fpbG7rPm4JpVVAhA_249);
		}
		LA12_: ;
		disc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((*disc).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA16_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, typ);
		}
		LA16_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
			T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T20_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*disc).loc);
			if (!(T20_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA21_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_251), TM__MQdRN7fpbG7rPm4JpVVAhA_252);
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T24_[0] = accessor;
		T24_[1] = (*disc).loc.r;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = percent___jw4Sb0OSpKH1T5cLz7iyzA(T24_, 2);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T26_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T39_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T40_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T41_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					if (!(i_4 < colontmp__2)) goto LA29;
					i_3 = i_4;
					branch = (*n)._kind_6.sons->data[i_3];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA32_;
						genCaseRange__KUz7NJSCXeUWRl4foF5zfg(p, branch);
					}
					goto LA30_;
					LA32_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T36_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
						T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T36_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T37_ = percent___TTRh79a14hh1gb0owIP1Y6Q(T36_, 0);
						T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T38_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T37_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T38_);
					}
					LA30_: ;
					T39_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T39_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
					specializeResetN__a4Eirucy5vgnjUqFNeFEfw(p, accessor, T39_, typ);
					T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T40_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T41_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T42_ = percent___TmeCjGna9cPfiHHcfqmKXjw(T41_, 0);
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T40_, T43_);
					i_4 += ((NI) 1);
				} LA29: ;
			}
		}
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T44_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T45_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = percent___FsfRVuOOBePjn9cQ9aK7Vh1w(T45_, 0);
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T46_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T44_, T47_);
		nimZeroMem((void*)T48_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T48_[0] = accessor;
		T48_[1] = (*disc).loc.r;
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T49_ = percent___paA0sar8RKZqiwEaDfWo2A(T48_, 2);
		T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T50_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*disc).loc);
		specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T49_, T50_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T65_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T67_;
		field = (*n)._kind_4.sym;
		{
			if (!((*(*field).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA54_;
			goto BeforeRet_;
		}
		LA54_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA58_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, typ);
		}
		LA58_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T62_;
			T62_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T62_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
			if (!(T62_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA63_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_251), TM__MQdRN7fpbG7rPm4JpVVAhA_253);
		}
		LA63_: ;
		nimZeroMem((void*)T65_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T65_[0] = accessor;
		T65_[1] = (*field).loc.r;
		T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T66_ = percent___paA0sar8RKZqiwEaDfWo2A(T65_, 2);
		T67_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T67_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*field).loc);
		specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T66_, T67_);
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_251), TM__MQdRN7fpbG7rPm4JpVVAhA_254);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* accessor, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
{	{
		if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, accessor, T6_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA arraySize;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA i;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		arraySize = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, (*typ).sons->data[((NI) 0)]);
		nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, T8_, (&i), NIM_FALSE);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_115));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_116));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
		cgFormatValue__JXx3ANPSFqQ9c8gmnEaNQ9cA((&res), arraySize);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), i.r);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_119));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA12_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA12_: ;
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T14_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T15_);
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), accessor);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), i.r);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T16_, (*typ).sons->data[((NI) 1)]);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T18_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = percent___BYiowJAm8zF7RBRISElaLg(T18_, 0);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T19_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T17_, T20_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
					if (!(i_3 < colontmp_)) goto LA24;
					i_2 = i_3;
					x = (*typ).sons->data[i_2];
					{
						if (!!((x == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA27_;
						x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(x, IL64(36275087638268176));
					}
					LA27_: ;
					T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T29_ = parentObj__uBOaBBiKguvub019cPppbOQcgen(accessor, (*p).module);
					specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T29_, x);
					i_3 += ((NI) 1);
				} LA24: ;
			}
		}
		{
			if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA32_;
			specializeResetN__a4Eirucy5vgnjUqFNeFEfw(p, accessor, (*typ).n, typ);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
		typ_2 = typ;
		{
			NI i_4;
			NI colontmp__2;
			NI i_5;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(typ_2);
			i_5 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* res_3;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
					if (!(i_5 < colontmp__2)) goto LA37;
					i_4 = i_5;
					res_3 = rawNewString(((NI) 80));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), accessor);
					res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_155));
					cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (i_4)));
					T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T38_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
					specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T38_, (*typ_2).sons->data[i_4]);
					i_5 += ((NI) 1);
				} LA37: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T40_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T40_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T41_);
		res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_255));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), accessor);
		res_4 = resizeString(res_4, 11);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_256));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA44_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA44_: ;
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T46_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T40_, T47_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T53_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			if (!((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA51_;
			T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T53_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_5 = rawNewString(((NI) 80));
			T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T54_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T54_);
			res_5 = resizeString(res_5, 10);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_255));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), accessor);
			res_5 = resizeString(res_5, 17);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_257));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA57_: ;
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T53_, T60_);
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_6 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), accessor);
			res_6 = resizeString(res_6, 17);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_258));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA64_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA64_: ;
			T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T66_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T66_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T67_);
		}
		goto LA49_;
		LA51_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T69_;
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T69_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_7 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), accessor);
			res_7 = resizeString(res_7, 11);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_259));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA72_;
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA72_: ;
			T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T74_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
			T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T75_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T74_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T69_, T75_);
		}
		LA49_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T77_;
		NimStringDesc* res_8;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
		T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T77_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_8 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), accessor);
		res_8 = resizeString(res_8, 5);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_247));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA80_;
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA80_: ;
		T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T82_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
		T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T83_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T82_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T77_, T83_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T85_;
		NimStringDesc* res_9;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
		T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T85_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_9 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), accessor);
		res_9 = resizeString(res_9, 11);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_259));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA88_;
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA88_: ;
		T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T90_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
		T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T91_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T90_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T85_, T91_);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__9cgrUeVA21BOQab6CBAvXRQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	specializeResetT__2tWZcLKL9aUNXJnFJbKKN9aQ(p, T1_, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* loc) {
	NIM_BOOL containsGcRef;
	NIM_BOOL T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
{	T1_ = (NIM_BOOL)0;
	T1_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0));
	if (!(T1_)) goto LA2_;
	T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T3_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
	T1_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T3_);
	LA2_: ;
	containsGcRef = T1_;
	T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T4_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T4_, IL64(36134350144710928));
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(typ);
		if (!T7_) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NIM_BOOL T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T16_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		if (!(T12_)) goto LA13_;
		T12_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28) || (*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
		LA13_: ;
		if (!T12_) goto LA14_;
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T16_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_74));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
		res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_75));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T23_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T16_, T24_);
	}
	goto LA10_;
	LA14_: ;
	{
		NIM_BOOL T26_;
		T26_ = (NIM_BOOL)0;
		T26_ = isComplexValueType__Fl17jclCP5VEr9a7Ycym1awcgen(typ);
		if (!!(T26_)) goto LA27_;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA nilLoc;
			if (!containsGcRef) goto LA31_;
			nimZeroMem((void*)(&nilLoc), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&nilLoc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1), (*loc).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
			nilLoc.r = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_94));
			genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, (*loc), nilLoc);
		}
		goto LA29_;
		LA31_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T34_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T34_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*loc));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T35_);
			res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_247));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA38_: ;
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T41_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T40_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T34_, T41_);
		}
		LA29_: ;
	}
	goto LA10_;
	LA27_: ;
	{
		{
			NIM_BOOL T45_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
			T45_ = (NIM_BOOL)0;
			T45_ = !(((*loc).storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2)));
			if (!(T45_)) goto LA46_;
			T45_ = containsGcRef;
			LA46_: ;
			if (!T45_) goto LA47_;
			specializeReset__9cgrUeVA21BOQab6CBAvXRQ(p, (*loc));
			T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T49_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
			genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), T49_, loc, ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0));
		}
		goto LA43_;
		LA47_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T51_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T54_;
			tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T55_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T68_;
			T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T51_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_78));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T52_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T53_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*loc));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T53_);
			res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
			T54_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T54_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
			T55_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
			{
				if (!((*(*loc).lode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA58_;
				T55_ = (*(*(*loc).lode)._kind_4.sym).kind;
			}
			goto LA56_;
			LA58_: ;
			{
				T55_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
			}
			LA56_: ;
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T61_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T54_, T55_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T61_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA64_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA64_: ;
			T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T66_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T66_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T51_, T67_);
			T68_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T68_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*loc));
			genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), T68_, loc, ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0));
		}
		LA43_: ;
	}
	LA10_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__PDMGXd7Yn9cB79asQW3arukQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ls;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* env;
{	{
		if (!!((((*(*prc).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 12))&63U)))!=0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	ls = lastSon__UPSW0jLTX5qJL51YMUAHgw((*(*prc).ast)._kind_6.sons->data[((NI) 3)]);
	{
		if (!!(((*ls).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA7_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*prc).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_260), TM__MQdRN7fpbG7rPm4JpVVAhA_261);
	}
	LA7_: ;
	env = (*ls)._kind_4.sym;
	assignLocalVar__UtJx89cn0a8CNSWWmaj6raA(p, ls);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T13_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10))) goto LA11_;
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T13_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*env).loc);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_262));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*env).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_263));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA19_: ;
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T13_, T22_);
	}
	goto LA9_;
	LA11_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T24_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T24_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*env).loc);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
		res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_76));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*env).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
		res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_264));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA29_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA29_: ;
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T31_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T24_, T32_);
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__IroqGJs3T8by0fVw4XMZJg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procBody) {
	genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, procBody);
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		if (!((48 & (*p).flags) == 16)) goto LA3_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 5)) & 7);
		res = rawNewString(((NI) 80));
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_265));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA7_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA7_: ;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0))- 0], T9_);
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_266));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_267));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T10_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1))- 0], T15_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, NimStringDesc* filename, NI line, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((NI) 0) < line);
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T8_ = (NimStringDesc*)0;
		T8_ = makeSingleLineCString__rMRFcrOdLs9cBLwxpf0jLag(filename);
		T7_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T8_);
		T7_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (line)));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___lS9bA1j3Ue6pp7sCliDsT8g(T7_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(r, T9_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__8gOq38UiI9arVxZ9at35m22Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NimStringDesc* T1_;
	NI T2_;
	T1_ = (NimStringDesc*)0;
	T1_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, info.fileIndex);
	T2_ = (NI)0;
	T2_ = safeLineNm__cb5f0VvvxoagMath9ay3UuQ(info);
	genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow(r, T1_, T2_, conf);
}
static N_INLINE(NIM_BOOL, isNoReturn__wKa9aVgc3t9a9atx3OlQKTJyQcgen)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16))&63U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = !(((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3)));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, initFrame__hSB0mXJGcFil9bvrhp0Qm5g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	NimStringDesc* res_2;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NI T3_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NI)0;
		T3_ = len__9b0YRltzV3kNSE9aQTsG82wg((*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2))- 0]);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_273));
		res = resizeString(res, 125);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_274));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_275));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_276));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_273));
		res = resizeString(res, 232);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_277));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_275));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_278));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_273));
		res = resizeString(res, 70);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_279));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2))- 0], T8_);
	}
	LA4_: ;
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_275));
	(void)(T9_);
	res_2 = rawNewString(((NI) 80));
	res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_280));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), procname);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), filename);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA12_;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA12_: ;
	result = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, deinitFrame__3AsTOpq9crZUYBL9aD1lXBng_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_282));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA4_: ;
	result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getProcTypeCast__kjPRfLdGk3b78KhSOOjbOA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*prc).loc);
	result = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T1_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* rettype;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
		tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
		if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA4_;
		rettype = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		params = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
		initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
		genProcParams__uApDq1rn2zPxULBMpTSrxQ(m, (*prc).typ, &rettype, &params, (&check), NIM_TRUE, NIM_FALSE);
		nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T6_[0] = rettype;
		T6_[1] = params;
		result = percent___tgUnLdPVK0vRqC0pWxMClQ(T6_, 2);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__HbYPOpwLApFuBkISFGrmEQ_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* header;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* returnStmt;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procBody;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* generatedProc;
	p = newProc__r9c9cj4fW68RhY7ht9btSvB8w(prc, m);
	header = genProcHeader__OWG529cW3RTHLgDJuQoIH8A(m, prc, NIM_FALSE);
	returnStmt = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	procBody = transformBody__ocxOgPRHWfivNZELIhOv7w((*(*m).g).graph, prc, NIM_FALSE);
	{
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41))&63U)))!=0)) goto LA3_;
		procBody = injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ((*(*m).g).graph, prc, procBody);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resNode;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* res;
		T7_ = (NIM_BOOL)0;
		T7_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*(*prc).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA8_: ;
		if (!T7_) goto LA9_;
		{
			NI T13_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast((*prc).ast);
			if (!(T13_ <= ((NI) 7))) goto LA14_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*prc).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_66), TM__MQdRN7fpbG7rPm4JpVVAhA_67);
		}
		LA14_: ;
		resNode = (*(*prc).ast)._kind_6.sons->data[((NI) 7)];
		res = (*resNode)._kind_4.sym;
		{
			NIM_BOOL T18_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			T18_ = (NIM_BOOL)0;
			T18_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*m).g).config, (*(*prc).typ).sons->data[((NI) 0)]);
			if (!!(T18_)) goto LA19_;
			{
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA23_;
				(*res).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14)) & 63);
			}
			LA23_: ;
			{
				NIM_BOOL T27_;
				NIM_BOOL T28_;
				NIM_BOOL T30_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* decl;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
				T27_ = (NIM_BOOL)0;
				T28_ = (NIM_BOOL)0;
				T28_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
				if (!(T28_)) goto LA29_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T30_) goto LA31_;
				T30_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA31_: ;
				T28_ = T30_;
				LA29_: ;
				T27_ = T28_;
				if (!(T27_)) goto LA32_;
				val = easyResultAsgn__oKhRC9bEKTxG5epdNiNWZ0w(procBody);
				T27_ = !((val == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
				LA32_: ;
				if (!T27_) goto LA33_;
				decl = localVarDecl__NYI5fC69aIqZGRakncXv9cNQ(p, resNode);
				nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, val, (&a));
				T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), decl);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T36_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T36_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA39_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA39_: ;
				T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T41_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T42_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T41_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T42_);
			}
			goto LA25_;
			LA33_: ;
			{
				assignLocalVar__UtJx89cn0a8CNSWWmaj6raA(p, resNode);
				initLocalVar__EpeofNfMJPurx0duaALCaA(p, res, NIM_FALSE);
			}
			LA25_: ;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_246));
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*res).loc);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T44_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA47_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA47_: ;
			returnStmt = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		}
		goto LA16_;
		LA19_: ;
		{
			fillResult__p9cP79bBkRq6WIT5fOHMaTzQ((*(*(*p).module).g).config, resNode);
			assignParam__9aFEJaMCg37I5D9b15sgctsw(p, res, (*(*prc).typ).sons->data[((NI) 0)]);
			{
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA52_;
			}
			goto LA50_;
			LA52_: ;
			{
				tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg T55_;
				T55_ = (tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg)0;
				T55_ = allPathsAsgnResult__3E19a9b4Xsk8ypT9b1MEmPyCQ(procBody);
				if (!(T55_ == ((tyEnum_InitResultEnum__9c9csRan2YP9boKbiUR9cP6PNg) 1))) goto LA56_;
			}
			goto LA50_;
			LA56_: ;
			{
				resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, (&(*res).loc));
			}
			LA50_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T61_;
				T61_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T61_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*res).typ, IL64(36134350135273744));
				if (!((*T61_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16))) goto LA62_;
				(*res).loc.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
			}
			LA62_: ;
		}
		LA16_: ;
	}
	LA9_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*prc).typ).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA66;
				i = i_2;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					param = (*(*(*(*prc).typ).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T70_;
						T70_ = (NIM_BOOL)0;
						T70_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*param).typ);
						if (!T70_) goto LA71_;
						goto LA67;
					}
					LA71_: ;
					assignParam__9aFEJaMCg37I5D9b15sgctsw(p, param, (*(*prc).typ).sons->data[((NI) 0)]);
				} LA67: ;
				i_2 += ((NI) 1);
			} LA66: ;
		}
	}
	closureSetup__PDMGXd7Yn9cB79asQW3arukQ(p, prc);
	genProcBody__IroqGJs3T8by0fVw4XMZJg(p, procBody);
	generatedProc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	genCLineDir__8gOq38UiI9arVxZ9at35m22Q(&generatedProc, (*prc).info, (*(*m).g).config);
	{
		NIM_BOOL T75_;
		T75_ = (NIM_BOOL)0;
		T75_ = isNoReturn__wKa9aVgc3t9a9atx3OlQKTJyQcgen((*p).module, prc);
		if (!T75_) goto LA76_;
		{
			if (!((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 6))&7U)))!=0)) goto LA80_;
			header = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_269), header);
		}
		LA80_: ;
	}
	LA76_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T94_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T95_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T96_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0)) goto LA84_;
		{
			if (!((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 6))&7U)))!=0)) goto LA88_;
			header = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_270), header);
		}
		LA88_: ;
		res_4 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), header);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA92_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA92_: ;
		T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T94_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*T94_));
		T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T95_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*T95_));
		T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T96_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*T96_));
		res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_272));
		T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T97_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T97_);
	}
	goto LA82_;
	LA84_: ;
	{
		NimStringDesc* res_5;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T136_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T137_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T149_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T150_;
		{
			NIM_BOOL T101_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T105_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
			T101_ = (NIM_BOOL)0;
			T101_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!(T101_)) goto LA102_;
			T101_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, prc);
			LA102_: ;
			if (!T101_) goto LA103_;
			nimZeroMem((void*)T105_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T105_[0] = header;
			T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T106_ = percent___QqzUiJcAEZE2azDhIWHrgg(T105_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T106_);
		}
		LA103_: ;
		res_5 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), header);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA109_;
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA109_: ;
		T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T111_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T111_);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T116_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T118_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0)) goto LA114_;
			T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T116_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, (*T116_));
			procname = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*prc).name).s);
			T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T117_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*(*p).module).g).config, (*prc).info);
			T118_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T118_ = initFrame__hSB0mXJGcFil9bvrhp0Qm5g(p, procname, T117_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T118_);
		}
		goto LA112_;
		LA114_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T120_;
			T120_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T120_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, (*T120_));
		}
		LA112_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T125_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T126_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T131_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 21))&31U)))!=0)) goto LA123_;
			T125_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T125_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			res_6 = rawNewString(((NI) 80));
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
			T126_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T126_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_281));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T126_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA129_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA129_: ;
			T131_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T131_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			add__IM4kcMNkkOLJtqdEqSxR8A(T125_, T131_);
		}
		LA123_: ;
		{
			if (!(((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0))&7U)))!=0)) goto LA134_;
			add__yG4AKzsBRS1W4MANDlXQeg(&generatedProc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		}
		LA134_: ;
		T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T136_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, (*T136_));
		T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T137_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, (*T137_));
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T142_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T143_;
			if (!(((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0))&7U)))!=0)) goto LA140_;
			nimZeroMem((void*)T142_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T143_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T143_ = percent___BBAyGuVoK6QA7nXfPUIYKA(T142_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T143_);
		}
		LA140_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T148_;
			if (!(((*prc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0)) goto LA146_;
			T148_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T148_ = deinitFrame__3AsTOpq9crZUYBL9aD1lXBng_3(p);
			add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T148_);
		}
		LA146_: ;
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, returnStmt);
		nimZeroMem((void*)T149_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T150_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T150_ = percent___g9b9arp3BWCGRHDe21SJso6w(T149_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&generatedProc, T150_);
	}
	LA82_: ;
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], generatedProc);
	{
		NIM_BOOL T153_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T156_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T157_;
		T153_ = (NIM_BOOL)0;
		T153_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, prc);
		if (!T153_) goto LA154_;
		nimZeroMem((void*)T156_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T156_[0] = (*prc).loc.r;
		T156_[1] = amp___Z7W1o5nPSc3ExfO5f7j1Gg((*prc).loc.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_53));
		T156_[2] = getProcTypeCast__kjPRfLdGk3b78KhSOOjbOA(m, prc);
		T156_[3] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, prc);
		T157_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T157_ = percent___09aVguRR64dWfw4b6fKBcqg(T156_, 4);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T157_);
	}
	LA154_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__SYG8r9a6ANje3aBM5rYzaeg)(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	n = (*lib).path;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26) || (*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__Q3RS49c6kF7OS9bmwvFHRQJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib) {
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!!((*lib).generated)) goto LA3_;
		(*lib).generated = NIM_TRUE;
		tmp = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
		asgnRef((void**) (&(*lib).name), tmp);
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = tmp;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___FBNsdfF5FNrY4P9cYQIfvZQ(T5_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T6_);
		{
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* loadlib;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			if (!((*(*lib).path).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*lib).path).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA9_;
			s = NIM_NIL;
			libCandidates__TEY9aqiaMWVK2l0NzZy7BwQ((*(*lib).path)._kind_3.strVal, (&s));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 73), (*(*lib).path)._kind_3.strVal, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_283, NIM_FALSE);
			loadlib = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
			{
				NI i;
				NI colontmp_;
				NI T12_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T12_ = ((s ? s->Sup.len : 0)-1);
				colontmp_ = T12_;
				res = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
						NimStringDesc* res_2;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
						if (!(res <= colontmp_)) goto LA14;
						i = res;
						(*m).labels += ((NI) 1);
						{
							if (!(((NI) 0) < i)) goto LA17_;
							add__yG4AKzsBRS1W4MANDlXQeg(&loadlib, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_284));
						}
						LA17_: ;
						n = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), s->data[i]);
						(*n).info = (*(*lib).path).info;
						res_2 = rawNewString(((NI) 80));
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), tmp);
						res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_285));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T19_);
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw(m, n);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T20_);
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA23_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA23_: ;
						T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
						add__IM4kcMNkkOLJtqdEqSxR8A(&loadlib, T25_);
						res += ((NI) 1);
					} LA14: ;
				}
			}
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 6);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_287));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), loadlib);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_288));
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_289));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T26_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw(m, (*lib).path);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T27_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA30_: ;
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T32_);
		}
		goto LA7_;
		LA9_: ;
		{
			tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest;
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T43_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			p = newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), m);
			(*p).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17)) & 31));
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 6)) & 7);
			nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&dest), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1), (*lib).path, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
			dest.r = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
			res_4 = rawNewString(((NI) 80));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*(*lib).path).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T34_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T35_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA38_: ;
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T40_);
			expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*lib).path, (&dest));
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], (*T41_));
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], (*T42_));
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T43_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], (*T43_));
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 6);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_287));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), tmp);
			res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_285));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T44_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T45_);
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_290));
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_289));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T46_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T47_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA50_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA50_: ;
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T52_);
		}
		LA7_: ;
	}
	LA3_: ;
	{
		if (!((*lib).name == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA55_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_291), TM__MQdRN7fpbG7rPm4JpVVAhA_292);
	}
	LA55_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 18))&63U)))!=0)) goto LA3_;
		result = rope__yShmEg9cffWxI7s5XzEKBow((*(*sym).name).s);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T6_;
		NimStringDesc* T7_;
		T6_ = (NimStringDesc*)0;
		T6_ = nimIntToStr((*sym).Sup.id);
		T7_ = (NimStringDesc*)0;
		T7_ = nsuFormatSingleElem(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_293), T6_);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T7_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib;
	NIM_BOOL isCall;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* extname;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T47_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T48_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
	lib = (*sym).annex;
	isCall = isGetProcAddr__SYG8r9a6ANje3aBM5rYzaeg(lib);
	extname = (*sym).loc.r;
	{
		if (!!(isCall)) goto LA3_;
		loadDynamicLib__Q3RS49c6kF7OS9bmwvFHRQJQ(m, lib);
	}
	LA3_: ;
	tmp = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(sym);
	asgnRef((void**) (&(*sym).loc.r), tmp);
	asgnRef((void**) (&(*(*sym).typ).sym), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	(*m).labels += ((NI) 2);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* load;
		tyArray__f7nG5LD47BH5K9c6mASit3g T15_;
		NimStringDesc* T16_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* last;
		NimStringDesc* idx;
		if (!isCall) goto LA7_;
		n = (*lib).path;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2((*m).initProc, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		params = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T9_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		{
			NI i;
			NI colontmp_;
			NI T11_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T11_ = (NI)0;
			T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp_ = (NI)(T11_ - ((NI) 1));
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2((*m).initProc, (*n)._kind_6.sons->data[i], (&a));
					T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					add__IM4kcMNkkOLJtqdEqSxR8A(&params, T14_);
					add__yG4AKzsBRS1W4MANDlXQeg(&params, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
		nimZeroMem((void*)T15_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T15_[0] = tmp;
		T15_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		T15_[2] = params;
		T16_ = (NimStringDesc*)0;
		T16_ = dollar___mZ66tEveFIQokq3arf8Klw(extname);
		T15_[3] = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T16_);
		load = percent___cB7zULPbG5vWWdCukRjdqg(T15_, 4);
		last = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		{
			if (!((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58))) goto LA19_;
			last = (*last)._kind_6.sons->data[((NI) 1)];
		}
		LA19_: ;
		{
			NimStringDesc* argX60gensym5781_;
			if (!!(((*last).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20)))) goto LA23_;
			argX60gensym5781_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_294);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym5781_, TM__MQdRN7fpbG7rPm4JpVVAhA_294);
		}
		LA23_: ;
		idx = (*last)._kind_3.strVal;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T29_;
			if (!((idx ? idx->Sup.len : 0) == ((NI) 0))) goto LA27_;
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T29_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			add__IM4kcMNkkOLJtqdEqSxR8A(T29_, load);
		}
		goto LA25_;
		LA27_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((idx ? idx->Sup.len : 0) == ((NI) 1));
			if (!(T31_)) goto LA32_;
			T31_ = (((NU8)(idx->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(idx->data[((NI) 0)])) <= ((NU8)(57)));
			LA32_: ;
			if (!T31_) goto LA33_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).extensionLoaders[(((NU8)(idx->data[((NI) 0)])))- 48], load);
		}
		goto LA25_;
		LA33_: ;
		{
			NimStringDesc* T36_;
			T36_ = (NimStringDesc*)0;
			T36_ = rawNewString((idx ? idx->Sup.len : 0) + 13);
appendString(T36_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_295));
appendString(T36_, idx);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*sym).info, T36_, TM__MQdRN7fpbG7rPm4JpVVAhA_296);
		}
		LA25_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
		NimStringDesc* T40_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), tmp);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_76));
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T38_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T38_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T39_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_297));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T39_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*lib).name);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T40_ = (NimStringDesc*)0;
		T40_ = dollar___mZ66tEveFIQokq3arf8Klw(extname);
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T40_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T41_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA44_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA44_: ;
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T46_);
	}
	LA5_: ;
	nimZeroMem((void*)T47_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T47_[0] = (*sym).loc.r;
	T48_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T48_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
	T47_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T48_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T49_ = percent___dpzmcz9a6kXbhFacdElIMOw(T47_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T49_);
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__TAVDUakAwQnRHDK9cFe6L7g_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	asgnRef((void**) (&(*sym).loc.r), mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(sym));
	asgnRef((void**) (&(*(*sym).typ).sym), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__HbYPOpwLApFuBkISFGrmEQ_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
{	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 7))&15U)))!=0)) goto LA3_;
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, prc);
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, (*(*prc).name).s);
		(void)(T5_);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0)) goto LA8_;
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(m, prc);
	}
	goto LA6_;
	LA8_: ;
	{
		if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5))) goto LA11_;
		{
			NIM_BOOL T15_;
			tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* T18_;
			T15_ = (NIM_BOOL)0;
			T15_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*m).declaredThings), (*prc).Sup.id);
			if (!!(T15_)) goto LA16_;
			T18_ = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
			T18_ = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA(m, prc);
			fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(T18_, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
			genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(m, prc);
			genProcAux__HbYPOpwLApFuBkISFGrmEQ_4(m, prc);
		}
		LA16_: ;
	}
	goto LA6_;
	LA11_: ;
	{
		tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* q;
		if (!(((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4))&15U)))!=0)) goto LA20_;
		q = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA(m, prc);
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(q, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(m, prc);
		{
			NIM_BOOL T24_;
			NIM_BOOL T26_;
			T24_ = (NIM_BOOL)0;
			T24_ = !((q == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			if (!(T24_)) goto LA25_;
			T26_ = (NIM_BOOL)0;
			T26_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*q).declaredThings), (*prc).Sup.id);
			T24_ = !(T26_);
			LA25_: ;
			if (!T24_) goto LA27_;
			symInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_3(q, prc);
			{
				NIM_BOOL T31_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T34_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T35_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
				T31_ = (NIM_BOOL)0;
				T31_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(q, prc);
				if (!T31_) goto LA32_;
				nimZeroMem((void*)T34_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T34_[0] = (*prc).loc.r;
				T35_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T35_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*prc).loc);
				T34_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(q, T35_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				T34_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*q).module);
				T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T36_ = percent___AWFBEodxoi9a61KDUc9aiw1w(T34_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*q).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T36_);
			}
			LA32_: ;
		}
		goto LA22_;
		LA27_: ;
		{
			symInDynamicLibPartial__TAVDUakAwQnRHDK9cFe6L7g_4(m, prc);
		}
		LA22_: ;
	}
	goto LA6_;
	LA20_: ;
	{
		tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* q_2;
		if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0))) goto LA39_;
		q_2 = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA(m, prc);
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(q_2, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T43_;
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			NIM_BOOL T47_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
			T43_ = (NIM_BOOL)0;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T45_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, prc);
			if (!(T45_)) goto LA46_;
			T47_ = (NIM_BOOL)0;
			T47_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*m).declaredProtos), (*prc).Sup.id);
			T45_ = !(T47_);
			LA46_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA48_;
			T44_ = !((q_2 == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			LA48_: ;
			T43_ = T44_;
			if (!(T43_)) goto LA49_;
			T43_ = !(((*(*q_2).module).Sup.id == (*(*m).module).Sup.id));
			LA49_: ;
			if (!T43_) goto LA50_;
			nimZeroMem((void*)T52_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T52_[0] = (*prc).loc.r;
			T52_[1] = getProcTypeCast__kjPRfLdGk3b78KhSOOjbOA(m, prc);
			T52_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, prc);
			T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T53_ = percent___vHbYzYlzLPcurSm0Hu8InQ(T52_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T53_);
		}
		LA50_: ;
		genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(m, prc);
		{
			NIM_BOOL T56_;
			NIM_BOOL T58_;
			T56_ = (NIM_BOOL)0;
			T56_ = !((q_2 == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			if (!(T56_)) goto LA57_;
			T58_ = (NIM_BOOL)0;
			T58_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*q_2).declaredThings), (*prc).Sup.id);
			T56_ = !(T58_);
			LA57_: ;
			if (!T56_) goto LA59_;
			{
				NIM_BOOL T63_;
				T63_ = (NIM_BOOL)0;
				T63_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, prc);
				if (!T63_) goto LA64_;
				genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(q_2, prc);
			}
			LA64_: ;
			genProcAux__HbYPOpwLApFuBkISFGrmEQ_4(q_2, prc);
		}
		LA59_: ;
	}
	goto LA6_;
	LA39_: ;
	{
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
		useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, prc);
		{
			if (!!((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0))) goto LA69_;
			genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g(m, prc);
		}
		LA69_: ;
	}
	LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProc__HbYPOpwLApFuBkISFGrmEQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
{	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30))&63U)))!=0);
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isActivated__FP3Xc9c0yhzvB6NLyfQJkYw(prc);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
	LA6_: ;
	{
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0)) goto LA10_;
		addForwardedProc__HbYPOpwLApFuBkISFGrmEQ_2(m, prc);
		fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA8_;
	LA10_: ;
	{
		genProcNoForward__HbYPOpwLApFuBkISFGrmEQ_3(m, prc);
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((262272 & (*prc).flags) == 128);
			if (!(T16_)) goto LA17_;
			T16_ = !(((*(*m).g).generatedHeader == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T15_ = !((((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0));
			LA18_: ;
			if (!T15_) goto LA19_;
			genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g((*(*m).g).generatedHeader, prc);
			{
				if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5))) goto LA23_;
				{
					NIM_BOOL T27_;
					T27_ = (NIM_BOOL)0;
					T27_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*(*m).g).generatedHeader).declaredThings), (*prc).Sup.id);
					if (!!(T27_)) goto LA28_;
					genProcAux__HbYPOpwLApFuBkISFGrmEQ_4((*(*m).g).generatedHeader, prc);
				}
				LA28_: ;
			}
			LA23_: ;
		}
		LA19_: ;
	}
	LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	if (!(T2_)) goto LA3_;
	T2_ = ((67108872 & (*s).flags) == 8);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((72 & (*s).loc.flags) == 0);
	LA4_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((71303168 & ~ (*conf).globalOptions)==0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__wDT42Iy4l3KGL9cd8rMjKRA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isExtern) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*m).g).config);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
			NI T12_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T13_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			T8_ = (NIM_BOOL)0;
			T8_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*m).g).nimtvDeclared), (*s).Sup.id);
			if (!!(T8_)) goto LA9_;
			T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T11_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
			asgnRef((void**) (&(*(*m).g).nimtvDeps), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*(*m).g).nimtvDeps), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
			T12_ = (*(*m).g).nimtvDeps->Sup.len++;
			asgnRef((void**) (&(*(*m).g).nimtvDeps->data[T12_]), T11_);
			nimZeroMem((void*)T13_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T14_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
			T13_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T14_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T13_[1] = (*s).loc.r;
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = percent___vzbf0XksfaFTXNoTT6BCwA(T13_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*m).g).nimtv, T15_);
		}
		LA9_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		{
			if (!isExtern) goto LA19_;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_298));
		}
		goto LA17_;
		LA19_: ;
		{
			if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5))&15U)))!=0)) goto LA22_;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_299));
		}
		goto LA17_;
		LA22_: ;
		{
			add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_24));
		}
		LA17_: ;
		{
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 22))&63U)))!=0)) goto LA27_;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_300));
		}
		LA27_: ;
		T29_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T29_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T29_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T30_);
		nimZeroMem((void*)T31_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T31_[0] = (*s).loc.r;
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = percent___nzT6Rke9c7tkW9b3XMmld2LA(T31_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T32_);
	}
	LA1_: ;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	result = &(*p).blocks->data[((NI) 0)].sections[(s)- 0];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__t9a9a9bxmaOztYOfsfhQUOXXw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
{	sym = (*n)._kind_4.sym;
	useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, sym);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = mangleName__RaNE9b8A430I9bfpgZmdrC1w(m, sym);
	fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 3), n, T1_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw(m, sym);
		if (!T4_) goto LA5_;
		(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0);
		if (T9_) goto LA10_;
		T9_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*m).declaredThings), (*sym).Sup.id);
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		if (!!(((*(*sym).owner).Sup.id == (*(*m).module).Sup.id))) goto LA15_;
		{
			if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0)) goto LA19_;
			declareThreadVar__wDT42Iy4l3KGL9cd8rMjKRA(m, sym, NIM_TRUE);
		}
		goto LA17_;
		LA19_: ;
		{
			NimStringDesc* T30_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
			incl__jENnK9c9bPE73pKmo2vYjpqg((&(*m).declaredThings), (*sym).Sup.id);
			{
				NIM_BOOL T24_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T28_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
				T24_ = (NIM_BOOL)0;
				T24_ = ((2622208 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
				if (!(T24_)) goto LA25_;
				T24_ = (((NI) 0) < (*sym)._kind_4.alignment);
				LA25_: ;
				if (!T24_) goto LA26_;
				nimZeroMem((void*)T28_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T28_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*sym)._kind_4.alignment)));
				T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T29_ = percent___iaEKHmIC9bNRZLxBqSNX0Sg(T28_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T29_);
			}
			LA26_: ;
			T30_ = (NimStringDesc*)0;
			{
				NIM_BOOL T33_;
				T33_ = (NIM_BOOL)0;
				T33_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T33_) goto LA34_;
				T30_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
			}
			goto LA31_;
			LA34_: ;
			{
				T30_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_298));
			}
			LA31_: ;
			add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T30_);
			T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T37_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T37_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T38_);
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T41_) goto LA42_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
			}
			LA42_: ;
			{
				if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4))&15U)))!=0)) goto LA46_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
			}
			LA46_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0)) goto LA50_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_69));
			}
			LA50_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0)) goto LA54_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_70));
			}
			LA54_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45))&63U)))!=0)) goto LA58_;
				add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_71));
			}
			LA58_: ;
			nimZeroMem((void*)T60_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T60_[0] = (*sym).loc.r;
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T61_ = percent___nzT6Rke9c7tkW9b3XMmld2LA(T60_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T61_);
			{
				NIM_BOOL T64_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T67_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T68_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T69_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
				T64_ = (NIM_BOOL)0;
				T64_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T64_) goto LA65_;
				T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T67_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
				nimZeroMem((void*)T68_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T68_[0] = (*sym).loc.r;
				T69_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T69_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
				T68_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T69_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
				T68_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, sym);
				T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T70_ = percent___9cCc2iMcL3MEBZTTL3LCW1w(T68_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(T67_, T70_);
			}
			LA65_: ;
		}
		LA17_: ;
	}
	LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__Mns9bHWQy2Dza12fE8Mjw9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** res, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*sym).flags & IL64(137438953536)) == 0);
		if (!(T4_)) goto LA5_;
		T4_ = ((*sym).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 7));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5));
		if (T7_) goto LA8_;
		T7_ = ((*(*sym).owner).Sup.id == (*module).Sup.id);
		LA8_: ;
		T3_ = T7_;
		LA6_: ;
		if (!T3_) goto LA9_;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_53));
		unsureAsgnRef((void**) (&(*res)), amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*res), T11_));
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, cgsym__arLmPq9aJc9b7GpWTbo6dvHg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* name) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	sym = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*m).g).graph, name);
	{
		if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		switch ((*sym).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
		{
			genProc__HbYPOpwLApFuBkISFGrmEQ(m, sym);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
			T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T7_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(sym);
			genVarPrototype__t9a9a9bxmaOztYOfsfhQUOXXw_2(m, T7_);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
			T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T9_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			(void)(T9_);
		}
		break;
		default:
		{
			NimStringDesc* T11_;
			T11_ = (NimStringDesc*)0;
			T11_ = rawNewString((name ? name->Sup.len : 0) + (reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_)) ? reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_))->Sup.len : 0) + 9);
appendString(T11_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_301));
appendString(T11_, name);
appendString(T11_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_302));
appendString(T11_, reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T11_, TM__MQdRN7fpbG7rPm4JpVVAhA_303);
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T13_;
		T13_ = (NimStringDesc*)0;
		T13_ = rawNewString((name ? name->Sup.len : 0) + 21);
appendString(T13_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_304));
appendString(T13_, name);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_305, NIM_FALSE);
	}
	LA1_: ;
	result = (*sym).loc.r;
	{
		NIM_BOOL T16_;
		NIM_BOOL T17_;
		T16_ = (NIM_BOOL)0;
		T17_ = (NIM_BOOL)0;
		T17_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!(T17_)) goto LA18_;
		T17_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA18_: ;
		T16_ = T17_;
		if (!(T16_)) goto LA19_;
		T16_ = ((61440 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
		LA19_: ;
		if (!T16_) goto LA20_;
		addActualSuffixForHCR__Mns9bHWQy2Dza12fE8Mjw9aw(&result, (*m).module, sym);
	}
	LA20_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_19));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = detectStrVersion__V25kMWfh1jWVNQQI5BNfLg(m);
		switch (T3_) {
		case ((NI) 2):
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
			T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_144));
			(void)(T5_);
			T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_145));
			(void)(T6_);
			result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_145));
		}
		break;
		default:
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
			T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T8_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_139));
			(void)(T8_);
			result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_306));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_307));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_308));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_309));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_19));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		result = typeNameOrLiteral__HJRyQju7CXfTTxFyPP3IJQ(m, typ, NumericalTypeToStr__do7KqFuyalEFiD7s8tBisg[((*typ).kind)- 31]);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	{
		result = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA(m, (*typ).sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
			if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA18_;
			T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T20_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
			result = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA(m, T20_);
		}
		goto LA16_;
		LA18_: ;
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_324), TM__MQdRN7fpbG7rPm4JpVVAhA_325);
		}
		LA16_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
		T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T23_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA(m, T23_);
	}
	break;
	default:
	{
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	break;
	}
	{
		NIM_BOOL T27_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
		T27_ = (NIM_BOOL)0;
		T27_ = !((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
		if (!(T27_)) goto LA28_;
		T27_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(typ);
		LA28_: ;
		if (!T27_) goto LA29_;
		nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__UdooXLclXL8uld7qLI5JRw(typ, 2, sig);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
			if (!(T33_ == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA34_;
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		}
		LA34_: ;
	}
	LA29_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypePre__zLenRlTUJy0Mn9b8JKwzEcQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyArray__qtqsWM5aXmcpMIVmvq3kAA sig) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_18));
	}
	goto LA1_;
	LA3_: ;
	{
		result = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA(m, typ);
		{
			if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
			result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__SaA9bA11X42SNop9bW9cVLmng)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name) {
	{
		NIM_BOOL T3_;
		NI64 size;
		NimStringDesc* msg;
		NimStringDesc* msg2;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*m).g).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_326));
		if (!(T3_)) goto LA4_;
		size = getSize__vCG1GF2Iu043oALVyuJfOw((*(*m).g).config, t);
		T3_ = !((size == IL64(-3)));
		LA4_: ;
		if (!T3_) goto LA5_;
		msg = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_327));
		addTypeHeader__EyWxAbFrjBhTQTF47MkGkA((&msg), (*(*m).g).config, t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 7), NIM_TRUE);
		msg2 = ((NimStringDesc*) NIM_NIL);
		addQuoted__45fPtFhY4FavRaYwDhRfuA((&msg2), msg);
		nimZeroMem((void*)T7_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T7_[0] = name;
		T7_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(size);
		T7_[2] = rope__yShmEg9cffWxI7s5XzEKBow(msg2);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___CSMWu6VMLe6j6b1nzeZ5iA(T7_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 7))- 0], T8_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getOpenArrayDesc__u9b36BB6lubIrq9aZ0T9bYwKg_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(t, 2, sig);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!(kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, (*t).sons->data[((NI) 0)], check, kind);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T5_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
	}
	goto LA1_;
	LA3_: ;
	{
		result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* elemType;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA9_;
			result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, t, sig);
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
			elemType = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, (*t).sons->data[((NI) 0)], check, kind);
			nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T11_[0] = result;
			T11_[1] = elemType;
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = percent___ZtuswTdSNk5KTSSCYKvEYQ(T11_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T12_);
		}
		LA9_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__YRbO0Zq30XmyAQjpf1Mi6g)(NimStringDesc* pat, NI* cursor, NI* outIdx, NI* outStars) {
	NIM_BOOL result;
	NI begin;
{	result = (NIM_BOOL)0;
	(*cursor) += ((NI) 1);
	begin = (*cursor);
	{
		while (1) {
			if (!((NU8)(pat->data[(*cursor)]) == (NU8)(42))) goto LA2;
			(*cursor) += ((NI) 1);
		} LA2: ;
	}
	{
		if (!(((NU8)(pat->data[(*cursor)])) >= ((NU8)(48)) && ((NU8)(pat->data[(*cursor)])) <= ((NU8)(57)))) goto LA5_;
		(*outIdx) = (NI)(((NU8)(pat->data[(*cursor)])) - ((NI) 48));
		(*outStars) = (NI)((*cursor) - begin);
		(*cursor) += ((NI) 1);
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA3_;
	LA5_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, resolveStarsInCppType__dTa9cSuyNlFVdzNe1dV0rag)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NI idx, NI stars) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		if (!(T3_ <= idx)) goto LA4_;
		{
			if (!NIM_TRUE) goto LA8_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_333));
		}
		LA8_: ;
	}
	LA4_: ;
	result = (*typ).sons->data[idx];
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= stars)) goto LA12;
				i = res;
				{
					NIM_BOOL T15_;
					NI T17_;
					T15_ = (NIM_BOOL)0;
					T15_ = !((result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T15_)) goto LA16_;
					T17_ = (NI)0;
					T17_ = len__5mJADrRYkP3r9auuiuDZN9cQast(result);
					T15_ = (((NI) 0) < T17_);
					LA16_: ;
					if (!T15_) goto LA18_;
					{
						if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11))) goto LA22_;
						result = (*result).sons->data[((NI) 1)];
					}
					goto LA20_;
					LA22_: ;
					{
						result = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(result);
					}
					LA20_: ;
				}
				LA18_: ;
				res += ((NI) 1);
			} LA12: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getRecordDesc__HJhu9cCeHNnnn2AMyLicEaw)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NIM_BOOL hasField;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* desc;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	hasField = NIM_FALSE;
	{
		if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 23))&63U)))!=0)) goto LA3_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
			if (!((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0)) goto LA7_;
			T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T9_ = structOrUnion__TLFDupRCidtMx8175pusWQ(typ);
			result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T9_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_338));
		}
		goto LA5_;
		LA7_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = structOrUnion__TLFDupRCidtMx8175pusWQ(typ);
			result = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_339), T11_);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = structOrUnion__TLFDupRCidtMx8175pusWQ(typ);
	}
	LA1_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, name);
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA15_;
		{
			if (!((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA19_;
			{
				NIM_BOOL T23_;
				NIM_BOOL T24_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
				T23_ = (NIM_BOOL)0;
				T24_ = (NIM_BOOL)0;
				T24_ = !(((*typ).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T24_)) goto LA25_;
				T24_ = (((*(*typ).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0);
				LA25_: ;
				T23_ = T24_;
				if (T23_) goto LA26_;
				T23_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0);
				LA26_: ;
				if (!T23_) goto LA27_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
				{
					if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA31_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA31_: ;
				T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T33_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T33_);
			}
			goto LA21_;
			LA27_: ;
			{
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
					if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA37_;
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA41_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA41_: ;
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_85));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T43_);
					res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_340));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA46_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA46_: ;
					T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T48_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T48_);
				}
				goto LA35_;
				LA37_: ;
				{
					NimStringDesc* res_3;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
					res_3 = rawNewString(((NI) 80));
					res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA52_;
						res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA52_: ;
					T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T54_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T54_);
					res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_340));
					{
						if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
						res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA57_: ;
					T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T59_);
				}
				LA35_: ;
				hasField = NIM_TRUE;
			}
			LA21_: ;
		}
		goto LA17_;
		LA19_: ;
		{
			NIM_BOOL T61_;
			NimStringDesc* res_4;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T65_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
			T61_ = (NIM_BOOL)0;
			T61_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T61_) goto LA62_;
			T61_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA62_: ;
			if (!T61_) goto LA63_;
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_341));
			T65_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T65_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[((NI) 0)], IL64(36275087638268176));
			T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T66_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T65_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T66_);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA69_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA69_: ;
			T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T71_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T71_);
			{
				NIM_BOOL T74_;
				T74_ = (NIM_BOOL)0;
				T74_ = isException__YPjOkGV9axAnGR3UfLeWZ1g_13(typ);
				if (!(T74_)) goto LA75_;
				T74_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2));
				LA75_: ;
				if (!T74_) goto LA76_;
			}
			LA76_: ;
			hasField = NIM_TRUE;
		}
		goto LA17_;
		LA63_: ;
		{
			NimStringDesc* res_5;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T83_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T89_;
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA81_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA81_: ;
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
			T83_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T83_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[((NI) 0)], IL64(36275087638268176));
			T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T84_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T83_, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T84_);
			res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_197));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA87_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA87_: ;
			T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T89_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T89_);
			hasField = NIM_TRUE;
		}
		LA17_: ;
	}
	goto LA13_;
	LA15_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T91_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
		nimZeroMem((void*)T91_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T91_[0] = name;
		T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T92_ = percent___0ul9cDZYl7YkH1RhZBTd9c6A(T91_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T92_);
	}
	LA13_: ;
	desc = getRecordFields__1Yw0f9bM6njBLDchKVMziZw(m, typ, check);
	{
		NIM_BOOL T95_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T99_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
		T95_ = (NIM_BOOL)0;
		T95_ = (desc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
		if (!(T95_)) goto LA96_;
		T95_ = !(hasField);
		LA96_: ;
		if (!T95_) goto LA97_;
		nimZeroMem((void*)T99_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T100_ = percent___QFf4DPoOk6Jy59cL2OASJzw(T99_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T100_);
	}
	goto LA93_;
	LA97_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, desc);
	}
	LA93_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_342));
	{
		NIM_BOOL T104_;
		T104_ = (NIM_BOOL)0;
		T104_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 23))&63U)))!=0);
		if (!(T104_)) goto LA105_;
		T104_ = !(((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0));
		LA105_: ;
		if (!T104_) goto LA106_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_343));
	}
	LA106_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTupleDesc__HJhu9cCeHNnnn2AMyLicEaw_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* desc;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = structOrUnion__TLFDupRCidtMx8175pusWQ(typ);
	T1_[1] = name;
	result = percent___q7DaQZqCe0lRO0rhBWzM0w(T1_, 2);
	desc = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T5_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				nimZeroMem((void*)T5_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T5_[0] = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*typ).sons->data[i], check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
				T5_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
				T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T6_ = percent___hGIvKp3CGssDQ2vSvfksxQ(T5_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&desc, T6_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		if (!(desc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA9_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_344));
	}
	goto LA7_;
	LA9_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, desc);
	}
	LA7_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_342));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origTyp, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	TSafePoint TM__MQdRN7fpbG7rPm4JpVVAhA_17;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origTyp, IL64(1189020670371048976));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(check, (*t).Sup.id);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NimStringDesc* T12_;
			NimStringDesc* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(origTyp);
			if (T8_) goto LA9_;
			T8_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(t);
			LA9_: ;
			if (!!(T8_)) goto LA10_;
			T12_ = (NimStringDesc*)0;
			T13_ = (NimStringDesc*)0;
			T13_ = typeToString__QlvraUan7WbHowhAbvDvdA(origTyp, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T12_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 28);
appendString(T12_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_14));
appendString(T12_, T13_);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T12_, TM__MQdRN7fpbG7rPm4JpVVAhA_15);
		}
		LA10_: ;
	}
	LA4_: ;
	{
		if (!!(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
		useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, (*t).sym);
	}
	LA16_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = !((t == origTyp));
		if (!(T20_)) goto LA21_;
		T20_ = !(((*origTyp).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA21_: ;
		if (!T20_) goto LA22_;
		useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, (*origTyp).sym);
	}
	LA22_: ;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(origTyp, 2, sig);
	pushSafePoint(&TM__MQdRN7fpbG7rPm4JpVVAhA_17);
	TM__MQdRN7fpbG7rPm4JpVVAhA_17.status = setjmp(TM__MQdRN7fpbG7rPm4JpVVAhA_17.context);
	if (TM__MQdRN7fpbG7rPm4JpVVAhA_17.status == 0) {
	result = getTypePre__zLenRlTUJy0Mn9b8JKwzEcQ(m, t, sig);
	{
		NIM_BOOL T26_;
		T26_ = (NIM_BOOL)0;
		T26_ = !((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
		if (!(T26_)) goto LA27_;
		T26_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)));
		LA27_: ;
		if (!T26_) goto LA28_;
		excl__jENnK9c9bPE73pKmo2vYjpqg_2(check, (*t).Sup.id);
		popSafePoint();
		{
			NIM_BOOL T32_;
			NIM_BOOL T34_;
			T32_ = (NIM_BOOL)0;
			T32_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!(T32_)) goto LA33_;
			T34_ = (NIM_BOOL)0;
			T34_ = containsOrIncl__KCQ2E6mQfCiuCUy6v2RUPw((&(*m).typeABICache), sig);
			T32_ = !(T34_);
			LA33_: ;
			if (!T32_) goto LA35_;
			addAbiCheck__SaA9bA11X42SNop9bW9cVLmng(m, t, result);
		}
		LA35_: ;
		goto BeforeRet_;
	}
	LA28_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		NimStringDesc* star;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* et;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* etB;
		{
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			NIM_BOOL T44_;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T41_)) goto LA42_;
			T41_ = !((((*origTyp).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0));
			LA42_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA43_;
			T44_ = (NIM_BOOL)0;
			T44_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T44_) goto LA45_;
			T44_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA45_: ;
			T40_ = T44_;
			LA43_: ;
			if (!T40_) goto LA46_;
			star = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_328));
		}
		goto LA38_;
		LA46_: ;
		{
			star = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
		}
		LA38_: ;
		T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T49_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origTyp, IL64(36134350135273744));
		et = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(T49_);
		etB = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(et, IL64(36134350135273744));
		{
			NIM_BOOL T52_;
			tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T53_;
			NIM_BOOL T55_;
			T52_ = (NIM_BOOL)0;
			T53_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
			T53_ = mapType__pNoigHLHIPJ32RkjLRvhAQ((*(*m).g).config, t, kind);
			T52_ = (T53_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 18));
			if (!(T52_)) goto LA54_;
			T55_ = (NIM_BOOL)0;
			T55_ = !(((*etB).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)));
			if (T55_) goto LA56_;
			T55_ = (kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			LA56_: ;
			T52_ = T55_;
			LA54_: ;
			if (!T52_) goto LA57_;
			{
				if (!((*etB).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19))) goto LA61_;
				et = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*m).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41));
			}
			goto LA59_;
			LA61_: ;
			{
				et = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(etB);
			}
			LA59_: ;
			etB = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(et, IL64(36134350135273744));
			star->data[((NI) 0)] = 42;
		}
		LA57_: ;
		switch ((*etB).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
		{
			{
				NIM_BOOL T67_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
				T67_ = (NIM_BOOL)0;
				T67_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(etB);
				if (!(T67_)) goto LA68_;
				T67_ = ((*et).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
				LA68_: ;
				if (!T67_) goto LA69_;
				T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T71_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, et, check, kind);
				result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T71_, star);
			}
			goto LA65_;
			LA69_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T73_;
				nimZeroMem((void*)T73_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__UdooXLclXL8uld7qLI5JRw(et, 2, T73_);
				name = getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2(m, et, T73_);
				result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(name, star);
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
			}
			LA65_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
				if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA77_;
				T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T79_ = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, et, check, kind);
				result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T79_, star);
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
			}
			goto LA75_;
			LA77_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name_2;
				tyArray__qtqsWM5aXmcpMIVmvq3kAA T81_;
				NimStringDesc* T82_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
				nimZeroMem((void*)T81_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
				hashType__UdooXLclXL8uld7qLI5JRw(et, 2, T81_);
				name_2 = getTypeForward__zLenRlTUJy0Mn9b8JKwzEcQ_2(m, et, T81_);
				T82_ = (NimStringDesc*)0;
				T82_ = seqStar__hiFj6GH2C6Qv8bI0r9caT5A(m);
				T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T83_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(name_2, T82_);
				result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T83_, star);
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
				pushType__4q3XOfd3NI3C8cSNkaF9cWA(m, et);
			}
			LA75_: ;
		}
		break;
		default:
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
			T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T85_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, et, check, kind);
			result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T85_, star);
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		result = getOpenArrayDesc__u9b36BB6lubIrq9aZ0T9bYwKg_2(m, t, check, kind);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
		{
			if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA90_;
			result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
			{
				NIM_BOOL T94_;
				NIM_BOOL T96_;
				NI size;
				T94_ = (NIM_BOOL)0;
				T94_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(t);
				if (T94_) goto LA95_;
				T96_ = (NIM_BOOL)0;
				T96_ = (((*(*t).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0);
				if (!(T96_)) goto LA97_;
				T96_ = ((*(*t).sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
				LA97_: ;
				T94_ = T96_;
				LA95_: ;
				if (!!(T94_)) goto LA98_;
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
				size = (NI)0;
				{
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T102_;
					NIM_BOOL T103_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T106_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
					T102_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*m).g).config, t);
					T103_ = (NIM_BOOL)0;
					T103_ = lt___nr9cP9b0OL9cabygV9bo19cJgZA_3(T102_, IL64(0));
					if (!T103_) goto LA104_;
					nimZeroMem((void*)T106_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T106_[0] = result;
					T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T107_ = percent___XI9awM9a9aQ9cB9bcS7uDRsa1Rw(T106_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T107_);
					size = ((NI) 4);
				}
				goto LA100_;
				LA104_: ;
				{
					NI64 T109_;
					T109_ = (NI64)0;
					T109_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*m).g).config, t);
					size = ((NI) (T109_));
					switch (size) {
					case ((NI) 1):
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T111_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
						nimZeroMem((void*)T111_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T111_[0] = result;
						T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T112_ = percent___9cWNaGuyEpBbdBlD9b5nY1ug(T111_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T112_);
					}
					break;
					case ((NI) 2):
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T114_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T115_;
						nimZeroMem((void*)T114_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T114_[0] = result;
						T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T115_ = percent___6P67I9czJ9aa9aZzVyYWUiGlw(T114_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T115_);
					}
					break;
					case ((NI) 4):
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T117_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T118_;
						nimZeroMem((void*)T117_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T117_[0] = result;
						T118_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T118_ = percent___XI9awM9a9aQ9cB9bcS7uDRsa1Rw(T117_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T118_);
					}
					break;
					case ((NI) 8):
					{
						tyArray__JiWwrsTRC6xqNlGcBthSVA T120_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T121_;
						nimZeroMem((void*)T120_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T120_[0] = result;
						T121_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T121_ = percent___S4jE5dFDtcCC8ODzxaJk6A(T120_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T121_);
					}
					break;
					default:
					{
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*(*t).sym).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_329), TM__MQdRN7fpbG7rPm4JpVVAhA_330);
					}
					break;
					}
				}
				LA100_: ;
			}
			LA98_: ;
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* rettype;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* desc;
		result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		rettype = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		desc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		genProcParams__uApDq1rn2zPxULBMpTSrxQ(m, t, &rettype, &desc, check, NIM_TRUE, NIM_TRUE);
		{
			NIM_BOOL T126_;
			T126_ = (NIM_BOOL)0;
			T126_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!!(T126_)) goto LA127_;
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T133_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T134_;
				if (!!(((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA131_;
				nimZeroMem((void*)T133_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T133_[0] = rope__yShmEg9cffWxI7s5XzEKBow(CallingConvToStr__A7GdKVVGtI3pvj9cV9adydpw[((*t).callConv)- 0]);
				T133_[1] = rettype;
				T133_[2] = result;
				T133_[3] = desc;
				T134_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T134_ = percent___Msid9awGKVeVe7p3v7WfNQA(T133_, 4);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T134_);
			}
			goto LA129_;
			LA131_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T136_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T137_;
				nimZeroMem((void*)T136_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T136_[0] = result;
				T136_[1] = rettype;
				T136_[2] = desc;
				T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T137_ = percent___xyRsdWsGY1DVVispyn0Xeg(T136_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T137_);
			}
			LA129_: ;
		}
		LA127_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		{
			if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA141_;
			result = getTypeDescWeak__u9b36BB6lubIrq9aZ0T9bYwKg(m, t, check, kind);
		}
		goto LA139_;
		LA141_: ;
		{
			NimStringDesc* T154_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T155_;
			NimStringDesc* T208_;
			result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA146_;
				result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
				{
					NIM_BOOL T150_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T153_;
					T150_ = (NIM_BOOL)0;
					T150_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
					if (!!(T150_)) goto LA151_;
					T153_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T153_ = structOrUnion__TLFDupRCidtMx8175pusWQ(t);
					addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg(m, T153_, result);
				}
				LA151_: ;
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).forwTypeCache), sig, result);
			}
			LA146_: ;
			T154_ = (NimStringDesc*)0;
			T154_ = seqStar__hiFj6GH2C6Qv8bI0r9caT5A(m);
			T155_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T155_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(result, T154_);
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, T155_);
			{
				NIM_BOOL T158_;
				T158_ = (NIM_BOOL)0;
				T158_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
				if (!!(T158_)) goto LA159_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T163_;
					T163_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T163_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(36134350135273744));
					if (!!(((*T163_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3)))) goto LA164_;
					{
						NIM_BOOL T168_;
						NimStringDesc* res;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T172_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T177_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T186_;
						T168_ = (NIM_BOOL)0;
						T168_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
						if (T168_) goto LA169_;
						T168_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
						LA169_: ;
						if (!T168_) goto LA170_;
						res = rawNewString(((NI) 80));
						res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_42));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
						res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_331));
						T172_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T172_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_142));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T172_);
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA175_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA175_: ;
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
						T177_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T177_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*t).sons->data[((NI) 0)], check, kind);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T177_);
						res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_332));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA180_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA180_: ;
						res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_193));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA184_;
							res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA184_: ;
						T186_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T186_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 5))- 0], T186_);
					}
					goto LA166_;
					LA170_: ;
					{
						NimStringDesc* res_2;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T192_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T197_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T206_;
						res_2 = rawNewString(((NI) 80));
						res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_42));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), result);
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_271));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA190_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA190_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
						T192_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T192_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_142));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T192_);
						res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_197));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA195_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA195_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
						T197_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T197_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*t).sons->data[((NI) 0)], check, kind);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T197_);
						res_2 = resizeString(res_2, 21);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_332));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA200_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA200_: ;
						res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_193));
						{
							if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA204_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA204_: ;
						T206_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T206_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 5))- 0], T206_);
					}
					LA166_: ;
				}
				goto LA161_;
				LA164_: ;
				{
					result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_142));
				}
				LA161_: ;
			}
			LA159_: ;
			T208_ = (NimStringDesc*)0;
			T208_ = seqStar__hiFj6GH2C6Qv8bI0r9caT5A(m);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, T208_);
		}
		LA139_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T212_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* foo;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T215_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T216_;
			T212_ = (NIM_BOOL)0;
			T212_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!!(T212_)) goto LA213_;
			foo = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*t).sons->data[((NI) 0)], check, kind);
			nimZeroMem((void*)T215_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T215_[0] = foo;
			T215_[1] = result;
			T216_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T216_ = percent___EPABzhs2B9atAvHV4CUTw2Q(T215_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T216_);
		}
		LA213_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		NI64 n;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T218_;
		T218_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*m).g).config, t);
		n = toInt64__1szweXXq3RBN50owrYu2Xw(T218_);
		{
			if (!(n <= IL64(0))) goto LA221_;
			n = IL64(1);
		}
		LA221_: ;
		result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T225_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* foo_2;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T228_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T229_;
			T225_ = (NIM_BOOL)0;
			T225_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!!(T225_)) goto LA226_;
			foo_2 = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*t).sons->data[((NI) 1)], check, kind);
			nimZeroMem((void*)T228_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T228_[0] = foo_2;
			T228_[1] = result;
			T228_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(n);
			T229_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T229_ = percent___2MhCcipNmSHgcDtN4cr8ng(T228_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T229_);
		}
		LA226_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			NIM_BOOL T233_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* cppName;
			NI i;
			NI chunkStart;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T300_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typedefName;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T301_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T302_;
			NimStringDesc* T303_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T304_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T305_;
			T233_ = (NIM_BOOL)0;
			T233_ = isImportedCppType__IafZhvqpthq9b9c13SFhzAOw(t);
			if (!(T233_)) goto LA234_;
			T233_ = ((*origTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
			LA234_: ;
			if (!T233_) goto LA235_;
			cppName = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, t, sig);
			i = ((NI) 0);
			chunkStart = ((NI) 0);
			{
				while (1) {
					if (!(i < ((*cppName).data ? (*cppName).data->Sup.len : 0))) goto LA238;
					{
						NI chunkEnd;
						NI idx;
						NI stars;
						if (!((NU8)((*cppName).data->data[i]) == (NU8)(39))) goto LA241_;
						chunkEnd = (NI)(i - ((NI) 1));
						idx = (NI)0;
						stars = (NI)0;
						{
							NIM_BOOL T245_;
							NimStringDesc* T248_;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInSlot;
							T245_ = (NIM_BOOL)0;
							T245_ = scanCppGenericSlot__YRbO0Zq30XmyAQjpf1Mi6g((*cppName).data, (&i), (&idx), (&stars));
							if (!T245_) goto LA246_;
							T248_ = (NimStringDesc*)0;
							T248_ = substr__2yh9cer0ymNRHlOOg8P7IuA((*cppName).data, chunkStart, chunkEnd);
							add__yG4AKzsBRS1W4MANDlXQeg(&result, T248_);
							chunkStart = i;
							typeInSlot = resolveStarsInCppType__dTa9cSuyNlFVdzNe1dV0rag(origTyp, (NI)(idx + ((NI) 1)), stars);
							{
								NIM_BOOL T251_;
								tyArray__qTjAvTvKF9anytN1At69aJMQ T255_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T256_;
								T251_ = (NIM_BOOL)0;
								T251_ = (typeInSlot == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
								if (T251_) goto LA252_;
								T251_ = ((*typeInSlot).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63));
								LA252_: ;
								if (!T251_) goto LA253_;
								nimZeroMem((void*)T255_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
								T256_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T256_ = percent___G9aA37gQrW88KHzpCAwhgjQ(T255_, 0);
								add__IM4kcMNkkOLJtqdEqSxR8A(&result, T256_);
							}
							goto LA249_;
							LA253_: ;
							{
								NimStringDesc* T264_;
								if (!((*typeInSlot).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA258_;
								{
									NimStringDesc* argX60gensym478_;
									if (!!(!(((*typeInSlot).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))) goto LA262_;
									argX60gensym478_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_334);
									internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym478_, TM__MQdRN7fpbG7rPm4JpVVAhA_334);
								}
								LA262_: ;
								T264_ = (NimStringDesc*)0;
								T264_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*typeInSlot).n, 0);
								add__yG4AKzsBRS1W4MANDlXQeg(&result, T264_);
							}
							goto LA249_;
							LA258_: ;
							{
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T266_;
								T266_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T266_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, typeInSlot, check, kind);
								add__IM4kcMNkkOLJtqdEqSxR8A(&result, T266_);
							}
							LA249_: ;
						}
						LA246_: ;
					}
					goto LA239_;
					LA241_: ;
					{
						i += ((NI) 1);
					}
					LA239_: ;
				} LA238: ;
			}
			{
				NimStringDesc* T272_;
				if (!!((chunkStart == ((NI) 0)))) goto LA270_;
				T272_ = (NimStringDesc*)0;
				T272_ = substr__iGg0RIKceRvsmvq8FUHOEw((*cppName).data, chunkStart);
				add__yG4AKzsBRS1W4MANDlXQeg(&result, T272_);
			}
			goto LA268_;
			LA270_: ;
			{
				result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(cppName, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_335));
				{
					NI i_2;
					NI colontmp_;
					NI T275_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					T275_ = (NI)0;
					T275_ = len__5mJADrRYkP3r9auuiuDZN9cQast(origTyp);
					colontmp_ = (NI)(T275_ - ((NI) 1));
					i_3 = ((NI) 1);
					{
						while (1) {
							if (!(i_3 < colontmp_)) goto LA277;
							i_2 = i_3;
							{
								if (!(((NI) 1) < i_2)) goto LA280_;
								add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_336));
							}
							LA280_: ;
							{
								NIM_BOOL T284_;
								tyArray__qTjAvTvKF9anytN1At69aJMQ T288_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T289_;
								T284_ = (NIM_BOOL)0;
								T284_ = ((*origTyp).sons->data[i_2] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
								if (T284_) goto LA285_;
								T284_ = ((*(*origTyp).sons->data[i_2]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63));
								LA285_: ;
								if (!T284_) goto LA286_;
								nimZeroMem((void*)T288_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
								T289_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T289_ = percent___G9aA37gQrW88KHzpCAwhgjQ(T288_, 0);
								add__IM4kcMNkkOLJtqdEqSxR8A(&result, T289_);
							}
							goto LA282_;
							LA286_: ;
							{
								NimStringDesc* T297_;
								if (!((*(*origTyp).sons->data[i_2]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA291_;
								{
									NimStringDesc* argX60gensym490_;
									if (!!(!(((*(*origTyp).sons->data[i_2]).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))) goto LA295_;
									argX60gensym490_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_334);
									internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym490_, TM__MQdRN7fpbG7rPm4JpVVAhA_334);
								}
								LA295_: ;
								T297_ = (NimStringDesc*)0;
								T297_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*(*origTyp).sons->data[i_2]).n, 0);
								add__yG4AKzsBRS1W4MANDlXQeg(&result, T297_);
							}
							goto LA282_;
							LA291_: ;
							{
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T299_;
								T299_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T299_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*origTyp).sons->data[i_2], check, kind);
								add__IM4kcMNkkOLJtqdEqSxR8A(&result, T299_);
							}
							LA282_: ;
							i_3 += ((NI) 1);
						} LA277: ;
					}
				}
				add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_337));
			}
			LA268_: ;
			T300_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T300_ = getRecordDesc__HJhu9cCeHNnnn2AMyLicEaw(m, t, result, check);
			(void)(T300_);
			nimZeroMem((void*)T301_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T302_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T302_ = percent___7yDHbEsisDNKcqQHIRgOuQ(T301_, 0);
			T303_ = (NimStringDesc*)0;
			T303_ = dollar___0A9bslyIJ49bWrftLGh13rvg(sig);
			typedefName = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T302_, T303_);
			nimZeroMem((void*)T304_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T304_[0] = result;
			T304_[1] = typedefName;
			T305_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T305_ = percent___GwVmUG4AZCEAP8dBk4TGHg(T304_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T305_);
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, typedefName);
			result = typedefName;
		}
		goto LA231_;
		LA235_: ;
		{
			result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).forwTypeCache, sig);
			{
				if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA309_;
				result = getTypeName__zLenRlTUJy0Mn9b8JKwzEcQ_3(m, origTyp, sig);
				X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).forwTypeCache), sig, result);
				{
					NIM_BOOL T313_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T316_;
					T313_ = (NIM_BOOL)0;
					T313_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
					if (!!(T313_)) goto LA314_;
					T316_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T316_ = structOrUnion__TLFDupRCidtMx8175pusWQ(t);
					addForwardStructFormat__pzRGCZRDAEWnDSHC2tztFg(m, T316_, result);
				}
				LA314_: ;
			}
			LA309_: ;
			X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
			{
				NIM_BOOL T319_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* recdesc;
				T319_ = (NIM_BOOL)0;
				T319_ = !(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T319_)) goto LA320_;
				T319_ = ((1040 & (*(*t).sym).flags) == 16);
				LA320_: ;
				if (!!(T319_)) goto LA321_;
				{
					if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)))) goto LA325_;
					recdesc = getRecordDesc__HJhu9cCeHNnnn2AMyLicEaw(m, t, result, check);
				}
				goto LA323_;
				LA325_: ;
				{
					recdesc = getTupleDesc__HJhu9cCeHNnnn2AMyLicEaw_2(m, t, result, check);
				}
				LA323_: ;
				{
					NIM_BOOL T330_;
					T330_ = (NIM_BOOL)0;
					T330_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
					if (!!(T330_)) goto LA331_;
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], recdesc);
				}
				goto LA328_;
				LA331_: ;
				{
					if (!!((((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 40))&63U)))!=0))) goto LA334_;
				}
				goto LA328_;
				LA334_: ;
				LA328_: ;
			}
			LA321_: ;
		}
		LA231_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		NimStringDesc* T337_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T338_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T339_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T340_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T341_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA T342_;
		NimStringDesc* T343_;
		T337_ = (NimStringDesc*)0;
		T337_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 1);
appendString(T337_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T337_, 95);
		T338_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T338_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		T339_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T339_ = typeName__qvCJ9bux56nS82Shxh5hLNg(T338_);
		T340_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T340_ = amp___4cYKitaHx6RQ9azRtQsZp6w(T337_, T339_);
		T341_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T341_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		nimZeroMem((void*)T342_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		hashType__UdooXLclXL8uld7qLI5JRw(T341_, 2, T342_);
		T343_ = (NimStringDesc*)0;
		T343_ = dollar___0A9bslyIJ49bWrftLGh13rvg(T342_);
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T340_, T343_);
		X5BX5Deq___zhbvOVNN6tTRFgZkPDZOmA((&(*m).typeCache), sig, result);
		{
			NIM_BOOL T346_;
			NI s;
			NI64 T349_;
			T346_ = (NIM_BOOL)0;
			T346_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!!(T346_)) goto LA347_;
			T349_ = (NI64)0;
			T349_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*m).g).config, t);
			s = ((NI) (T349_));
			switch (s) {
			case ((NI) 1):
			case ((NI) 2):
			case ((NI) 4):
			case ((NI) 8):
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T351_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T352_;
				nimZeroMem((void*)T351_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T351_[0] = result;
				T351_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(s * ((NI) 8)))));
				T352_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T352_ = percent___9c1P82lz6H9anMKDbz1vYNpg(T351_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T352_);
			}
			break;
			default:
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T354_;
				NI64 T355_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T356_;
				nimZeroMem((void*)T354_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T354_[0] = result;
				T355_ = (NI64)0;
				T355_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*m).g).config, t);
				T354_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(T355_);
				T356_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T356_ = percent___dbg9bsMENUwtF9aO45wEGG3Q(T354_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T356_);
			}
			break;
			}
		}
		LA347_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T358_;
		T358_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T358_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		result = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, T358_, check, kind);
	}
	break;
	default:
	{
		NimStringDesc* T360_;
		T360_ = (NimStringDesc*)0;
		T360_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 16);
appendString(T360_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_345));
appendString(T360_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T360_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T360_, TM__MQdRN7fpbG7rPm4JpVVAhA_346);
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	break;
	}
	excl__jENnK9c9bPE73pKmo2vYjpqg_2(check, (*t).Sup.id);
	popSafePoint();
	}
	else {
		popSafePoint();
	}
	{
		{
			NIM_BOOL T365_;
			NIM_BOOL T367_;
			T365_ = (NIM_BOOL)0;
			T365_ = isImportedType__IafZhvqpthq9b9c13SFhzAOw_2(t);
			if (!(T365_)) goto LA366_;
			T367_ = (NIM_BOOL)0;
			T367_ = containsOrIncl__KCQ2E6mQfCiuCUy6v2RUPw((&(*m).typeABICache), sig);
			T365_ = !(T367_);
			LA366_: ;
			if (!T365_) goto LA368_;
			addAbiCheck__SaA9bA11X42SNop9bW9cVLmng(m, t, result);
		}
		LA368_: ;
		if (TM__MQdRN7fpbG7rPm4JpVVAhA_17.status != 0) nimLeaveFinally();
	}
	if (TM__MQdRN7fpbG7rPm4JpVVAhA_17.status != 0) reraiseException();
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTypeDesc__iIMq9aNL1HScA9cVz83avtdg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	result = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, typ, (&check), kind);
	return result;
}
static N_INLINE(NIM_BOOL, requiresExternC__axmagSzN10JTkqlmiAFoqQcgen)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	NIM_BOOL T10_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
	if (!(T3_)) goto LA4_;
	T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T5_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(sym);
	T3_ = !((((*T5_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = !(((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2)));
	LA6_: ;
	T1_ = T2_;
	if (T1_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T10_ = (NIM_BOOL)0;
	T10_ = (((*sym).flags & IL64(2147746048)) == 0);
	if (!(T10_)) goto LA11_;
	T10_ = !((((*sym).flags & 192) == 0));
	LA11_: ;
	T9_ = T10_;
	if (!(T9_)) goto LA12_;
	T9_ = ((*sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
	LA12_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA13_;
	T8_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
	LA13_: ;
	T1_ = T8_;
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
{	useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, sym);
	{
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4))&15U)))!=0)) goto LA7_;
		{
			NIM_BOOL T11_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
			NIM_BOOL T14_;
			NimStringDesc* res;
			NimStringDesc* T17_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			T11_ = (NIM_BOOL)0;
			T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T12_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(sym);
			T11_ = !(((*T12_).Sup.id == (*(*m).module).Sup.id));
			if (!(T11_)) goto LA13_;
			T14_ = (NIM_BOOL)0;
			T14_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*m).declaredThings), (*sym).Sup.id);
			T11_ = !(T14_);
			LA13_: ;
			if (!T11_) goto LA15_;
			res = rawNewString(((NI) 80));
			T17_ = (NimStringDesc*)0;
			{
				NIM_BOOL T20_;
				T20_ = (NIM_BOOL)0;
				T20_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, sym);
				if (!T20_) goto LA21_;
				T17_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_11));
			}
			goto LA18_;
			LA21_: ;
			{
				T17_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_12));
			}
			LA18_: ;
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), T17_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T24_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T24_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T25_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(sym);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T26_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA29_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA29_: ;
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T31_);
			{
				NIM_BOOL T34_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T37_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T38_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
				T34_ = (NIM_BOOL)0;
				T34_ = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, sym);
				if (!T34_) goto LA35_;
				nimZeroMem((void*)T37_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T37_[0] = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(sym);
				T38_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T38_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
				T37_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T38_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				T37_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, sym);
				T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T39_ = percent___vHbYzYlzLPcurSm0Hu8InQ(T37_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T39_);
			}
			LA35_: ;
		}
		LA15_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL T41_;
		NIM_BOOL asPtr;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* header;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
		T41_ = (NIM_BOOL)0;
		T41_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*m).declaredProtos), (*sym).Sup.id);
		if (!!(T41_)) goto LA42_;
		asPtr = isReloadable__bilAk8nY4d5fxUpVg9bnphQ(m, sym);
		header = genProcHeader__OWG529cW3RTHLgDJuQoIH8A(m, sym, asPtr);
		{
			if (!!(asPtr)) goto LA46_;
			{
				NIM_BOOL T50_;
				T50_ = (NIM_BOOL)0;
				T50_ = isNoReturn__wKa9aVgc3t9a9atx3OlQKTJyQcgen(m, sym);
				if (!(T50_)) goto LA51_;
				T50_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 6))&7U)))!=0);
				LA51_: ;
				if (!T50_) goto LA52_;
				header = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_269), header);
			}
			LA52_: ;
			{
				NIM_BOOL T56_;
				T56_ = (NIM_BOOL)0;
				T56_ = !(((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5)));
				if (!(T56_)) goto LA57_;
				T56_ = requiresExternC__axmagSzN10JTkqlmiAFoqQcgen(m, sym);
				LA57_: ;
				if (!T56_) goto LA58_;
				header = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_347), header);
			}
			LA58_: ;
			{
				NIM_BOOL T62_;
				T62_ = (NIM_BOOL)0;
				T62_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0);
				if (!(T62_)) goto LA63_;
				T62_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0);
				LA63_: ;
				if (!T62_) goto LA64_;
				add__yG4AKzsBRS1W4MANDlXQeg(&header, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_348));
			}
			LA64_: ;
			{
				NIM_BOOL T68_;
				T68_ = (NIM_BOOL)0;
				T68_ = isNoReturn__wKa9aVgc3t9a9atx3OlQKTJyQcgen(m, sym);
				if (!(T68_)) goto LA69_;
				T68_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*m).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 7))&7U)))!=0);
				LA69_: ;
				if (!T68_) goto LA70_;
				add__yG4AKzsBRS1W4MANDlXQeg(&header, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_349));
			}
			LA70_: ;
		}
		LA46_: ;
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), header);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_350));
		T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T72_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T72_);
	}
	goto LA5_;
	LA42_: ;
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA s) {
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA3_;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 2))&15U)))!=0)) goto LA7_;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), s, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), s, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		genericAssign((void*)(&(*d)), (void*)(&s), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__y9bTRtTAknVsv9apXKbpJYJA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36275087632017680));
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24)));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA4_: ;
	T1_ = !(T3_);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__6NyA5DzsDGY17BhjidN65Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw s) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA3_;
		initLoc__qlujIAW86QclHYUVxlHRiQ((&a), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), n, s);
		a.r = r;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 2))&15U)))!=0)) goto LA7_;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), a, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), a, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6);
		unsureAsgnRef((void**) (&(*d).lode), n);
		unsureAsgnRef((void**) (&(*d).r), r);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__POVv0myAK3ae9cYA55o72Fw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* q;
{	m = (*p).module;
	useHeader__TAVDUakAwQnRHDK9cFe6L7g_2(m, sym);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!((*sym).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = mangleName__RaNE9b8A430I9bfpgZmdrC1w((*p).module, sym);
		fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 8), (*sym).ast, T5_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
	}
	LA3_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T8_) goto LA9_;
		(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
	}
	LA9_: ;
	{
		if (!(((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0)) goto LA13_;
		goto BeforeRet_;
	}
	LA13_: ;
	q = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA(m, sym);
	{
		NIM_BOOL T17_;
		NIM_BOOL T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* actualConstName;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		T17_ = (NIM_BOOL)0;
		T17_ = !((q == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
		if (!(T17_)) goto LA18_;
		T19_ = (NIM_BOOL)0;
		T19_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*q).declaredThings), (*sym).Sup.id);
		T17_ = !(T19_);
		LA18_: ;
		if (!T17_) goto LA20_;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!T24_) goto LA25_;
			actualConstName = amp___Z7W1o5nPSc3ExfO5f7j1Gg((*sym).loc.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_355));
		}
		goto LA22_;
		LA25_: ;
		{
			actualConstName = (*sym).loc.r;
		}
		LA22_: ;
		nimZeroMem((void*)T28_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T28_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(q, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T28_[1] = actualConstName;
		T28_[2] = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw((*q).initProc, (*sym).ast, NIM_TRUE, (*sym).typ);
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = percent___eMtcjnP5EASsGpHWzVmIXA(T28_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*q).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T29_);
		{
			NIM_BOOL T32_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T35_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T38_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			T32_ = (NIM_BOOL)0;
			T32_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!T32_) goto LA33_;
			nimZeroMem((void*)T35_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T36_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T35_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T36_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			T35_[1] = (*sym).loc.r;
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = percent___ptz4AXVYEvsEioVLNYw0bw(T35_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*q).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T37_);
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T38_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*q).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			nimZeroMem((void*)T39_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T39_[0] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(q, sym);
			T39_[1] = (*sym).loc.r;
			T39_[2] = rdLoc__xidyzuHqIciXbQyEOKahDg((*sym).loc);
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = percent___0Wha51b9br4aUzohTFPS9boA(T39_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(T38_, T40_);
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T41_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*q).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(q, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T42_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*sym).loc.r);
			res = resizeString(res, 20);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_213));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), actualConstName);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*sym).loc);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T43_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*q).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA46_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA46_: ;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(T41_, T48_);
		}
		LA33_: ;
	}
	LA20_: ;
	{
		NIM_BOOL T51_;
		NIM_BOOL T53_;
		T51_ = (NIM_BOOL)0;
		T51_ = !((q == m));
		if (!(T51_)) goto LA52_;
		T53_ = (NIM_BOOL)0;
		T53_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*m).declaredThings), (*sym).Sup.id);
		T51_ = !(T53_);
		LA52_: ;
		if (!T51_) goto LA54_;
		{
			NIM_BOOL T58_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T61_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T64_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T65_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			T58_ = (NIM_BOOL)0;
			T58_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!T58_) goto LA59_;
			nimZeroMem((void*)T61_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T62_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T62_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T61_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T62_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			T61_[1] = (*sym).loc.r;
			T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T63_ = percent___ptz4AXVYEvsEioVLNYw0bw(T61_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T63_);
			T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T64_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			nimZeroMem((void*)T65_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T65_[0] = (*sym).loc.r;
			T66_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T66_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T65_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T66_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			T65_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(q, sym);
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = percent___9cCc2iMcL3MEBZTTL3LCW1w(T65_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(T64_, T67_);
		}
		goto LA56_;
		LA59_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* headerDecl;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T69_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T70_;
			nimZeroMem((void*)T69_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T70_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T70_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
			T69_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T70_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			T69_[1] = (*sym).loc.r;
			headerDecl = percent___VsLzrOz1nS9cRBBz9ccZfETQ(T69_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], headerDecl);
			{
				NIM_BOOL T73_;
				T73_ = (NIM_BOOL)0;
				T73_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7))&63U)))!=0);
				if (!(T73_)) goto LA74_;
				T73_ = !(((*(*(*p).module).g).generatedHeader == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
				LA74_: ;
				if (!T73_) goto LA75_;
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*(*(*p).module).g).generatedHeader).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], headerDecl);
			}
			LA75_: ;
		}
		LA56_: ;
	}
	LA54_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__ARtcpl8G0t9cQCPr2Np8Srw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	requestConstImpl__POVv0myAK3ae9cYA55o72Fw(p, sym);
	putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__4xOIY9bgIMy9bAzg2ZyIieBw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value) {
	{
		if (!!(((*value).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*value).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15)))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*value).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_356), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_357, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T6_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T6_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T7_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ((*value)._kind_1.intVal);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___tRSKshYob5uzZE3eBVe59cg(T7_, 1);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T8_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T6_, T9_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__NAlbw3fU59aFdo7L5aQtmkw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*(*(*p).module).g).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, potentialValueInit__ZPEw9bE7bf9b89ciOwNlnaiIg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*v).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4))&15U)))!=0);
		if (T4_) goto LA5_;
		T4_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T3_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
		LA6_: ;
		if (!T3_) goto LA7_;
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		NIM_BOOL T13_;
		NIM_BOOL T16_;
		NIM_BOOL T20_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T13_ = (NIM_BOOL)0;
		T13_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0);
		if (!(T13_)) goto LA14_;
		T13_ = !((value == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA14_: ;
		T12_ = T13_;
		if (!(T12_)) goto LA15_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T16_) goto LA17_;
		T16_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA17_: ;
		T12_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(value, T16_);
		LA15_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA18_;
		T11_ = ((*p).withinLoop == ((NI) 0));
		LA18_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA19_;
		T20_ = (NIM_BOOL)0;
		T20_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3((*v).typ);
		T10_ = !(T20_);
		LA19_: ;
		if (!T10_) goto LA21_;
		result = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, value, NIM_FALSE, (*v).typ);
	}
	goto LA1_;
	LA21_: ;
	{
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* extname;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	NimStringDesc* T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	lib = (*sym).annex;
	extname = (*sym).loc.r;
	loadDynamicLib__Q3RS49c6kF7OS9bmwvFHRQJQ(m, lib);
	(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
	tmp = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(sym);
	asgnRef((void**) (&(*sym).loc.r), tmp);
	(*m).labels += ((NI) 2);
	res = rawNewString(((NI) 80));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), tmp);
	res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_76));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_359));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_297));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*lib).name);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
	T3_ = (NimStringDesc*)0;
	T3_ = dollar___mZ66tEveFIQokq3arf8Klw(extname);
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T3_);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T4_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA7_: ;
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T9_);
	nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T10_[0] = (*sym).loc.r;
	T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T11_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
	T10_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T11_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = percent___vcbf2lEZaiSjbAHwgt9aKXw(T10_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T12_);
}
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__yX9bZpeKIzp3RLrjnzlc0NQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	s = (*n)._kind_4.sym;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!((*s).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = mangleName__RaNE9b8A430I9bfpgZmdrC1w((*p).module, s);
		fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*s).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 3), n, T5_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw((*p).module, s);
			if (!T8_) goto LA9_;
			(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15);
		}
		LA9_: ;
	}
	LA3_: ;
	{
		tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* q;
		if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4))&15U)))!=0)) goto LA13_;
		q = findPendingModule__Dhy9cmzSsJkQqlfDq047WUA((*p).module, s);
		{
			NIM_BOOL T17_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = !((q == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			if (!(T17_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*q).declaredThings), (*s).Sup.id);
			T17_ = !(T19_);
			LA18_: ;
			if (!T17_) goto LA20_;
			varInDynamicLib__TAVDUakAwQnRHDK9cFe6L7g_5(q, s);
		}
		goto LA15_;
		LA20_: ;
		{
			asgnRef((void**) (&(*s).loc.r), mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(s));
		}
		LA15_: ;
		{
			if (!!((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA25_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_360), TM__MQdRN7fpbG7rPm4JpVVAhA_361);
		}
		LA25_: ;
		goto BeforeRet_;
	}
	LA13_: ;
	useHeader__TAVDUakAwQnRHDK9cFe6L7g_2((*p).module, s);
	{
		if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0)) goto LA29_;
		goto BeforeRet_;
	}
	LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).module).declaredThings), (*s).Sup.id);
		if (!!(T33_)) goto LA34_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0)) goto LA38_;
			declareThreadVar__wDT42Iy4l3KGL9cd8rMjKRA((*p).module, s, (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
			{
				if (!!((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA42_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_362), TM__MQdRN7fpbG7rPm4JpVVAhA_363);
			}
			LA42_: ;
		}
		goto LA36_;
		LA38_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* decl;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* td;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
			decl = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
			T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T45_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
			td = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T45_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			{
				if (!((*s).constraint == 0)) goto LA48_;
				{
					NIM_BOOL T52_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T56_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
					T52_ = (NIM_BOOL)0;
					T52_ = ((2622208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					if (!(T52_)) goto LA53_;
					T52_ = (((NI) 0) < (*s)._kind_4.alignment);
					LA53_: ;
					if (!T52_) goto LA54_;
					nimZeroMem((void*)T56_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T56_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*s)._kind_4.alignment)));
					T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T57_ = percent___iaEKHmIC9bNRZLxBqSNX0Sg(T56_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&decl, T57_);
				}
				LA54_: ;
				{
					NIM_BOOL T60_;
					T60_ = (NIM_BOOL)0;
					T60_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
					if (!T60_) goto LA61_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
				}
				goto LA58_;
				LA61_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0)) goto LA64_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_298));
				}
				goto LA58_;
				LA64_: ;
				{
					if (!(((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5))&15U)))!=0)) goto LA67_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_299));
				}
				goto LA58_;
				LA67_: ;
				{
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_24));
				}
				LA58_: ;
				{
					NIM_BOOL T72_;
					T72_ = (NIM_BOOL)0;
					T72_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
					if (!(T72_)) goto LA73_;
					T72_ = !((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
					LA73_: ;
					if (!T72_) goto LA74_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_364));
				}
				LA74_: ;
				add__IM4kcMNkkOLJtqdEqSxR8A(&decl, td);
				{
					NIM_BOOL T78_;
					T78_ = (NIM_BOOL)0;
					T78_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
					if (!T78_) goto LA79_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
				}
				LA79_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0)) goto LA83_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_69));
				}
				LA83_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0)) goto LA87_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_70));
				}
				LA87_: ;
				{
					if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45))&63U)))!=0)) goto LA91_;
					add__yG4AKzsBRS1W4MANDlXQeg(&decl, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_71));
				}
				LA91_: ;
				{
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T97_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T98_;
					if (!!((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA95_;
					nimZeroMem((void*)T97_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T97_[0] = (*s).loc.r;
					T97_[1] = value;
					T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T98_ = percent___8aeHBTewuDsR3u9akMPiPqQ(T97_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&decl, T98_);
				}
				goto LA93_;
				LA95_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T100_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
					nimZeroMem((void*)T100_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T100_[0] = (*s).loc.r;
					T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T101_ = percent___nzT6Rke9c7tkW9b3XMmld2LA(T100_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&decl, T101_);
				}
				LA93_: ;
			}
			goto LA46_;
			LA48_: ;
			{
				{
					NimStringDesc* T107_;
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T108_;
					if (!!((value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA105_;
					T107_ = (NimStringDesc*)0;
					T107_ = rawNewString(((*(*s).constraint)._kind_3.strVal ? (*(*s).constraint)._kind_3.strVal->Sup.len : 0) + 8);
appendString(T107_, (*(*s).constraint)._kind_3.strVal);
appendString(T107_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_365));
					nimZeroMem((void*)T108_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T108_[0] = td;
					T108_[1] = (*s).loc.r;
					T108_[2] = value;
					decl = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T107_, T108_, 3);
				}
				goto LA103_;
				LA105_: ;
				{
					NimStringDesc* T110_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T111_;
					T110_ = (NimStringDesc*)0;
					T110_ = rawNewString(((*(*s).constraint)._kind_3.strVal ? (*(*s).constraint)._kind_3.strVal->Sup.len : 0) + 3);
appendString(T110_, (*(*s).constraint)._kind_3.strVal);
appendString(T110_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_366));
					nimZeroMem((void*)T111_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T111_[0] = td;
					T111_[1] = (*s).loc.r;
					decl = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T110_, T111_, 2);
				}
				LA103_: ;
			}
			LA46_: ;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], decl);
		}
		LA36_: ;
	}
	LA34_: ;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = (((NI) 0) < (*p).withinLoop);
		if (!(T114_)) goto LA115_;
		T114_ = (value == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
		LA115_: ;
		if (!T114_) goto LA116_;
		resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, (&(*s).loc));
	}
	LA116_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__IpGUPLhMYizrVHs0OdHySA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T7_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*(*p).module).g).config);
		if (!(T3_)) goto LA4_;
		T3_ = !((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 1))&7U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 1)) & 7);
		(*(*p).module).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 1)) & 7);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T7_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		nimZeroMem((void*)T8_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___sb2NV56uvmvOtYkgVsaVQQ(T8_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(T7_, T9_);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T10_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 27);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_367));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_368));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA14_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA14_: ;
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T16_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTraverseProcForGlobal__N6PVM8zp2L2vM3WsaTEaJQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg c;
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* sLoc;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* header;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* generatedProc;
	tyArray__f7nG5LD47BH5K9c6mASit3g T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T14_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2(m, T1_, info);
	(void)(T2_);
	nimZeroMem((void*)(&c), sizeof(tyObject_TTraversalClosure__xQv4a9atAYFpL11GCS9cY9bCg));
	p = newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), m);
	sLoc = rdLoc__xidyzuHqIciXbQyEOKahDg((*s).loc);
	result = getTempName__ao6gUnuVfQLtZ89c4kaIKfg(m);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0);
		if (!(T5_)) goto LA6_;
		T5_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*m).g).config);
		LA6_: ;
		if (!T5_) goto LA7_;
		accessThreadLocalVar__IpGUPLhMYizrVHs0OdHySA(p, s);
		sLoc = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_369), sLoc);
	}
	LA7_: ;
	c.visitorFrmt = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
	c.p = p;
	nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T9_[0] = result;
	header = percent___7STLi75js8HXlmFg7Abt9bQ(T9_, 1);
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*s).loc);
	genTraverseProc__LXrm7ZbTiXTVtbB5E60yIA_2(c, sLoc, T10_);
	nimZeroMem((void*)T11_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T11_[0] = header;
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	T11_[1] = (*T12_);
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T13_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
	T11_[2] = (*T13_);
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T14_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	T11_[3] = (*T14_);
	generatedProc = percent___5O50gePV9adn3wgFGWjlOLQ(T11_, 4);
	nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T15_[0] = header;
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = percent___9a3Y7eeGNXkOCLUktwxzN9ag(T15_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T16_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], generatedProc);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTraverseProc__V1atRcoAv09bVdrCPNlvW8Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((960 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
		if (!(T4_)) goto LA5_;
		T4_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T7_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*v).loc);
		T3_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(T7_);
		LA6_: ;
		if (!T3_) goto LA8_;
		result = genTraverseProcForGlobal__N6PVM8zp2L2vM3WsaTEaJQ((*p).module, v, (*v).info);
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__BwxixSWhJWbQ369cJZeckHA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* traverseProc) {
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*(*p).module).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		res = rawNewString(((NI) 80));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA8_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA8_: ;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_370));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), traverseProc);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA17_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA17_: ;
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T19_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T21_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata((*(*p).module).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		res_2 = rawNewString(((NI) 80));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA24_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA24_: ;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_371));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), traverseProc);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA29_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA29_: ;
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA33_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA33_: ;
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T35_);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, isAssignedImmediately__udBNoPxZaHjsWUNp37jAdwcgen)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag(conf, (*n).typ);
		if (!T7_) goto LA8_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA8_: ;
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__7ClJaTgavvBeZEMW4B6fYA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*p).lastLineInfo.line == info.line));
		if (T3_) goto LA4_;
		T3_ = !(((*p).lastLineInfo.fileIndex == info.fileIndex));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).lastLineInfo.line = info.line;
		(*p).lastLineInfo.fileIndex = info.fileIndex;
		result = NIM_TRUE;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	NI line;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T11_;
	NimStringDesc* T12_;
	line = safeLineNm__cb5f0VvvxoagMath9ay3UuQ((*t).info);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 28))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T6_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___Ng8dczn37bLzoM9bsVdPwjQ(T6_, 0);
		T8_ = (NimStringDesc*)0;
		T8_ = sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ((*(*(*p).module).g).config, (*t).info);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T7_, T8_);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T9_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T10_);
	}
	LA3_: ;
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T11_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	T12_ = (NimStringDesc*)0;
	T12_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*(*p).module).g).config, (*t).info.fileIndex);
	genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow(T11_, T12_, line, (*(*(*p).module).g).config);
	{
		NIM_BOOL T15_;
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		T15_ = (NIM_BOOL)0;
		T16_ = (NIM_BOOL)0;
		T16_ = ((655360 & (*p).options) == 655360);
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (T18_) goto LA19_;
		T18_ = !((((*(*p).prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0));
		LA19_: ;
		T16_ = T18_;
		LA17_: ;
		T15_ = T16_;
		if (!(T15_)) goto LA20_;
		T15_ = !(((*t).info.fileIndex == ((NI32) -1)));
		LA20_: ;
		if (!T15_) goto LA21_;
		{
			NIM_BOOL T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T28_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			T25_ = (NIM_BOOL)0;
			T25_ = freshLineInfo__7ClJaTgavvBeZEMW4B6fYA(p, (*t).info);
			if (!T25_) goto LA26_;
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T28_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_372));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (line)));
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*(*p).module).g).config, (*t).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T29_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA32_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA32_: ;
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T34_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T28_, T35_);
		}
		LA26_: ;
	}
	LA21_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, NIM_BOOL needsTmp, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* Result) {
	(*Result).k = 0;
	(*Result).storage = 0;
	unsureAsgnRef((void**)&(*Result).lode, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).r, NIM_NIL);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI64 T9_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = needsTmp;
		if (!(T5_)) goto LA6_;
		T5_ = !(((*a.lode).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((48 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T9_ = (NI64)0;
		T9_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, (*a.lode).typ);
		T3_ = (T9_ < IL64(1024));
		LA8_: ;
		if (!T3_) goto LA10_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*a.lode).typ, Result, NIM_FALSE);
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*Result), a, 0);
	}
	goto LA1_;
	LA10_: ;
	{
		genericAssign((void*)Result, (void*)(&a), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	}
	LA1_: ;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArgStringToCString__6LeXitLQkjwfrebQPKcpoAcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL needsTmp) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_373));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg(p, a, needsTmp, (&T2_));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = rdLoc__xidyzuHqIciXbQyEOKahDg(T2_);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T3_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArgNoParam__idr0athfhAF2aTg9arX9bWAg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL needsTmp) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71))) goto LA3_;
		result = genArgStringToCString__6LeXitLQkjwfrebQPKcpoAcgen(p, n, needsTmp);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T6_;
		initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, n, (&a));
		nimZeroMem((void*)(&T6_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg(p, a, needsTmp, (&T6_));
		result = rdLoc__xidyzuHqIciXbQyEOKahDg(T6_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOtherArg__9a86z5oGsAZjkB52zPdLZJQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NI T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* paramType;
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		if (!(i < T3_)) goto LA4_;
		paramType = (*(*typ).n)._kind_6.sons->data[i];
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*paramType).typ);
			if (!T8_) goto LA9_;
			result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		}
		goto LA6_;
		LA9_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*typ).sons->data[i]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*ri)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64));
			LA13_: ;
			if (!T12_) goto LA14_;
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*(*ri)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], NIM_FALSE);
		}
		goto LA6_;
		LA14_: ;
		{
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*ri)._kind_6.sons->data[i], NIM_FALSE);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			if (!!((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0))&63U)))!=0))) goto LA20_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*ri).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_374), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_375, NIM_FALSE);
			result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		}
		goto LA18_;
		LA20_: ;
		{
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*ri)._kind_6.sons->data[i], NIM_FALSE);
		}
		LA18_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, notYetAlive__4MUa2M7mDMhaGJLAFrkWDw_2cgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* r;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	r = getRoot__QppXrRxPfamDSGF2rYPMlw(n);
	T1_ = (NIM_BOOL)0;
	T1_ = !((r == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*r).loc.lode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__iRZAnpxF4CwuSQ4C7wQilQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NI T4_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T4_ = (NI)0;
	T4_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
	T3_ = (T4_ == ((NI) 2));
	if (!(T3_)) goto LA5_;
	T3_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	LA5_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = eqStrings((*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_384));
	LA6_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA7_;
	T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T8_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*e)._kind_6.sons->data[((NI) 1)]);
	T1_ = notYetAlive__4MUa2M7mDMhaGJLAFrkWDw_2cgen(T8_);
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipTrivialIndirections__oKhRC9bEKTxG5epdNiNWZ0w_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__VM9crKDs5ctG1rw9aot9a4zEQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* potentialWrites) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** p;
		NI i;
		NI L;
		NI T2_;
		p = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		i = ((NI) 0);
		T2_ = (potentialWrites ? potentialWrites->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				p = &potentialWrites->data[i];
				{
					tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ T7_;
					T7_ = (tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ)0;
					T7_ = instrTargets__w1KaHRCZ7rX9a4bWRvZGRmQ((*p), n);
					if (!!((T7_ == ((tyEnum_InstrTargetKind__jS7zjwSSXtKIkBLJzNXXAQ) 0)))) goto LA8_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA8_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, getPotentialReads__1E9ailIhVU2zHYmHnsdAukQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* result;
	result = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		NI T3_;
		result = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
		T3_ = result->Sup.len++;
		asgnRef((void**) (&result->data[T3_]), n);
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T6_;
			s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*n)._kind_6.sons;
			i = ((NI) 0);
			T6_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T6_;
			{
				while (1) {
					tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T9_;
					if (!(i < L)) goto LA8;
					s = &colontmp_->data[i];
					T9_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
					T9_ = getPotentialReads__1E9ailIhVU2zHYmHnsdAukQ((*s));
					add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T9_->data, (T9_ ? T9_->Sup.len : 0));
					i += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL mutate) {
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* result;
	result = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NI T7_;
			if (!mutate) goto LA5_;
			result = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)(result), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
			T7_ = result->Sup.len++;
			asgnRef((void**) (&result->data[T7_]), n);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T9_;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T10_;
		T9_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		T9_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
		add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T9_->data, (T9_ ? T9_->Sup.len : 0));
		T10_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		T10_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*n)._kind_6.sons->data[((NI) 1)], mutate);
		add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T10_->data, (T10_ ? T10_->Sup.len : 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T12_;
		T12_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		T12_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
		add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T12_->data, (T12_ ? T12_->Sup.len : 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T15_;
			s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*n)._kind_6.sons;
			i = ((NI) 0);
			T15_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T15_;
			{
				while (1) {
					tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T18_;
					if (!(i < L)) goto LA17;
					s = &colontmp_->data[i];
					T18_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
					T18_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*s), NIM_TRUE);
					add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T18_->data, (T18_ ? T18_->Sup.len : 0));
					i += ((NI) 1);
				} LA17: ;
			}
		}
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s_2;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp__2;
			NI i_2;
			NI L_2;
			NI T21_;
			s_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp__2 = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp__2 = (*n)._kind_6.sons;
			i_2 = ((NI) 0);
			T21_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
			L_2 = T21_;
			{
				while (1) {
					tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T24_;
					if (!(i_2 < L_2)) goto LA23;
					s_2 = &colontmp__2->data[i_2];
					T24_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
					T24_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*s_2), mutate);
					add__VtZAvh3FTvs4RsUIdDz79aQ((&result), T24_->data, (T24_ ? T24_->Sup.len : 0));
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NI L;
		NI T5_;
		if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3))) goto LA3_;
		T5_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		L = T5_;
		{
			NimStringDesc* res;
			if (!(L == ((NI) 0))) goto LA8_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0)) & 7);
			res = rawNewString(((NI) 80));
			res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_392));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA12_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA12_: ;
			result = rope__yShmEg9cffWxI7s5XzEKBow(res);
		}
		goto LA6_;
		LA8_: ;
		{
			NimStringDesc* res_2;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_393));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_2), ((NI64) ((*p).nestedTryStmts->data[(NI)(L - ((NI) 1))].Field2)));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_394));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA17_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA17_: ;
			result = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		}
		LA6_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, intLiteral__0L2LUBpuDvHdOo5Bdh2tRw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI64 T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NI64)0;
	T1_ = toInt64__1szweXXq3RBN50owrYu2Xw(i);
	result = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdCharLoc__xidyzuHqIciXbQyEOKahDg_2)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T4_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T3_, IL64(36134350136322320));
		if (!((*T4_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T7_[0] = result;
		result = percent___TmT2Gs9cB7RN9cmo9c9cBpfKsA(T7_, 1);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__Hw9c2IcxFuX7vhYGTZsoSPA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA arr, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(arr);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350144710928));
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			NIM_BOOL T5_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			T5_ = (NIM_BOOL)0;
			T5_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(arr.lode);
			if (!T5_) goto LA6_;
			T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385));
			T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
			res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_386));
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(arr);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
			res = resizeString(res, 17);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_388));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(arr);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
			res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_389));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_390));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA19_: ;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T22_);
		}
		goto LA3_;
		LA6_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T24_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T24_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385));
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
			res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_386));
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = rdLoc__xidyzuHqIciXbQyEOKahDg(arr);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
			res_2 = resizeString(res_2, 15);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_395));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rdLoc__xidyzuHqIciXbQyEOKahDg(arr);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T30_);
			res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_396));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_390));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T32_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA35_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA35_: ;
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T37_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T24_, T38_);
		}
		LA3_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* first;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T40_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T48_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T55_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
		T40_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
		first = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T40_);
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T42_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T42_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385));
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T43_);
		res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_397));
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T44_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T44_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385));
		T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T45_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T45_);
		res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_398));
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T46_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), first);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T47_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_400));
		T48_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T49_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T48_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T49_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
		T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T50_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T50_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), first);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
		T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T51_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T51_);
		res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_400));
		T52_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
		T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T53_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T52_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T53_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_390));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T54_);
		res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
		T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T55_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T55_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA58_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA58_: ;
		T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T60_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T61_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T60_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T41_, T61_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T63_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T63_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T64_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T64_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_385));
		T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T65_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T65_);
		res_4 = resizeString(res_4, 16);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_386));
		T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T66_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T66_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_402));
		T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T67_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, arr);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T67_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_403));
		T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T68_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T68_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_402));
		T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T69_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, arr);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T69_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
		T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T70_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_390));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T70_);
		res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
		T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T71_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T71_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA74_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA74_: ;
		T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T76_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T77_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T76_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T63_, T77_);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArraySlice__OgTjHQyQeIgTGpsUfPmxRQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* q, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formalType, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* destType, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA c;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* dest;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lengthExpr;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).Field1, NIM_NIL);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&c), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*q)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*q)._kind_6.sons->data[((NI) 2)], (&b));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*q)._kind_6.sons->data[((NI) 3)], (&c));
	{
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA3_;
		genBoundsCheck__Hw9c2IcxFuX7vhYGTZsoSPA(p, a, b, c);
	}
	LA3_: ;
	T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T5_, IL64(36275087634114832));
	dest = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, destType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T6_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(c);
	T6_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
	lengthExpr = percent___9b9cGfmDPAxEWXZ4v4mdlErQ(T6_, 2);
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		NI64 first;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T8_;
		T8_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
		first = toInt64__1szweXXq3RBN50owrYu2Xw(T8_);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__2;
			if (!(first == IL64(0))) goto LA11_;
			nimZeroMem((void*)T13_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T13_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T13_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T13_[2] = dest;
			colontmp_ = percent___CvKvzmiW59auxFBRDFxCJSQ(T13_, 3);
			colontmp__2 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp_);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__2);
		}
		goto LA9_;
		LA11_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__3;
			tyArray__f7nG5LD47BH5K9c6mASit3g T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__4;
			nimZeroMem((void*)T15_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T15_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T15_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T15_[2] = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(first);
			T15_[3] = dest;
			colontmp__3 = percent___02C88mFwGG7GLN49c9cza4CQ(T15_, 4);
			colontmp__4 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__3);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__4);
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			NIM_BOOL T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__5;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__6;
			T19_ = (NIM_BOOL)0;
			T19_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen((*q)._kind_6.sons->data[((NI) 1)]);
			if (!T19_) goto LA20_;
			nimZeroMem((void*)T22_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T22_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T22_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T22_[2] = dest;
			colontmp__5 = percent___mR3c5JSpBB2VsIXEipMwMA(T22_, 3);
			colontmp__6 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__5);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__6);
		}
		goto LA17_;
		LA20_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__7;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__8;
			nimZeroMem((void*)T24_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T24_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T24_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T24_[2] = dest;
			colontmp__7 = percent___7KIiDutBmiUJL6kpESJ8ZA(T24_, 3);
			colontmp__8 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__7);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__8);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__9;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__10;
		nimZeroMem((void*)T26_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T26_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T26_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T26_[2] = dest;
		colontmp__9 = percent___7KIiDutBmiUJL6kpESJ8ZA(T26_, 3);
		colontmp__10 = lengthExpr;
		unsureAsgnRef((void**) (&(*Result).Field0), colontmp__9);
		unsureAsgnRef((void**) (&(*Result).Field1), colontmp__10);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* atyp;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
		T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T28_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		atyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T28_, IL64(36134350135273744));
		{
			NIM_BOOL T31_;
			NIM_BOOL T32_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T38_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			T31_ = (NIM_BOOL)0;
			T32_ = (NIM_BOOL)0;
			T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T33_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(formalType, IL64(36134350135273744));
			T32_ = ((*T33_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T32_)) goto LA34_;
			T32_ = ((*atyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
			LA34_: ;
			T31_ = T32_;
			if (!(T31_)) goto LA35_;
			T31_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
			LA35_: ;
			if (!T31_) goto LA36_;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T38_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_236));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T39_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T40_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA43_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA43_: ;
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T45_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T38_, T46_);
		}
		LA36_: ;
		{
			NIM_BOOL T49_;
			NIM_BOOL T51_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__11;
			tyArray__f7nG5LD47BH5K9c6mASit3g T55_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__12;
			T49_ = (NIM_BOOL)0;
			T49_ = ((*atyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T49_)) goto LA50_;
			T51_ = (NIM_BOOL)0;
			T51_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T51_) goto LA52_;
			T51_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA52_: ;
			T49_ = !(T51_);
			LA50_: ;
			if (!T49_) goto LA53_;
			nimZeroMem((void*)T55_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T55_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T55_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T55_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
			T55_[3] = dest;
			colontmp__11 = percent___j7I7KYCBLEVOBnBFpLQp4A(T55_, 4);
			colontmp__12 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__11);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__12);
		}
		goto LA47_;
		LA53_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__13;
			tyArray__f7nG5LD47BH5K9c6mASit3g T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__14;
			nimZeroMem((void*)T57_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T57_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T57_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T57_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
			T57_[3] = dest;
			colontmp__13 = percent___btjbbzpOIPgksCcMaA2TQg(T57_, 4);
			colontmp__14 = lengthExpr;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__13);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__14);
		}
		LA47_: ;
	}
	break;
	default:
	{
		NimStringDesc* T59_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
		NimStringDesc* T61_;
		T59_ = (NimStringDesc*)0;
		T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T60_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T61_ = (NimStringDesc*)0;
		T61_ = typeToString__QlvraUan7WbHowhAbvDvdA(T60_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T59_ = rawNewString((T61_ ? T61_->Sup.len : 0) + 14);
appendString(T59_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_404));
appendString(T59_, T61_);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T59_, TM__MQdRN7fpbG7rPm4JpVVAhA_405);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, openArrayLoc__6mPoivdljN39aZZDBAbjmIw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formalType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* q;
	NIM_BOOL skipped;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	q = skipConv__BH9abOhPX8pH0DnEWlRxmlw(n);
	skipped = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T3_;
			NI T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((*q).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
			if (!(T3_)) goto LA4_;
			T5_ = (NI)0;
			T5_ = len__P89cqdlERShb9alU3iC0yj8wast(q);
			T3_ = (((NI) 0) < T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			skipped = NIM_TRUE;
			q = lastSon__UPSW0jLTX5qJL51YMUAHgw(q);
		} LA2: ;
	}
	{
		tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T8_;
		tyTuple__nsNHL3sm0TZE9bootw2pEXw T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* y;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		T8_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
		T8_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(q);
		if (!(T8_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126))) goto LA9_;
		{
			if (!skipped) goto LA13_;
			q = skipConv__BH9abOhPX8pH0DnEWlRxmlw(n);
			{
				while (1) {
					NIM_BOOL T17_;
					NI T19_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*q).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
					if (!(T17_)) goto LA18_;
					T19_ = (NI)0;
					T19_ = len__P89cqdlERShb9alU3iC0yj8wast(q);
					T17_ = (((NI) 0) < T19_);
					LA18_: ;
					if (!T17_) goto LA16;
					{
						NI i;
						NI colontmp_;
						NI T21_;
						NI i_2;
						i = (NI)0;
						colontmp_ = (NI)0;
						T21_ = (NI)0;
						T21_ = len__P89cqdlERShb9alU3iC0yj8wast(q);
						colontmp_ = (NI)(T21_ - ((NI) 1));
						i_2 = ((NI) 0);
						{
							while (1) {
								if (!(i_2 < colontmp_)) goto LA23;
								i = i_2;
								genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*q)._kind_6.sons->data[i]);
								i_2 += ((NI) 1);
							} LA23: ;
						}
					}
					q = lastSon__UPSW0jLTX5qJL51YMUAHgw(q);
				} LA16: ;
			}
		}
		LA13_: ;
		nimZeroMem((void*)(&T24_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
		genOpenArraySlice__OgTjHQyQeIgTGpsUfPmxRQ(p, q, formalType, (*(*n).typ).sons->data[((NI) 0)], (&T24_));
		x = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		x = T24_.Field0;
		y = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		y = T24_.Field1;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(x, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T25_, y);
	}
	goto LA6_;
	LA9_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T34_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58))) goto LA30_;
			T27_ = (*n)._kind_6.sons->data[((NI) 1)];
		}
		goto LA28_;
		LA30_: ;
		{
			T27_ = n;
		}
		LA28_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, T27_, (&a));
		T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T33_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T34_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T34_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T33_, IL64(36275087632017680));
		switch ((*T34_).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		{
			{
				NIM_BOOL T38_;
				T38_ = (NIM_BOOL)0;
				T38_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(n);
				if (!T38_) goto LA39_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T46_;
					T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T43_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
					if (!((*T43_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*T43_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))) goto LA44_;
					nimZeroMem((void*)T46_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T46_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					result = percent___fzzklE4aYpRPohWGI2Uilg(T46_, 1);
				}
				goto LA41_;
				LA44_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T48_;
					nimZeroMem((void*)T48_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T48_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					result = percent___LzOSzuN9b2AE9bvskk0YuAww(T48_, 1);
				}
				LA41_: ;
			}
			goto LA36_;
			LA39_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T50_;
				nimZeroMem((void*)T50_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T50_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				result = percent___L3AeZ1n9aK4C1jsBCeaCmlQ(T50_, 1);
			}
			LA36_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ntyp;
			ntyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
			{
				NIM_BOOL T54_;
				NIM_BOOL T55_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T56_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
				T54_ = (NIM_BOOL)0;
				T55_ = (NIM_BOOL)0;
				T56_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T56_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(formalType, IL64(36134350135273744));
				T55_ = ((*T56_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
				if (!(T55_)) goto LA57_;
				T55_ = ((*ntyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
				LA57_: ;
				T54_ = T55_;
				if (!(T54_)) goto LA58_;
				T54_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
				LA58_: ;
				if (!T54_) goto LA59_;
				T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res = rawNewString(((NI) 80));
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_236));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T62_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T63_);
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA66_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA66_: ;
				T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T68_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T69_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T68_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T69_);
			}
			LA59_: ;
			{
				NIM_BOOL T72_;
				NIM_BOOL T74_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA t;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T78_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T79_;
				T72_ = (NIM_BOOL)0;
				T72_ = ((*ntyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
				if (!(T72_)) goto LA73_;
				T74_ = (NIM_BOOL)0;
				T74_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T74_) goto LA75_;
				T74_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA75_: ;
				T72_ = !(T74_);
				LA73_: ;
				if (!T72_) goto LA76_;
				nimZeroMem((void*)(&t), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)T78_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T78_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				t.r = percent___TbMwXzwNL7txOQADiTjwKA(T78_, 1);
				nimZeroMem((void*)T79_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T79_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				T79_[1] = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, t);
				T79_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
				result = percent___ebmRHYtM9cCbYF6WvKDfQ9cg(T79_, 3);
			}
			goto LA70_;
			LA76_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T81_;
				nimZeroMem((void*)T81_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T81_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				T81_[1] = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
				T81_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
				result = percent___qE1JtEDDOvP6J49a9cv9aK1Dg(T81_, 3);
			}
			LA70_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T83_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T84_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T85_;
			nimZeroMem((void*)T83_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T83_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T84_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T84_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
			T85_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, T84_);
			T83_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T85_);
			result = percent___ctvQ2lU9b9bnVVpNP4GhIo2Q(T83_, 2);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T87_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T88_;
			T87_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T87_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
			T88_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T88_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(T87_);
			switch ((*T88_).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA t_2;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T90_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T91_;
				nimZeroMem((void*)(&t_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)T90_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T90_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				t_2.r = percent___TbMwXzwNL7txOQADiTjwKA(T90_, 1);
				nimZeroMem((void*)T91_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T91_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				T91_[1] = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, t_2);
				T91_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
				result = percent___ebmRHYtM9cCbYF6WvKDfQ9cg(T91_, 3);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T93_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T94_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T95_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T96_;
				nimZeroMem((void*)T93_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T93_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				T94_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T94_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
				T95_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T95_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(T94_);
				T96_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, T95_);
				T93_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T96_);
				result = percent___ctvQ2lU9b9bnVVpNP4GhIo2Q(T93_, 2);
			}
			break;
			default:
			{
				NimStringDesc* T98_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T99_;
				NimStringDesc* T100_;
				T98_ = (NimStringDesc*)0;
				T99_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T99_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
				T100_ = (NimStringDesc*)0;
				T100_ = typeToString__QlvraUan7WbHowhAbvDvdA(T99_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T98_ = rawNewString((T100_ ? T100_->Sup.len : 0) + 14);
appendString(T98_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_404));
appendString(T98_, T100_);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T98_, TM__MQdRN7fpbG7rPm4JpVVAhA_406);
			}
			break;
			}
		}
		break;
		default:
		{
			NimStringDesc* T102_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T103_;
			NimStringDesc* T104_;
			T102_ = (NimStringDesc*)0;
			T103_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T103_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
			T104_ = (NimStringDesc*)0;
			T104_ = typeToString__QlvraUan7WbHowhAbvDvdA(T103_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T102_ = rawNewString((T104_ ? T104_->Sup.len : 0) + 14);
appendString(T102_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_404));
appendString(T102_, T104_);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T102_, TM__MQdRN7fpbG7rPm4JpVVAhA_407);
		}
		break;
		}
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genArg__NyG7NHKT5F2mihfTt1JRVA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, NIM_BOOL needsTmp) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71))) goto LA3_;
		result = genArgStringToCString__6LeXitLQkjwfrebQPKcpoAcgen(p, n, needsTmp);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*param).typ, IL64(36275087632017680));
		if (!((*T6_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*T6_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA7_;
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64)))) goto LA11_;
			n_2 = n;
		}
		goto LA9_;
		LA11_: ;
		{
			n_2 = (*n)._kind_6.sons->data[((NI) 0)];
		}
		LA9_: ;
		result = openArrayLoc__6mPoivdljN39aZZDBAbjmIw(p, (*param).typ, n_2);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T15_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T18_;
		T15_ = (NIM_BOOL)0;
		T15_ = ccgIntroducedPtr__W9aw79b629bysnh3DDOpE3OTg((*(*(*p).module).g).config, param, (*(*(*call)._kind_6.sons->data[((NI) 0)]).typ).sons->data[((NI) 0)]);
		if (!T15_) goto LA16_;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n, (&a));
		nimZeroMem((void*)(&T18_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg(p, a, needsTmp, (&T18_));
		result = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, T18_);
	}
	goto LA1_;
	LA16_: ;
	{
		NIM_BOOL T20_;
		NIM_BOOL T21_;
		NIM_BOOL T22_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callee;
		T20_ = (NIM_BOOL)0;
		T21_ = (NIM_BOOL)0;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T22_) goto LA23_;
		T22_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA23_: ;
		T21_ = T22_;
		if (!(T21_)) goto LA24_;
		T21_ = ((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
		LA24_: ;
		T20_ = T21_;
		if (!(T20_)) goto LA25_;
		T20_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64));
		LA25_: ;
		if (!T20_) goto LA26_;
		initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		callee = (*call)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T30_;
			NIM_BOOL T31_;
			T30_ = (NIM_BOOL)0;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*callee).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T31_)) goto LA32_;
			T31_ = ((IL64(2147745856) & (*(*callee)._kind_4.sym).flags) == 64);
			LA32_: ;
			T30_ = T31_;
			if (!(T30_)) goto LA33_;
			T30_ = !(((72 & (*(*callee)._kind_4.sym).loc.flags) == 0));
			LA33_: ;
			if (!T30_) goto LA34_;
			result = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a);
		}
		goto LA28_;
		LA34_: ;
		{
			result = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		}
		LA28_: ;
	}
	goto LA1_;
	LA26_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA T38_;
		initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, n, (&a));
		nimZeroMem((void*)(&T38_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		withTmpIfNeeded__SvGIZlLFrbp85sMHDsj9apg(p, a, needsTmp, (&T38_));
		result = rdLoc__xidyzuHqIciXbQyEOKahDg(T38_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genParams__KMtRYhmblciqOHa6LfFLDw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tySequence__shxop0zPIs5Ec3k71aCLuQ* needTmp;
	NI T1_;
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* potentialWrites;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
	needTmp = newSeq__rt1It5NRu1MxMaCLDXp0Ew(((NI) ((NI)(T1_ - ((NI) 1)))));
	potentialWrites = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
		colontmp_ = (NI)(T3_ - ((NI) 1));
		res = colontmp_;
		{
			while (1) {
				if (!(((NI) 1) <= res)) goto LA5;
				i = res;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
					T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T8_ = skipTrivialIndirections__oKhRC9bEKTxG5epdNiNWZ0w_2((*ri)._kind_6.sons->data[i]);
					if (!((*T8_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA9_;
					needTmp->data[(NI)(i - ((NI) 1))] = potentialAlias__VM9crKDs5ctG1rw9aot9a4zEQ((*ri)._kind_6.sons->data[i], potentialWrites);
				}
				goto LA6_;
				LA9_: ;
				{
					tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T20_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n;
						tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp__2;
						NI i_2;
						NI L;
						NI T13_;
						n = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
						colontmp__2 = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
						colontmp__2 = getPotentialReads__1E9ailIhVU2zHYmHnsdAukQ((*ri)._kind_6.sons->data[i]);
						i_2 = ((NI) 0);
						T13_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
						L = T13_;
						{
							while (1) {
								if (!(i_2 < L)) goto LA15;
								n = &colontmp__2->data[i_2];
								{
									if (!!(needTmp->data[(NI)(i - ((NI) 1))])) goto LA18_;
									needTmp->data[(NI)(i - ((NI) 1))] = potentialAlias__VM9crKDs5ctG1rw9aot9a4zEQ((*n), potentialWrites);
								}
								LA18_: ;
								i_2 += ((NI) 1);
							} LA15: ;
						}
					}
					T20_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
					T20_ = getPotentialWrites__B7Yg1gpaDb6Z9a3P5pTbYYw((*ri)._kind_6.sons->data[i], NIM_FALSE);
					add__VtZAvh3FTvs4RsUIdDz79aQ((&potentialWrites), T20_->data, (T20_ ? T20_->Sup.len : 0));
				}
				LA6_: ;
				{
					if (!((*(*ri)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA23_;
					needTmp->data[(NI)(i - ((NI) 1))] = NIM_FALSE;
				}
				LA23_: ;
				res -= ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI i_3;
		NI colontmp__3;
		NI i_4;
		i_3 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(ri);
		i_4 = ((NI) 1);
		{
			while (1) {
				if (!(i_4 < colontmp__3)) goto LA27;
				i_3 = i_4;
				{
					NI T30_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* paramType;
					T30_ = (NI)0;
					T30_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
					if (!(i_3 < T30_)) goto LA31_;
					paramType = (*(*typ).n)._kind_6.sons->data[i_3];
					{
						NIM_BOOL T35_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
						T35_ = (NIM_BOOL)0;
						T35_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*paramType).typ);
						if (!!(T35_)) goto LA36_;
						{
							tyArray__qTjAvTvKF9anytN1At69aJMQ T42_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
							if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA40_;
							nimZeroMem((void*)T42_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
							T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T43_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T42_, 0);
							add__IM4kcMNkkOLJtqdEqSxR8A(&result, T43_);
						}
						LA40_: ;
						T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T44_ = genArg__NyG7NHKT5F2mihfTt1JRVA(p, (*ri)._kind_6.sons->data[i_3], (*paramType)._kind_4.sym, ri, needTmp->data[(NI)(i_3 - ((NI) 1))]);
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T44_);
					}
					LA36_: ;
				}
				goto LA28_;
				LA31_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T50_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
						if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA48_;
						nimZeroMem((void*)T50_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T51_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T50_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T51_);
					}
					LA48_: ;
					T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T52_ = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*ri)._kind_6.sons->data[i_3], needTmp->data[(NI)(i_3 - ((NI) 1))]);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T52_);
				}
				LA28_: ;
				i_4 += ((NI) 1);
			} LA27: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__Y9bFh7BmZkh729bS2kZ5kwnQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = !(((IL64(4398046773312) & (*(*n)._kind_4.sym).flags) == 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		NIM_BOOL T10_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 46))&63U)))!=0);
		if (T8_) goto LA9_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T10_)) goto LA11_;
		T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T12_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*n)._kind_4.sym);
		T10_ = (((*T12_).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
		LA11_: ;
		T8_ = T10_;
		LA9_: ;
		if (!T8_) goto LA13_;
		result = canRaise__qAerQ9bftuf70QDk42UIFXg_2(n);
	}
	goto LA1_;
	LA13_: ;
	{
		result = canRaiseConservative__qAerQ9bftuf70QDk42UIFXg(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__fKz9bDGxeJtVdl9bZW9aX2KFA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, NIM_BOOL inTryStmt) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
{	result = (NIM_BOOL)0;
	n = le;
	{
		while (1) {
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
			{
				{
					if (!!(((*(*n)._kind_4.sym).owner == (*p).prc))) goto LA6_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA4_;
				LA6_: ;
				{
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = inTryStmt;
					if (!(T9_)) goto LA10_;
					T9_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 43))&63U)))!=0);
					LA10_: ;
					if (!T9_) goto LA11_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA4_;
				LA11_: ;
				LA4_: ;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
			{
				n = (*n)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
			{
				n = (*n)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			break;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__VzIhhB7jFivZ9c6NgOwxU1Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!((le == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					r = (*ri)._kind_6.sons->data[i];
					{
						tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w T10_;
						T10_ = (tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w)0;
						T10_ = isPartOf__1otDDZAmvFsmbqPyFytXFg(le, r);
						if (!!((T10_ == ((tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w) 0)))) goto LA11_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		{
			NIM_BOOL T15_;
			NI T17_;
			NimStringDesc* T20_;
			T15_ = (NIM_BOOL)0;
			T15_ = canRaise__qAerQ9bftuf70QDk42UIFXg_2((*ri)._kind_6.sons->data[((NI) 0)]);
			if (!(T15_)) goto LA16_;
			T17_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
			T15_ = locationEscapes__fKz9bDGxeJtVdl9bZW9aX2KFA(p, le, (((NI) 0) < T17_));
			LA16_: ;
			if (!T15_) goto LA18_;
			T20_ = (NimStringDesc*)0;
			T20_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(le);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*le).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 50), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_408, NIM_FALSE);
		}
		LA18_: ;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, hasNoInit__XO14mevzEVVwQTyfj9cMewwcgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*call)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, addComma__WAlh7NpO6KFA22Kxnp9aoaw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		result = r;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		nimZeroMem((void*)T6_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T6_, 0);
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(r, T7_);
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyTuple__FxkU4d1VDodDMc9ah6Mbagw*, X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem)(tyTuple__FxkU4d1VDodDMc9ah6Mbagw* s, NI sLen_0, NI i) {
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw* result;
	result = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__0dpuY9coTlraj8JXIe2BzVw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	{
		if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 6))&7U)))!=0))) goto LA3_;
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 4)) & 7);
		{
			NI T7_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			T7_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
			if (!(T7_ == ((NI) 0))) goto LA8_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0)) & 7);
			T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 44);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_409));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA13_: ;
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T16_);
		}
		goto LA5_;
		LA8_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T18_;
			NimStringDesc* res_2;
			tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T18_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 35);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_410));
			T19_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
			T19_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_2), ((NI64) ((*T19_).Field2)));
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_394));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA22_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA22_: ;
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T24_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T18_, T25_);
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__4h2Oud7u5jWCpkY1i8QUDg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, NIM_BOOL canRaise, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((3 &((NU16)1<<((NU)(d.k)&15U)))!=0);
		if (T3_) goto LA4_;
		T3_ = !(canRaise);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (d.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 2));
		if (!(T8_)) goto LA9_;
		T8_ = ((*p).withinTryWithExcept == ((NI) 0));
		LA9_: ;
		if (!T8_) goto LA10_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA10_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__HKkL9adNEIcNHeJ0iZ6uitg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA op;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pl;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* rawProc;
	NIM_BOOL canRaise;
	NIM_BOOL T1_;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	pl = genParams__KMtRYhmblciqOHa6LfFLDw(p, ri, typ);
	rawProc = getClosureType__lWDfUH9cj8K8DjyEqo9cmP3A((*p).module, typ, ((tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw) 0));
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3));
	if (!(T1_)) goto LA2_;
	T1_ = canRaiseDisp__Y9bFh7BmZkh729bS2kZ5kwnQ(p, (*ri)._kind_6.sons->data[((NI) 0)]);
	LA2_: ;
	canRaise = T1_;
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*(*p).module).g).config, (*typ).sons->data[((NI) 0)]);
			if (!T9_) goto LA10_;
			{
				NI T14_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T17_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
				T14_ = (NI)0;
				T14_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
				if (!(((NI) 1) < T14_)) goto LA15_;
				nimZeroMem((void*)T17_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T18_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T17_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T18_);
			}
			LA15_: ;
			{
				NIM_BOOL T21_;
				NIM_BOOL T23_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
				T21_ = (NIM_BOOL)0;
				T21_ = ((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0);
				if (T21_) goto LA22_;
				T23_ = (NIM_BOOL)0;
				T23_ = preventNrvo__VzIhhB7jFivZ9c6NgOwxU1Q(p, le, ri);
				T21_ = !(T23_);
				LA22_: ;
				if (!T21_) goto LA24_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA28_;
					getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				goto LA26_;
				LA28_: ;
				{
					NIM_BOOL T31_;
					NIM_BOOL T33_;
					T31_ = (NIM_BOOL)0;
					T31_ = !(((2 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
					if (!(T31_)) goto LA32_;
					T33_ = (NIM_BOOL)0;
					T33_ = hasNoInit__XO14mevzEVVwQTyfj9cMewwcgen(ri);
					T31_ = !(T33_);
					LA32_: ;
					if (!T31_) goto LA34_;
				}
				goto LA26_;
				LA34_: ;
				LA26_: ;
				T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T36_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*d));
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T36_);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T42_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
					if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA39_;
					T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T42_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					T42_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
					T42_[1] = pl;
					T42_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
					T42_[3] = rawProc;
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = percent___8bHx2qDxS2yWIId1X52mqg(T42_, 4);
					T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T44_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T43_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T41_, T44_);
				}
				goto LA37_;
				LA39_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T46_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T47_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
					T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T46_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T47_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					T47_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
					T47_[1] = pl;
					T47_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
					T47_[3] = rawProc;
					T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T48_ = percent___kTDR7D9c9aomjcaUQOmKJ9csg(T47_, 4);
					T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T49_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T48_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T46_, T49_);
				}
				LA37_: ;
			}
			goto LA19_;
			LA24_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T51_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmp);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T51_);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T56_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T57_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
					if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA54_;
					T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T56_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T57_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					T57_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
					T57_[1] = pl;
					T57_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
					T57_[3] = rawProc;
					T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T58_ = percent___8bHx2qDxS2yWIId1X52mqg(T57_, 4);
					T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T59_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T58_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T56_, T59_);
				}
				goto LA52_;
				LA54_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T62_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
					T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T62_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					T62_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
					T62_[1] = pl;
					T62_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
					T62_[3] = rawProc;
					T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T63_ = percent___kTDR7D9c9aomjcaUQOmKJ9csg(T62_, 4);
					T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T64_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T63_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T64_);
				}
				LA52_: ;
				{
					if (!canRaise) goto LA67_;
					raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
				}
				LA67_: ;
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
			}
			LA19_: ;
		}
		goto LA7_;
		LA10_: ;
		{
			NIM_BOOL T70_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list;
			T70_ = (NIM_BOOL)0;
			T70_ = isHarmlessStore__4h2Oud7u5jWCpkY1i8QUDg(p, canRaise, (*d));
			if (!T70_) goto LA71_;
			{
				if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA75_;
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
			}
			LA75_: ;
			nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&list), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T81_;
				if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA79_;
				nimZeroMem((void*)T81_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T81_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
				T81_[1] = pl;
				T81_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
				T81_[3] = rawProc;
				list.r = percent___1tj59chZC08k4TWYeZiqDnQ(T81_, 4);
			}
			goto LA77_;
			LA79_: ;
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T83_;
				nimZeroMem((void*)T83_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T83_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
				T83_[1] = pl;
				T83_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
				T83_[3] = rawProc;
				list.r = percent___533QKY9a8quvLM1SsLE1JfQ(T83_, 4);
			}
			LA77_: ;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), list, 0);
			{
				if (!canRaise) goto LA86_;
				raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
			}
			LA86_: ;
		}
		goto LA7_;
		LA71_: ;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp_2;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list_2;
			nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], (&tmp_2), NIM_FALSE);
			nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&list_2), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T93_;
				if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA91_;
				nimZeroMem((void*)T93_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T93_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
				T93_[1] = pl;
				T93_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
				T93_[3] = rawProc;
				list_2.r = percent___1tj59chZC08k4TWYeZiqDnQ(T93_, 4);
			}
			goto LA89_;
			LA91_: ;
			{
				tyArray__f7nG5LD47BH5K9c6mASit3g T95_;
				nimZeroMem((void*)T95_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T95_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
				T95_[1] = pl;
				T95_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
				T95_[3] = rawProc;
				list_2.r = percent___533QKY9a8quvLM1SsLE1JfQ(T95_, 4);
			}
			LA89_: ;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmp_2, list_2, 0);
			{
				if (!canRaise) goto LA98_;
				raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
			}
			LA98_: ;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp_2, 0);
		}
		LA7_: ;
	}
	goto LA3_;
	LA5_: ;
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T105_;
			tyArray__f7nG5LD47BH5K9c6mASit3g T106_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
			if (!(((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0)) goto LA103_;
			T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T105_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T106_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
			T106_[1] = pl;
			T106_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
			T106_[3] = rawProc;
			T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T107_ = percent___8bHx2qDxS2yWIId1X52mqg(T106_, 4);
			T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T108_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T107_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T105_, T108_);
		}
		goto LA101_;
		LA103_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T110_;
			tyArray__f7nG5LD47BH5K9c6mASit3g T111_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
			T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T110_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T111_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T111_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
			T111_[1] = pl;
			T111_[2] = addComma__WAlh7NpO6KFA22Kxnp9aoaw(pl);
			T111_[3] = rawProc;
			T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T112_ = percent___kTDR7D9c9aomjcaUQOmKJ9csg(T111_, 4);
			T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T113_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T112_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T110_, T113_);
		}
		LA101_: ;
		{
			if (!canRaise) goto LA116_;
			raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
		}
		LA116_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddrDeref__vMC9cau6W2PcQ0Z0zO9cDXMA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* node) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NIM_BOOL isAddr;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	n = node;
	isAddr = NIM_FALSE;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		n = (*n)._kind_6.sons->data[((NI) 0)];
		isAddr = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		n = (*n)._kind_6.sons->data[((NI) 0)];
	}
	break;
	default:
	{
		result = n;
		goto BeforeRet_;
	}
	break;
	}
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66))) goto LA6_;
		n = (*n)._kind_6.sons->data[((NI) 0)];
	}
	LA6_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = isAddr;
		if (!(T10_)) goto LA11_;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA8_;
	LA12_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA15_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA8_;
	LA15_: ;
	{
		result = node;
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genThisArg__9a86z5oGsAZjkB52zPdLZJQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri_2;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NI T3_;
		NimStringDesc* argX60gensym1395_;
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		if (!!((i < T3_))) goto LA4_;
		argX60gensym1395_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_415);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1395_, TM__MQdRN7fpbG7rPm4JpVVAhA_415);
	}
	LA4_: ;
	ri_2 = (*ri)._kind_6.sons->data[i];
	{
		while (1) {
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66))) goto LA7;
			ri_2 = (*ri_2)._kind_6.sons->data[((NI) 0)];
		} LA7: ;
	}
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[i], IL64(70368744179728));
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23))) goto LA10_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA14_;
			x = (*ri_2)._kind_6.sons->data[((NI) 0)];
		}
		goto LA12_;
		LA14_: ;
		{
			x = ri_2;
		}
		LA12_: ;
		{
			if (!((*(*x).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA19_;
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, x, NIM_FALSE);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_416));
		}
		goto LA17_;
		LA19_: ;
		{
			NIM_BOOL T22_;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47));
			if (!(T22_)) goto LA23_;
			T22_ = ((*(*(*x)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
			LA23_: ;
			if (!T22_) goto LA24_;
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*x)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_416));
		}
		goto LA17_;
		LA24_: ;
		{
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, x, NIM_FALSE);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
		}
		LA17_: ;
	}
	goto LA8_;
	LA10_: ;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA28_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA32_;
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*ri_2)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
		}
		goto LA30_;
		LA32_: ;
		{
			result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, ri_2, NIM_FALSE);
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_416));
		}
		LA30_: ;
	}
	goto LA8_;
	LA28_: ;
	{
		ri_2 = skipAddrDeref__vMC9cau6W2PcQ0Z0zO9cDXMA(ri_2);
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA38_;
			ri_2 = (*ri_2)._kind_6.sons->data[((NI) 0)];
		}
		LA38_: ;
		result = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, ri_2, NIM_FALSE);
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genPatternCall__n9aN0vqKCBL7B9cV6pjBnGNg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, NimStringDesc* pat, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI i;
	NI j;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	i = ((NI) 0);
	j = ((NI) 1);
	{
		while (1) {
			if (!(i < (pat ? pat->Sup.len : 0))) goto LA2;
			switch (((NU8)(pat->data[i]))) {
			case 64:
			{
				NIM_BOOL first;
				first = NIM_TRUE;
				{
					NI k;
					NI colontmp_;
					NI i_2;
					k = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
					i_2 = j;
					{
						while (1) {
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* arg;
							if (!(i_2 < colontmp_)) goto LA6;
							k = i_2;
							arg = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, ri, k, typ);
							{
								NI T9_;
								T9_ = (NI)0;
								T9_ = len__9b0YRltzV3kNSE9aQTsG82wg(arg);
								if (!(((NI) 0) < T9_)) goto LA10_;
								{
									tyArray__qTjAvTvKF9anytN1At69aJMQ T16_;
									tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
									if (!!(first)) goto LA14_;
									nimZeroMem((void*)T16_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
									T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
									T17_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T16_, 0);
									add__IM4kcMNkkOLJtqdEqSxR8A(&result, T17_);
								}
								LA14_: ;
								first = NIM_FALSE;
								add__IM4kcMNkkOLJtqdEqSxR8A(&result, arg);
							}
							LA10_: ;
							i_2 += ((NI) 1);
						} LA6: ;
					}
				}
				i += ((NI) 1);
			}
			break;
			case 35:
			{
				{
					NIM_BOOL T21_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri_2;
					T21_ = (NIM_BOOL)0;
					T21_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T21_)) goto LA22_;
					T21_ = (((NU8)(pat->data[(NI)(i + ((NI) 1))])) == ((NU8)(43)) || ((NU8)(pat->data[(NI)(i + ((NI) 1))])) == ((NU8)(64)));
					LA22_: ;
					if (!T21_) goto LA23_;
					ri_2 = (*ri)._kind_6.sons->data[j];
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T34_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T48_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
						if (!((*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*ri_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA27_;
						typ_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri_2)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
							if (!((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(43))) goto LA31_;
							T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T33_ = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, (*ri_2)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
							add__IM4kcMNkkOLJtqdEqSxR8A(&result, T33_);
						}
						LA31_: ;
						nimZeroMem((void*)T34_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T35_ = percent___uFJUSitn9c1Tw6cF9cZf6x6Q(T34_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T35_);
						{
							NI T38_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
							T38_ = (NI)0;
							T38_ = len__P89cqdlERShb9alU3iC0yj8wast(ri_2);
							if (!(((NI) 1) < T38_)) goto LA39_;
							T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T41_ = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, ri_2, ((NI) 1), typ_2);
							add__IM4kcMNkkOLJtqdEqSxR8A(&result, T41_);
						}
						LA39_: ;
						{
							NI k_2;
							NI colontmp__2;
							NI colontmp__3;
							NI i_3;
							k_2 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__2 = (NI)(j + ((NI) 1));
							colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(ri_2);
							i_3 = colontmp__2;
							{
								while (1) {
									tyArray__qTjAvTvKF9anytN1At69aJMQ T45_;
									tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
									tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
									if (!(i_3 < colontmp__3)) goto LA44;
									k_2 = i_3;
									nimZeroMem((void*)T45_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
									T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
									T46_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T45_, 0);
									add__IM4kcMNkkOLJtqdEqSxR8A(&result, T46_);
									T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
									T47_ = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, ri_2, k_2, typ_2);
									add__IM4kcMNkkOLJtqdEqSxR8A(&result, T47_);
									i_3 += ((NI) 1);
								} LA44: ;
							}
						}
						nimZeroMem((void*)T48_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T49_ = percent___G8iCcDovsaw25PkF7wHs0g(T48_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T49_);
					}
					goto LA25_;
					LA27_: ;
					{
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*ri_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_413), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_414, NIM_FALSE);
					}
					LA25_: ;
					i += ((NI) 1);
				}
				goto LA19_;
				LA23_: ;
				{
					NIM_BOOL T52_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
					T52_ = (NIM_BOOL)0;
					T52_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T52_)) goto LA53_;
					T52_ = ((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(46));
					LA53_: ;
					if (!T52_) goto LA54_;
					T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T56_ = genThisArg__9a86z5oGsAZjkB52zPdLZJQ_2(p, ri, j, typ);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T56_);
					i += ((NI) 1);
				}
				goto LA19_;
				LA54_: ;
				{
					NIM_BOOL T58_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
					T58_ = (NIM_BOOL)0;
					T58_ = ((NI)(i + ((NI) 1)) < (pat ? pat->Sup.len : 0));
					if (!(T58_)) goto LA59_;
					T58_ = ((NU8)(pat->data[(NI)(i + ((NI) 1))]) == (NU8)(91));
					LA59_: ;
					if (!T58_) goto LA60_;
					arg_2 = skipAddrDeref__vMC9cau6W2PcQ0Z0zO9cDXMA((*ri)._kind_6.sons->data[j]);
					{
						while (1) {
							if (!((*arg_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*arg_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64) || (*arg_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66))) goto LA63;
							arg_2 = (*arg_2)._kind_6.sons->data[((NI) 0)];
						} LA63: ;
					}
					T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T64_ = genArgNoParam__idr0athfhAF2aTg9arX9bWAg(p, arg_2, NIM_FALSE);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T64_);
				}
				goto LA19_;
				LA60_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
					T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T66_ = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, ri, j, typ);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T66_);
				}
				LA19_: ;
				j += ((NI) 1);
				i += ((NI) 1);
			}
			break;
			case 39:
			{
				NI idx;
				NI stars;
				idx = (NI)0;
				stars = (NI)0;
				{
					NIM_BOOL T70_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
					T70_ = (NIM_BOOL)0;
					T70_ = scanCppGenericSlot__YRbO0Zq30XmyAQjpf1Mi6g(pat, (&i), (&idx), (&stars));
					if (!T70_) goto LA71_;
					t = resolveStarsInCppType__dTa9cSuyNlFVdzNe1dV0rag(typ, idx, stars);
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T77_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
						if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA75_;
						nimZeroMem((void*)T77_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T78_ = percent___G9aA37gQrW88KHzpCAwhgjQ(T77_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T78_);
					}
					goto LA73_;
					LA75_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T80_;
						T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T80_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, T80_);
					}
					LA73_: ;
				}
				LA71_: ;
			}
			break;
			default:
			{
				NI start;
				start = i;
				{
					while (1) {
						if (!(i < (pat ? pat->Sup.len : 0))) goto LA83;
						{
							if (!!((((NU8)(pat->data[i])) == ((NU8)(64)) || ((NU8)(pat->data[i])) == ((NU8)(35)) || ((NU8)(pat->data[i])) == ((NU8)(39))))) goto LA86_;
							i += ((NI) 1);
						}
						goto LA84_;
						LA86_: ;
						{
							goto LA82;
						}
						LA84_: ;
					} LA83: ;
				} LA82: ;
				{
					NimStringDesc* T93_;
					if (!(start <= (NI)(i - ((NI) 1)))) goto LA91_;
					T93_ = (NimStringDesc*)0;
					T93_ = substr__2yh9cer0ymNRHlOOg8P7IuA(pat, start, (NI)(i - ((NI) 1)));
					add__yG4AKzsBRS1W4MANDlXQeg(&result, T93_);
				}
				LA91_: ;
			}
			break;
			}
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__17YlQRjV7sYeIVr87qv2GA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* value) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	(*p).labels += ((NI) 1);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___Z7W1o5nPSc3ExfO5f7j1Gg(T2_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3)));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T4_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*result).r);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), value);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA7_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA7_: ;
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T9_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T10_);
	(*result).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1);
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(t));
	(*result).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__5AieZFwkpMkLKPnkORd7Cw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* callee, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params) {
	NIM_BOOL canRaise;
	NIM_BOOL T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pl;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3));
	if (!(T1_)) goto LA2_;
	T1_ = canRaiseDisp__Y9bFh7BmZkh729bS2kZ5kwnQ(p, (*ri)._kind_6.sons->data[((NI) 0)]);
	LA2_: ;
	canRaise = T1_;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, ri);
	nimZeroMem((void*)T3_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = percent___uFJUSitn9c1Tw6cF9cZf6x6Q(T3_, 0);
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(callee, T4_);
	pl = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T5_, params);
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*(*p).module).g).config, (*typ).sons->data[((NI) 0)]);
			if (!T12_) goto LA13_;
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T19_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
				if (!!((params == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA17_;
				nimZeroMem((void*)T19_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T20_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T19_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T20_);
			}
			LA17_: ;
			{
				NIM_BOOL T23_;
				NIM_BOOL T25_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T39_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
				T23_ = (NIM_BOOL)0;
				T23_ = ((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0);
				if (T23_) goto LA24_;
				T25_ = (NIM_BOOL)0;
				T25_ = preventNrvo__VzIhhB7jFivZ9c6NgOwxU1Q(p, le, ri);
				T23_ = !(T25_);
				LA24_: ;
				if (!T23_) goto LA26_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA30_;
					getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				goto LA28_;
				LA30_: ;
				{
					NIM_BOOL T33_;
					NIM_BOOL T35_;
					T33_ = (NIM_BOOL)0;
					T33_ = !(((2 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
					if (!(T33_)) goto LA34_;
					T35_ = (NIM_BOOL)0;
					T35_ = hasNoInit__XO14mevzEVVwQTyfj9cMewwcgen(ri);
					T33_ = !(T35_);
					LA34_: ;
					if (!T33_) goto LA36_;
				}
				goto LA28_;
				LA36_: ;
				LA28_: ;
				T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T38_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*d));
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T38_);
				nimZeroMem((void*)T39_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T40_ = percent___bhkFYKbURxGcJnKpswdr2Q(T39_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T40_);
				T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T42_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
				add__IM4kcMNkkOLJtqdEqSxR8A(T41_, T42_);
			}
			goto LA21_;
			LA26_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T45_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T44_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmp);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T44_);
				nimZeroMem((void*)T45_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T46_ = percent___bhkFYKbURxGcJnKpswdr2Q(T45_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T46_);
				T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T47_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T48_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
				add__IM4kcMNkkOLJtqdEqSxR8A(T47_, T48_);
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
			}
			LA21_: ;
			{
				if (!canRaise) goto LA51_;
				raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
			}
			LA51_: ;
		}
		goto LA10_;
		LA13_: ;
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T54_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T55_;
			nimZeroMem((void*)T54_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T55_ = percent___G8iCcDovsaw25PkF7wHs0g(T54_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T55_);
			{
				NIM_BOOL T58_;
				T58_ = (NIM_BOOL)0;
				T58_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T58_) goto LA59_;
				T58_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA59_: ;
				if (!T58_) goto LA60_;
				{
					if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8))&15U)))!=0)) goto LA64_;
					(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9);
					unsureAsgnRef((void**) (&(*d).r), pl);
					(*d).flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8)) & 15));
				}
				goto LA62_;
				LA64_: ;
				{
					{
						NIM_BOOL T69_;
						T69_ = (NIM_BOOL)0;
						T69_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
						if (!(T69_)) goto LA70_;
						T69_ = ((*p).splitDecls == ((NI) 0));
						LA70_: ;
						if (!T69_) goto LA71_;
						getTempCpp__17YlQRjV7sYeIVr87qv2GA(p, (*typ).sons->data[((NI) 0)], d, pl);
					}
					goto LA67_;
					LA71_: ;
					{
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list;
						{
							if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA76_;
							getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
						}
						LA76_: ;
						nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						initLoc__qlujIAW86QclHYUVxlHRiQ((&list), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
						list.r = pl;
						genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), list, 0);
						{
							if (!canRaise) goto LA80_;
							raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
						}
						LA80_: ;
					}
					LA67_: ;
				}
				LA62_: ;
			}
			goto LA56_;
			LA60_: ;
			{
				NIM_BOOL T83_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list_2;
				T83_ = (NIM_BOOL)0;
				T83_ = isHarmlessStore__4h2Oud7u5jWCpkY1i8QUDg(p, canRaise, (*d));
				if (!T83_) goto LA84_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA88_;
					getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
				}
				LA88_: ;
				nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLoc__qlujIAW86QclHYUVxlHRiQ((&list_2), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				list_2.r = pl;
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), list_2, 0);
				{
					if (!canRaise) goto LA92_;
					raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
				}
				LA92_: ;
			}
			goto LA56_;
			LA84_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp_2;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list_3;
				nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], (&tmp_2), NIM_TRUE);
				nimZeroMem((void*)(&list_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLoc__qlujIAW86QclHYUVxlHRiQ((&list_3), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				list_3.r = pl;
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmp_2, list_3, 0);
				{
					if (!canRaise) goto LA97_;
					raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
				}
				LA97_: ;
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp_2, 0);
			}
			LA56_: ;
		}
		LA10_: ;
	}
	goto LA6_;
	LA8_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T100_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T102_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
		nimZeroMem((void*)T100_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T101_ = percent___bhkFYKbURxGcJnKpswdr2Q(T100_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T101_);
		T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T102_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T103_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
		add__IM4kcMNkkOLJtqdEqSxR8A(T102_, T103_);
		{
			if (!canRaise) goto LA106_;
			raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
		}
		LA106_: ;
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__HKkL9adNEIcNHeJ0iZ6uitg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA op;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	NimStringDesc* pat;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	pat = (*(*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).loc.r).data;
	{
		NimStringDesc* argX60gensym1440_;
		if (!!((((NI) 0) < (pat ? pat->Sup.len : 0)))) goto LA3_;
		argX60gensym1440_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_411);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1440_, TM__MQdRN7fpbG7rPm4JpVVAhA_411);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pl;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
		T7_ = (NIM_BOOL)0;
		T7_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ(pat, TM__MQdRN7fpbG7rPm4JpVVAhA_412);
		if (!T7_) goto LA8_;
		pl = genPatternCall__n9aN0vqKCBL7B9cV6pjBnGNg(p, ri, pat, typ);
		typ_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		{
			if (!!(((*typ_2).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA12_;
			{
				NIM_BOOL T16_;
				NIM_BOOL T17_;
				T16_ = (NIM_BOOL)0;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T17_) goto LA18_;
				T17_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA18_: ;
				T16_ = T17_;
				if (!(T16_)) goto LA19_;
				T16_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8))&15U)))!=0);
				LA19_: ;
				if (!T16_) goto LA20_;
				(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9);
				unsureAsgnRef((void**) (&(*d).r), pl);
				(*d).flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 8)) & 15));
			}
			goto LA14_;
			LA20_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list;
				{
					if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA25_;
					getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ_2).sons->data[((NI) 0)], d, NIM_FALSE);
				}
				LA25_: ;
				nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLoc__qlujIAW86QclHYUVxlHRiQ((&list), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), (*d).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				list.r = pl;
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), list, 0);
			}
			LA14_: ;
		}
		goto LA10_;
		LA12_: ;
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			nimZeroMem((void*)T28_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = percent___SY4U2QvmoQxocaG8MOmyHA(T28_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T29_);
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T30_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
			add__IM4kcMNkkOLJtqdEqSxR8A(T30_, T31_);
		}
		LA10_: ;
	}
	goto LA5_;
	LA8_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pl_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
		pl_2 = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		{
			NI T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			T35_ = (NI)0;
			T35_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			if (!(((NI) 1) < T35_)) goto LA36_;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = genThisArg__9a86z5oGsAZjkB52zPdLZJQ_2(p, ri, ((NI) 1), typ);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl_2, T38_);
		}
		LA36_: ;
		add__IM4kcMNkkOLJtqdEqSxR8A(&pl_2, op.r);
		params = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			i_2 = ((NI) 2);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
					if (!(i_2 < colontmp_)) goto LA41;
					i = i_2;
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T46_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
						if (!!((params == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA44_;
						nimZeroMem((void*)T46_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T47_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T46_, 0);
						add__IM4kcMNkkOLJtqdEqSxR8A(&params, T47_);
					}
					LA44_: ;
					T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T48_ = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, ri, i, typ);
					add__IM4kcMNkkOLJtqdEqSxR8A(&params, T48_);
					i_2 += ((NI) 1);
				} LA41: ;
			}
		}
		fixupCall__5AieZFwkpMkLKPnkORd7Cw(p, le, ri, d, pl_2, params);
	}
	LA5_: ;
}
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__31wM5Ui9c8jnrQ5QD4oPxOQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__9azKdI6vAayTOFEcJtCTo1g)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA op;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* pl;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	NimStringDesc* pat;
	NI start;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	nimZeroMem((void*)T1_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	pl = percent___lTsL0bi6njxzDh9c8A32r2w(T1_, 0);
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	pat = (*(*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).loc.r).data;
	{
		NimStringDesc* argX60gensym1469_;
		if (!!((((NI) 0) < (pat ? pat->Sup.len : 0)))) goto LA4_;
		argX60gensym1469_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_417);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1469_, TM__MQdRN7fpbG7rPm4JpVVAhA_417);
	}
	LA4_: ;
	start = ((NI) 3);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(pat->data, (pat ? pat->Sup.len : 0), 32);
		if (!T8_) goto LA9_;
		start = ((NI) 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&pl, op.r);
		{
			NI T13_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			if (!(((NI) 1) < T13_)) goto LA14_;
			nimZeroMem((void*)T16_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = percent___k4VEB3kaBL72FRQN8buzSg(T16_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T17_);
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = genArg__NyG7NHKT5F2mihfTt1JRVA(p, (*ri)._kind_6.sons->data[((NI) 1)], (*(*(*typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym, ri, NIM_FALSE);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T18_);
			start = ((NI) 2);
		}
		LA14_: ;
	}
	goto LA6_;
	LA9_: ;
	{
		{
			NI T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			T22_ = (NI)0;
			T22_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			if (!(((NI) 1) < T22_)) goto LA23_;
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = genArg__NyG7NHKT5F2mihfTt1JRVA(p, (*ri)._kind_6.sons->data[((NI) 1)], (*(*(*typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym, ri, NIM_FALSE);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T25_);
			nimZeroMem((void*)T26_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = percent___gMbiWAc0IjihIq46IYhmAw(T26_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T27_);
		}
		LA23_: ;
		add__IM4kcMNkkOLJtqdEqSxR8A(&pl, op.r);
		{
			NI T30_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			T30_ = (NI)0;
			T30_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
			if (!(((NI) 2) < T30_)) goto LA31_;
			nimZeroMem((void*)T33_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = percent___k4VEB3kaBL72FRQN8buzSg(T33_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T34_);
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = genArg__NyG7NHKT5F2mihfTt1JRVA(p, (*ri)._kind_6.sons->data[((NI) 2)], (*(*(*typ).n)._kind_6.sons->data[((NI) 2)])._kind_4.sym, ri, NIM_FALSE);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T35_);
		}
		LA31_: ;
	}
	LA6_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
		i_2 = start;
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T44_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T46_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
				if (!(i_2 < colontmp_)) goto LA38;
				i = i_2;
				{
					NI T41_;
					T41_ = (NI)0;
					T41_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
					if (!(T41_ <= i)) goto LA42_;
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*ri).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_418), TM__MQdRN7fpbG7rPm4JpVVAhA_419);
				}
				LA42_: ;
				param = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
				nimZeroMem((void*)T44_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T45_ = percent___gMbiWAc0IjihIq46IYhmAw(T44_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T45_);
				add__yG4AKzsBRS1W4MANDlXQeg(&pl, (*(*param).name).s);
				nimZeroMem((void*)T46_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T47_ = percent___k4VEB3kaBL72FRQN8buzSg(T46_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T47_);
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T48_ = genArg__NyG7NHKT5F2mihfTt1JRVA(p, (*ri)._kind_6.sons->data[i], param, ri, NIM_FALSE);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T48_);
				i_2 += ((NI) 1);
			} LA38: ;
		}
	}
	{
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA51_;
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = isInvalidReturnType__ugBeCbo3I6LqXHcpCBFN9ag((*(*(*p).module).g).config, (*typ).sons->data[((NI) 0)]);
			if (!T55_) goto LA56_;
			{
				NI T60_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
				T60_ = (NI)0;
				T60_ = len__P89cqdlERShb9alU3iC0yj8wast(ri);
				if (!(((NI) 1) < T60_)) goto LA61_;
				nimZeroMem((void*)T63_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T64_ = percent___gMbiWAc0IjihIq46IYhmAw(T63_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T64_);
			}
			LA61_: ;
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T73_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T76_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T78_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
				if (!((3 &((NU16)1<<((NU)((*d).k)&15U)))!=0)) goto LA67_;
				{
					if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA71_;
					getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_TRUE);
				}
				LA71_: ;
				nimZeroMem((void*)T73_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T74_ = percent___YbQIA9cHUESCyYT1WEeIVbA(T73_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T74_);
				T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T75_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*d));
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T75_);
				nimZeroMem((void*)T76_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T77_ = percent___66KauNYQRukYNgmb6bVXEA(T76_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T77_);
				T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T78_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T79_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
				add__IM4kcMNkkOLJtqdEqSxR8A(T78_, T79_);
			}
			goto LA65_;
			LA67_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T82_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T84_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
				nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], (&tmp), NIM_TRUE);
				T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T81_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmp);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T81_);
				nimZeroMem((void*)T82_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T83_ = percent___66KauNYQRukYNgmb6bVXEA(T82_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T83_);
				T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T84_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T85_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
				add__IM4kcMNkkOLJtqdEqSxR8A(T84_, T85_);
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
			}
			LA65_: ;
		}
		goto LA53_;
		LA56_: ;
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T87_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T88_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA list;
			nimZeroMem((void*)T87_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T88_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T88_ = percent___S550SlHmWbDpD7rs0J2lrA(T87_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T88_);
			{
				if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA91_;
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*typ).sons->data[((NI) 0)], d, NIM_FALSE);
			}
			LA91_: ;
			nimZeroMem((void*)(&list), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&list), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), ri, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			list.r = pl;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), list, 0);
		}
		LA53_: ;
	}
	goto LA49_;
	LA51_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T94_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T96_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
		nimZeroMem((void*)T94_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T95_ = percent___66KauNYQRukYNgmb6bVXEA(T94_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&pl, T95_);
		T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T96_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T97_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, pl);
		add__IM4kcMNkkOLJtqdEqSxR8A(T96_, T97_);
	}
	LA49_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__HKkL9adNEIcNHeJ0iZ6uitg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA op;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* callee;
	nimZeroMem((void*)(&op), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*ri)._kind_6.sons->data[((NI) 0)], (&op));
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	params = genParams__KMtRYhmblciqOHa6LfFLDw(p, ri, typ);
	callee = rdLoc__xidyzuHqIciXbQyEOKahDg(op);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		addActualSuffixForHCR__Mns9bHWQy2Dza12fE8Mjw9aw(&callee, (*(*p).module).module, (*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	}
	LA5_: ;
	fixupCall__5AieZFwkpMkLKPnkORd7Cw(p, le, ri, d, callee, params);
}
static N_INLINE(void, postStmtActions__hU2pQ4yYkske4uOCGEGfMwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T1_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	add__IM4kcMNkkOLJtqdEqSxR8A(T1_, (*(*p).module).injectStmt);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__HKkL9adNEIcNHeJ0iZ6uitg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*p).withinBlockLeaveActions);
		if (!(T3_)) goto LA4_;
		T3_ = isInactiveDestructorCall__iRZAnpxF4CwuSQ4C7wQilQ(p, ri);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
		T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*ri)._kind_6.sons->data[((NI) 0)]).typ, IL64(105553116268560));
		if (!((*T9_).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA10_;
		genClosureCall__HKkL9adNEIcNHeJ0iZ6uitg_2(p, le, ri, d);
	}
	goto LA7_;
	LA10_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T13_)) goto LA14_;
		T13_ = (((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA14_: ;
		if (!T13_) goto LA15_;
		genInfixCall__HKkL9adNEIcNHeJ0iZ6uitg_3(p, le, ri, d);
	}
	goto LA7_;
	LA15_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T18_)) goto LA19_;
		T18_ = (((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 32))&63U)))!=0);
		LA19_: ;
		if (!T18_) goto LA20_;
		genNamedParamCall__9azKdI6vAayTOFEcJtCTo1g(p, ri, d);
	}
	goto LA7_;
	LA20_: ;
	{
		genPrefixCall__HKkL9adNEIcNHeJ0iZ6uitg_4(p, le, ri, d);
	}
	LA7_: ;
	postStmtActions__hU2pQ4yYkske4uOCGEGfMwcgen(p);
	}BeforeRet_: ;
}
static N_INLINE(void, loadInto__vkEx8Dn9aiGOI04WjvQIHIwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*ri)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		if (T5_) goto LA6_;
		T5_ = ((*(*(*ri)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		genAsgnCall__HKkL9adNEIcNHeJ0iZ6uitg(p, le, ri, a);
	}
	goto LA1_;
	LA7_: ;
	{
		(*a).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9)) & 15);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, ri, a);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__T7FeUoHVfLrGm0JydrFabA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value) {
	tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* targetProc;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* traverseProc;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* valueAsRope;
	NIM_BOOL forHcr;
{	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0)) goto LA3_;
		genGotoVar__4xOIY9bgIMy9bAzg2ZyIieBw(p, value);
		goto BeforeRet_;
	}
	LA3_: ;
	targetProc = p;
	traverseProc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	valueAsRope = potentialValueInit__ZPEw9bE7bf9b89ciOwNlnaiIg(p, v, value);
	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0)) goto LA7_;
		{
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = (((*v).flags & 192) == 64);
			if (!(T12_)) goto LA13_;
			T12_ = ((*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA14_;
			T11_ = !((((*v).loc.flags & 72) == 0));
			LA14_: ;
			if (!T11_) goto LA15_;
			goto BeforeRet_;
		}
		LA15_: ;
		{
			if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0)) goto LA19_;
			targetProc = (*(*p).module).preInitProc;
		}
		LA19_: ;
		assignGlobalVar__yX9bZpeKIzp3RLrjnzlc0NQ(targetProc, vn, valueAsRope);
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
			if (!(valueAsRope == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA23_;
			nimZeroMem((void*)(&loc), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			genericAssign((void*)(&loc), (void*)(&(*v).loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
			{
				NIM_BOOL T27_;
				NIM_BOOL T28_;
				T27_ = (NIM_BOOL)0;
				T28_ = (NIM_BOOL)0;
				T28_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0);
				if (!(T28_)) goto LA29_;
				T28_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*(*p).module).g).config);
				LA29_: ;
				T27_ = T28_;
				if (!(T27_)) goto LA30_;
				T27_ = isComplexValueType__Fl17jclCP5VEr9a7Ycym1awcgen((*v).typ);
				LA30_: ;
				if (!T27_) goto LA31_;
				initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw((*(*p).module).preInitProc, vn, (&loc));
			}
			LA31_: ;
			genObjectInit__UANnSFbuKD1BS6RrMbZs2A((*(*p).module).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*v).typ, (&loc), ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0));
		}
		LA23_: ;
		{
			NIM_BOOL T35_;
			T35_ = (NIM_BOOL)0;
			T35_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7))&63U)))!=0);
			if (!(T35_)) goto LA36_;
			T35_ = !(((*(*(*p).module).g).generatedHeader == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)));
			LA36_: ;
			if (!T35_) goto LA37_;
			genVarPrototype__t9a9a9bxmaOztYOfsfhQUOXXw_2((*(*(*p).module).g).generatedHeader, vn);
		}
		LA37_: ;
		traverseProc = getTraverseProc__V1atRcoAv09bVdrCPNlvW8Q(p, v);
		{
			NIM_BOOL T41_;
			NIM_BOOL T43_;
			T41_ = (NIM_BOOL)0;
			T41_ = !((traverseProc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
			if (!(T41_)) goto LA42_;
			T43_ = (NIM_BOOL)0;
			T43_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
			T41_ = !(T43_);
			LA42_: ;
			if (!T41_) goto LA44_;
			registerTraverseProc__BwxixSWhJWbQ369cJZeckHA(p, v, traverseProc);
		}
		LA44_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		NIM_BOOL imm;
		imm = isAssignedImmediately__udBNoPxZaHjsWUNp37jAdwcgen((*(*(*p).module).g).config, value);
		{
			NIM_BOOL T49_;
			NIM_BOOL T50_;
			NIM_BOOL T51_;
			NIM_BOOL T53_;
			NIM_BOOL T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* decl;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
			T49_ = (NIM_BOOL)0;
			T50_ = (NIM_BOOL)0;
			T51_ = (NIM_BOOL)0;
			T51_ = imm;
			if (!(T51_)) goto LA52_;
			T53_ = (NIM_BOOL)0;
			T53_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T53_) goto LA54_;
			T53_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA54_: ;
			T51_ = T53_;
			LA52_: ;
			T50_ = T51_;
			if (!(T50_)) goto LA55_;
			T50_ = ((*p).splitDecls == ((NI) 0));
			LA55_: ;
			T49_ = T50_;
			if (!(T49_)) goto LA56_;
			T57_ = (NIM_BOOL)0;
			T57_ = containsHiddenPointer__IVXYI9cxSeivThgKCncHRnA_5((*v).typ);
			T49_ = !(T57_);
			LA56_: ;
			if (!T49_) goto LA58_;
			genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, vn);
			decl = localVarDecl__NYI5fC69aIqZGRakncXv9cNQ(p, vn);
			nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			{
				NIM_BOOL T62_;
				NIM_BOOL T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* params;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
				T62_ = (NIM_BOOL)0;
				T63_ = (NIM_BOOL)0;
				T63_ = ((*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
				if (!(T63_)) goto LA64_;
				T63_ = ((*(*value)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				LA64_: ;
				T62_ = T63_;
				if (!(T62_)) goto LA65_;
				T62_ = (((*(*(*value)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 28))&63U)))!=0);
				LA65_: ;
				if (!T62_) goto LA66_;
				params = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*value)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(value);
					i_2 = ((NI) 1);
					{
						while (1) {
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
							if (!(i_2 < colontmp_)) goto LA70;
							i = i_2;
							{
								tyArray__qTjAvTvKF9anytN1At69aJMQ T75_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
								if (!!((params == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA73_;
								nimZeroMem((void*)T75_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
								T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T76_ = percent___PoDv5ydEvGdd9aiIF9cOiAPw(T75_, 0);
								add__IM4kcMNkkOLJtqdEqSxR8A(&params, T76_);
							}
							LA73_: ;
							T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T77_ = genOtherArg__9a86z5oGsAZjkB52zPdLZJQ(p, value, i, typ);
							add__IM4kcMNkkOLJtqdEqSxR8A(&params, T77_);
							i_2 += ((NI) 1);
						} LA70: ;
					}
				}
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T82_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T83_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
					if (!(params == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA80_;
					T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T82_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T83_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T83_[0] = decl;
					T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T84_ = percent___boICAAvO1zkTlYDOuEaj6g(T83_, 1);
					T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T85_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T84_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T82_, T85_);
				}
				goto LA78_;
				LA80_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T87_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T88_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T89_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
					T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T87_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T88_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T88_[0] = decl;
					T88_[1] = params;
					T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T89_ = percent___LeuvM3mIc6pSNktpm9cHSVw(T88_, 2);
					T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T90_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T89_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T87_, T90_);
				}
				LA78_: ;
			}
			goto LA60_;
			LA66_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T92_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T93_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
				initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, value, (&tmp));
				T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T92_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T93_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T93_[0] = decl;
				T93_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
				T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T94_ = percent___mxQQ2vwZhwfDagj5SEXeHA(T93_, 2);
				T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T95_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T94_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T92_, T95_);
			}
			LA60_: ;
			goto BeforeRet_;
		}
		LA58_: ;
		assignLocalVar__UtJx89cn0a8CNSWWmaj6raA(p, vn);
		initLocalVar__EpeofNfMJPurx0duaALCaA(p, v, imm);
	}
	LA5_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T100_;
		if (!(traverseProc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA98_;
		nimZeroMem((void*)T100_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		traverseProc = percent___x2NKZw9brJpylbwEtLfx9a9bg(T100_, 0);
	}
	LA98_: ;
	forHcr = treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw((*p).module, v);
	{
		NIM_BOOL T103_;
		NIM_BOOL T104_;
		NI T106_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T110_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T118_;
		T103_ = (NIM_BOOL)0;
		T104_ = (NIM_BOOL)0;
		T104_ = forHcr;
		if (!(T104_)) goto LA105_;
		T106_ = ((*targetProc).blocks ? (*targetProc).blocks->Sup.len : 0);
		T104_ = (((NI) 3) < T106_);
		LA105_: ;
		T103_ = T104_;
		if (!(T103_)) goto LA107_;
		T103_ = ((*(*v).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
		LA107_: ;
		if (!T103_) goto LA108_;
		T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T110_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(targetProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_377));
		T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T111_ = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3((*p).module, v);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T111_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_378));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*v).loc.r);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_379));
		T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T112_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*v).loc);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T112_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_380));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), traverseProc);
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_381));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*v).loc.r);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*targetProc).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA115_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA115_: ;
		T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T117_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T118_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T118_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(targetProc, T117_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T110_, T118_);
		forHcr = NIM_FALSE;
	}
	LA108_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T123_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T124_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T125_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T126_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T127_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T128_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T133_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T134_;
		NI T135_;
		if (!forHcr) goto LA121_;
		T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T123_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(targetProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 22);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_382));
		T124_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T124_ = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3((*p).module, v);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T124_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_378));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*v).loc.r);
		res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_379));
		T125_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T125_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*v).loc);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T125_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_380));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), traverseProc);
		res_2 = resizeString(res_2, 11);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_381));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*v).loc.r);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_383));
		T126_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T126_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T127_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T127_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(targetProc, T126_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T123_, T127_);
		T128_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T128_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(targetProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*targetProc).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA131_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA131_: ;
		T133_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T133_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T134_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T134_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(targetProc, T133_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T128_, T134_);
		T135_ = (NI)0;
		T135_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(targetProc);
	}
	LA121_: ;
	{
		NIM_BOOL T138_;
		T138_ = (NIM_BOOL)0;
		T138_ = !(((*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		if (!(T138_)) goto LA139_;
		T138_ = (valueAsRope == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
		LA139_: ;
		if (!T138_) goto LA140_;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(targetProc, vn);
		loadInto__vkEx8Dn9aiGOI04WjvQIHIwcgen(targetProc, vn, value, (&(*v).loc));
	}
	LA140_: ;
	{
		if (!forHcr) goto LA144_;
		endBlock__0dpuY9coTlraj8JXIe2BzVw(targetProc);
	}
	LA144_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__fYECstGN5jPehhn5p8Iclg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA3_;
		initLoc__qlujIAW86QclHYUVxlHRiQ((&a), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 8), n, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
		a.r = r;
		{
			if (!(((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 2))&15U)))!=0)) goto LA7_;
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), a, 0);
		}
		goto LA5_;
		LA7_: ;
		{
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), a, 1);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 8);
		unsureAsgnRef((void**) (&(*d).lode), n);
		unsureAsgnRef((void**) (&(*d).r), r);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getLabel__3AsTOpq9crZUYBL9aD1lXBng_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	(*p).labels += ((NI) 1);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T1_);
	result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T2_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* labl) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T1_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T2_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T2_[0] = labl;
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___ZpwWwpfBXgcQ6xoLOH4CJw(T2_, 1);
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T3_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T1_, T4_);
}
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__yX5yxw6c9agMF4ZvIHKAZvg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* L;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	L = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, (&tmp), NIM_FALSE);
	(*p).splitDecls += ((NI) 1);
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
	L = getLabel__3AsTOpq9crZUYBL9aD1lXBng_5(p);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		if (!(m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T6_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
		T6_[1] = L;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___sGnLi1DjaBomQ9c9a6MOCA5g(T6_, 2);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T7_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T8_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T11_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
		T11_[1] = L;
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___bEKtSmboScaCP8PPnlOWqw(T11_, 2);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T12_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T13_);
	}
	LA1_: ;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 2)], (&tmp));
	fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, L);
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA16_;
		genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	}
	goto LA14_;
	LA16_: ;
	{
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
	}
	LA14_: ;
	(*p).splitDecls -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__TU9cJnldbmGa9bZDxaR6I4tg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	t = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350136322320));
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T2_;
		NI64 T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
		nimZeroMem((void*)T2_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T2_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T3_ = (NI64)0;
		T3_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T2_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T3_ * IL64(8)));
		T2_[2] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T4_ = percent___GHW5yjG8N9c2BQBun6aBJzQ(T2_, 3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T4_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 97):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T6_;
		NI64 T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		nimZeroMem((void*)T6_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T6_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T7_ = (NI64)0;
		T7_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T6_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T7_ * IL64(8)));
		T6_[2] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T6_, 3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 98):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T10_;
		NI64 T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)T10_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T10_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T11_ = (NI64)0;
		T11_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T10_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T11_ * IL64(8)));
		T10_[2] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___Yup67SPGRVcwMdmZwc9cSag(T10_, 3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T12_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 99):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T14_;
		NI64 T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		nimZeroMem((void*)T14_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T14_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T15_ = (NI64)0;
		T15_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T14_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T15_ * IL64(8)));
		T14_[2] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T14_, 3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T16_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 100):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T18_;
		NI64 T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		nimZeroMem((void*)T18_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T18_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T19_ = (NI64)0;
		T19_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T18_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T19_ * IL64(8)));
		T18_[2] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = percent___ec65mR1N7BSL9cmUa3z9czvA(T18_, 3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	t = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350136322320));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_430));
		T7_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, t);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T7_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_432));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T16_);
	}
	LA3_: ;
	switch (m) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T18_;
		NI64 T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		nimZeroMem((void*)T18_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T18_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T19_ = (NI64)0;
		T19_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		T18_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ((NI64)(T19_ * IL64(8)));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = percent___ibyK70G44kCK9cN8nAkxyGA(T18_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 94):
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		nimZeroMem((void*)T22_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T22_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = percent___ec65mR1N7BSL9cmUa3z9czvA(T22_, 1);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T23_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 95):
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		nimZeroMem((void*)T25_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T25_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = percent___H9b69aGZGrLOiKWQdd30yQ9bg(T25_, 1);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T26_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__TU9cJnldbmGa9bZDxaR6I4tg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	NI64 s;
	NI64 k;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	NI64 T2_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
	NI64 T4_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
	NI64 T6_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	s = (NI64)0;
	k = (NI64)0;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	T2_ = (NI64)0;
	T2_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T1_);
	T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T3_ = t__XNOXh7uniWNgiq58C9bW49awcgen(b);
	T4_ = (NI64)0;
	T4_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T3_);
	s = (NI64)(((T2_ >= T4_) ? T2_ : T4_) * IL64(8));
	T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	T6_ = (NI64)0;
	T6_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T5_);
	k = (NI64)(T6_ * IL64(8));
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 53):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		nimZeroMem((void*)T8_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T8_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T8_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T8_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T8_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T8_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___Te7bvH18PbGe5siNJ9aDTTA(T8_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T9_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 54):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)T11_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T11_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T11_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T11_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T11_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T11_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___MUaBvSw0MHw3qQi9bYavAmg(T11_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T12_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 55):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		nimZeroMem((void*)T14_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T14_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T14_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T14_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T14_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T14_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = percent___bWYxjLMocXEvYgQQcC63rw(T14_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T15_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 56):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		nimZeroMem((void*)T17_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T17_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T17_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T17_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T17_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T17_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = percent___ZpcNBrQMfioSvQNxKHhu9aw(T17_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T18_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		nimZeroMem((void*)T20_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T20_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T20_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T20_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T20_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T20_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = percent___gywCjjjPZobIva6liQWNLQ(T20_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T21_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 58):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		nimZeroMem((void*)T23_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T23_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T23_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T23_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T23_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T23_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = percent___6PDHoyz05lEjxGNE0k0ikw(T23_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T24_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 59):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		nimZeroMem((void*)T26_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T26_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T26_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T26_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T26_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T26_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = percent___AXGsBlGV5DoEOwPJSl9bdJw(T26_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T27_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 60):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		nimZeroMem((void*)T29_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T29_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T29_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T29_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T29_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T29_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = percent___ygzR9aJ6oM1bZTq4Z2lNO3Q(T29_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T30_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 61):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		nimZeroMem((void*)T32_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T32_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T32_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T32_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T32_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T32_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = percent___uYVc6UX8hcaEdrHosUQAOw(T32_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T33_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 62):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		nimZeroMem((void*)T35_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T35_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T35_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T35_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T35_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T35_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = percent___AlV8xJkjCXujAUesHxezgw(T35_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T36_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 63):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T38_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
		nimZeroMem((void*)T38_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T38_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T38_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T38_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T38_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T38_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T39_ = percent___L9asecuKwevQN2h9cWzyv6oA(T38_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T39_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 64):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T41_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
		nimZeroMem((void*)T41_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T41_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T41_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T41_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T41_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T41_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T42_ = percent___nZD9cadh12dcqTFsXBHbCRg(T41_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T42_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 65):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T44_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
		nimZeroMem((void*)T44_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T44_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T44_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T44_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T44_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T44_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T45_ = percent___dz1JHdrf1p9bPB9ad2dZBtYw(T44_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T45_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T47_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
		nimZeroMem((void*)T47_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T47_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T47_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T47_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T47_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T47_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T48_ = percent___0MUu7DVBoaLHTVUZe9bKoIA(T47_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T48_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 67):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T50_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
		nimZeroMem((void*)T50_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T50_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T50_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T50_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T50_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T50_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T51_ = percent___29aIWEGnJW0wnITIeSKWfFg(T50_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T51_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 68):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		nimZeroMem((void*)T53_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T53_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T53_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T53_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T53_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T53_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = percent___n2CigWG38YNInkiL4n8g7A(T53_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T54_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 69):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		nimZeroMem((void*)T56_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T56_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T56_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T56_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T56_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T56_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = percent___bb3v9bDRLv9c9bcQzGH9c5H4Gw(T56_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T57_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 70):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T59_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
		nimZeroMem((void*)T59_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T59_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T59_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T59_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T59_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T59_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T60_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T59_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T60_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 71):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T62_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		nimZeroMem((void*)T62_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T62_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T62_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T62_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T62_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T62_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = percent___oyQkqbRkRzo43y6iRevkaA(T62_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T63_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 72):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T65_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
		nimZeroMem((void*)T65_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T65_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T65_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T65_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T65_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T65_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T66_ = percent___YuphtPwdJHG6BUJOVa9bX3w(T65_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T66_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 73):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T68_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
		nimZeroMem((void*)T68_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T68_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T68_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T68_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T68_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T68_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T69_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T68_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T69_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 74):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T71_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
		nimZeroMem((void*)T71_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T71_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T71_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T71_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T71_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T71_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T72_ = percent___oyQkqbRkRzo43y6iRevkaA(T71_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T72_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 75):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T74_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
		nimZeroMem((void*)T74_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T74_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T74_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T74_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T74_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T74_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T75_ = percent___YuphtPwdJHG6BUJOVa9bX3w(T74_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T75_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 76):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T77_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
		nimZeroMem((void*)T77_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T77_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T77_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T77_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T77_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T77_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T78_ = percent___EQxs5xa4FNWtMfcvmFZ9cMA(T77_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T78_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 77):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T80_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
		nimZeroMem((void*)T80_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T80_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T80_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T80_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T80_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T80_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T81_ = percent___5YbjRZxm0g3SrdnL73aQaw(T80_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T81_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 78):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T83_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
		nimZeroMem((void*)T83_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T83_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T83_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T83_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T83_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T83_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T84_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T83_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T84_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 79):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T86_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
		nimZeroMem((void*)T86_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T86_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T86_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T86_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T86_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T86_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T87_ = percent___oyQkqbRkRzo43y6iRevkaA(T86_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T87_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 80):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T89_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
		nimZeroMem((void*)T89_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T89_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T89_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T89_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T89_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T89_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T90_ = percent___YuphtPwdJHG6BUJOVa9bX3w(T89_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T90_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 81):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T92_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
		nimZeroMem((void*)T92_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T92_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T92_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T92_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T92_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T92_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T93_ = percent___4JrnABFfF3UTQ3nO9a6mXzQ(T92_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T93_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 82):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T95_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
		nimZeroMem((void*)T95_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T95_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T95_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T95_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T95_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T95_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T96_ = percent___bkAwkKoaz09cAQo9arQjGA0A(T95_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T96_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 83):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T98_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T99_;
		nimZeroMem((void*)T98_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T98_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T98_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T98_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T98_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T98_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T99_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T99_ = percent___7N9bV9cjVBHs9ciAhz7vgdI9aw(T98_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T99_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 84):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T101_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
		nimZeroMem((void*)T101_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T101_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T101_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T101_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T101_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T101_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T102_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T101_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T102_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 85):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T104_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T105_;
		nimZeroMem((void*)T104_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T104_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T104_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T104_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T104_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T104_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T105_ = percent___oyQkqbRkRzo43y6iRevkaA(T104_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T105_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 86):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T107_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
		nimZeroMem((void*)T107_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T107_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T107_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T107_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T107_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T107_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T108_ = percent___YuphtPwdJHG6BUJOVa9bX3w(T107_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T108_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 87):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T110_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
		nimZeroMem((void*)T110_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T110_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T110_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T110_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T110_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T110_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T111_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T110_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T111_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 88):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T113_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
		nimZeroMem((void*)T113_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T113_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T113_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T113_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T113_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T113_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T114_ = percent___oyQkqbRkRzo43y6iRevkaA(T113_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T114_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 89):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T116_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
		nimZeroMem((void*)T116_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T116_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T116_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T116_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T116_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T116_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T117_ = percent___YuphtPwdJHG6BUJOVa9bX3w(T116_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T117_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 90):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T119_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T120_;
		nimZeroMem((void*)T119_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T119_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T119_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T119_[2] = rope__KOisMGxcPhz6CcSmxgwEQQ(s);
		T119_[3] = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*e).typ);
		T119_[4] = rope__KOisMGxcPhz6CcSmxgwEQQ(k);
		T120_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T120_ = percent___QX9cU2fNK0jJrZNDQKnAycA(T119_, 5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T120_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__yX5yxw6c9agMF4ZvIHKAZvg_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		if (!!(((384 & (*p).options) == 0))) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_433));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), opr__jSXnH9c8YRRwSdXyVdSg9acA[(m)- 53]);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_435));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = getSimpleTypeDesc__jXUNYqSX189axAU8O9bJBgpA((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_433));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T9_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T14_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 7))&31U)))!=0)) goto LA12_;
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T14_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T15_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_436));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T16_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_437));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T17_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T18_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA21_: ;
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T23_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T14_, T24_);
		}
		LA12_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T29_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 8))&31U)))!=0)) goto LA27_;
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T29_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T30_);
			res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_438));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T31_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_439));
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T32_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_441));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T33_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T34_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T35_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA38_: ;
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T41_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T40_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T29_, T41_);
		}
		LA27_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		binaryArith__TU9cJnldbmGa9bZDxaR6I4tg_3(p, e, d, m);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__BKdMcfvryaJLplX0oFPcAQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T4_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T3_, IL64(36134350135273744));
		if (!((*T4_).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T7_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___vTbVjc6faJqdBrTckFLLWQ(T7_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T10_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T10_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = percent___tkJq8W3gQVDjuu9aT3THC6Q(T10_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T11_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350136322320));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* res;
		tyArray__f7nG5LD47BH5K9c6mASit3g T5_;
		if (!!((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T5_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T5_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T5_[2] = rope__yShmEg9cffWxI7s5XzEKBow(opr__UAWyVnvyQoWbplounFNlGg[(m)- 46]);
		T5_[3] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		res = percent___v4k9cDtOUzGyUHJbnJ7kQKg(T5_, 4);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, res, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* res_3;
		NI64 sizeX60gensym3619_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* storageX60gensym3619_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resultX60gensym3619_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T26_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
		NimStringDesc* res_5;
		NimStringDesc* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T70_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T11_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			if (!(m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 49) || m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 50))) goto LA9_;
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T11_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T12_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_444));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_445));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T13_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T14_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA17_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA17_: ;
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T19_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T11_, T20_);
		}
		LA9_: ;
		sizeX60gensym3619_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, t);
		{
			if (!(sizeX60gensym3619_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)))) goto LA23_;
			storageX60gensym3619_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_310));
		}
		goto LA21_;
		LA23_: ;
		{
			storageX60gensym3619_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		}
		LA21_: ;
		resultX60gensym3619_ = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T26_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		res_4 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), storageX60gensym3619_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), resultX60gensym3619_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA29_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA29_: ;
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T31_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T26_, T32_);
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_5 = rawNewString(((NI) 80));
		res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T34_ = (NimStringDesc*)0;
		{
			if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35))) goto LA37_;
			T34_ = copyString(prc64__9bTptLAKOOYdunqlEwXM6PQ[(m)- 46]);
		}
		goto LA35_;
		LA37_: ;
		{
			T34_ = copyString(prc__8UqUr1y9abLbrO1vSUF2CqQ[(m)- 46]);
		}
		LA35_: ;
		T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T40_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, T34_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T40_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T41_);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T42_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T42_);
		res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_456));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), resultX60gensym3619_);
		res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_457));
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_432));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T43_);
		res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T44_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T44_);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_193));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA47_;
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA47_: ;
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T49_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T50_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T49_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T50_);
		{
			NIM_BOOL T53_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T57_;
			NimStringDesc* res_6;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T58_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
			T53_ = (NIM_BOOL)0;
			T53_ = (sizeX60gensym3619_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)));
			if (T53_) goto LA54_;
			T53_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
			LA54_: ;
			if (!T53_) goto LA55_;
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T57_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_6 = rawNewString(((NI) 80));
			res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), resultX60gensym3619_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
			T58_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, t);
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T58_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T59_);
			res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), resultX60gensym3619_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_400));
			T60_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, t);
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T61_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T60_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T61_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
			T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T62_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_432));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T62_);
			res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T63_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T63_);
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA66_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA66_: ;
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T69_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T68_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T57_, T69_);
		}
		LA55_: ;
		res_3 = resultX60gensym3619_;
		nimZeroMem((void*)T70_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T70_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T70_[1] = res_3;
		T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T71_ = percent___0ym49cR6ES8k9bYWsnh1fELA(T70_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T71_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__Faz6su3hXrHmiSECd9c9a6Pg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NimStringDesc* T5_;
		if (!((*conf).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 1))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 43), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_475, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRepr__BKdMcfvryaJLplX0oFPcAQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_458), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_459, NIM_FALSE);
	}
	LA3_: ;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		res = rawNewString(((NI) 80));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_460));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_461));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		res_2 = rawNewString(((NI) 80));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_462));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T10_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T11_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T12_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		res_3 = rawNewString(((NI) 80));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_463));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T14_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T15_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T16_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		res_4 = rawNewString(((NI) 80));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_464));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T18_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T19_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	{
		NimStringDesc* res_5;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		res_5 = rawNewString(((NI) 80));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_465));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T22_);
		res_5 = resizeString(res_5, 5);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_466));
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T23_);
		res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T24_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T25_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		NimStringDesc* res_6;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		res_6 = rawNewString(((NI) 80));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_467));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T27_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T28_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T29_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		NimStringDesc* res_7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		res_7 = rawNewString(((NI) 80));
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_468));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T31_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T32_);
		res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T33_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T34_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
		NimStringDesc* res_8;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T36_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T37_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T36_, IL64(36134350144710928));
		switch ((*T37_).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			nimZeroMem((void*)T39_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T39_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = percent___L3AeZ1n9aK4C1jsBCeaCmlQ(T39_, 1);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, (&b), e, T40_, a.storage);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			nimZeroMem((void*)T42_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T42_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T42_[1] = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
			T42_[2] = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = percent___qE1JtEDDOvP6J49a9cv9aK1Dg(T42_, 3);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, (&b), e, T43_, a.storage);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T45_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			nimZeroMem((void*)T45_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T45_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T46_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
			T47_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, T46_);
			T45_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T47_);
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = percent___ctvQ2lU9b9bnVVpNP4GhIo2Q(T45_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, (&b), e, T48_, a.storage);
		}
		break;
		default:
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_469), TM__MQdRN7fpbG7rPm4JpVVAhA_470);
		}
		break;
		}
		res_8 = rawNewString(((NI) 80));
		T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T50_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_471));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T50_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T51_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T51_);
		res_8 = resizeString(res_8, 2);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T52_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T52_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(t);
		T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T53_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T52_, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T53_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T54_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		NimStringDesc* res_9;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
		res_9 = rawNewString(((NI) 80));
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_472));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T56_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T57_);
		res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T58_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T58_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T59_, a.storage);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_473), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_474, NIM_FALSE);
	}
	break;
	default:
	{
		NimStringDesc* res_10;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
		res_10 = rawNewString(((NI) 80));
		T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T62_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_472));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T62_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T63_);
		res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T64_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T64_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T65_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T65_, a.storage);
	}
	break;
	}
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__BKdMcfvryaJLplX0oFPcAQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
	(void)(T1_);
	t = (*(*e)._kind_6.sons->data[((NI) 1)]).typ;
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*e).info);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T2_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdMType__JrPFcJ0c8lx7StUeWoJrrQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** nilCheck, NIM_BOOL enforceV1) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350135273744));
	{
		while (1) {
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
			if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22))) goto LA3;
			{
				if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47)))) goto LA6_;
				unsureAsgnRef((void**) (&(*nilCheck)), result);
			}
			LA6_: ;
			{
				NIM_BOOL T10_;
				NIM_BOOL T12_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T16_;
				T10_ = (NIM_BOOL)0;
				T10_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47)));
				if (T10_) goto LA11_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T12_) goto LA13_;
				T12_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA13_: ;
				T10_ = !(T12_);
				LA11_: ;
				if (!T10_) goto LA14_;
				nimZeroMem((void*)T16_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T16_[0] = result;
				result = percent___TbMwXzwNL7txOQADiTjwKA(T16_, 1);
			}
			LA14_: ;
			T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T17_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T17_, IL64(36134350135273744));
		} LA3: ;
	}
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T18_);
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T21_) goto LA22_;
		T21_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA22_: ;
		if (!!(T21_)) goto LA23_;
		{
			while (1) {
				NIM_BOOL T27_;
				T27_ = (NIM_BOOL)0;
				T27_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
				if (!(T27_)) goto LA28_;
				T27_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				LA28_: ;
				if (!T27_) goto LA26;
				add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
				t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(36275087638268176));
			} LA26: ;
		}
	}
	LA23_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_477));
	{
		NIM_BOOL T31_;
		T31_ = (NIM_BOOL)0;
		T31_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0);
		if (!(T31_)) goto LA32_;
		T31_ = enforceV1;
		LA32_: ;
		if (!T31_) goto LA33_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_478));
	}
	LA33_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__BKdMcfvryaJLplX0oFPcAQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = (*(*e)._kind_6.sons->data[((NI) 1)]).typ;
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isFinal__YPjOkGV9axAnGR3UfLeWZ1g_5(t);
		if (T3_) goto LA4_;
		T3_ = !(eqStrings((*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_476)));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg((*p).module, t, (*e).info);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T7_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nilCheck;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		nilCheck = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rdMType__JrPFcJ0c8lx7StUeWoJrrQ(p, a, &nilCheck, NIM_FALSE);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T9_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__UtJx89cn0a8CNSWWmaj6raA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* strCandidate;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		strCandidate = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*strCandidate).typ, IL64(36134350135273744));
			if (!((*T9_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28))) goto LA10_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, strCandidate, (&a));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_236));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA17_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA17_: ;
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T19_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T12_, T20_);
		}
		LA10_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSwap__BKdMcfvryaJLplX0oFPcAQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	cowBracket__UtJx89cn0a8CNSWWmaj6raA_2(p, (*e)._kind_6.sons->data[((NI) 1)]);
	cowBracket__UtJx89cn0a8CNSWWmaj6raA_2(p, (*e)._kind_6.sons->data[((NI) 2)]);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
	getTemp__VjOFVqypINqQv5C3ECnxbw(p, T1_, (&tmp), NIM_FALSE);
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmp, a, 0);
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, a, b, 0);
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, b, tmp, 0);
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__FWB0HmRDLgoWdgSy9bfL9b5w)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NimStringDesc* op) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_479), TM__MQdRN7fpbG7rPm4JpVVAhA_480);
	}
	LA3_: ;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
	cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), op);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA10_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA10_: ;
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T12_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T13_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, strLoc__09c8G9aj7c6ktd6DIBLVcdnw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA d) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		result = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, d);
	}
	goto LA1_;
	LA3_: ;
	{
		result = rdLoc__xidyzuHqIciXbQyEOKahDg(d);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__BKdMcfvryaJLplX0oFPcAQ_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	NI L;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* appends;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lens;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
	NimStringDesc* res_3;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, (&tmp), NIM_FALSE);
	L = ((NI) 0);
	appends = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	lens = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[(NI)(i + ((NI) 1))], (&a));
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
					NimStringDesc* res;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).typ, IL64(36134350144710928));
					if (!((*T7_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA8_;
					L += ((NI) 1);
					res = rawNewString(((NI) 80));
					T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_483));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T11_ = strLoc__09c8G9aj7c6ktd6DIBLVcdnw(p, tmp);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA15_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA15_: ;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					add__IM4kcMNkkOLJtqdEqSxR8A(&appends, T17_);
				}
				goto LA5_;
				LA8_: ;
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
					{
						if (!((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA21_;
						L += ((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))])._kind_3.strVal ? (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 1))])._kind_3.strVal->Sup.len : 0);
					}
					goto LA19_;
					LA21_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
						T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T24_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
						add__IM4kcMNkkOLJtqdEqSxR8A(&lens, T24_);
						add__yG4AKzsBRS1W4MANDlXQeg(&lens, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_484));
					}
					LA19_: ;
					res_2 = rawNewString(((NI) 80));
					T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T25_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_485));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = strLoc__09c8G9aj7c6ktd6DIBLVcdnw(p, tmp);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA30_: ;
					T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&appends, T32_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_3 = rawNewString(((NI) 80));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), tmp.r);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
	T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T34_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_486));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T34_);
	res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), lens);
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (L)));
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA37_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA37_: ;
	T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T39_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T40_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T39_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T40_);
	T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	add__IM4kcMNkkOLJtqdEqSxR8A(T41_, appends);
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA44_;
		genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	}
	goto LA42_;
	LA44_: ;
	{
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
	}
	LA42_: ;
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__vxeaiXjty5M8JXT1fo429aQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NimStringDesc* cpname) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_487), TM__MQdRN7fpbG7rPm4JpVVAhA_488);
	}
	LA3_: ;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, cpname);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA11_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA11_: ;
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T13_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T14_);
}
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__BKdMcfvryaJLplX0oFPcAQ_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* appends;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lens;
	NI L;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T49_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	appends = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	lens = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	L = ((NI) 0);
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&dest));
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
		colontmp_ = (NI)(T2_ - ((NI) 2));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[(NI)(i + ((NI) 2))], (&a));
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
					NimStringDesc* res;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).typ, IL64(36134350144710928));
					if (!((*T7_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA8_;
					L += ((NI) 1);
					res = rawNewString(((NI) 80));
					T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_483));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T11_ = strLoc__09c8G9aj7c6ktd6DIBLVcdnw(p, dest);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA15_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA15_: ;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					add__IM4kcMNkkOLJtqdEqSxR8A(&appends, T17_);
				}
				goto LA5_;
				LA8_: ;
				{
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
					{
						if (!((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA21_;
						L += ((*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))])._kind_3.strVal ? (*(*e)._kind_6.sons->data[(NI)(i + ((NI) 2))])._kind_3.strVal->Sup.len : 0);
					}
					goto LA19_;
					LA21_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
						T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T24_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
						add__IM4kcMNkkOLJtqdEqSxR8A(&lens, T24_);
						add__yG4AKzsBRS1W4MANDlXQeg(&lens, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_484));
					}
					LA19_: ;
					res_2 = rawNewString(((NI) 80));
					T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T25_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_485));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = strLoc__09c8G9aj7c6ktd6DIBLVcdnw(p, dest);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
					res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA30_: ;
					T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&appends, T32_);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T37_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA35_;
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T37_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T38_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_491));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T38_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T39_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T39_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), lens);
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (L)));
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA42_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA42_: ;
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T44_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T45_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T44_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T37_, T45_);
	}
	goto LA33_;
	LA35_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
		initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
		res_4 = rawNewString(((NI) 80));
		T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T47_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_492));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T47_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T48_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T48_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), lens);
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_4), ((NI64) (L)));
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, dest, call, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	LA33_: ;
	T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T49_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	add__IM4kcMNkkOLJtqdEqSxR8A(T49_, appends);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__W0UItHZuQBLie8iFE3EjmA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), (*baseType).owner);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, baseType);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeAddr__oKhRC9bEKTxG5epdNiNWZ0w_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T6_;
		nimZeroMem((void*)T6_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T6_[0] = n;
		result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64), T6_, 1);
		asgnRef((void**) (&(*result).typ), makePtrType__W0UItHZuQBLie8iFE3EjmA((*n).typ));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__BKdMcfvryaJLplX0oFPcAQ_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	genAsgnCall__HKkL9adNEIcNHeJ0iZ6uitg(p, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), e, d);
}
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__SrOtkNNSJNR1CbG2n3nFcg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* result) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
	(*p).labels += ((NI) 1);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111), T1_);
	unsureAsgnRef((void**) (&(*result).r), amp___Z7W1o5nPSc3ExfO5f7j1Gg(T2_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3)));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_495));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*result).r);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA6_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA6_: ;
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T8_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T9_);
	(*result).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1);
	(*result).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	unsureAsgnRef((void**) (&(*result).lode), lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T10_));
	(*result).flags = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__BKdMcfvryaJLplX0oFPcAQ_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmpL;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqType;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T16_;
	NimStringDesc* res_3;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
	NimStringDesc* res_4;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&tmpL), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	seqType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, 8388608);
	initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	{
		NIM_BOOL T3_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_493));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 16);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_494));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_380));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqType, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	goto LA1_;
	LA5_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T12_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_493));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T13_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T14_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqType, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T15_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	}
	LA1_: ;
	genRefAssign__jdslQ8TsNpkTt8SvBLJjEA(p, a, call);
	initLoc__qlujIAW86QclHYUVxlHRiQ((&dest), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), (*e)._kind_6.sons->data[((NI) 2)], ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	getIntTemp__SrOtkNNSJNR1CbG2n3nFcg(p, (&tmpL));
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T16_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_3 = rawNewString(((NI) 80));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), tmpL.r);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T17_);
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_416));
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = lenField__3AsTOpq9crZUYBL9aD1lXBng(p);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T18_);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_496));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA21_: ;
	T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T23_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T24_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T23_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T16_, T24_);
	res_4 = rawNewString(((NI) 80));
	T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T25_);
	T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T26_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T26_);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), tmpL.r);
	res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
	dest.r = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, dest, b, 1);
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__BKdMcfvryaJLplX0oFPcAQ_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA x;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	a = (*e)._kind_6.sons->data[((NI) 1)];
	b = (*e)._kind_6.sons->data[((NI) 2)];
	{
		NIM_BOOL T3_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*a).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*a).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
		if (!(T3_)) goto LA4_;
		T3_ = (((*a)._kind_3.strVal ? (*a)._kind_3.strVal->Sup.len : 0) == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&x));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, x);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_497));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T10_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*b).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*b).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
		if (!(T10_)) goto LA11_;
		T10_ = (((*b)._kind_3.strVal ? (*b)._kind_3.strVal->Sup.len : 0) == 0);
		LA11_: ;
		if (!T10_) goto LA12_;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&x));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, x);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T14_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_497));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T15_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA12_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5065_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym5065_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		nimZeroMem((void*)(&aX60gensym5065_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&bX60gensym5065_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5065_));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5065_));
		res_3 = rawNewString(((NI) 80));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_498));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T17_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5065_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T18_);
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym5065_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T19_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__BKdMcfvryaJLplX0oFPcAQ_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
	{
		NIM_BOOL T3_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym3732_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)(&aX60gensym3732_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym3732_));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym3732_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_502));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym3738_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		nimZeroMem((void*)(&aX60gensym3738_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym3738_));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym3738_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T10_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_497));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T11_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__BKdMcfvryaJLplX0oFPcAQ_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* toStrProc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
	toStrProc = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	{
		NI* idx;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** p_2;
		NI i;
		NI L;
		NI T2_;
		idx = (NI*)0;
		p_2 = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		T2_ = ((*t).methods ? (*t).methods->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				idx = (&(*t).methods->data[i].Field0);
				p_2 = &(*t).methods->data[i].Field1;
				{
					if (!((*idx) == ((NI) -4))) goto LA7_;
					toStrProc = (*p_2);
					goto LA1;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	} LA1: ;
	{
		tyTuple__zwpS6d6iewrdlBSTNFoyVA T13_;
		NI T14_;
		if (!(toStrProc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA11_;
		toStrProc = genEnumToStrProc__1dNAvAAONCZJhs8N6saOAw(t, (*e).info, (*(*(*p).module).g).graph);
		nimZeroMem((void*)(&T13_), sizeof(tyTuple__zwpS6d6iewrdlBSTNFoyVA));
		T13_.Field0 = ((NI) -4);
		T13_.Field1 = toStrProc;
		asgnRef((void**) (&(*t).methods), (tySequence__MvZmat48bhe9b6x9aUD58D5Q*) incrSeqV3((TGenericSeq*)((*t).methods), (&NTI__MvZmat48bhe9b6x9aUD58D5Q_)));
		T14_ = (*t).methods->Sup.len++;
		(*t).methods->data[T14_].Field0 = T13_.Field0;
		asgnRef((void**) (&(*t).methods->data[T14_].Field1), T13_.Field1);
	}
	LA11_: ;
	n = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(e);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(toStrProc));
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, n, d);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genOfHelper__syG9ah9cBD4IpDknTLKkLglQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA3_;
		res = rawNewString(((NI) 80));
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), a);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_513));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg((*p).module, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* ti;
		ti = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, dest, info);
		{
			NIM_BOOL T10_;
			NIM_BOOL T12_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
			T10_ = (NIM_BOOL)0;
			T10_ = (((*dest).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0);
			if (T10_) goto LA11_;
			T12_ = (NIM_BOOL)0;
			T12_ = (((*(*p).module).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 5))&7U)))!=0);
			if (!(T12_)) goto LA13_;
			T12_ = !((((*dest).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 5))&63U)))!=0));
			LA13_: ;
			T10_ = T12_;
			LA11_: ;
			if (!T10_) goto LA14_;
			nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T16_[0] = a;
			T16_[1] = ti;
			result = percent___s0lnM9cZDB9bOREa4Fx1leBw(T16_, 2);
		}
		goto LA8_;
		LA14_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* cache;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T20_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
			(void)(T18_);
			(*(*p).module).labels += ((NI) 1);
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*(*p).module).labels)));
			cache = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_514), T19_);
			nimZeroMem((void*)T20_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T20_[0] = cache;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = percent___aT7p9bNEmP3LxrK3OhspnSw(T20_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T21_);
			res_2 = rawNewString(((NI) 80));
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_515));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), a);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_513));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), ti);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), cache);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			result = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__uDNhebNf5Eggw4ZZsc4T9cg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nilCheck;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36275087638309136));
	r = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	nilCheck = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350135273744));
	{
		while (1) {
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
			if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22))) goto LA3;
			{
				if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47)))) goto LA6_;
				nilCheck = r;
			}
			LA6_: ;
			{
				NIM_BOOL T10_;
				NIM_BOOL T12_;
				NimStringDesc* res;
				T10_ = (NIM_BOOL)0;
				T10_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47)));
				if (T10_) goto LA11_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T12_) goto LA13_;
				T12_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA13_: ;
				T10_ = !(T12_);
				LA11_: ;
				if (!T10_) goto LA14_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_65));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), r);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				r = rope__yShmEg9cffWxI7s5XzEKBow(res);
			}
			LA14_: ;
			T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T16_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T16_, IL64(36134350135273744));
		} LA3: ;
	}
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T17_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T17_);
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T20_) goto LA21_;
		T20_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA21_: ;
		if (!!(T20_)) goto LA22_;
		{
			while (1) {
				NIM_BOOL T26_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T28_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
				T26_ = (NIM_BOOL)0;
				T26_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
				if (!(T26_)) goto LA27_;
				T26_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				LA27_: ;
				if (!T26_) goto LA25;
				nimZeroMem((void*)T28_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T29_ = percent___Jx78R9a9anGvjjocCaP8YgIg(T28_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&r, T29_);
				t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(36275087638268176));
			} LA25: ;
		}
	}
	LA22_: ;
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(t);
		if (!T32_) goto LA33_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_509), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__MQdRN7fpbG7rPm4JpVVAhA_510, NIM_FALSE);
	}
	LA33_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
		if (!!((nilCheck == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA37_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), nilCheck);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_511));
		T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T39_ = genOfHelper__syG9ah9cBD4IpDknTLKkLglQ(p, dest, r, (*x).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T39_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
		r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	}
	goto LA35_;
	LA37_: ;
	{
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = genOfHelper__syG9ah9cBD4IpDknTLKkLglQ(p, dest, r, (*x).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T41_);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		r = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	}
	LA35_: ;
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, x, r, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__8mAL9ckajemzgfLPfeZVNoQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	genOf__uDNhebNf5Eggw4ZZsc4T9cg(p, (*n)._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[((NI) 2)]).typ, d);
}
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* sizeExpr, NIM_BOOL needsInit) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* sizeExpr_2;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* refType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bt;
	sizeExpr_2 = sizeExpr;
	typ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLoc__qlujIAW86QclHYUVxlHRiQ((&b), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), (*a).lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	refType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	bt = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(refType);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!(sizeExpr_2 == 0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, bt, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		sizeExpr_2 = percent___mV75vMLuQ8rrQEUzNz6llA(T5_, 1);
	}
	LA3_: ;
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA8_;
		{
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			if (!needsInit) goto LA12_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_516));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), sizeExpr_2);
			res = resizeString(res, 14);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_517));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, bt, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
			b.r = rope__yShmEg9cffWxI7s5XzEKBow(res);
		}
		goto LA10_;
		LA12_: ;
		{
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T18_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_518));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T19_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), sizeExpr_2);
			res_2 = resizeString(res_2, 14);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_517));
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, bt, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T20_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
			b.r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		}
		LA10_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*a), b, 0);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* ti;
		ti = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, typ, (*(*a).lode).info);
		{
			NIM_BOOL T24_;
			NIM_BOOL T26_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA f;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			T24_ = (NIM_BOOL)0;
			T24_ = !(((*bt).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T24_)) goto LA25_;
			T26_ = (NIM_BOOL)0;
			T26_ = isTrivialProc__0ARm8KufT2VWgot8ref79bwcgen((*bt).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]);
			T24_ = !(T26_);
			LA25_: ;
			if (!T24_) goto LA27_;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = ((*(*bt).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				if (T31_) goto LA32_;
				T31_ = !(((*(*(*bt).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0)));
				LA32_: ;
				if (!T31_) goto LA33_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*(*a).lode).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_519), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_520, NIM_FALSE);
			}
			LA33_: ;
			nimZeroMem((void*)(&f), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T35_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*bt).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]);
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, T35_, (&f));
			nimZeroMem((void*)T36_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T36_[0] = ti;
			T36_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(f);
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = percent___jhVz7tKuf0heLM2D3nL0gw(T36_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T37_);
		}
		LA27_: ;
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = ((*a).storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
			if (!(T40_)) goto LA41_;
			T40_ = usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options((*(*(*p).module).g).config);
			LA41_: ;
			if (!T40_) goto LA42_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
				NIM_BOOL T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T50_;
				NimStringDesc* res_3;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T46_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
				T47_ = (NIM_BOOL)0;
				T47_ = canFormAcycle__IVXYI9cxSeivThgKCncHRnA(T46_);
				if (!T47_) goto LA48_;
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T50_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_3 = rawNewString(((NI) 80));
				res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T51_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T51_);
				res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
				T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T52_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_521));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T52_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T53_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T53_);
				res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
				T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T54_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T54_);
				res_3 = resizeString(res_3, 13);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_522));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA57_: ;
				T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T50_, T60_);
			}
			goto LA44_;
			LA48_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T62_;
				NimStringDesc* res_4;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T62_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T63_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
				T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T64_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_226));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T64_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T65_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T65_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
				T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T66_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T66_);
				res_4 = resizeString(res_4, 13);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_522));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA69_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA69_: ;
				T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T71_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
				T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T72_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T71_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T62_, T72_);
			}
			LA44_: ;
			{
				NimStringDesc* res_5;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T79_;
				NimStringDesc* res_6;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T80_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T88_;
				if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10))) goto LA75_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T77_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T77_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T78_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_523));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T78_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), ti);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), sizeExpr_2);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				b.r = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
				T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T79_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_6 = rawNewString(((NI) 80));
				T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T80_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T80_);
				res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
				T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T81_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, (*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T81_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T82_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T82_);
				res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA85_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA85_: ;
				T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T87_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
				T88_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T88_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T87_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T79_, T88_);
			}
			goto LA73_;
			LA75_: ;
			{
				NimStringDesc* res_7;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T92_;
				NimStringDesc* res_8;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T99_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T90_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T90_);
				res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T91_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_524));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T91_);
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), ti);
				res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), sizeExpr_2);
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				b.r = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
				T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T92_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_8 = rawNewString(((NI) 80));
				T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T93_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T93_);
				res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T94_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T94_);
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA97_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA97_: ;
				T99_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T99_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
				T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T100_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T99_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T92_, T100_);
			}
			LA73_: ;
		}
		goto LA38_;
		LA42_: ;
		{
			NimStringDesc* res_9;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
			res_9 = rawNewString(((NI) 80));
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T102_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T102_);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
			T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T103_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_523));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T103_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), ti);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), sizeExpr_2);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			b.r = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*a), b, 0);
		}
		LA38_: ;
	}
	LA6_: ;
	genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), bt, a, ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 1));
}
N_LIB_PRIVATE N_NIMCALL(void, genNew__X9cSqNhqEboci9cdmwBMNcBw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	{
		NI T3_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA se;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		nimZeroMem((void*)(&se), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&se));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(se);
		rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg(p, (&a), T6_, NIM_TRUE);
	}
	goto LA1_;
	LA4_: ;
	{
		rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg(p, (&a), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL), NIM_TRUE);
	}
	LA1_: ;
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__X9cSqNhqEboci9cdmwBMNcBw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA f;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* refType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bt;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* ti;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&f), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	refType = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	bt = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	ti = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	refType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&f));
	initLoc__qlujIAW86QclHYUVxlHRiQ((&b), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), a.lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA3_;
		ti = genTypeInfoV2__BeEYMOjEPJinzbFpsfTaZg((*p).module, refType, (*e).info);
	}
	goto LA1_;
	LA3_: ;
	{
		ti = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, refType, (*e).info);
	}
	LA1_: ;
	nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T6_[0] = ti;
	T6_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(f);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = percent___jhVz7tKuf0heLM2D3nL0gw(T6_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 16))- 0], T7_);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, refType, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_523));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), ti);
	res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(refType);
	T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T10_, IL64(36134350136322320));
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T11_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
	b.r = rope__yShmEg9cffWxI7s5XzEKBow(res);
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, a, b, 0);
	T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T13_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(refType);
	bt = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T13_, IL64(36134350136322320));
	genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), bt, (&a), ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 1));
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__Ri3gLeBVOaUltgSIU2SrQQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* length, NIM_BOOL lenIsZero) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqtype;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
	seqtype = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350144710928));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), dest.lode, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (dest.storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
		if (!(T4_)) goto LA5_;
		T4_ = usesWriteBarrier__TzsgO9bY9cwAf4hwmbs7dTmg_2options((*(*(*p).module).g).config);
		LA5_: ;
		if (!T4_) goto LA6_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
			NIM_BOOL T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T14_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T10_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T11_ = (NIM_BOOL)0;
			T11_ = canFormAcycle__IVXYI9cxSeivThgKCncHRnA(T10_);
			if (!T11_) goto LA12_;
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T14_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_521));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_522));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA21_: ;
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T23_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T14_, T24_);
		}
		goto LA8_;
		LA12_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T26_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T26_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_226));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T30_);
			res_2 = resizeString(res_2, 13);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_522));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA33_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA33_: ;
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T35_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T26_, T36_);
		}
		LA8_: ;
		{
			if (!!(lenIsZero)) goto LA39_;
			{
				NimStringDesc* res_3;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T48_;
				NimStringDesc* res_4;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
				if (!((*(*(*(*p).module).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 10))) goto LA43_;
				res_3 = rawNewString(((NI) 80));
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T45_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, seqtype, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T45_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T46_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_529));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T46_);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T47_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqtype, (*dest.lode).info);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T47_);
				res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), length);
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T48_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_4 = rawNewString(((NI) 80));
				T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T49_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_216));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T49_);
				res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_215));
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T50_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T50_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T51_ = rdLoc__xidyzuHqIciXbQyEOKahDg(call);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T51_);
				res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA54_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA54_: ;
				T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T56_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
				T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T57_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T56_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T48_, T57_);
			}
			goto LA41_;
			LA43_: ;
			{
				NimStringDesc* res_5;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T62_;
				NimStringDesc* res_6;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T59_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, seqtype, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T59_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_530));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T60_);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T61_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqtype, (*dest.lode).info);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T61_);
				res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), length);
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T62_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_6 = rawNewString(((NI) 80));
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T63_);
				res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
				T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T64_ = rdLoc__xidyzuHqIciXbQyEOKahDg(call);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T64_);
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA67_;
					res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA67_: ;
				T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T69_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
				T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T70_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T69_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T62_, T70_);
			}
			LA41_: ;
		}
		LA39_: ;
	}
	goto LA2_;
	LA6_: ;
	{
		{
			if (!lenIsZero) goto LA74_;
			call.r = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_204));
		}
		goto LA72_;
		LA74_: ;
		{
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T77_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
			res_7 = rawNewString(((NI) 80));
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T77_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, seqtype, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T77_);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
			T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T78_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_529));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T78_);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T79_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqtype, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T79_);
			res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), length);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		}
		LA72_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, dest, call, 0);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__X9cSqNhqEboci9cdmwBMNcBw_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqtype;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		seqtype = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_525));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_526));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2((*p).module, seqtype);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_359));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_527));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
		T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T12_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T12_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_528));
		T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T14_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T14_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA18_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA18_: ;
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T20_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T21_);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL lenIsZero;
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T24_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0));
		if (!(T24_)) goto LA25_;
		T24_ = ((*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
		LA25_: ;
		T23_ = T24_;
		if (!(T23_)) goto LA26_;
		T23_ = ((*(*e)._kind_6.sons->data[((NI) 2)])._kind_1.intVal == IL64(0));
		LA26_: ;
		lenIsZero = T23_;
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		genNewSeqAux__Ri3gLeBVOaUltgSIU2SrQQ(p, a, T27_, lenIsZero);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__BKdMcfvryaJLplX0oFPcAQ_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqtype;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	seqtype = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350144710928));
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA7_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA7_: ;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_74));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_526));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2((*p).module, seqtype);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_359));
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_527));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
		T15_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T15_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T15_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_528));
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T17_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA21_: ;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T23_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T24_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, seqtype, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_531));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, seqtype, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T30_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__BKdMcfvryaJLplX0oFPcAQ_14)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* etyp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* srcTyp;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
	etyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350136322320));
	srcTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49));
		if (!(T3_)) goto LA4_;
		T3_ = !(((a.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0))&15U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T7_[1] = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___duX6hgjmpJtFFdvJVuoafg(T7_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T8_, a.storage);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		if (!(T11_)) goto LA12_;
		T11_ = ((*etyp).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = !(((*srcTyp).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)));
		LA13_: ;
		if (!T10_) goto LA14_;
		nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T16_[0] = getClosureType__lWDfUH9cj8K8DjyEqo9cmP3A((*p).module, etyp, ((tyEnum_TClosureTypeKind__cLHRMz1vnpSK0uePy2qbWw) 1));
		T16_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = percent___GNSb4l0oRsR1gu66azz1LQ(T16_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T17_, a.storage);
	}
	goto LA1_;
	LA14_: ;
	{
		{
			NIM_BOOL T21_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*srcTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*srcTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
			if (!(T21_)) goto LA22_;
			T21_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14) || (*etyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) && (*etyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35) || (*etyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) && (*etyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39) || (*etyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*etyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
			LA22_: ;
			if (!T21_) goto LA23_;
			nimZeroMem((void*)T25_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T25_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T25_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = percent___LGbUtKnsZL8FcQiQN7sWEA(T25_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T26_, a.storage);
		}
		goto LA19_;
		LA23_: ;
		{
			NIM_BOOL T28_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			T28_ = (NIM_BOOL)0;
			T28_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
			if (!(T28_)) goto LA29_;
			T28_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24) || (*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
			LA29_: ;
			if (!T28_) goto LA30_;
			nimZeroMem((void*)T32_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T32_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T32_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = percent___e8Xf9ajw9cRlpuqnFnlEuSpA(T32_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T33_, a.storage);
		}
		goto LA19_;
		LA30_: ;
		{
			NIM_BOOL T35_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*etyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
			if (!(T35_)) goto LA36_;
			T35_ = ((*srcTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1) || (*srcTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2) || (*srcTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14) || (*srcTyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) && (*srcTyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35) || (*srcTyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) && (*srcTyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39) || (*srcTyp).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*srcTyp).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
			LA36_: ;
			if (!T35_) goto LA37_;
			nimZeroMem((void*)T39_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T39_[0] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = percent___BDuDfIpocbuOrxKmsugV6Q(T39_, 1);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T40_, a.storage);
		}
		goto LA19_;
		LA37_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			nimZeroMem((void*)T42_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T42_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T42_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = percent___GNSb4l0oRsR1gu66azz1LQ(T42_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T43_, a.storage);
		}
		LA19_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrd__BKdMcfvryaJLplX0oFPcAQ_15)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4976_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	nimZeroMem((void*)(&aX60gensym4976_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4976_));
	res = rawNewString(((NI) 80));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4976_);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T2_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__TU9cJnldbmGa9bZDxaR6I4tg_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	a = (*e)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		a = (*a)._kind_6.sons->data[((NI) 0)];
	}
	LA3_: ;
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*a).typ, IL64(49785886514129168));
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA c;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
			if (!(T9_)) goto LA10_;
			T9_ = ((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA10_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA11_;
			T8_ = ((*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126));
			LA11_: ;
			if (!T8_) goto LA12_;
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&c), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*a)._kind_6.sons->data[((NI) 2)], (&b));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*a)._kind_6.sons->data[((NI) 3)], (&c));
			{
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
				if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA16_;
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(c);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
				res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_535));
				T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T20_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			}
			goto LA14_;
			LA16_: ;
			{
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T22_ = rdLoc__xidyzuHqIciXbQyEOKahDg(c);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_535));
				T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T23_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T23_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_536));
				T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T24_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T24_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			}
			LA14_: ;
		}
		goto LA6_;
		LA12_: ;
		{
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(a);
				if (!!(T28_)) goto LA29_;
				{
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4599_;
					NimStringDesc* res_3;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
					if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA33_;
					nimZeroMem((void*)(&aX60gensym4599_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4599_));
					res_3 = rawNewString(((NI) 80));
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4599_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T35_);
					res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_537));
					T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T36_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T36_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				}
				goto LA31_;
				LA33_: ;
				{
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4605_;
					NimStringDesc* res_4;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
					nimZeroMem((void*)(&aX60gensym4605_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4605_));
					res_4 = rawNewString(((NI) 80));
					T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T38_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4605_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T38_);
					res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_538));
					T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T39_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T39_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				}
				LA31_: ;
			}
			goto LA26_;
			LA29_: ;
			{
				{
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4611_;
					NimStringDesc* res_5;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
					if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA43_;
					nimZeroMem((void*)(&aX60gensym4611_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4611_));
					res_5 = rawNewString(((NI) 80));
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T45_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4611_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T45_);
					res_5 = resizeString(res_5, 10);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_539));
					T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T46_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T46_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				}
				goto LA41_;
				LA43_: ;
				{
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4617_;
					NimStringDesc* res_6;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
					nimZeroMem((void*)(&aX60gensym4617_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4617_));
					res_6 = rawNewString(((NI) 80));
					T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T48_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4617_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T48_);
					res_6 = resizeString(res_6, 7);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_540));
					T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T49_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T49_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				}
				LA41_: ;
			}
			LA26_: ;
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4623_;
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T55_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA53_;
			nimZeroMem((void*)(&aX60gensym4623_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4623_));
			res_7 = rawNewString(((NI) 80));
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T55_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4623_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T55_);
			res_7 = resizeString(res_7, 4);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_541));
			T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T56_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_542));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T56_);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T57_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4623_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T57_);
			res_7 = resizeString(res_7, 10);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_543));
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T58_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		goto LA51_;
		LA53_: ;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4629_;
			NimStringDesc* res_8;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
			nimZeroMem((void*)(&aX60gensym4629_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4629_));
			res_8 = rawNewString(((NI) 80));
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4629_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T60_);
			res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_544));
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T61_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_542));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T61_);
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T62_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4629_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T62_);
			res_8 = resizeString(res_8, 6);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_545));
			T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T63_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T63_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
		x = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a_2);
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T69_;
			if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA67_;
			nimZeroMem((void*)T69_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T69_[0] = x;
			x = percent___nVQhtKHyPC8pvPbUAUBU7A(T69_, 1);
		}
		LA67_: ;
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, x, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_3;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T76_;
		NimStringDesc* res_9;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_3));
		getIntTemp__SrOtkNNSJNR1CbG2n3nFcg(p, (&tmp));
		x_2 = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a_3);
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T75_;
			if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA73_;
			nimZeroMem((void*)T75_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T75_[0] = x_2;
			x_2 = percent___nVQhtKHyPC8pvPbUAUBU7A(T75_, 1);
		}
		LA73_: ;
		T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T76_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_9 = rawNewString(((NI) 80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), tmp.r);
		res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), x_2);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA79_;
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA79_: ;
		T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T81_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
		T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T82_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T81_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T76_, T82_);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, tmp.r, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T88_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T89_;
			if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9))) goto LA86_;
			T88_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, typ);
			T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T89_ = rope__b5mr3rjXEwHVfmNLJr4cBA(T88_);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T89_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		goto LA84_;
		LA86_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T91_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
			T91_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, typ);
			T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T92_ = rope__b5mr3rjXEwHVfmNLJr4cBA(T91_);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T92_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		LA84_: ;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_546), TM__MQdRN7fpbG7rPm4JpVVAhA_547);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__BKdMcfvryaJLplX0oFPcAQ_16)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		binaryStmtAddr__vxeaiXjty5M8JXT1fo429aQ(p, e, d, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_553));
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA8_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_554), TM__MQdRN7fpbG7rPm4JpVVAhA_555);
		}
		LA8_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
		res = rawNewString(((NI) 80));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_556));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res);
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, a, call, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__BKdMcfvryaJLplX0oFPcAQ_17)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	{
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		asgnRef((void**) (&(*e)._kind_6.sons->data[((NI) 1)]), makeAddr__oKhRC9bEKTxG5epdNiNWZ0w_3((*e)._kind_6.sons->data[((NI) 1)]));
		genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, e, d);
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	x = (*e)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA7_;
		x = (*x)._kind_6.sons->data[((NI) 0)];
	}
	LA7_: ;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, 8388608);
	initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
	{
		NIM_BOOL T11_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T11_) goto LA12_;
		T11_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA12_: ;
		if (!!(T11_)) goto LA13_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_557));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_558));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_559));
		T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T18_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T18_, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	goto LA9_;
	LA13_: ;
	{
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_557));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T23_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T24_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T25_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T25_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T25_, (*e).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	}
	LA9_: ;
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, a, call, 0);
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* setType;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
	setType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36275087638309136));
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
		NIM_BOOL T4_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T8_;
		T3_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(conf, setType);
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T3_, IL64(0));
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = result;
		T8_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(conf, setType);
		T7_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T8_);
		result = percent___qTicKO8EMC9cWGOyybIz4WQ(T7_, 2);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__vBGSIpCyq29bEZNYsVP3V6w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!!(((*s).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39)))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NI64 T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NI64)0;
		T8_ = getSize__vCG1GF2Iu043oALVyuJfOw(conf, (*s).typ);
		T7_ = (T8_ <= ((NI64) ((*conf).target.intSize)));
		if (!(T7_)) goto LA9_;
		T7_ = (((*s).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 4))&31U)))!=0);
		LA9_: ;
		if (!T7_) goto LA10_;
		result = NIM_FALSE;
	}
	goto LA5_;
	LA10_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2((*s).typ);
		if (!((*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) || (*T13_).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33) && (*T13_).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35))) goto LA14_;
		result = NIM_TRUE;
	}
	goto LA5_;
	LA14_: ;
	{
		NI T17_;
		T17_ = (NI)0;
		T17_ = len__P89cqdlERShb9alU3iC0yj8wast(s);
		result = (T17_ <= ((NI) 8));
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__9cclvr8sbqtJj8irRbQQpqQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* b, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	NI64 T2_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
	T2_ = (NI64)0;
	T2_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T1_);
	switch (((NI) (T2_))) {
	case ((NI) 1):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		nimZeroMem((void*)T4_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T4_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
		T4_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, (*b), T5_);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___9cZzkwYphs086zWiuLotXLA(T4_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T6_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((NI) 2):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T8_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T9_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
		T8_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, (*b), T9_);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = percent___kPsYd8d9cco3hhqO7CEAFeg(T8_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T10_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((NI) 4):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T12_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
		T12_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, (*b), T13_);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = percent___BbOsdTh4ZRNKmiISHDyg3A(T12_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T14_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((NI) 8):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T16_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
		T16_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, (*b), T17_);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = percent___Py40oiVtYdIelNuiQQjpjw(T16_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T18_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	default:
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T20_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		nimZeroMem((void*)T20_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T20_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*a));
		T21_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T21_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
		T20_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, (*b), T21_);
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = percent___QzVlk7tEXgagMWC19aLvbkg(T20_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T22_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genInOp__BKdMcfvryaJLplX0oFPcAQ_18)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA x;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA y;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&y), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ea;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39));
		if (!(T3_)) goto LA4_;
		T3_ = fewCmps__vBGSIpCyq29bEZNYsVP3V6w((*(*(*p).module).g).config, (*e)._kind_6.sons->data[((NI) 1)]);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70) || (*(*e)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69))) goto LA9_;
			ea = (*(*e)._kind_6.sons->data[((NI) 2)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA7_;
		LA9_: ;
		{
			ea = (*e)._kind_6.sons->data[((NI) 2)];
		}
		LA7_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, ea, (&a));
		initLoc__qlujIAW86QclHYUVxlHRiQ((&b), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__P89cqdlERShb9alU3iC0yj8wast((*e)._kind_6.sons->data[((NI) 1)]);
			if (!(((NI) 0) < T14_)) goto LA15_;
			b.r = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*e)._kind_6.sons->data[((NI) 1)]);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
						if (!(i_2 < colontmp_)) goto LA19;
						i = i_2;
						it = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[i];
						{
							tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T24_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
							if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA22_;
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it)._kind_6.sons->data[((NI) 0)], (&x));
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it)._kind_6.sons->data[((NI) 1)], (&y));
							nimZeroMem((void*)T24_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
							T24_[0] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
							T24_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(x);
							T24_[2] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(y);
							T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T25_ = percent___nEiBK88oEGnvYfkiei9cyJA(T24_, 3);
							add__IM4kcMNkkOLJtqdEqSxR8A(&b.r, T25_);
						}
						goto LA20_;
						LA22_: ;
						{
							tyArray__mrugoXXRZUEeG9bEXo9auBKw T27_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, it, (&x));
							nimZeroMem((void*)T27_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
							T27_[0] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
							T27_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(x);
							T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T28_ = percent___Psy1qActyEYmIhrRo2KkJA(T27_, 2);
							add__IM4kcMNkkOLJtqdEqSxR8A(&b.r, T28_);
						}
						LA20_: ;
						{
							NI T31_;
							T31_ = (NI)0;
							T31_ = len__P89cqdlERShb9alU3iC0yj8wast((*e)._kind_6.sons->data[((NI) 1)]);
							if (!(i < (NI)(T31_ - ((NI) 1)))) goto LA32_;
							add__yG4AKzsBRS1W4MANDlXQeg(&b.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
						}
						LA32_: ;
						i_2 += ((NI) 1);
					} LA19: ;
				}
			}
			add__yG4AKzsBRS1W4MANDlXQeg(&b.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		}
		goto LA12_;
		LA15_: ;
		{
			b.r = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_108));
		}
		LA12_: ;
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, b.r, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA5_: ;
	{
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
		genInExprAux__9cclvr8sbqtJj8irRbQQpqQ(p, e, (&a), (&b), d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__TU9cJnldbmGa9bZDxaR6I4tg_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA i;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* setType;
	NI size;
	NI64 T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&i), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	setType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
	T1_ = (NI64)0;
	T1_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, setType);
	size = ((NI) (T1_));
	switch (size) {
	case ((NI) 1):
	case ((NI) 2):
	case ((NI) 4):
	case ((NI) 8):
	{
		switch (op) {
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 40):
		{
			switch (size) {
			case ((NI) 1):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4739_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4739_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
				nimZeroMem((void*)(&aX60gensym4739_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4739_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4739_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4739_));
				T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T6_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4739_);
				T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T7_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4739_);
				T6_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4739_, T7_);
				T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T8_ = percent___9bI5GhokFUA9bgO9av819cgdBg(T6_, 2);
				T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T9_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T8_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T9_);
			}
			break;
			case ((NI) 2):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4746_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4746_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T11_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
				nimZeroMem((void*)(&aX60gensym4746_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4746_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4746_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4746_));
				T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T11_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T12_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4746_);
				T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T13_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4746_);
				T12_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4746_, T13_);
				T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T14_ = percent___yZHx0qMqBvbhmZ0fMuAP6A(T12_, 2);
				T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T15_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T14_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T11_, T15_);
			}
			break;
			case ((NI) 4):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4753_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4753_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T18_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
				nimZeroMem((void*)(&aX60gensym4753_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4753_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4753_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4753_));
				T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T18_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T18_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4753_);
				T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T19_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4753_);
				T18_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4753_, T19_);
				T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T20_ = percent___YQzyPnY5vKAqE2RyLX0cew(T18_, 2);
				T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T21_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T20_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T17_, T21_);
			}
			break;
			case ((NI) 8):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4760_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4760_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T25_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
				nimZeroMem((void*)(&aX60gensym4760_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4760_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4760_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4760_));
				T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T24_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4760_);
				T25_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T25_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4760_);
				T24_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4760_, T25_);
				T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T26_ = percent___cIILAsA6BeRrvHfloZIscg(T24_, 2);
				T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T27_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T26_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T27_);
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 41):
		{
			switch (size) {
			case ((NI) 1):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4769_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4769_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T31_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T32_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
				nimZeroMem((void*)(&aX60gensym4769_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4769_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4769_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4769_));
				T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T31_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T32_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T32_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4769_);
				T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T33_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4769_);
				T32_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4769_, T33_);
				T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T34_ = percent___IwDTuHqkGn7wW16ga2ktSg(T32_, 2);
				T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T35_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T34_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T31_, T35_);
			}
			break;
			case ((NI) 2):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4776_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4776_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T37_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T38_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T39_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
				nimZeroMem((void*)(&aX60gensym4776_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4776_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4776_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4776_));
				T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T37_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T38_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T38_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4776_);
				T39_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T39_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4776_);
				T38_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4776_, T39_);
				T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T40_ = percent___lbkoHJP5AIgE86vP7MmlKw(T38_, 2);
				T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T41_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T40_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T37_, T41_);
			}
			break;
			case ((NI) 4):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4783_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4783_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T43_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T44_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
				nimZeroMem((void*)(&aX60gensym4783_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4783_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4783_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4783_));
				T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T43_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T44_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T44_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4783_);
				T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T45_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4783_);
				T44_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4783_, T45_);
				T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T46_ = percent___9b84wNYrm79cLYfx9bsPNHjPQ(T44_, 2);
				T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T47_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T46_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T43_, T47_);
			}
			break;
			case ((NI) 8):
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4790_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4790_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T49_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T50_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
				nimZeroMem((void*)(&aX60gensym4790_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				nimZeroMem((void*)(&bX60gensym4790_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4790_));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4790_));
				T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T49_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T50_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T50_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4790_);
				T51_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T51_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4790_);
				T50_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4790_, T51_);
				T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T52_ = percent___K5ihI3kW9cFBh6sKlfEpJwg(T50_, 2);
				T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T53_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T52_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T49_, T53_);
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 42):
		{
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4799_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				if (!(size <= ((NI) 4))) goto LA58_;
				nimZeroMem((void*)(&aX60gensym4799_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4799_));
				res = rawNewString(((NI) 80));
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_560));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T60_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T61_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4799_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T61_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T62_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			}
			goto LA56_;
			LA58_: ;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4805_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
				nimZeroMem((void*)(&aX60gensym4805_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4805_));
				res_2 = rawNewString(((NI) 80));
				T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T64_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_561));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T64_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T65_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4805_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T65_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
				T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T66_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T66_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
			}
			LA56_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4811_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4811_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
			nimZeroMem((void*)(&aX60gensym4811_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4811_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4811_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4811_));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_562));
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4811_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T68_);
			res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_563));
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T69_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(bX60gensym4811_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T69_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_564));
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4811_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T70_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_436));
			T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T71_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(bX60gensym4811_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T71_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_286));
			T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T72_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T72_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 120):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4826_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4826_;
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
			nimZeroMem((void*)(&aX60gensym4826_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4826_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4826_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4826_));
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
			T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T74_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym4826_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T74_);
			res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_563));
			T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T75_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(bX60gensym4826_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T75_);
			res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_565));
			T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T76_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T76_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 119):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4841_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4841_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T80_;
			nimZeroMem((void*)(&aX60gensym4841_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4841_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4841_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4841_));
			res_5 = rawNewString(((NI) 80));
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T78_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4841_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T78_);
			res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_430));
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T79_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym4841_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T79_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T80_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T80_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 122):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4856_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4856_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
			nimZeroMem((void*)(&aX60gensym4856_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4856_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4856_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4856_));
			res_6 = rawNewString(((NI) 80));
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T82_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4856_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T82_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_566));
			T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T83_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym4856_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T83_);
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T84_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T84_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 123):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4871_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4871_;
			NimStringDesc* res_7;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T88_;
			nimZeroMem((void*)(&aX60gensym4871_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4871_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4871_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4871_));
			res_7 = rawNewString(((NI) 80));
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T86_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4871_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T86_);
			res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_567));
			T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T87_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym4871_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T87_);
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			T88_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T88_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T88_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 124):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4886_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4886_;
			NimStringDesc* res_8;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
			nimZeroMem((void*)(&aX60gensym4886_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4886_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4886_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4886_));
			res_8 = rawNewString(((NI) 80));
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T90_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4886_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T90_);
			res_8 = resizeString(res_8, 5);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_563));
			T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T91_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym4886_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T91_);
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T92_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T92_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134):
		{
			genInOp__BKdMcfvryaJLplX0oFPcAQ_18(p, e, d);
		}
		break;
		default:
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_568), TM__MQdRN7fpbG7rPm4JpVVAhA_569);
		}
		break;
		}
	}
	break;
	default:
	{
		switch (op) {
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 40):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4904_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4904_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T97_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T98_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T99_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
			nimZeroMem((void*)(&aX60gensym4904_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4904_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4904_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4904_));
			T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T97_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T98_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T98_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4904_);
			T99_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T99_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4904_);
			T98_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4904_, T99_);
			T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T100_ = percent___qxufH5vUl9aY2l9cFq39bnVwA(T98_, 2);
			T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T101_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T100_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T97_, T101_);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 41):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym4911_;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym4911_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T103_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T104_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T105_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
			nimZeroMem((void*)(&aX60gensym4911_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&bX60gensym4911_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym4911_));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym4911_));
			T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T103_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T104_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T104_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym4911_);
			T105_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T105_ = t__XNOXh7uniWNgiq58C9bW49awcgen(aX60gensym4911_);
			T104_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, bX60gensym4911_, T105_);
			T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T106_ = percent___jiTCvQQpgMU0bTrdVuECiw(T104_, 2);
			T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T107_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T106_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T103_, T107_);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 42):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
			NimStringDesc* res_9;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T109_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T110_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
			res_9 = rawNewString(((NI) 80));
			T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T109_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_570));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T109_);
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T110_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T110_);
			res_9 = resizeString(res_9, 2);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_9), ((NI64) (size)));
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T111_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T111_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 120):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T113_;
			T113_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T113_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, T113_, (&i), NIM_FALSE);
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T118_;
				if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA116_;
				T118_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T118_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, T118_, d, NIM_FALSE);
			}
			LA116_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T123_;
				NimStringDesc* res_10;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T124_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T125_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T126_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T131_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T132_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T133_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T134_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T135_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T140_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T145_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T146_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T147_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T148_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T149_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T154_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T155_;
				if (!(op == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121))) goto LA121_;
				T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T123_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_10 = rawNewString(((NI) 80));
				res_10 = resizeString(res_10, 5);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_115));
				T124_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T124_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T124_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_116));
				T125_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T125_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T125_);
				res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
				cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_10), ((NI64) (size)));
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
				T126_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T126_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T126_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_571));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA129_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA129_: ;
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
				T131_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T131_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T131_);
				res_10 = resizeString(res_10, 5);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_572));
				T132_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T132_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T132_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
				T133_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T133_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T133_);
				res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_573));
				T134_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T134_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T134_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
				T135_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T135_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T135_);
				res_10 = resizeString(res_10, 9);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_574));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA138_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA138_: ;
				res_10 = resizeString(res_10, 7);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_575));
				T140_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T140_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T140_);
				res_10 = resizeString(res_10, 9);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_576));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA143_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA143_: ;
				res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T145_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T145_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T145_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_225));
				T146_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T146_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T146_);
				res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_76));
				T147_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T147_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_577));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T147_);
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T148_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T148_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T148_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T149_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T149_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T149_);
				res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_10), ((NI64) (size)));
				res_10 = resizeString(res_10, 8);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_578));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA152_;
					res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA152_: ;
				T154_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T154_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
				T155_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T155_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T154_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T123_, T155_);
			}
			goto LA119_;
			LA121_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T157_;
				NimStringDesc* res_11;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T158_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T159_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T160_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T165_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T166_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T167_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T168_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T169_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T174_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T179_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T180_;
				T157_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T157_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_11 = rawNewString(((NI) 80));
				res_11 = resizeString(res_11, 5);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_115));
				T158_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T158_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T158_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_116));
				T159_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T159_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T159_);
				res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
				cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_11), ((NI64) (size)));
				res_11 = resizeString(res_11, 2);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
				T160_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T160_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T160_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_571));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA163_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA163_: ;
				res_11 = resizeString(res_11, 2);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_196));
				T165_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T165_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T165_);
				res_11 = resizeString(res_11, 5);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_572));
				T166_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T166_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T166_);
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
				T167_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T167_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T167_);
				res_11 = resizeString(res_11, 6);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_573));
				T168_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T168_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T168_);
				res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
				T169_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T169_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T169_);
				res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_574));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA172_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA172_: ;
				res_11 = resizeString(res_11, 7);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_575));
				T174_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T174_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T174_);
				res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_576));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA177_;
					res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA177_: ;
				T179_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T179_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
				T180_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T180_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T179_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T157_, T180_);
			}
			LA119_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 119):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_3;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b_2;
			NimStringDesc* res_12;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T182_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T183_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T184_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T185_;
			nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_3));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_2));
			res_12 = rawNewString(((NI) 80));
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T182_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T182_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_577));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T182_);
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T183_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T183_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a_3);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T183_);
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T184_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T184_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T184_);
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_12), ((NI64) (size)));
			res_12 = resizeString(res_12, 5);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_565));
			T185_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T185_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T185_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 122):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 123):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 124):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T187_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T192_;
			tyArray__dNfZYyzVYdaWfURv4pxodA T193_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T194_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T195_;
			T187_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T187_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, T187_, (&i), NIM_FALSE);
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			{
				if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA190_;
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, setType, d, NIM_FALSE);
			}
			LA190_: ;
			T192_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T192_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T193_, sizeof(tyArray__dNfZYyzVYdaWfURv4pxodA));
			T193_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(i);
			T193_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (size)));
			T193_[2] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			T193_[3] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T193_[4] = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			T193_[5] = rope__yShmEg9cffWxI7s5XzEKBow(lookupOpr__w7WuexLq9cuXtAtqil9csnVQ[(op)- 120]);
			T194_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T194_ = percent___n4OrLXC1r9a83k5wz2NoWxQ(T193_, 6);
			T195_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T195_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T194_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T192_, T195_);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134):
		{
			genInOp__BKdMcfvryaJLplX0oFPcAQ_18(p, e, d);
		}
		break;
		default:
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_582), TM__MQdRN7fpbG7rPm4JpVVAhA_583);
		}
		break;
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genDefault__8mAL9ckajemzgfLPfeZVNoQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_TRUE);
	}
	goto LA1_;
	LA3_: ;
	{
		resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReset__UtJx89cn0a8CNSWWmaj6raA_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	specializeReset__9cgrUeVA21BOQab6CBAvXRQ(p, a);
}
N_LIB_PRIVATE N_NIMCALL(void, genEcho__UtJx89cn0a8CNSWWmaj6raA_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NimStringDesc* argX60gensym4083_;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA3_;
		argX60gensym4083_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_584);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4083_, TM__MQdRN7fpbG7rPm4JpVVAhA_584);
	}
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* args;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T22_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		if (!((*(*(*(*p).module).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 25))) goto LA7_;
		args = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T10_;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*n)._kind_6.sons;
			i = ((NI) 0);
			T10_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					if (!(i < L)) goto LA12;
					it = &colontmp_->data[i];
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
						T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T15_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*it));
						if (!((*T15_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA16_;
						add__yG4AKzsBRS1W4MANDlXQeg(&args, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_585));
					}
					goto LA13_;
					LA16_: ;
					{
						NimStringDesc* res;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
						initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it), (&a));
						res = rawNewString(((NI) 80));
						res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_586));
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
						res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_587));
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
						res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_588));
						T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
						add__IM4kcMNkkOLJtqdEqSxR8A(&args, T21_);
					}
					LA13_: ;
					i += ((NI) 1);
				} LA12: ;
			}
		}
		includeHeader__G5jzmdnwglHVk5qfDcXonA((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_589));
		includeHeader__G5jzmdnwglHVk5qfDcXonA((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_590));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T22_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 14);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_591));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), args);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA25_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA25_: ;
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T27_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T22_, T28_);
	}
	goto LA5_;
	LA7_: ;
	{
		{
			NI T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			NI T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			T32_ = (NI)0;
			T32_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T32_ == ((NI) 0))) goto LA33_;
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_592));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T36_);
			res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_593));
			T37_ = (NI)0;
			T37_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (T37_)));
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA40_: ;
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T43_);
		}
		goto LA30_;
		LA33_: ;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T45_;
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			NI T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n, (&a_2));
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T45_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_4 = rawNewString(((NI) 80));
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_592));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T46_);
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T47_);
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T48_ = (NI)0;
			T48_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_4), ((NI64) (T48_)));
			res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA51_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA51_: ;
			T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T53_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T54_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T53_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T45_, T54_);
		}
		LA30_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__edSekmjUCfSNOPSuXdUClg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y;
		y = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(b);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					y = (*b)._kind_6.sons->data[i];
					{
						tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w T7_;
						T7_ = (tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w)0;
						T7_ = isPartOf__1otDDZAmvFsmbqPyFytXFg(a, y);
						if (!!((T7_ == ((tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w) 0)))) goto LA8_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__8mAL9ckajemzgfLPfeZVNoQ_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA arr;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	NIM_BOOL doesAlias;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* dest;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* l;
	NI T13_;
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	doesAlias = lhsDoesAlias__edSekmjUCfSNOPSuXdUClg((*d).lode, n);
	{
		if (!doesAlias) goto LA3_;
		dest = (&tmp);
	}
	goto LA1_;
	LA3_: ;
	{
		dest = d;
	}
	LA1_: ;
	{
		if (!doesAlias) goto LA8_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, (&tmp), NIM_FALSE);
	}
	goto LA6_;
	LA8_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA11_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
	}
	goto LA6_;
	LA11_: ;
	LA6_: ;
	T13_ = (NI)0;
	T13_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	l = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (T13_)));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqtype;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T18_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA16_;
		seqtype = (*n).typ;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T18_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*dest));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_525));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), l);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*dest));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_526));
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2((*p).module, seqtype);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T21_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_359));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_527));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T22_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), l);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
		T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T23_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T23_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T24_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_528));
		T25_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T25_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T25_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T26_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA29_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA29_: ;
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T31_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T18_, T32_);
	}
	goto LA14_;
	LA16_: ;
	{
		NIM_BOOL T34_;
		NI T36_;
		T34_ = (NIM_BOOL)0;
		T34_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0));
		if (!(T34_)) goto LA35_;
		T36_ = (NI)0;
		T36_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T34_ = (T36_ == ((NI) 0));
		LA35_: ;
		genNewSeqAux__Ri3gLeBVOaUltgSIU2SrQQ(p, (*dest), l, T34_);
	}
	LA14_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
				if (!(i_2 < colontmp_)) goto LA39;
				i = i_2;
				initLoc__qlujIAW86QclHYUVxlHRiQ((&arr), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), (*n)._kind_6.sons->data[i], ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
				res_2 = rawNewString(((NI) 80));
				T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T40_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*dest));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T40_);
				T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T41_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T41_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
				T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T42_ = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (i)));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T42_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
				arr.r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				arr.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*n)._kind_6.sons->data[i], (&arr));
				i_2 += ((NI) 1);
			} LA39: ;
		}
	}
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, n);
	{
		if (!doesAlias) goto LA45_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA49_;
			genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
		}
		goto LA47_;
		LA49_: ;
		{
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
		}
		LA47_: ;
	}
	LA45_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__8mAL9ckajemzgfLPfeZVNoQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA elem;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA arr;
	NI L;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
{	nimZeroMem((void*)(&elem), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA3_;
		asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 1)]).typ), (*n).typ);
		genSeqConstr__8mAL9ckajemzgfLPfeZVNoQ_6(p, (*n)._kind_6.sons->data[((NI) 1)], d);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA7_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
	}
	LA7_: ;
	T9_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	L = toInt__TIX0sFuRf3uBpOBltYp7bw(T9_);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqtype;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T14_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA12_;
		seqtype = (*n).typ;
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T14_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_525));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (L)));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_526));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = getSeqPayloadType__HPYuz9bvVOGBv0EUX9c74xhg_2((*p).module, seqtype);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_359));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_527));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (L)));
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
		T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T19_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T19_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
		res = resizeString(res, 15);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_528));
		T21_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T21_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(seqtype);
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T21_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T22_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA25_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA25_: ;
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T27_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T14_, T28_);
	}
	goto LA10_;
	LA12_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		NIM_BOOL T31_;
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (L)));
		T31_ = (NIM_BOOL)0;
		T31_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0));
		if (!(T31_)) goto LA32_;
		T31_ = (L == ((NI) 0));
		LA32_: ;
		genNewSeqAux__Ri3gLeBVOaUltgSIU2SrQQ(p, (*d), T30_, T31_);
	}
	LA10_: ;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	{
		if (!(L < ((NI) 10))) goto LA35_;
		{
			NI i;
			NI i_2;
			i = (NI)0;
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T40_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T41_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T47_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T48_;
					NimStringDesc* res_3;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
					if (!(i_2 < L)) goto LA39;
					i = i_2;
					T40_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T40_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
					T41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T41_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(T40_);
					T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T42_ = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T41_);
					initLoc__qlujIAW86QclHYUVxlHRiQ((&elem), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), T42_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
					res_2 = rawNewString(((NI) 80));
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T43_);
					T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T44_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T44_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
					T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T45_ = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (i)));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T45_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
					elem.r = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					elem.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
					T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T46_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350135273744));
					T47_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T47_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(T46_);
					T48_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T48_ = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T47_);
					initLoc__qlujIAW86QclHYUVxlHRiQ((&arr), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), T48_, a.storage);
					res_3 = rawNewString(((NI) 80));
					T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T49_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T49_);
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
					T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T50_ = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (i)));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T50_);
					res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
					arr.r = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
					genAssignment__BtucsTdHw7orsXIL75hNVg(p, elem, arr, 1);
					i_2 += ((NI) 1);
				} LA39: ;
			}
		}
	}
	goto LA33_;
	LA35_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA i_3;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T53_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T61_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T62_;
		NimStringDesc* res_5;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T66_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T67_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T68_;
		NimStringDesc* res_6;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T71_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T72_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
		nimZeroMem((void*)(&i_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T52_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T52_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, T52_, (&i_3), NIM_FALSE);
		T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T53_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_115));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), i_3.r);
		res_4 = resizeString(res_4, 6);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_116));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), i_3.r);
		res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_4), ((NI64) (L)));
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), i_3.r);
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_119));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA56_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA56_: ;
		T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T58_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T59_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T58_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T53_, T59_);
		T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T60_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
		T61_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T61_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(T60_);
		T62_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T62_ = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T61_);
		initLoc__qlujIAW86QclHYUVxlHRiQ((&elem), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), T62_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
		res_5 = rawNewString(((NI) 80));
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T63_);
		T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T64_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T64_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T65_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i_3);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T65_);
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		elem.r = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		elem.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
		T66_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T66_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350135273744));
		T67_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T67_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(T66_);
		T68_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T68_ = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T67_);
		initLoc__qlujIAW86QclHYUVxlHRiQ((&arr), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), T68_, a.storage);
		res_6 = rawNewString(((NI) 80));
		T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T69_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T69_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T70_ = rdLoc__xidyzuHqIciXbQyEOKahDg(i_3);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T70_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		arr.r = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, elem, arr, 1);
		T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T71_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T72_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T73_ = percent___BYiowJAm8zF7RBRISElaLg(T72_, 0);
		T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T74_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T73_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T71_, T74_);
	}
	LA33_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__jdslQ8TsNpkTt8SvBLJjEA_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(1189055854751557904));
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T3_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T3_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T4_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_598));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T4_);
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmpX60gensym3495_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
			if (!(src.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6))) goto LA9_;
			nimZeroMem((void*)(&tmpX60gensym3495_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T11_ = t__XNOXh7uniWNgiq58C9bW49awcgen(src);
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, T11_, (&tmpX60gensym3495_), NIM_FALSE);
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmpX60gensym3495_, src, 0);
			T6_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmpX60gensym3495_);
		}
		goto LA7_;
		LA9_: ;
		{
			T6_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
		}
		LA7_: ;
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T13_, (*dest.lode).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA17_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA17_: ;
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T19_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T3_, T20_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T26_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA24_;
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T26_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_598));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
			res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			{
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmpX60gensym3509_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T34_;
				if (!(src.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6))) goto LA32_;
				nimZeroMem((void*)(&tmpX60gensym3509_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				T34_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T34_ = t__XNOXh7uniWNgiq58C9bW49awcgen(src);
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, T34_, (&tmpX60gensym3509_), NIM_FALSE);
				genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmpX60gensym3509_, src, 0);
				T29_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmpX60gensym3509_);
			}
			goto LA30_;
			LA32_: ;
			{
				T29_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
			}
			LA30_: ;
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T36_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T36_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T36_, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T37_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA40_: ;
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T26_, T43_);
		}
		goto LA22_;
		LA24_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T45_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T55_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T45_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_599));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T46_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T47_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T48_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T49_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T50_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T49_, (*dest.lode).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T50_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA53_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA53_: ;
			T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T55_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T56_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T55_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T45_, T56_);
		}
		LA22_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T58_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
		T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T58_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T59_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_600));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T59_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
		T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T60_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T60_);
		res_4 = resizeString(res_4, 9);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_219));
		T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmpX60gensym3530_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T66_;
			if (!(src.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6))) goto LA64_;
			nimZeroMem((void*)(&tmpX60gensym3530_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			T66_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T66_ = t__XNOXh7uniWNgiq58C9bW49awcgen(src);
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, T66_, (&tmpX60gensym3530_), NIM_FALSE);
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, tmpX60gensym3530_, src, 0);
			T61_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, tmpX60gensym3530_);
		}
		goto LA62_;
		LA64_: ;
		{
			T61_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, src);
		}
		LA62_: ;
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T61_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T68_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T68_);
		res_4 = resizeString(res_4, 7);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_240));
		T69_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T69_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
		T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T70_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, T69_, (*dest.lode).info);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T70_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA73_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA73_: ;
		T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T75_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T76_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T75_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T58_, T76_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T80_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T83_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T87_;
			NI64 T88_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
			T80_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
			T80_ = mapSetType__K9aceyVl15zb9aYN9b6YJ8TnA((*(*(*p).module).g).config, ty);
			if (!(T80_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17))) goto LA81_;
			T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T83_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_5 = rawNewString(((NI) 80));
			T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T84_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_212));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T84_);
			res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_79));
			T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T85_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T85_);
			res_5 = resizeString(res_5, 19);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_217));
			T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T86_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T86_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T87_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T87_ = t__XNOXh7uniWNgiq58C9bW49awcgen(dest);
			T88_ = (NI64)0;
			T88_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, T87_);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_5), T88_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA91_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA91_: ;
			T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T93_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T94_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T93_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T83_, T94_);
		}
		goto LA78_;
		LA81_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T96_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T98_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T104_;
			T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T96_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_6 = rawNewString(((NI) 80));
			T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T97_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T97_);
			res_6 = resizeString(res_6, 3);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
			T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T98_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T98_);
			res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA101_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA101_: ;
			T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T103_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			T104_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T104_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T103_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T96_, T104_);
		}
		LA78_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T106_;
		NimStringDesc* res_7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
		T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T106_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_7 = rawNewString(((NI) 80));
		T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T107_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T107_);
		res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T108_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T108_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA111_;
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA111_: ;
		T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T113_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T114_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T113_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T106_, T114_);
	}
	break;
	default:
	{
		NimStringDesc* T116_;
		T116_ = (NimStringDesc*)0;
		T116_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 13);
appendString(T116_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_601));
appendString(T116_, reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T116_, TM__MQdRN7fpbG7rPm4JpVVAhA_602);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__oKhRC9bEKTxG5epdNiNWZ0w_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__UtJx89cn0a8CNSWWmaj6raA_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n1;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	n1 = skipAddr__oKhRC9bEKTxG5epdNiNWZ0w_4((*n)._kind_6.sons->data[((NI) 1)]);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*p).withinBlockLeaveActions);
		if (!(T3_)) goto LA4_;
		T3_ = notYetAlive__4MUa2M7mDMhaGJLAFrkWDw_2cgen(n1);
		LA4_: ;
		if (!T3_) goto LA5_;
	}
	goto LA1_;
	LA5_: ;
	{
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, n1, (&a));
		resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, (&a));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMove__8mAL9ckajemzgfLPfeZVNoQ_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = skipAddr__oKhRC9bEKTxG5epdNiNWZ0w_4((*n)._kind_6.sons->data[((NI) 1)]);
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, T1_, (&a));
	{
		NI T4_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA src;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T7_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T4_ == ((NI) 4))) goto LA5_;
		nimZeroMem((void*)(&src), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 2)], (&src));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T7_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_603));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_604));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T10_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T7_, T11_);
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*n)._kind_6.sons->data[((NI) 3)]);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA15_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA15_: ;
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T17_);
		res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_525));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T18_);
		res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_605));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T19_);
		res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_606));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rdLoc__xidyzuHqIciXbQyEOKahDg(src);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T20_);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_607));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA23_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA23_: ;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T12_, T26_);
	}
	goto LA2_;
	LA5_: ;
	{
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA30_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
		}
		LA30_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), a, 0);
		resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, (&a));
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__UtJx89cn0a8CNSWWmaj6raA_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA3_;
		arg = skipAddr__oKhRC9bEKTxG5epdNiNWZ0w_4((*n)._kind_6.sons->data[((NI) 1)]);
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36134350135273744));
		switch ((*t).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, arg, (&a));
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 22))&63U)))!=0)) goto LA8_;
				T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
				res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_608));
				T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
				res = resizeString(res, 29);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_609));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA15_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA15_: ;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
				T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T17_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_610));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_611));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA21_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA21_: ;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA25_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA25_: ;
				T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T27_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T28_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T27_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T28_);
			}
			goto LA6_;
			LA8_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T30_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
				T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T30_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T31_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
				res_2 = resizeString(res_2, 8);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_608));
				T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T32_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T32_);
				res_2 = resizeString(res_2, 29);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_609));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA35_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA35_: ;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
				T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T37_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_612));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T37_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T38_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T38_);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_611));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA41_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA41_: ;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA45_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA45_: ;
				T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T47_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T48_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T47_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T30_, T48_);
			}
			LA6_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T50_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, arg, (&a_2));
			T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T50_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T51_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T51_);
			res_3 = resizeString(res_3, 8);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_608));
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T52_);
			res_3 = resizeString(res_3, 29);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_609));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA55_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA55_: ;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T57_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_613));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T57_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T58_);
			res_3 = resizeString(res_3, 16);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_614));
			T59_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T59_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T59_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T60_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA63_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA63_: ;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA67_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA67_: ;
			T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T69_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T69_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T50_, T70_);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
		{
			NIM_BOOL T75_;
			NI T77_;
			T75_ = (NIM_BOOL)0;
			T75_ = !(((*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T75_)) goto LA76_;
			T77_ = (NI)0;
			T77_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]).ast)._kind_6.sons->data[((NI) 6)]);
			T75_ = !((T77_ == ((NI) 0)));
			LA76_: ;
			if (!T75_) goto LA78_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_615), TM__MQdRN7fpbG7rPm4JpVVAhA_616);
		}
		LA78_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSlice__BKdMcfvryaJLplX0oFPcAQ_19)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyTuple__nsNHL3sm0TZE9bootw2pEXw T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* y;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T7_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*e).typ);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
	genOpenArraySlice__OgTjHQyQeIgTGpsUfPmxRQ(p, e, (*e).typ, T1_, (&T2_));
	x = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	x = T2_.Field0;
	y = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	y = T2_.Field1;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA5_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
	}
	LA5_: ;
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T7_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_231));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), x);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
	res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_233));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), y);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA12_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA12_: ;
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T15_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T14_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T7_, T15_);
}
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__TU9cJnldbmGa9bZDxaR6I4tg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109):
	{
		genAndOr__yX5yxw6c9agMF4ZvIHKAZvg(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 100):
	{
		unaryArith__TU9cJnldbmGa9bZDxaR6I4tg_2(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 95):
	{
		unaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_2(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 53) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 56):
	{
		binaryFloatArith__yX5yxw6c9agMF4ZvIHKAZvg_3(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 90):
	{
		binaryArith__TU9cJnldbmGa9bZDxaR6I4tg_3(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 92):
	{
		genEqProc__BKdMcfvryaJLplX0oFPcAQ(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 46) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52):
	{
		binaryArithOverflow__yX5yxw6c9agMF4ZvIHKAZvg_4(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 135):
	{
		genRepr__BKdMcfvryaJLplX0oFPcAQ_2(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 257):
	{
		genGetTypeInfo__BKdMcfvryaJLplX0oFPcAQ_3(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 258):
	{
		genGetTypeInfoV2__BKdMcfvryaJLplX0oFPcAQ_4(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 142):
	{
		genSwap__BKdMcfvryaJLplX0oFPcAQ_5(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 29):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 30):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* underlying;
		underlying = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(211106241980432));
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0));
			if (T15_) goto LA16_;
			T15_ = ((*underlying).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*underlying).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
			LA16_: ;
			if (!T15_) goto LA17_;
			binaryStmt__FWB0HmRDLgoWdgSy9bfL9b5w(p, e, d, opr__O7uP3jzNu3e9auWdRdRa9cJA[(op)- 29]);
		}
		goto LA13_;
		LA17_: ;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ranged;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* res;
			NI64 sizeX60gensym5218_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* storageX60gensym5218_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resultX60gensym5218_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T25_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T32_;
			NimStringDesc* res_3;
			NimStringDesc* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b));
			ranged = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(211106240923664));
			sizeX60gensym5218_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, ranged);
			{
				if (!(sizeX60gensym5218_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)))) goto LA22_;
				storageX60gensym5218_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_310));
			}
			goto LA20_;
			LA22_: ;
			{
				storageX60gensym5218_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ranged, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			}
			LA20_: ;
			resultX60gensym5218_ = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T25_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			res_2 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), storageX60gensym5218_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), resultX60gensym5218_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA28_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA28_: ;
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T30_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T25_, T31_);
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T32_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T33_ = (NimStringDesc*)0;
			{
				if (!((*underlying).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35))) goto LA36_;
				T33_ = copyString(fun64__fjrbodMqcYB619bEDCGfJsA[(op)- 29]);
			}
			goto LA34_;
			LA36_: ;
			{
				T33_ = copyString(fun__gOe15RXeJ2duD5In6NwLXA[(op)- 29]);
			}
			LA34_: ;
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, T33_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T39_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T40_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T41_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T41_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_456));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), resultX60gensym5218_);
			res_3 = resizeString(res_3, 5);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_457));
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_432));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T42_);
			res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T43_);
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_193));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA46_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA46_: ;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T49_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T48_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T32_, T49_);
			{
				NIM_BOOL T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T56_;
				NimStringDesc* res_4;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T57_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T59_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
				T52_ = (NIM_BOOL)0;
				T52_ = (sizeX60gensym5218_ < ((NI64) ((*(*(*(*p).module).g).config).target.intSize)));
				if (T52_) goto LA53_;
				T52_ = ((*ranged).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20) || (*ranged).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
				LA53_: ;
				if (!T52_) goto LA54_;
				T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T56_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), resultX60gensym5218_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
				T57_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ranged);
				T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T58_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T57_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T58_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), resultX60gensym5218_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_400));
				T59_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ranged);
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T59_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T60_);
				res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
				T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T61_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_432));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T61_);
				res_4 = resizeString(res_4, 4);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T62_);
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA65_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA65_: ;
				T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T67_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
				T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T68_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T67_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T56_, T68_);
			}
			LA54_: ;
			res = resultX60gensym5218_;
			nimZeroMem((void*)T69_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T69_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, ranged, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T69_[1] = res;
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = percent___0ym49cR6ES8k9bYWsnh1fELA(T69_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, (&a), (*e)._kind_6.sons->data[((NI) 1)], T70_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		LA13_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 125):
	{
		genStrConcat__BKdMcfvryaJLplX0oFPcAQ_6(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 131):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA75_;
			binaryStmtAddr__vxeaiXjty5M8JXT1fo429aQ(p, e, d, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_489));
		}
		goto LA73_;
		LA75_: ;
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA dest;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b_2;
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA call;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T80_;
			nimZeroMem((void*)(&dest), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			nimZeroMem((void*)(&call), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLoc__qlujIAW86QclHYUVxlHRiQ((&call), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 9), e, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&dest));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_2));
			res_5 = rawNewString(((NI) 80));
			T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T78_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_490));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T78_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T79_ = rdLoc__xidyzuHqIciXbQyEOKahDg(dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T79_);
			res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T80_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b_2);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T80_);
			res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
			call.r = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, dest, call, 0);
		}
		LA73_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 132):
	{
		genStrAppend__BKdMcfvryaJLplX0oFPcAQ_7(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 133):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA85_;
			asgnRef((void**) (&(*e)._kind_6.sons->data[((NI) 1)]), makeAddr__oKhRC9bEKTxG5epdNiNWZ0w_3((*e)._kind_6.sons->data[((NI) 1)]));
			genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, e, d);
		}
		goto LA83_;
		LA85_: ;
		{
			genSeqElemAppend__BKdMcfvryaJLplX0oFPcAQ_9(p, e, d);
		}
		LA83_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 116):
	{
		genStrEquals__BKdMcfvryaJLplX0oFPcAQ_10(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 117):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5262_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym5262_;
		NimStringDesc* res_6;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
		nimZeroMem((void*)(&aX60gensym5262_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&bX60gensym5262_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5262_));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5262_));
		res_6 = rawNewString(((NI) 80));
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T90_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_499));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T90_);
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T91_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5262_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T91_);
		res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T92_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym5262_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T92_);
		res_6 = resizeString(res_6, 7);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_500));
		T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T93_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T93_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 118):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5277_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA bX60gensym5277_;
		NimStringDesc* res_7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T98_;
		nimZeroMem((void*)(&aX60gensym5277_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&bX60gensym5277_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5277_));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&bX60gensym5277_));
		res_7 = rawNewString(((NI) 80));
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T95_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_499));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T95_);
		res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T96_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5277_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T96_);
		res_7 = resizeString(res_7, 2);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
		T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T97_ = rdLoc__xidyzuHqIciXbQyEOKahDg(bX60gensym5277_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), T97_);
		res_7 = resizeString(res_7, 6);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_501));
		T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T98_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T98_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 143):
	{
		genIsNil__BKdMcfvryaJLplX0oFPcAQ_11(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 103):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5292_;
		NimStringDesc* res_8;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
		nimZeroMem((void*)(&aX60gensym5292_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5292_));
		res_8 = rawNewString(((NI) 80));
		T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T101_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_503));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T101_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T102_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5292_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T102_);
		res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5292_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
		aX60gensym5292_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA105_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA105_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5292_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 104):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5299_;
		NimStringDesc* res_9;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T109_;
		nimZeroMem((void*)(&aX60gensym5299_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5299_));
		res_9 = rawNewString(((NI) 80));
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T108_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_504));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T108_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T109_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5299_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T109_);
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5299_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
		aX60gensym5299_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA112_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA112_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5299_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 102):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5306_;
		NimStringDesc* res_10;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T115_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T116_;
		nimZeroMem((void*)(&aX60gensym5306_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5306_));
		res_10 = rawNewString(((NI) 80));
		T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T115_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_505));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T115_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T116_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5306_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T116_);
		res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5306_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
		aX60gensym5306_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA119_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA119_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5306_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 101):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5313_;
		NimStringDesc* res_11;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T122_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T123_;
		nimZeroMem((void*)(&aX60gensym5313_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5313_));
		res_11 = rawNewString(((NI) 80));
		T122_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T122_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_506));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T122_);
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T123_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5313_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T123_);
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5313_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
		aX60gensym5313_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA126_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA126_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5313_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 105):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5320_;
		NimStringDesc* res_12;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T129_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T130_;
		nimZeroMem((void*)(&aX60gensym5320_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5320_));
		res_12 = rawNewString(((NI) 80));
		T129_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T129_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_507));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T129_);
		res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T130_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T130_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5320_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T130_);
		res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5320_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
		aX60gensym5320_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA133_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA133_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5320_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 106):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5327_;
		NimStringDesc* res_13;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T136_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T137_;
		nimZeroMem((void*)(&aX60gensym5327_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5327_));
		res_13 = rawNewString(((NI) 80));
		T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T136_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_508));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T136_);
		res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T137_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5327_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T137_);
		res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		aX60gensym5327_.r = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
		aX60gensym5327_.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 0)) & 15));
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA140_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA140_: ;
		genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), aX60gensym5327_, 0);
		gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 152):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 153):
	{
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 108):
	{
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA146_;
			genEnumToStr__BKdMcfvryaJLplX0oFPcAQ_12(p, e, d);
		}
		goto LA144_;
		LA146_: ;
		{
			genRepr__BKdMcfvryaJLplX0oFPcAQ_2(p, e, d);
		}
		LA144_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 15):
	{
		genOf__8mAL9ckajemzgfLPfeZVNoQ_3(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 32):
	{
		genNew__X9cSqNhqEboci9cdmwBMNcBw(p, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33):
	{
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA154_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&a_2));
			rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg(p, (&a_2), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL), NIM_TRUE);
			gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
		}
		goto LA152_;
		LA154_: ;
		{
			genNewFinalize__X9cSqNhqEboci9cdmwBMNcBw_2(p, e);
		}
		LA152_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 34):
	{
		genNewSeq__X9cSqNhqEboci9cdmwBMNcBw_3(p, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 35):
	{
		genNewSeqOfCap__BKdMcfvryaJLplX0oFPcAQ_13(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 10):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T160_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T161_;
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, 256);
		nimZeroMem((void*)T160_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T160_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		T161_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T161_ = percent___c4YKWXetPKpaUUF7Qft2gA(T160_, 1);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T161_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 11):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T163_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T164_;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, 256);
		nimZeroMem((void*)T163_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T163_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t_2, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		T164_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T164_ = percent___9a4eEIrTth9cYD1nB3M11LRQ(T163_, 1);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T164_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 12):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dotExpr;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tname;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* member;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T180_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T181_;
		dotExpr = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA168_;
			dotExpr = (*e)._kind_6.sons->data[((NI) 1)];
		}
		goto LA166_;
		LA168_: ;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46))) goto LA171_;
			dotExpr = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA166_;
		LA171_: ;
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_532), TM__MQdRN7fpbG7rPm4JpVVAhA_533);
		}
		LA166_: ;
		t_3 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*dotExpr)._kind_6.sons->data[((NI) 0)]).typ, 256);
		tname = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t_3, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T178_;
			if (!((*t_3).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA176_;
			T178_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T178_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*(*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym).position)));
			member = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_534), T178_);
		}
		goto LA174_;
		LA176_: ;
		{
			member = (*(*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym).loc.r;
		}
		LA174_: ;
		nimZeroMem((void*)T180_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T180_[0] = tname;
		T180_[1] = member;
		T181_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T181_ = percent___lXaYcLcHHuQ46VvpH6Qr2A(T180_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T181_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 43):
	{
		genSomeCast__BKdMcfvryaJLplX0oFPcAQ_14(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 31):
	{
		genOrd__BKdMcfvryaJLplX0oFPcAQ_15(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 38):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 37):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 39):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 36):
	{
		genArrayLen__TU9cJnldbmGa9bZDxaR6I4tg_4(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 44):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5354_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T190_;
		NimStringDesc* res_14;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T191_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T192_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T193_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T198_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T199_;
		nimZeroMem((void*)(&aX60gensym5354_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA188_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_548), TM__MQdRN7fpbG7rPm4JpVVAhA_549);
		}
		LA188_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5354_));
		T190_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T190_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_14 = rawNewString(((NI) 80));
		res_14 = resizeString(res_14, 4);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T191_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T191_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5354_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_14), T191_);
		res_14 = resizeString(res_14, 4);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
		T192_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T192_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_550));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_14), T192_);
		res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T193_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T193_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5354_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_14), T193_);
		res_14 = resizeString(res_14, 4);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_551));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA196_;
			res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA196_: ;
		T198_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T198_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
		T199_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T199_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T198_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T190_, T199_);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 45):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5368_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T205_;
		NimStringDesc* res_15;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T206_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T207_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T208_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T213_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T214_;
		nimZeroMem((void*)(&aX60gensym5368_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		{
			if (!!(((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0)))) goto LA203_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_548), TM__MQdRN7fpbG7rPm4JpVVAhA_549);
		}
		LA203_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5368_));
		T205_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T205_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_15 = rawNewString(((NI) 80));
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T206_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T206_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5368_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T206_);
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_440));
		T207_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T207_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_552));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T207_);
		res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T208_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T208_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5368_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T208_);
		res_15 = resizeString(res_15, 4);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_551));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA211_;
			res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA211_: ;
		T213_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T213_ = rope__yShmEg9cffWxI7s5XzEKBow(res_15);
		T214_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T214_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T213_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T205_, T214_);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 137):
	{
		genSetLengthStr__BKdMcfvryaJLplX0oFPcAQ_16(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 138):
	{
		genSetLengthSeq__BKdMcfvryaJLplX0oFPcAQ_17(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 40):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 41):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 42):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 120):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 119):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 122):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 123):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 124):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134):
	{
		genSetOp__TU9cJnldbmGa9bZDxaR6I4tg_5(p, e, d, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 145):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 146):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 136):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 147):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opr;
		opr = (*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
			NimStringDesc* T223_;
			NIM_BOOL wasDeclared;
			NimStringDesc* T224_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T225_;
			if (!!((((*opr).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0))) goto LA221_;
			T223_ = (NimStringDesc*)0;
			T223_ = dollar___mZ66tEveFIQokq3arf8Klw((*opr).loc.r);
			prc = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*(*p).module).g).graph, T223_);
			wasDeclared = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).module).declaredProtos), (*prc).Sup.id);
			T224_ = (NimStringDesc*)0;
			T224_ = dollar___mZ66tEveFIQokq3arf8Klw((*opr).loc.r);
			T225_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T225_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, T224_);
			(void)(T225_);
			{
				NIM_BOOL T228_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T232_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T233_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T234_;
				T228_ = (NIM_BOOL)0;
				T228_ = !(wasDeclared);
				if (!(T228_)) goto LA229_;
				T228_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
				LA229_: ;
				if (!T228_) goto LA230_;
				nimZeroMem((void*)T232_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T232_[0] = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(prc);
				T233_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T233_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*prc).loc);
				T232_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T233_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				T232_[2] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3((*p).module, prc);
				T234_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T234_ = percent___vHbYzYlzLPcurSm0Hu8InQ(T232_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 18))- 0], T234_);
			}
			LA230_: ;
		}
		LA221_: ;
		genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 151):
	{
		genDefault__8mAL9ckajemzgfLPfeZVNoQ_4(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 155):
	{
		genReset__UtJx89cn0a8CNSWWmaj6raA_3(p, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 20):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T238_;
		T238_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T238_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*e)._kind_6.sons->data[((NI) 1)]);
		genEcho__UtJx89cn0a8CNSWWmaj6raA_4(p, T238_);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 144):
	{
		genArrToSeq__8mAL9ckajemzgfLPfeZVNoQ_5(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 208) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 255):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 22) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 28):
	{
		NimStringDesc* T241_;
		T241_ = (NimStringDesc*)0;
		T241_ = nsuFormatSingleElem(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_594), (*(*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T241_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_595, NIM_FALSE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		n = wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw((*(*(*p).module).g).graph, (*(*p).module).module, e, (*e).typ, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, n, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 141):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
		n_2 = liftParallel__ndOOzgg7N9cEw3E9bRfkcIDw((*(*(*p).module).g).graph, (*(*p).module).module, e);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, n_2, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 195):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_3;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b_3;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		{
			NIM_BOOL T247_;
			T247_ = (NIM_BOOL)0;
			T247_ = ((48 &((NU16)1<<((NU)((*(*(*(*p).module).g).config).selectedGC)&15U)))!=0);
			if (!(T247_)) goto LA248_;
			T247_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 51))&63U)))!=0));
			LA248_: ;
			if (!T247_) goto LA249_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_596), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_597, NIM_FALSE);
		}
		LA249_: ;
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&b_3), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) || (*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA253_;
			x = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		}
		goto LA251_;
		LA253_: ;
		{
			x = (*e)._kind_6.sons->data[((NI) 1)];
		}
		LA251_: ;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a_3));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 2)], (&b_3));
		genDeepCopy__jdslQ8TsNpkTt8SvBLJjEA_2(p, a_3, b_3);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 127):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 91):
	{
		genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 149):
	{
		genWasMoved__UtJx89cn0a8CNSWWmaj6raA_5(p, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 148):
	{
		genMove__8mAL9ckajemzgfLPfeZVNoQ_7(p, e, d);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 150):
	{
		genDestroy__UtJx89cn0a8CNSWWmaj6raA_6(p, e);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 154):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym5403_;
		NimStringDesc* res_16;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T261_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T262_;
		nimZeroMem((void*)(&aX60gensym5403_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 1)], (&aX60gensym5403_));
		res_16 = rawNewString(((NI) 80));
		T261_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T261_ = rdLoc__xidyzuHqIciXbQyEOKahDg(aX60gensym5403_);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_16), T261_);
		res_16 = resizeString(res_16, 6);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_159));
		T262_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T262_ = rope__yShmEg9cffWxI7s5XzEKBow(res_16);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T262_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126):
	{
		genSlice__BKdMcfvryaJLplX0oFPcAQ_19(p, e, d);
	}
	break;
	default:
	{
		NimStringDesc* T265_;
		T265_ = (NimStringDesc*)0;
		T265_ = rawNewString((reprEnum((NI)op, (&NTI__shZhZOdbVC5nnFvcXQAImg_)) ? reprEnum((NI)op, (&NTI__shZhZOdbVC5nnFvcXQAImg_))->Sup.len : 0) + 14);
appendString(T265_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_617));
appendString(T265_, reprEnum((NI)op, (&NTI__shZhZOdbVC5nnFvcXQAImg_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, T265_, TM__MQdRN7fpbG7rPm4JpVVAhA_618);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genSetNode__NYI5fC69aIqZGRakncXv9cNQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NI size;
	NI64 T1_;
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* cs;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NI64)0;
	T1_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, (*n).typ);
	size = ((NI) (T1_));
	cs = toBitSet__Ccp5iPnBYFcoF9aTCBpla6A((*(*(*p).module).g).config, n);
	{
		NI id;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!(((NI) 8) < size)) goto LA4_;
		id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
		result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*(*p).module).tmpBase, T6_);
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			if (!(id == ((NI) ((*(*p).module).labels)))) goto LA9_;
			(*(*p).module).labels += ((NI) 1);
			nimZeroMem((void*)T11_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T11_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T11_[1] = result;
			T11_[2] = genRawSetData__P8T6oQDSZlTI5UtVVMB9c9aw(cs, size);
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = percent___bJpxHYPJaxWBQn6QxwBA4w(T11_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T12_);
		}
		LA9_: ;
	}
	goto LA2_;
	LA4_: ;
	{
		result = genRawSetData__P8T6oQDSZlTI5UtVVMB9c9aw(cs, size);
	}
	LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__BKdMcfvryaJLplX0oFPcAQ_20)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA idx;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&idx), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!(((*e).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 4))&31U)))!=0)) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = genSetNode__NYI5fC69aIqZGRakncXv9cNQ_3(p, e);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T5_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	goto LA1_;
	LA3_: ;
	{
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA9_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*e).typ, d, NIM_FALSE);
		}
		LA9_: ;
		{
			NI64 T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T16_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			T13_ = (NI64)0;
			T13_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, (*e).typ);
			if (!(IL64(8) < T13_)) goto LA14_;
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T16_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_78));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_81));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_82));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA22_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA22_: ;
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T24_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T16_, T25_);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
				tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
				NI i;
				NI L;
				NI T27_;
				it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
				colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
				colontmp_ = (*e)._kind_6.sons;
				i = ((NI) 0);
				T27_ = (colontmp_ ? colontmp_->Sup.len : 0);
				L = T27_;
				{
					while (1) {
						if (!(i < L)) goto LA29;
						it = &colontmp_->data[i];
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T34_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
							tyArray__f7nG5LD47BH5K9c6mASit3g T36_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
							if (!((*(*it)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA32_;
							T34_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T34_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
							getTemp__VjOFVqypINqQv5C3ECnxbw(p, T34_, (&idx), NIM_FALSE);
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*it))._kind_6.sons->data[((NI) 0)], (&a));
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*it))._kind_6.sons->data[((NI) 1)], (&b));
							T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T36_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
							T36_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(idx);
							T36_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
							T36_[2] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, a, (*e).typ);
							T36_[3] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, b, (*e).typ);
							T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T37_ = percent___fOn9b5Ij3ytw2Ui9a2CPI5zw(T36_, 4);
							T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T38_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T37_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T38_);
						}
						goto LA30_;
						LA32_: ;
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T40_;
							tyArray__mrugoXXRZUEeG9bEXo9auBKw T41_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it), (&a));
							T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T40_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T41_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
							T41_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
							T41_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, a, (*e).typ);
							T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T42_ = percent___zJU3FoYOdJ9bmuODPmqtgdQ(T41_, 2);
							T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T40_, T43_);
						}
						LA30_: ;
						i += ((NI) 1);
					} LA29: ;
				}
			}
		}
		goto LA11_;
		LA14_: ;
		{
			NimStringDesc* ts;
			NimStringDesc* T45_;
			NI64 T46_;
			NimStringDesc* T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T48_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T49_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
			T45_ = (NimStringDesc*)0;
			T46_ = (NI64)0;
			T46_ = getSize__vCG1GF2Iu043oALVyuJfOw((*(*(*p).module).g).config, (*e).typ);
			T47_ = (NimStringDesc*)0;
			T47_ = nimInt64ToStr((NI64)(T46_ * IL64(8)));
			T45_ = rawNewString((T47_ ? T47_->Sup.len : 0) + 2);
appendString(T45_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_319));
appendString(T45_, T47_);
			ts = T45_;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T48_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T49_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T49_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
			T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T50_ = percent___1MXpJAdeOMc2XMg5H7t9aSg(T49_, 1);
			T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T51_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T50_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T48_, T51_);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it_2;
				tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp__2;
				NI i_2;
				NI L_2;
				NI T53_;
				it_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
				colontmp__2 = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
				colontmp__2 = (*e)._kind_6.sons;
				i_2 = ((NI) 0);
				T53_ = (colontmp__2 ? colontmp__2->Sup.len : 0);
				L_2 = T53_;
				{
					while (1) {
						if (!(i_2 < L_2)) goto LA55;
						it_2 = &colontmp__2->data[i_2];
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
							tyArray__duFhZXIIlrbrM62cWjNekg T62_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
							if (!((*(*it_2)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA58_;
							T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T60_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*(*p).module).g).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
							getTemp__VjOFVqypINqQv5C3ECnxbw(p, T60_, (&idx), NIM_FALSE);
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*it_2))._kind_6.sons->data[((NI) 0)], (&a));
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*it_2))._kind_6.sons->data[((NI) 1)], (&b));
							T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T62_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
							T62_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(idx);
							T62_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
							T62_[2] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, a, (*e).typ);
							T62_[3] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, b, (*e).typ);
							T62_[4] = rope__yShmEg9cffWxI7s5XzEKBow(ts);
							T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T63_ = percent___VNAv31sqVgxrd9aXeFF5wYw(T62_, 5);
							T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T64_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T63_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T64_);
						}
						goto LA56_;
						LA58_: ;
						{
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T66_;
							tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T67_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
							initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it_2), (&a));
							T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T66_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T67_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
							T67_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
							T67_[1] = rdSetElemLoc__yZiAKtQMz62JmONYJ0rLzg((*(*(*p).module).g).config, a, (*e).typ);
							T67_[2] = rope__yShmEg9cffWxI7s5XzEKBow(ts);
							T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T68_ = percent___MULS9c8dKz2mJ1U9a9cMyTCYw(T67_, 3);
							T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T69_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T68_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T66_, T69_);
						}
						LA56_: ;
						i_2 += ((NI) 1);
					} LA55: ;
				}
			}
		}
		LA11_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__8mAL9ckajemzgfLPfeZVNoQ_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	NI id;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	t = (*n).typ;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T1_);
	id = nodeTableTestOrSet__tWmKJP7glBWLCISQFGGk2Q((&(*(*p).module).dataCache), n, ((NI) ((*(*p).module).labels)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
	tmp = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*(*p).module).tmpBase, T2_);
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		if (!(id == ((NI) ((*(*p).module).labels)))) goto LA5_;
		(*(*p).module).labels += ((NI) 1);
		nimZeroMem((void*)T7_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T7_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
		T7_[1] = tmp;
		T7_[2] = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, n, NIM_TRUE, t);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___bJpxHYPJaxWBQn6QxwBA4w(T7_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T8_);
	}
	LA5_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA11_;
		fillLoc__o49bXuxJYpCizOgQ54UViIg(d, ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 8), n, tmp, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
	}
	goto LA9_;
	LA11_: ;
	{
		putDataIntoDest__fYECstGN5jPehhn5p8Iclg(p, d, n, tmp);
		{
			if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)))) goto LA16_;
			(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1);
		}
		LA16_: ;
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__3euU5r9bcG0Rnz4QchCOUyw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38)) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
		LA7_: ;
		if (!T3_) goto LA8_;
		rawConstExpr__8mAL9ckajemzgfLPfeZVNoQ_2(p, n, d);
		result = NIM_TRUE;
	}
	goto LA1_;
	LA8_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__8mAL9ckajemzgfLPfeZVNoQ_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA arr;
	nimZeroMem((void*)(&arr), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = handleConstExpr__3euU5r9bcG0Rnz4QchCOUyw(p, n, d);
		if (!!(T3_)) goto LA4_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA8_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
		}
		LA8_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T13_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
					T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T14_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(T13_);
					T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T15_ = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(T14_);
					initLoc__qlujIAW86QclHYUVxlHRiQ((&arr), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), T15_, (*d).storage);
					nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T16_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
					T16_[1] = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (i)));
					arr.r = percent___jadqNPnY9aM3oxYK6jarLrA(T16_, 2);
					expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*n)._kind_6.sons->data[i], (&arr));
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	LA4_: ;
}
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
static N_INLINE(NIM_BOOL, isConstClosure__4MUa2M7mDMhaGJLAFrkWDw_3cgen)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = isRoutine__Ye2MiAptq3GrXxTQeyXNeAast((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosure__8mAL9ckajemzgfLPfeZVNoQ_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = isConstClosure__4MUa2M7mDMhaGJLAFrkWDw_3cgen(n);
		if (!T3_) goto LA4_;
		(*(*p).module).labels += ((NI) 1);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*(*p).module).labels)));
		tmp = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_619), T6_);
		nimZeroMem((void*)T7_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T7_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T7_[1] = tmp;
		T7_[2] = genBracedInit__WsN9cGbdvAooGZ9cFyHMz0gw(p, n, NIM_TRUE, (*n).typ);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___bJpxHYPJaxWBQn6QxwBA4w(T7_, 3);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 9))- 0], T8_);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, tmp, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp_2;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T15_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&b));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
			T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T12_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[((NI) 0)]);
			if (!((*T12_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA13_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_620), TM__MQdRN7fpbG7rPm4JpVVAhA_621);
		}
		LA13_: ;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, (&tmp_2), NIM_FALSE);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T15_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp_2);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_228));
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp_2);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_622));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA22_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA22_: ;
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T24_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T15_, T25_);
		putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, tmp_2);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__8mAL9ckajemzgfLPfeZVNoQ_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA rec;
	nimZeroMem((void*)(&rec), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = handleConstExpr__3euU5r9bcG0Rnz4QchCOUyw(p, n, d);
		if (!!(T3_)) goto LA4_;
		t = (*n).typ;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		(void)(T6_);
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA9_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, t, d, NIM_FALSE);
		}
		LA9_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T18_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA16_;
						it = (*it)._kind_6.sons->data[((NI) 1)];
					}
					LA16_: ;
					initLoc__qlujIAW86QclHYUVxlHRiQ((&rec), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), it, (*d).storage);
					nimZeroMem((void*)T18_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T18_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
					T18_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
					rec.r = percent___5TB09c2Iz60T0YagbSbI5RQ(T18_, 2);
					rec.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9)) & 15);
					expr__8mAL9ckajemzgfLPfeZVNoQ(p, it, (&rec));
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupFieldAgain__x9bTneajlTd1ibxrXw5m2Pw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** r, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** resTyp) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty_2;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	ty_2 = ty;
	{
		while (1) {
			if (!!((ty_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA2;
			ty_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty_2, IL64(36275087638268176));
			result = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*ty_2).n, (*field).name);
			{
				if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA5_;
				{
					if (!!((resTyp == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**) NIM_NIL)))) goto LA9_;
					unsureAsgnRef((void**) (&(*resTyp)), ty_2);
				}
				LA9_: ;
				goto LA1;
			}
			LA5_: ;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
				if (T13_) goto LA14_;
				T13_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
				LA14_: ;
				if (!!(T13_)) goto LA15_;
				add__yG4AKzsBRS1W4MANDlXQeg(r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
			}
			LA15_: ;
			ty_2 = (*ty_2).sons->data[((NI) 0)];
		} LA2: ;
	} LA1: ;
	{
		if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA19_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*field).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_623), TM__MQdRN7fpbG7rPm4JpVVAhA_624);
	}
	LA19_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__9bUUELnkXphPuPspD3YnKHQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA test;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA u;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA v;
	nimZeroMem((void*)(&test), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&u), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&v), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* disc;
				NimStringDesc* msg;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* strLit;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*e)._kind_6.sons->data[i];
				op = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
				{
					if (!((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96))) goto LA6_;
					it = (*it)._kind_6.sons->data[((NI) 1)];
				}
				LA6_: ;
				disc = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*it)._kind_6.sons->data[((NI) 2)]);
				initLoc__qlujIAW86QclHYUVxlHRiQ((&test), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0), it, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it)._kind_6.sons->data[((NI) 1)], (&u));
				initLoc__qlujIAW86QclHYUVxlHRiQ((&v), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), disc, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				v.r = obj;
				add__yG4AKzsBRS1W4MANDlXQeg(&v.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
				add__IM4kcMNkkOLJtqdEqSxR8A(&v.r, (*(*disc)._kind_4.sym).loc.r);
				genInExprAux__9cclvr8sbqtJj8irRbQQpqQ(p, it, (&u), (&v), (&test));
				msg = genFieldDefect__NFvxltQN2CgyfP8SjDTS1g(field, (*disc)._kind_4.sym);
				T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T8_ = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), msg);
				strLit = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw((*p).module, T8_);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T13_;
					NimStringDesc* res;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
					if (!((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96))) goto LA11_;
					T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T13_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
					T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(test);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
					res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
					T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T15_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_627));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), strLit);
					res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
					T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T16_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA19_: ;
					T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T13_, T22_);
				}
				goto LA9_;
				LA11_: ;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T24_;
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
					T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T24_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 6);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_287));
					T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T25_ = rdLoc__xidyzuHqIciXbQyEOKahDg(test);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T25_);
					res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_627));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T26_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), strLit);
					res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA30_: ;
					T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T33_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T32_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T24_, T33_);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__BKdMcfvryaJLplX0oFPcAQ_21)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NIM_BOOL isRef;
	NIM_BOOL useTemp;
	NIM_BOOL T14_;
	NIM_BOOL T15_;
	tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w T18_;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
{	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T4_) goto LA5_;
		T4_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA5_: ;
		T3_ = !(T4_);
		if (!(T3_)) goto LA6_;
		T3_ = !((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = handleConstExpr__3euU5r9bcG0Rnz4QchCOUyw(p, e, d);
			if (!T11_) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
	}
	LA7_: ;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350135273744));
	isRef = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22));
	T14_ = (NIM_BOOL)0;
	T15_ = (NIM_BOOL)0;
	T15_ = isRef;
	if (T15_) goto LA16_;
	T15_ = !(((62 &((NU16)1<<((NU)((*d).k)&15U)))!=0));
	LA16_: ;
	T14_ = T15_;
	if (T14_) goto LA17_;
	T18_ = (tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w)0;
	T18_ = isPartOf__1otDDZAmvFsmbqPyFytXFg((*d).lode, e);
	T14_ = !((T18_ == ((tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w) 0)));
	LA17_: ;
	useTemp = T14_;
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	r = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!useTemp) goto LA21_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, t, (&tmp), NIM_FALSE);
		r = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T27_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T28_;
			if (!isRef) goto LA25_;
			rawGenNew__9cYWmo3ycKMiJEsDvNXZAQg(p, (&tmp), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL), !((((*e).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 1))&31U)))!=0)));
			T27_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T27_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T27_, IL64(36134350135273744));
			nimZeroMem((void*)T28_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T28_[0] = r;
			r = percent___TbMwXzwNL7txOQADiTjwKA(T28_, 1);
			gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, e);
		}
		goto LA23_;
		LA25_: ;
		{
			constructLoc__Q4oQMHZIwSi4nGkYAuAC8A(p, (&tmp), NIM_FALSE);
		}
		LA23_: ;
	}
	goto LA19_;
	LA21_: ;
	{
		resetLoc__B9bNAYVEwjQtkUkvoOVhV2Q(p, d);
		r = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
	}
	LA19_: ;
	T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T31_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T31_);
	ty = t;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp2;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
				if (!(i_2 < colontmp_)) goto LA34;
				i = i_2;
				it = (*e)._kind_6.sons->data[i];
				nimZeroMem((void*)(&tmp2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				tmp2.r = r;
				field = lookupFieldAgain__x9bTneajlTd1ibxrXw5m2Pw(p, ty, (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym, &tmp2.r, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**) NIM_NIL));
				{
					if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA37_;
					fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, ty);
				}
				LA37_: ;
				{
					if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA41_;
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_625), TM__MQdRN7fpbG7rPm4JpVVAhA_626);
				}
				LA41_: ;
				{
					NIM_BOOL T45_;
					NI T46_;
					T45_ = (NIM_BOOL)0;
					T46_ = (NI)0;
					T46_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T45_ = (T46_ == ((NI) 3));
					if (!(T45_)) goto LA47_;
					T45_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 2))&31U)))!=0);
					LA47_: ;
					if (!T45_) goto LA48_;
					genFieldCheck__9bUUELnkXphPuPspD3YnKHQ(p, (*it)._kind_6.sons->data[((NI) 2)], r, field);
				}
				LA48_: ;
				add__yG4AKzsBRS1W4MANDlXQeg(&tmp2.r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
				add__IM4kcMNkkOLJtqdEqSxR8A(&tmp2.r, (*field).loc.r);
				{
					if (!useTemp) goto LA52_;
					tmp2.k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1);
					{
						if (!isRef) goto LA56_;
						tmp2.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
					}
					goto LA54_;
					LA56_: ;
					{
						tmp2.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
					}
					LA54_: ;
				}
				goto LA50_;
				LA52_: ;
				{
					tmp2.k = (*d).k;
					{
						if (!isRef) goto LA62_;
						tmp2.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
					}
					goto LA60_;
					LA62_: ;
					{
						tmp2.storage = (*d).storage;
					}
					LA60_: ;
				}
				LA50_: ;
				tmp2.lode = (*it)._kind_6.sons->data[((NI) 1)];
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*it)._kind_6.sons->data[((NI) 1)], (&tmp2));
				i_2 += ((NI) 1);
			} LA34: ;
		}
	}
	{
		if (!useTemp) goto LA67_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA71_;
			genericAssign((void*)(&(*d)), (void*)(&tmp), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
		}
		goto LA69_;
		LA71_: ;
		{
			genAssignment__BtucsTdHw7orsXIL75hNVg(p, (*d), tmp, 0);
		}
		LA69_: ;
	}
	LA67_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCast__BKdMcfvryaJLplX0oFPcAQ_22)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* destt;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* srct;
	destt = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(36134350136322320));
	srct = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lbl;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*destt).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) && (*destt).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39) || (*destt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*destt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*destt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16));
		if (T3_) goto LA4_;
		T3_ = ((*srct).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) && (*srct).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39) || (*srct).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*srct).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*srct).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*p).labels += ((NI) 1);
		lbl = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
		nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T7_[0] = lbl;
		tmp.r = percent___NIzUqj4Mr1E3EKy0AkJaXQ(T7_, 1);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_628));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*e)._kind_6.sons->data[((NI) 1)]).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T9_);
		res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_629));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*e).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_630));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), lbl);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T16_);
		tmp.k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6);
		tmp.lode = lodeTyp__Zo4XKVi6BmwOZE51Yogqwg(srct);
		tmp.storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2);
		tmp.flags = 0;
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
		nimZeroMem((void*)T17_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T17_[0] = lbl;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = percent___yQdCkIARIVr9aqI8oVxi9cQw(T17_, 1);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T18_, tmp.storage);
	}
	goto LA1_;
	LA5_: ;
	{
		genSomeCast__BKdMcfvryaJLplX0oFPcAQ_14(p, e, d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConv__BKdMcfvryaJLplX0oFPcAQ_23)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* destType;
	destType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(211106240923664));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameBackendType__n70Tq9c0HITdaYm9cT8YLryw(destType, (*(*e)._kind_6.sons->data[((NI) 1)]).typ);
		if (!T3_) goto LA4_;
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 1)], d);
	}
	goto LA1_;
	LA4_: ;
	{
		genSomeCast__BKdMcfvryaJLplX0oFPcAQ_14(p, e, d);
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, isCppRef__Rt7PF9bsOeNWjGFhSpqAlTwcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
	if (T3_) goto LA4_;
	T3_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	T2_ = ((*T6_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
	LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA7_;
	T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	T1_ = !((((*T8_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0));
	LA7_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAddr__BKdMcfvryaJLplX0oFPcAQ_24)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		if (!((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA4_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_328), a.r);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T6_, a.storage);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T8_;
		tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T9_;
		tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w T15_;
		T8_ = (NIM_BOOL)0;
		T9_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
		{
			if (!((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA12_;
			T9_ = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind;
		}
		goto LA10_;
		LA12_: ;
		{
			T9_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
		}
		LA10_: ;
		T15_ = (tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w)0;
		T15_ = mapType__pNoigHLHIPJ32RkjLRvhAQ((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).typ, T9_);
		T8_ = (T15_ == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 17));
		if (T8_) goto LA16_;
		T8_ = isCppRef__Rt7PF9bsOeNWjGFhSpqAlTwcgen(p, (*e).typ);
		LA16_: ;
		if (!T8_) goto LA17_;
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 0)], d);
	}
	goto LA1_;
	LA17_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 0)], (&a_2));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T20_, a_2.storage);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, y, (&b));
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		(*d).storage = a.storage;
	}
	LA3_: ;
	res = rawNewString(((NI) 80));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T7_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* first;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T2_;
	NimStringDesc* res_3;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, y, (&b));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(49785886521469200));
	T2_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
	first = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T2_);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0);
		if (!(T5_)) goto LA6_;
		T5_ = !(((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49)));
		LA6_: ;
		if (!T5_) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2(y);
			if (!!(T11_)) goto LA12_;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T16_;
				NIM_BOOL T17_;
				T16_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
				T17_ = (NIM_BOOL)0;
				T17_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T16_, IL64(0));
				if (!T17_) goto LA18_;
				{
					NIM_BOOL T22_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T24_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T25_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T27_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T29_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T32_;
					NimStringDesc* res;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T34_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T38_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
					T22_ = (NIM_BOOL)0;
					T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T23_ = t__XNOXh7uniWNgiq58C9bW49awcgen(b);
					T24_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, T23_);
					T25_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
					T22_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T24_, T25_);
					if (T22_) goto LA26_;
					T27_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
					T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T28_ = t__XNOXh7uniWNgiq58C9bW49awcgen(b);
					T29_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, T28_);
					T22_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T27_, T29_);
					LA26_: ;
					if (!T22_) goto LA30_;
					T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T32_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_631));
					T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T33_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T33_);
					res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_632));
					T34_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
					T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T35_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T34_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T35_);
					res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
					T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T36_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_633));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T36_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
					T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T37_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T37_);
					res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
					T38_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
					T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T39_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T38_);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T39_);
					res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
					T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T40_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T40_);
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA43_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA43_: ;
					T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T45_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T46_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T45_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T32_, T46_);
				}
				LA30_: ;
			}
			goto LA14_;
			LA18_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T48_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T51_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T55_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T48_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T49_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T49_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_117));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), first);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T50_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T50_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_400));
				T51_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
				T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T52_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T51_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T52_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
				T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T53_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_634));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T53_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T54_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T54_);
				res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), first);
				res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T55_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
				T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T56_ = intLiteral__0L2LUBpuDvHdOo5Bdh2tRw(T55_);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T56_);
				res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
				T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T57_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T57_);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA60_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA60_: ;
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T62_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T48_, T63_);
			}
			LA14_: ;
		}
		goto LA9_;
		LA12_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA idx;
			idx = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(y, Max__zlJMNfqX7LwCYj0PF6ncWQ);
			{
				NIM_BOOL T67_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T68_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T70_;
				NimStringDesc* T73_;
				T67_ = (NIM_BOOL)0;
				T68_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
				T67_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(idx, T68_);
				if (T67_) goto LA69_;
				T70_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
				T67_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T70_, idx);
				LA69_: ;
				if (!T67_) goto LA71_;
				T73_ = (NimStringDesc*)0;
				{
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T76_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T77_;
					NIM_BOOL T78_;
					T76_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
					T77_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
					T78_ = (NIM_BOOL)0;
					T78_ = lt___7c5Zw7H31uJfWmmhZe9aEqw_3(T76_, T77_);
					if (!T78_) goto LA79_;
					T73_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_635));
				}
				goto LA74_;
				LA79_: ;
				{
					NimStringDesc* T82_;
					NimStringDesc* T83_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T84_;
					NimStringDesc* T85_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T86_;
					NimStringDesc* T87_;
					T82_ = (NimStringDesc*)0;
					T83_ = (NimStringDesc*)0;
					T83_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(idx);
					T84_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, ty);
					T85_ = (NimStringDesc*)0;
					T85_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(T84_);
					T86_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, ty);
					T87_ = (NimStringDesc*)0;
					T87_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(T86_);
					T82_ = rawNewString((T83_ ? T83_->Sup.len : 0) + (T85_ ? T85_->Sup.len : 0) + (T87_ ? T87_->Sup.len : 0) + 18);
appendString(T82_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_636));
appendString(T82_, T83_);
appendString(T82_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_637));
appendString(T82_, T85_);
appendString(T82_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_638));
appendString(T82_, T87_);
					T73_ = T82_;
				}
				LA74_: ;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T73_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_639, NIM_FALSE);
			}
			LA71_: ;
		}
		LA9_: ;
	}
	LA7_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA90_;
		(*d).storage = a.storage;
	}
	LA90_: ;
	res_3 = rawNewString(((NI) 80));
	T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T92_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T92_);
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_640));
	T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T93_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T93_);
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_641));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), first);
	res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
	T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T94_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T94_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, y, (&b));
	{
		NIM_BOOL T3_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		T3_ = (NIM_BOOL)0;
		T3_ = reifiedOpenArray__4MUa2M7mDMhaGJLAFrkWDwcgen(x);
		if (!!(T3_)) goto LA4_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA8_;
			T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_631));
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T12_);
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_642));
			T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_633));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T13_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T14_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_643));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
			res = resizeString(res, 10);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_644));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA19_: ;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T22_);
		}
		LA8_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA25_;
			(*d).storage = a.storage;
		}
		LA25_: ;
		res_2 = rawNewString(((NI) 80));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T29_, a.storage);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA33_;
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_631));
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T36_);
			res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_387));
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T37_);
			res_3 = resizeString(res_3, 11);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_645));
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_633));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T38_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T39_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_643));
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T40_);
			res_3 = resizeString(res_3, 12);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_646));
			T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T41_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T41_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA44_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA44_: ;
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T46_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T47_);
		}
		LA33_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA50_;
			(*d).storage = a.storage;
		}
		LA50_: ;
		res_4 = rawNewString(((NI) 80));
		T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T52_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T52_);
		res_4 = resizeString(res_4, 8);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_647));
		T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T53_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T53_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T54_, a.storage);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__BCJD8YW9ak7zQIm4nTPgpMQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	NimStringDesc* res_5;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, y, (&b));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350144710928));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA4_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(ty);
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T6_, IL64(36134350144710928));
	}
	LA4_: ;
	{
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA9_;
		{
			NIM_BOOL T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
			if (!(T13_)) goto LA14_;
			T13_ = NIM_FALSE;
			LA14_: ;
			if (!T13_) goto LA15_;
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 9);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_631));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_648));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_633));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T21_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_643));
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T22_);
			res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T23_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA26_: ;
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T28_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T17_, T29_);
		}
		goto LA11_;
		LA15_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T31_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T31_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_631));
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T32_);
			res_2 = resizeString(res_2, 9);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_402));
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T33_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_633));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T34_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg(b);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T35_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_643));
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = lenExpr__Xfvxpx3W1zkiCqENsur9ckg(p, a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T36_);
			res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_649));
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T37_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA40_: ;
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T31_, T43_);
		}
		LA11_: ;
	}
	LA9_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA46_;
		(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
	}
	LA46_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T51_;
		NimStringDesc* res_3;
		T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T50_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		T51_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T51_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T50_, IL64(36275087632017680));
		if (!((*T51_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T51_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA52_;
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_65));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), a.r);
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		a.r = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	}
	LA52_: ;
	{
		NIM_BOOL T56_;
		NIM_BOOL T57_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T62_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
		T56_ = (NIM_BOOL)0;
		T57_ = (NIM_BOOL)0;
		T57_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 10))&15U)))!=0);
		if (!(T57_)) goto LA58_;
		T57_ = ((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
		LA58_: ;
		T56_ = T57_;
		if (!(T56_)) goto LA59_;
		T56_ = (((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		LA59_: ;
		if (!T56_) goto LA60_;
		T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T62_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T63_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_236));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T63_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T64_ = byRefLoc__Xfvxpx3W1zkiCqENsur9ckg_2(p, a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T64_);
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA67_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA67_: ;
		T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T69_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T70_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T69_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T62_, T70_);
	}
	LA60_: ;
	res_5 = rawNewString(((NI) 80));
	T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T71_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T71_);
	T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T72_ = dataField__3AsTOpq9crZUYBL9aD1lXBng_2(p);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T72_);
	res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
	T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T73_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T73_);
	res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
	T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T74_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T74_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__BCJD8YW9ak7zQIm4nTPgpMQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&b), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, x, (&a));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, y, (&b));
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		(*d).storage = a.storage;
	}
	LA3_: ;
	res = rawNewString(((NI) 80));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T5_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(b);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_121));
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T7_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__BKdMcfvryaJLplX0oFPcAQ_25)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NI i;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tupType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	i = (NI)0;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	tupType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(36134350143662352));
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA4_;
		(*d).storage = a.storage;
	}
	LA4_: ;
	T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T6_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T6_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T7_);
	r = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	switch ((*(*e)._kind_6.sons->data[((NI) 1)]).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		i = ((NI) ((*(*e)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_650), TM__MQdRN7fpbG7rPm4JpVVAhA_651);
	}
	break;
	}
	nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T10_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = percent___WYvjnWcyRjjjI0lasIi1YA(T10_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&r, T11_);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, r, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__8mAL9ckajemzgfLPfeZVNoQ_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(49645149026822416));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21))) goto LA3_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(ty);
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T5_, IL64(36134350144710928));
	}
	LA3_: ;
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		genUncheckedArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		genArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_2(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		genOpenArrayElem__BCJD8YW9ak7zQIm4nTPgpMQ_3(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		genSeqElem__BCJD8YW9ak7zQIm4nTPgpMQ_4(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		genCStringElem__BCJD8YW9ak7zQIm4nTPgpMQ_5(p, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		genTupleElem__BKdMcfvryaJLplX0oFPcAQ_25(p, n, d);
	}
	break;
	default:
	{
		NimStringDesc* T13_;
		T13_ = (NimStringDesc*)0;
		T13_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 21);
appendString(T13_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_652));
appendString(T13_, reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T13_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T13_, TM__MQdRN7fpbG7rPm4JpVVAhA_653);
	}
	break;
	}
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T14_);
}
N_LIB_PRIVATE N_NIMCALL(void, genDeref__BKdMcfvryaJLplX0oFPcAQ_26)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w mt;
	tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T1_;
{	T1_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
	{
		if (!((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA4_;
		T1_ = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind;
	}
	goto LA2_;
	LA4_: ;
	{
		T1_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
	}
	LA2_: ;
	mt = mapType__pNoigHLHIPJ32RkjLRvhAQ((*(*(*p).module).g).config, (*(*e)._kind_6.sons->data[((NI) 0)]).typ, T1_);
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((393216 &((NU32)1<<((NU)(mt)&31U)))!=0);
		if (!(T9_)) goto LA10_;
		T9_ = !((((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9))&15U)))!=0));
		LA10_: ;
		if (!T9_) goto LA11_;
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 0)], d);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T15_;
			T15_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T15_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*e)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
			if (!((*T15_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22))) goto LA16_;
			(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
		}
		LA16_: ;
	}
	goto LA7_;
	LA11_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		typ = (*(*e)._kind_6.sons->data[((NI) 0)]).typ;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) || (*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53));
			if (!(T21_)) goto LA22_;
			T21_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
			LA22_: ;
			if (!T21_) goto LA23_;
			typ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		}
		LA23_: ;
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
		{
			NIM_BOOL T27_;
			NIM_BOOL T28_;
			NIM_BOOL T29_;
			NIM_BOOL T32_;
			T27_ = (NIM_BOOL)0;
			T28_ = (NIM_BOOL)0;
			T29_ = (NIM_BOOL)0;
			T29_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			if (!(T29_)) goto LA30_;
			T29_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0));
			LA30_: ;
			T28_ = T29_;
			if (!(T28_)) goto LA31_;
			T32_ = (NIM_BOOL)0;
			T32_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T32_) goto LA33_;
			T32_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA33_: ;
			T28_ = T32_;
			LA31_: ;
			T27_ = T28_;
			if (!(T27_)) goto LA34_;
			T27_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64));
			LA34_: ;
			if (!T27_) goto LA35_;
			initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, (*(*e)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], d);
			goto BeforeRet_;
		}
		goto LA25_;
		LA35_: ;
		{
			initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
		}
		LA25_: ;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA40_;
			switch ((*typ).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 3);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
				{
					NIM_BOOL T46_;
					NIM_BOOL T47_;
					NIM_BOOL T49_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
					T46_ = (NIM_BOOL)0;
					T47_ = (NIM_BOOL)0;
					T47_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0));
					if (!(T47_)) goto LA48_;
					T49_ = (NIM_BOOL)0;
					T49_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
					if (T49_) goto LA50_;
					T49_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
					LA50_: ;
					T47_ = T49_;
					LA48_: ;
					T46_ = T47_;
					if (!(T46_)) goto LA51_;
					T46_ = ((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
					LA51_: ;
					if (!T46_) goto LA52_;
					T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T54_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T54_, a.storage);
					goto BeforeRet_;
				}
				LA52_: ;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
			{
				(*d).storage = ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0);
			}
			break;
			default:
			{
				NimStringDesc* T57_;
				T57_ = (NimStringDesc*)0;
				T57_ = rawNewString((reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 9);
appendString(T57_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_654));
appendString(T57_, reprEnum((NI)(*typ).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, T57_, TM__MQdRN7fpbG7rPm4JpVVAhA_655);
			}
			break;
			}
		}
		goto LA38_;
		LA40_: ;
		{
			NIM_BOOL T59_;
			T59_ = (NIM_BOOL)0;
			T59_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T59_) goto LA60_;
			T59_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA60_: ;
			if (!T59_) goto LA61_;
			{
				NIM_BOOL T65_;
				NIM_BOOL T66_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
				T65_ = (NIM_BOOL)0;
				T66_ = (NIM_BOOL)0;
				T66_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
				if (!(T66_)) goto LA67_;
				T66_ = !((((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0));
				LA67_: ;
				T65_ = T66_;
				if (!(T65_)) goto LA68_;
				T65_ = ((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
				LA68_: ;
				if (!T65_) goto LA69_;
				T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T71_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T71_, a.storage);
				goto BeforeRet_;
			}
			LA69_: ;
		}
		goto LA38_;
		LA61_: ;
		LA38_: ;
		{
			NIM_BOOL T74_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
			T74_ = (NIM_BOOL)0;
			T74_ = (mt == ((tyEnum_TCTypeKind__ceqS9bAmd9bxxuxr8tfIIw5w) 18));
			if (!(T74_)) goto LA75_;
			T74_ = (((*d).flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9))&15U)))!=0);
			LA75_: ;
			if (!T74_) goto LA76_;
			T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T78_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T78_, a.storage);
		}
		goto LA72_;
		LA76_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T80_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T81_;
			nimZeroMem((void*)T80_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T80_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T81_ = percent___TbMwXzwNL7txOQADiTjwKA(T80_, 1);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, T81_, a.storage);
		}
		LA72_: ;
	}
	LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__O8nIPJbfEFU0FjR77WG5eA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 0)], a);
	{
		if (!!(((*(*e)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_656), TM__MQdRN7fpbG7rPm4JpVVAhA_657);
	}
	LA3_: ;
	{
		if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA7_;
		(*d).storage = (*a).storage;
	}
	LA7_: ;
	T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T9_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*a));
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T9_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	(void)(T10_);
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__BKdMcfvryaJLplX0oFPcAQ_27)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	genRecordFieldAux__O8nIPJbfEFU0FjR77WG5eA(p, e, d, (&a));
	r = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	f = (*(*e)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, IL64(49645149017385232));
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*f).position)));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___WYvjnWcyRjjjI0lasIi1YA(T6_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&r, T7_);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, r, a.storage);
	}
	goto LA2_;
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rtyp;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		rtyp = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		field = lookupFieldAgain__x9bTneajlTd1ibxrXw5m2Pw(p, ty, f, &r, &rtyp);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
			if (!(T11_)) goto LA12_;
			T11_ = !((rtyp == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA12_: ;
			if (!T11_) goto LA13_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, rtyp);
		}
		LA13_: ;
		{
			NimStringDesc* T19_;
			NimStringDesc* T20_;
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA17_;
			T19_ = (NimStringDesc*)0;
			T20_ = (NimStringDesc*)0;
			T20_ = typeToString__QlvraUan7WbHowhAbvDvdA(ty, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T19_ = rawNewString((T20_ ? T20_->Sup.len : 0) + 17);
appendString(T19_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_658));
appendString(T19_, T20_);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, T19_, TM__MQdRN7fpbG7rPm4JpVVAhA_659);
		}
		LA17_: ;
		nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T21_[0] = (*field).loc.r;
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = percent___hR4oq6WdDjEl0JIvQtvUlg(T21_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&r, T22_);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, e, r, a.storage);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__BKdMcfvryaJLplX0oFPcAQ_28)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 2))&31U)))!=0)) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		genRecordFieldAux__O8nIPJbfEFU0FjR77WG5eA(p, (*e)._kind_6.sons->data[((NI) 0)], d, (&a));
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T5_, IL64(49645149017385232));
		r = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		f = (*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		field = lookupFieldAgain__x9bTneajlTd1ibxrXw5m2Pw(p, ty, f, &r, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**) NIM_NIL));
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
			fillObjectFields__4q3XOfd3NI3C8cSNkaF9cWA_2((*p).module, ty);
		}
		LA8_: ;
		{
			if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*e).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_623), TM__MQdRN7fpbG7rPm4JpVVAhA_660);
		}
		LA12_: ;
		genFieldCheck__9bUUELnkXphPuPspD3YnKHQ(p, e, r, field);
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_93));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*field).loc.r);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&r, T14_);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, (*e)._kind_6.sons->data[((NI) 0)], r, a.storage);
	}
	goto LA1_;
	LA3_: ;
	{
		genRecordField__BKdMcfvryaJLplX0oFPcAQ_27(p, (*e)._kind_6.sons->data[((NI) 0)], d);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__8mAL9ckajemzgfLPfeZVNoQ_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NI oldBreakIdxX60gensym1948_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!!(T3_)) goto LA4_;
		{
			if (!((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA8_;
			getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
		}
		LA8_: ;
		(*d).flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9)) & 15);
	}
	LA4_: ;
	oldBreakIdxX60gensym1948_ = (*p).breakIdx;
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA13_: ;
	T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T16_);
	(*p).breakIdx = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA19_;
		sym = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		(*sym).loc.k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 10);
		(*sym).position = (NI)((*p).breakIdx + ((NI) 1));
	}
	LA19_: ;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*n)._kind_6.sons->data[((NI) 1)], d);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	(*p).breakIdx = oldBreakIdxX60gensym1948_;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, initFrameNoDebug__pzdwBzdMmIm0ZmOmWB6yqA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frame, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename, NI line) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	NimStringDesc* res;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_275));
	(void)(T1_);
	nimZeroMem((void*)T2_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T2_[0] = frame;
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___84GQPNcrIJtbrzuA7JnMPw(T2_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).blocks->data[((NI) 0)].sections[(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0))- 0], T3_);
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_662));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), procname);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_663));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), filename);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_664));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_665));
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (line)));
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_118));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_666));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA6_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA6_: ;
	result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, deinitFrameNoDebug__i9b8wSa9cUkrnf3r9bmZ8OzfA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frame) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_667));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), frame);
	res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA4_: ;
	result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__8mAL9ckajemzgfLPfeZVNoQ_14)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NIM_BOOL hasNimFrame;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frameName;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = !((((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (((*(*p).prc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0);
	LA4_: ;
	hasNimFrame = T1_;
	frameName = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T6_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24))) goto LA11_;
					{
						NIM_BOOL T15_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* theMacro;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
						T15_ = (NIM_BOOL)0;
						T15_ = hasNimFrame;
						if (!(T15_)) goto LA16_;
						T15_ = (frameName == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
						LA16_: ;
						if (!T15_) goto LA17_;
						(*p).labels += ((NI) 1);
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_661), T19_);
						frameName = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T20_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
						theMacro = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T22_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*theMacro).name).s);
						T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T23_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*(*p).module).g).config, (*theMacro).info);
						T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T24_ = initFrameNoDebug__pzdwBzdMmIm0ZmOmWB6yqA(p, frameName, T22_, T23_, ((NI) ((*it).info.line)));
						add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T24_);
					}
					LA17_: ;
				}
				goto LA9_;
				LA11_: ;
				{
					genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, it);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI T28_;
		NI T31_;
		T28_ = (NI)0;
		T28_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 0) < T28_)) goto LA29_;
		T31_ = (NI)0;
		T31_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*n)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))], d);
	}
	LA29_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T36_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
		if (!!((frameName == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA34_;
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T36_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T37_ = deinitFrameNoDebug__i9b8wSa9cUkrnf3r9bmZ8OzfA(p, frameName);
		add__IM4kcMNkkOLJtqdEqSxR8A(T36_, T37_);
	}
	LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__UtJx89cn0a8CNSWWmaj6raA_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL hasNimFrame;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* frameName;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = !((((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (((*(*p).prc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0);
	LA4_: ;
	hasNimFrame = T1_;
	frameName = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T6_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24))) goto LA11_;
					{
						NIM_BOOL T15_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* theMacro;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
						T15_ = (NIM_BOOL)0;
						T15_ = hasNimFrame;
						if (!(T15_)) goto LA16_;
						T15_ = (frameName == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
						LA16_: ;
						if (!T15_) goto LA17_;
						(*p).labels += ((NI) 1);
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_661), T19_);
						frameName = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T20_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
						theMacro = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T22_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*theMacro).name).s);
						T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T23_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*(*p).module).g).config, (*theMacro).info);
						T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T24_ = initFrameNoDebug__pzdwBzdMmIm0ZmOmWB6yqA(p, frameName, T22_, T23_, ((NI) ((*it).info.line)));
						add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T24_);
					}
					LA17_: ;
				}
				goto LA9_;
				LA11_: ;
				{
					genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, it);
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	{
		NI T28_;
		NI T31_;
		T28_ = (NI)0;
		T28_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 0) < T28_)) goto LA29_;
		T31_ = (NI)0;
		T31_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*n)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))]);
	}
	LA29_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T36_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
		if (!!((frameName == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA34_;
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T36_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T37_ = deinitFrameNoDebug__i9b8wSa9cUkrnf3r9bmZ8OzfA(p, frameName);
		add__IM4kcMNkkOLJtqdEqSxR8A(T36_, T37_);
	}
	LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__8mAL9ckajemzgfLPfeZVNoQ_15)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lelse;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lend;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	lelse = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
	}
	LA6_: ;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, n);
	lend = getLabel__3AsTOpq9crZUYBL9aD1lXBng_5(p);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
		NI i;
		NI L;
		NI T9_;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T9_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T9_;
		{
			while (1) {
				if (!(i < L)) goto LA11;
				it = &colontmp_->data[i];
				{
					NIM_BOOL T14_;
					T14_ = (NIM_BOOL)0;
					T14_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
					if (!(T14_)) goto LA15_;
					T14_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
					LA15_: ;
					if (!T14_) goto LA16_;
					(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
				}
				LA16_: ;
				{
					NI T20_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
					NimStringDesc* res;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
					NI T30_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T31_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T32_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
					T20_ = (NI)0;
					T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*it));
					if (!(T20_ == ((NI) 2))) goto LA21_;
					T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res = rawNewString(((NI) 80));
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
						res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA26_: ;
					T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
					T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T29_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T28_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T29_);
					T30_ = (NI)0;
					T30_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
					initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, (*(*it))._kind_6.sons->data[((NI) 0)], (&a));
					lelse = getLabel__3AsTOpq9crZUYBL9aD1lXBng_5(p);
					(*p).labels += ((NI) 1);
					T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T31_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T32_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T32_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
					T32_[1] = lelse;
					T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T33_ = percent___SqZEI7bxySjmJX4GsXyvKw(T32_, 2);
					T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T34_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T33_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T31_, T34_);
					{
						NIM_BOOL T37_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T41_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
						T37_ = (NIM_BOOL)0;
						T37_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
						if (T37_) goto LA38_;
						T37_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
						LA38_: ;
						if (!T37_) goto LA39_;
						T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T41_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						add__yG4AKzsBRS1W4MANDlXQeg(T41_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
						expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*it))._kind_6.sons->data[((NI) 1)], d);
						T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						add__yG4AKzsBRS1W4MANDlXQeg(T42_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
					}
					goto LA35_;
					LA39_: ;
					{
						expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*it))._kind_6.sons->data[((NI) 1)], d);
					}
					LA35_: ;
					endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
					{
						NI T46_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T49_;
						tyArray__JiWwrsTRC6xqNlGcBthSVA T50_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
						T46_ = (NI)0;
						T46_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						if (!(((NI) 1) < T46_)) goto LA47_;
						T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T49_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T50_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T50_[0] = lend;
						T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T51_ = percent___c1f569aWpTd825BTnv9bq4Xg(T50_, 1);
						T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T52_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T51_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T49_, T52_);
					}
					LA47_: ;
					fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lelse);
				}
				goto LA18_;
				LA21_: ;
				{
					NI T54_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T57_;
					NimStringDesc* res_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
					NI T64_;
					T54_ = (NI)0;
					T54_ = len__P89cqdlERShb9alU3iC0yj8wast((*it));
					if (!(T54_ == ((NI) 1))) goto LA55_;
					T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T57_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_2 = rawNewString(((NI) 80));
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA60_;
						res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA60_: ;
					T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T62_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
					T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T63_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T62_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T57_, T63_);
					T64_ = (NI)0;
					T64_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
					expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*it))._kind_6.sons->data[((NI) 0)], d);
					endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
				}
				goto LA18_;
				LA55_: ;
				{
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_668), TM__MQdRN7fpbG7rPm4JpVVAhA_669);
				}
				LA18_: ;
				i += ((NI) 1);
			} LA11: ;
		}
	}
	{
		NI T68_;
		T68_ = (NI)0;
		T68_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 1) < T68_)) goto LA69_;
		fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lend);
	}
	LA69_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, downConv__8mAL9ckajemzgfLPfeZVNoQ_16)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T7_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		(void)(T8_);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*n)._kind_6.sons->data[((NI) 0)], d);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
		NIM_BOOL isRef;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087638309136));
		arg = (*n)._kind_6.sons->data[((NI) 0)];
		{
			while (1) {
				if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66))) goto LA11;
				arg = (*arg)._kind_6.sons->data[((NI) 0)];
			} LA11: ;
		}
		src = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36275087638309136));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, src, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		(void)(T12_);
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, arg, (&a));
		r = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36134350135273744));
		isRef = ((*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
		{
			if (!isRef) goto LA16_;
			add__yG4AKzsBRS1W4MANDlXQeg(&r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_670));
		}
		goto LA14_;
		LA16_: ;
		{
			add__yG4AKzsBRS1W4MANDlXQeg(&r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
		}
		LA14_: ;
		{
			NI i;
			NI colontmp_;
			NI T20_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T20_ = (NI)0;
			T20_ = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(dest, src);
			colontmp_ = (T20_ > 0? (T20_) : -(T20_));
			res = ((NI) 2);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA22;
					i = res;
					add__yG4AKzsBRS1W4MANDlXQeg(&r, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_83));
					res += ((NI) 1);
				} LA22: ;
			}
		}
		{
			if (!isRef) goto LA25_;
			{
				NIM_BOOL T29_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T34_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
				T29_ = (NIM_BOOL)0;
				T29_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
				if (!(T29_)) goto LA30_;
				T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T31_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
				T29_ = ((*T31_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*T31_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) || (*T31_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*T31_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
				LA30_: ;
				if (!T29_) goto LA32_;
				getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*n).typ, d, NIM_FALSE);
				T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T34_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T35_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*d));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T35_);
				res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_671));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), r);
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA38_: ;
				T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T41_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T40_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T34_, T41_);
			}
			goto LA27_;
			LA32_: ;
			{
				r = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_328), r);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, r, a.storage);
			}
			LA27_: ;
		}
		goto LA23_;
		LA25_: ;
		{
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, r, a.storage);
		}
		LA23_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, upConv__8mAL9ckajemzgfLPfeZVNoQ_17)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087638309136));
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* nilCheck;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* checkFor;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 1))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isObjLackingTypeField__kS4QQNg40ThwD2ps8HD9aQgcgen(dest);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		nilCheck = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		r = rdMType__JrPFcJ0c8lx7StUeWoJrrQ(p, a, &nilCheck, NIM_FALSE);
		{
			if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA10_;
			checkFor = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg((*p).module, dest);
		}
		goto LA8_;
		LA10_: ;
		{
			checkFor = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, dest, (*n).info);
		}
		LA8_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			if (!!((nilCheck == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA15_;
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), nilCheck);
			res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_672));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), r);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), checkFor);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_673));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA23_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA23_: ;
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T17_, T26_);
		}
		goto LA13_;
		LA15_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T28_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T28_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_674));
			T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T29_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), r);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), checkFor);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_673));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T30_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA34_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA34_: ;
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T36_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T28_, T37_);
		}
		LA13_: ;
	}
	LA6_: ;
	{
		if (!!(((*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)))) goto LA40_;
		{
			NIM_BOOL T44_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			T44_ = (NIM_BOOL)0;
			T44_ = isLValue__kCP6QlI8uS4X0pOQUdr7tg(n);
			if (!T44_) goto LA45_;
			nimZeroMem((void*)T47_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T47_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T47_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = percent___THj7TLQ2KRJ59bBAfaCkUxA(T47_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T48_, a.storage);
		}
		goto LA42_;
		LA45_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T50_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
			nimZeroMem((void*)T50_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T50_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			T50_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T51_ = percent___GNSb4l0oRsR1gu66azz1LQ(T50_, 2);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T51_, a.storage);
		}
		LA42_: ;
	}
	goto LA38_;
	LA40_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T53_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		nimZeroMem((void*)T53_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T53_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, dest, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		T53_[1] = addrLoc__9b8NbhHc4w1oBKAy127l3xQ((*(*(*p).module).g).config, a);
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = percent___duX6hgjmpJtFFdvJVuoafg(T53_, 2);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T54_, a.storage);
	}
	LA38_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__8mAL9ckajemzgfLPfeZVNoQ_18)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T59_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 3))&31U)))!=0));
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*dest).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*dest).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
		if (!(T5_)) goto LA6_;
		T5_ = !((((*(*(*(*p).module).g).config).legacyFeatures &((NU8)1<<((NU)(((tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA) 1))&7U)))!=0));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
	}
	goto LA1_;
	LA7_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n0t;
		n0t = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T14_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
			if (!((*n0t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) || (*n0t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44))) goto LA12_;
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T14_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T15_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_675));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, n0t, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T16_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_433));
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T17_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_401));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_676));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_391));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T19_);
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA22_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA22_: ;
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T25_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T24_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T14_, T25_);
		}
		goto LA10_;
		LA12_: ;
		{
			NimStringDesc* raiser;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			NimStringDesc* boundaryCast;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T44_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			T27_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T27_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
			switch ((*T27_).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
			{
				raiser = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_677));
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
			{
				raiser = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_678));
			}
			break;
			default:
			{
				raiser = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_679));
			}
			break;
			}
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, raiser);
			(void)(T31_);
			{
				NIM_BOOL T34_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T35_;
				NIM_BOOL T37_;
				NIM_BOOL T38_;
				T34_ = (NIM_BOOL)0;
				T35_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T35_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(n0t, IL64(36134350144710928));
				T34_ = ((*T35_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) || (*T35_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43) || (*T35_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
				if (T34_) goto LA36_;
				T37_ = (NIM_BOOL)0;
				T38_ = (NIM_BOOL)0;
				T38_ = !(((*n0t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T38_)) goto LA39_;
				T38_ = (((*(*(*n0t).sym).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
				LA39_: ;
				T37_ = T38_;
				if (!(T37_)) goto LA40_;
				T37_ = eqStrings((*(*(*n0t).sym).name).s, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_680));
				LA40_: ;
				T34_ = T37_;
				LA36_: ;
				if (!T34_) goto LA41_;
				boundaryCast = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_681));
			}
			goto LA32_;
			LA41_: ;
			{
				boundaryCast = ((NimStringDesc*) NIM_NIL);
			}
			LA32_: ;
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T44_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_2), boundaryCast);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T45_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_682));
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*n)._kind_6.sons->data[((NI) 1)], dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T46_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_399));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_2), boundaryCast);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T47_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T47_);
			res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_683));
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T48_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_431));
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_2), raiser);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
			T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T49_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T49_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T50_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*n)._kind_6.sons->data[((NI) 1)], dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T50_);
			res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T51_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*n)._kind_6.sons->data[((NI) 2)], dest);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T51_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_442));
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T52_);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA55_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA55_: ;
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T57_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T57_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T44_, T58_);
		}
		LA10_: ;
	}
	LA1_: ;
	nimZeroMem((void*)T59_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T59_[0] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, dest, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	T59_[1] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
	T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T60_ = percent___GNSb4l0oRsR1gu66azz1LQ(T59_, 2);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T60_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__8mAL9ckajemzgfLPfeZVNoQ_19)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_373));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T3_, a.storage);
}
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__8mAL9ckajemzgfLPfeZVNoQ_20)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	res = rawNewString(((NI) 80));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_508));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T2_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T3_, a.storage);
	gcUsage__Faz6su3hXrHmiSECd9c9a6Pg((*(*(*p).module).g).config, n);
}
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__UtJx89cn0a8CNSWWmaj6raA_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	NI casePos;
	NI arraySize;
	NI id;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T33_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* gotoArray;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T34_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T40_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseStmt;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T47_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T48_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
{	n_2 = flattenStmts__qsyX8NJX39ctdwAi4rC8W1g(n);
	casePos = ((NI) -1);
	arraySize = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n_2)._kind_6.sons->data[i];
				{
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA aSize;
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97))) goto LA6_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
						T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T10_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
						if (!!(((*T10_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85)))) goto LA11_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_685), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_686, NIM_FALSE);
						goto BeforeRet_;
					}
					LA11_: ;
					casePos = i;
					{
						NIM_BOOL T15_;
						T15_ = (NIM_BOOL)0;
						T15_ = enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3((*(*it)._kind_6.sons->data[((NI) 0)]).typ);
						if (!T15_) goto LA16_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_687), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_688, NIM_FALSE);
						goto BeforeRet_;
					}
					LA16_: ;
					aSize = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
					{
						NIM_BOOL T20_;
						T20_ = (NIM_BOOL)0;
						T20_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(10000), aSize);
						if (!T20_) goto LA21_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_689), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_690, NIM_FALSE);
						goto BeforeRet_;
					}
					LA21_: ;
					arraySize = toInt__TIX0sFuRf3uBpOBltYp7bw(aSize);
					{
						tyObject_Int128__9a9axPfb75jdWY25AamJewkA T25_;
						NIM_BOOL T26_;
						T25_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*(*p).module).g).config, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
						T26_ = (NIM_BOOL)0;
						T26_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T25_, IL64(0));
						if (!!(T26_)) goto LA27_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_691), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_692, NIM_FALSE);
						goto BeforeRet_;
					}
					LA27_: ;
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		if (!(casePos < ((NI) 0))) goto LA31_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_693), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_694, NIM_FALSE);
		goto BeforeRet_;
	}
	LA31_: ;
	id = (NI)(((NI) ((*p).labels)) + ((NI) 1));
	(*p).labels += (NI)(arraySize + ((NI) 1));
	nimZeroMem((void*)T33_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T33_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (id)));
	tmp = percent___ibl3qMPOrpGT2x8X7vmbeQ(T33_, 1);
	nimZeroMem((void*)T34_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T34_[0] = tmp;
	T34_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (arraySize)));
	gotoArray = percent___bBcuDHMXr6Kz1tr7BzD9aKw(T34_, 2);
	{
		NI i_3;
		NI colontmp__2;
		NI res;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = (NI)(arraySize - ((NI) 1));
		res = ((NI) 1);
		{
			while (1) {
				tyArray__JiWwrsTRC6xqNlGcBthSVA T38_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
				if (!(res <= colontmp__2)) goto LA37;
				i_3 = res;
				nimZeroMem((void*)T38_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T38_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(id + i_3))));
				T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T39_ = percent___aDvifvZOUmduC6Unfm69bKA(T38_, 1);
				add__IM4kcMNkkOLJtqdEqSxR8A(&gotoArray, T39_);
				res += ((NI) 1);
			} LA37: ;
		}
	}
	nimZeroMem((void*)T40_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T40_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(id + arraySize))));
	T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T41_ = percent___5kuxCbMO8PVJc9aJbXScUOQ(T40_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&gotoArray, T41_);
	T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
	T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, gotoArray);
	add__IM4kcMNkkOLJtqdEqSxR8A(T42_, T43_);
	{
		NI j;
		NI i_4;
		j = (NI)0;
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < casePos)) goto LA46;
				j = i_4;
				genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*n_2)._kind_6.sons->data[j]);
				i_4 += ((NI) 1);
			} LA46: ;
		}
	}
	caseStmt = (*n_2)._kind_6.sons->data[casePos];
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*caseStmt)._kind_6.sons->data[((NI) 0)], (&a));
	T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T47_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T48_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T48_[0] = tmp;
	T48_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T49_ = percent___Uu9cBz7dxPVDFhF9aLzWecyQ(T48_, 2);
	T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T50_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T49_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T47_, T50_);
	{
		NI i_5;
		NI colontmp__3;
		NI i_6;
		i_5 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(caseStmt);
		i_6 = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T54_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				NI T61_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_2;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T75_;
				tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T105_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T106_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
				if (!(i_6 < colontmp__3)) goto LA53;
				i_5 = i_6;
				T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T54_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA57_: ;
				T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T54_, T60_);
				T61_ = (NI)0;
				T61_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				it_2 = (*caseStmt)._kind_6.sons->data[i_5];
				{
					NI j_2;
					NI colontmp__4;
					NI T63_;
					NI i_7;
					j_2 = (NI)0;
					colontmp__4 = (NI)0;
					T63_ = (NI)0;
					T63_ = len__P89cqdlERShb9alU3iC0yj8wast(it_2);
					colontmp__4 = (NI)(T63_ - ((NI) 1));
					i_7 = ((NI) 0);
					{
						while (1) {
							tyObject_Int128__9a9axPfb75jdWY25AamJewkA val;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T70_;
							tyArray__JiWwrsTRC6xqNlGcBthSVA T71_;
							NI64 T72_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
							if (!(i_7 < colontmp__4)) goto LA65;
							j_2 = i_7;
							{
								if (!((*(*it_2)._kind_6.sons->data[j_2]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA68_;
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_695), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_696, NIM_FALSE);
								goto BeforeRet_;
							}
							LA68_: ;
							val = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*it_2)._kind_6.sons->data[j_2], Max__zlJMNfqX7LwCYj0PF6ncWQ);
							T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T70_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T71_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
							T72_ = (NI64)0;
							T72_ = toInt64__1szweXXq3RBN50owrYu2Xw(val);
							T71_[0] = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg((NI64)((NI64)(T72_ + ((NI64) (id))) + IL64(1)));
							T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T73_ = percent___WWt3il4CHPiYP10KdNLrWw(T71_, 1);
							T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T74_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T73_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T70_, T74_);
							i_7 += ((NI) 1);
						} LA65: ;
					}
				}
				T75_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T75_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it_2);
				genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, T75_);
				{
					NI j_3;
					NI colontmp__5;
					NI colontmp__6;
					NI i_8;
					j_3 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__5 = (NI)(casePos + ((NI) 1));
					colontmp__6 = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
					i_8 = colontmp__5;
					{
						while (1) {
							if (!(i_8 < colontmp__6)) goto LA78;
							j_3 = i_8;
							genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*n_2)._kind_6.sons->data[j_3]);
							i_8 += ((NI) 1);
						} LA78: ;
					}
				}
				{
					NI j_4;
					NI i_9;
					j_4 = (NI)0;
					i_9 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_3;
							if (!(i_9 < casePos)) goto LA81;
							j_4 = i_9;
							it_3 = (*n_2)._kind_6.sons->data[j_4];
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgn;
								if (!((*it_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100) || (*it_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99))) goto LA84_;
								asgn = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(it_3);
								transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(asgn, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 73));
								asgnRef((void**) (&(*asgn)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*asgn)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) 2)));
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sym;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value;
									sym = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									value = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* identDefs;
										identDefs = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										{
											NI i_10;
											NI colontmp__7;
											NI i_11;
											i_10 = (NI)0;
											colontmp__7 = (NI)0;
											colontmp__7 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it_3);
											i_11 = ((NI) 0);
											{
												while (1) {
													if (!(i_11 < colontmp__7)) goto LA90;
													i_10 = i_11;
													identDefs = (*it_3)._kind_6.sons->data[i_10];
													{
														tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* valueSym;
														NI T95_;
														if (!((*identDefs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35))) goto LA93_;
														T95_ = (NI)0;
														T95_ = len__P89cqdlERShb9alU3iC0yj8wast(identDefs);
														valueSym = (*identDefs)._kind_6.sons->data[(NI)(T95_ - ((NI) 1))];
														{
															NI i_12;
															NI colontmp__8;
															NI T97_;
															NI i_13;
															i_12 = (NI)0;
															colontmp__8 = (NI)0;
															T97_ = (NI)0;
															T97_ = len__P89cqdlERShb9alU3iC0yj8wast(identDefs);
															colontmp__8 = (NI)(T97_ - ((NI) 2));
															i_13 = ((NI) 0);
															{
																while (1) {
																	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* memberSym;
																	if (!(i_13 < colontmp__8)) goto LA99;
																	i_12 = i_13;
																	memberSym = (*identDefs)._kind_6.sons->data[i_12];
																	sym = memberSym;
																	value = valueSym;
																	{
																		if (!!(((*value).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA102_;
																		asgnRef((void**) (&(*asgn)._kind_6.sons->data[((NI) 0)]), sym);
																		asgnRef((void**) (&(*asgn)._kind_6.sons->data[((NI) 1)]), value);
																		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, asgn);
																	}
																	LA102_: ;
																	i_13 += ((NI) 1);
																} LA99: ;
															}
														}
													}
													LA93_: ;
													i_11 += ((NI) 1);
												} LA90: ;
											}
										}
									}
								}
							}
							goto LA82_;
							LA84_: ;
							{
								genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, it_3);
							}
							LA82_: ;
							i_9 += ((NI) 1);
						} LA81: ;
					}
				}
				nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*caseStmt)._kind_6.sons->data[((NI) 0)], (&a_2));
				T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T105_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T106_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T106_[0] = tmp;
				T106_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
				T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T107_ = percent___Uu9cBz7dxPVDFhF9aLzWecyQ(T106_, 2);
				T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T108_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T107_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T105_, T108_);
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
				i_6 += ((NI) 1);
			} LA53: ;
		}
	}
	{
		NI j_5;
		NI colontmp__9;
		NI colontmp__10;
		NI i_14;
		j_5 = (NI)0;
		colontmp__9 = (NI)0;
		colontmp__10 = (NI)0;
		colontmp__9 = (NI)(casePos + ((NI) 1));
		colontmp__10 = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		i_14 = colontmp__9;
		{
			while (1) {
				if (!(i_14 < colontmp__10)) goto LA111;
				j_5 = i_14;
				genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*n_2)._kind_6.sons->data[j_5]);
				i_14 += ((NI) 1);
			} LA111: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, assignLabel__mIFKIo7g6Echd7EokLhQegcgen)(tyObject_TBlock__GFhahvekTq3dDOkWyhchMA* b) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*b).id)));
	unsureAsgnRef((void**) (&(*b).label), amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T1_));
	result = (*b).label;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__QrTB5DOwbDX9bKAW7PNbuJA_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NI oldBreakIdxX60gensym1919_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	(*p).withinLoop += ((NI) 1);
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	oldBreakIdxX60gensym1919_ = (*p).breakIdx;
	loopBody = (*t)._kind_6.sons->data[((NI) 1)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = stmtsContainPragma__QPJXGOVirAPBlaL8RY5bwA(loopBody, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 202));
		if (!(T3_)) goto LA4_;
		T3_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 1))&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NI T10_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(loopBody);
			T9_ = (T10_ == ((NI) 2));
			if (!(T9_)) goto LA11_;
			T9_ = ((*(*loopBody)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA11_: ;
			if (!T9_) goto LA12_;
			loopBody = (*loopBody)._kind_6.sons->data[((NI) 1)];
		}
		LA12_: ;
		genComputedGoto__UtJx89cn0a8CNSWWmaj6raA_8(p, loopBody);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T15_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T15_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 11);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_697));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA18_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA18_: ;
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T20_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T15_, T21_);
		(*p).breakIdx = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		(*p).blocks->data[(*p).breakIdx].isLoop = NIM_TRUE;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		{
			NIM_BOOL T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* label;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T28_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			T24_ = (NIM_BOOL)0;
			T24_ = !(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)));
			if (T24_) goto LA25_;
			T24_ = ((*(*t)._kind_6.sons->data[((NI) 0)])._kind_1.intVal == IL64(0));
			LA25_: ;
			if (!T24_) goto LA26_;
			label = assignLabel__mIFKIo7g6Echd7EokLhQegcgen((&(*p).blocks->data[(*p).breakIdx]));
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T28_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T29_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T29_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
			T29_[1] = label;
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = percent___SqZEI7bxySjmJX4GsXyvKw(T29_, 2);
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T30_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T28_, T31_);
		}
		LA26_: ;
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, loopBody);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T36_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
			if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 21))&31U)))!=0)) goto LA34_;
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T36_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_2 = rawNewString(((NI) 80));
			T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T37_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_281));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T37_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA40_: ;
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T36_, T43_);
		}
		LA34_: ;
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	}
	LA1_: ;
	(*p).breakIdx = oldBreakIdxX60gensym1919_;
	(*p).withinLoop -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__9c6v9b6B8RZkui111YH4cbEw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
{	v = (*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T7_ = ((*(*p).prc).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
			LA10_: ;
			if (!T7_) goto LA11_;
		}
		goto LA5_;
		LA11_: ;
		{
			goto BeforeRet_;
		}
		LA5_: ;
	}
	LA3_: ;
	genSingleVar__T7FeUoHVfLrGm0JydrFabA(p, v, (*a)._kind_6.sons->data[((NI) 0)], (*a)._kind_6.sons->data[((NI) 2)]);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__9c6v9b6B8RZkui111YH4cbEw_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	NIM_BOOL immediateAsgn;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA v;
	immediateAsgn = !(((*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
	nimZeroMem((void*)(&v), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*a)._kind_6.sons->data[((NI) 0)], (&v));
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, a);
	{
		if (!immediateAsgn) goto LA3_;
		loadInto__vkEx8Dn9aiGOI04WjvQIHIwcgen(p, (*a)._kind_6.sons->data[((NI) 0)], (*a)._kind_6.sons->data[((NI) 2)], (&v));
	}
	goto LA1_;
	LA3_: ;
	{
		constructLoc__Q4oQMHZIwSi4nGkYAuAC8A(p, (&v), NIM_FALSE);
	}
	LA1_: ;
}
static N_NIMCALL(void, Marker_tySequence__sno9c9bXUVS2CqhtWOJadaCw)(void* p, NI op) {
	tySequence__sno9c9bXUVS2CqhtWOJadaCw* a;
	NI T1_;
	a = (tySequence__sno9c9bXUVS2CqhtWOJadaCw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0.lode, op);
	nimGCvisit((void*)a->data[T1_].Field0.r, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__UtJx89cn0a8CNSWWmaj6raA_10)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tup;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA field;
	NIM_BOOL forHcr;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* hcrCond;
	tySequence__sno9c9bXUVS2CqhtWOJadaCw* hcrGlobals;
	NIM_BOOL isGlobalInBlock;
	NIM_BOOL T19_;
	NI T21_;
	NIM_BOOL T22_;
	NI T43_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T44_;
{	nimZeroMem((void*)(&tup), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&field), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_698), TM__MQdRN7fpbG7rPm4JpVVAhA_699);
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI T6_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T6_ - ((NI) 2));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
					if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA11_;
					T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T13_ = lowerTupleUnpacking__8A4G64HByteFanrMUexmNw_2((*(*(*p).module).g).graph, n, (*p).prc);
					genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, T13_);
					goto BeforeRet_;
				}
				LA11_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	forHcr = treatGlobalDifferentlyForHCR__AaEyY9c5j7G9bThwkB9ajJ8Pw((*p).module, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	{
		if (!forHcr) goto LA16_;
		hcrCond = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
	}
	goto LA14_;
	LA16_: ;
	{
		hcrCond = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA14_: ;
	hcrGlobals = (tySequence__sno9c9bXUVS2CqhtWOJadaCw*)0;
	T19_ = (NIM_BOOL)0;
	T19_ = forHcr;
	if (!(T19_)) goto LA20_;
	T21_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	T19_ = (((NI) 2) < T21_);
	LA20_: ;
	isGlobalInBlock = T19_;
	T22_ = (NIM_BOOL)0;
	T22_ = forHcr;
	if (!(T22_)) goto LA23_;
	T22_ = !(isGlobalInBlock);
	LA23_: ;
	forHcr = T22_;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T28_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
		NI T42_;
		if (!forHcr) goto LA26_;
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T28_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), hcrCond);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA31_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA31_: ;
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T33_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T28_, T34_);
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA38_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA38_: ;
		T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T41_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T40_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T41_);
		T42_ = (NI)0;
		T42_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	}
	LA26_: ;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, n);
	T43_ = (NI)0;
	T43_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[(NI)(T43_ - ((NI) 1))], (&tup));
	T44_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T44_ = t__XNOXh7uniWNgiq58C9bW49awcgen(tup);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T44_, IL64(36134350135273744));
	{
		NI i_3;
		NI colontmp__2;
		NI T46_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T46_ = (NI)0;
		T46_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp__2 = (NI)(T46_ - ((NI) 2));
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA48;
				i_3 = i_4;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vn;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* traverseProc;
					vn = (*n)._kind_6.sons->data[i_3];
					v = (*vn)._kind_4.sym;
					{
						if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA52_;
						goto LA49;
					}
					LA52_: ;
					traverseProc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					{
						if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0)) goto LA56_;
						assignGlobalVar__yX9bZpeKIzp3RLrjnzlc0NQ(p, vn, ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
						genObjectInit__UANnSFbuKD1BS6RrMbZs2A(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*v).typ, (&(*v).loc), ((tyEnum_ObjConstrMode__9agQ3x8C5KfK9c9a3uY9abfUTw) 0));
						traverseProc = getTraverseProc__V1atRcoAv09bVdrCPNlvW8Q(p, v);
						{
							NIM_BOOL T60_;
							NIM_BOOL T62_;
							T60_ = (NIM_BOOL)0;
							T60_ = !((traverseProc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
							if (!(T60_)) goto LA61_;
							T62_ = (NIM_BOOL)0;
							T62_ = hcrOn__NAlbw3fU59aFdo7L5aQtmkw(p);
							T60_ = !(T62_);
							LA61_: ;
							if (!T60_) goto LA63_;
							registerTraverseProc__BwxixSWhJWbQ369cJZeckHA(p, v, traverseProc);
						}
						LA63_: ;
					}
					goto LA54_;
					LA56_: ;
					{
						NI T66_;
						NIM_BOOL T67_;
						assignLocalVar__UtJx89cn0a8CNSWWmaj6raA(p, vn);
						T66_ = (NI)0;
						T66_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						T67_ = (NIM_BOOL)0;
						T67_ = isAssignedImmediately__udBNoPxZaHjsWUNp37jAdwcgen((*(*(*p).module).g).config, (*n)._kind_6.sons->data[(NI)(T66_ - ((NI) 1))]);
						initLocalVar__EpeofNfMJPurx0duaALCaA(p, v, T67_);
					}
					LA54_: ;
					initLoc__qlujIAW86QclHYUVxlHRiQ((&field), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), vn, tup.storage);
					{
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T72_;
						if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA70_;
						nimZeroMem((void*)T72_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T72_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(tup);
						T72_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i_3)));
						field.r = percent___5TB09c2Iz60T0YagbSbI5RQ(T72_, 2);
					}
					goto LA68_;
					LA70_: ;
					{
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T78_;
						{
							if (!!(((*(*(*t).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA76_;
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_698), TM__MQdRN7fpbG7rPm4JpVVAhA_700);
						}
						LA76_: ;
						nimZeroMem((void*)T78_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T78_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(tup);
						T78_[1] = mangleRecFieldName__HzLa9cY9ad9bp8c63DnHIEfWA((*p).module, (*(*(*t).n)._kind_6.sons->data[i_3])._kind_4.sym);
						field.r = percent___paA0sar8RKZqiwEaDfWo2A(T78_, 2);
					}
					LA68_: ;
					putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, (&(*v).loc), field);
					{
						NIM_BOOL T81_;
						tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA T85_;
						NI T92_;
						T81_ = (NIM_BOOL)0;
						T81_ = forHcr;
						if (T81_) goto LA82_;
						T81_ = isGlobalInBlock;
						LA82_: ;
						if (!T81_) goto LA83_;
						nimZeroMem((void*)(&T85_), sizeof(tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA));
						genericAssign((void*)(&T85_.Field0), (void*)(&(*v).loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
						{
							tyArray__qTjAvTvKF9anytN1At69aJMQ T90_;
							if (!(traverseProc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA88_;
							nimZeroMem((void*)T90_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
							T85_.Field1 = percent___x2NKZw9brJpylbwEtLfx9a9bg(T90_, 0);
						}
						goto LA86_;
						LA88_: ;
						{
							T85_.Field1 = traverseProc;
						}
						LA86_: ;
						hcrGlobals = (tySequence__sno9c9bXUVS2CqhtWOJadaCw*) incrSeqV3((TGenericSeq*)(hcrGlobals), (&NTI__sno9c9bXUVS2CqhtWOJadaCw_));
						T92_ = hcrGlobals->Sup.len++;
						genericAssign((void*)(&hcrGlobals->data[T92_].Field0), (void*)(&T85_.Field0), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
						asgnRef((void**) (&hcrGlobals->data[T92_].Field1), T85_.Field1);
					}
					LA83_: ;
				} LA49: ;
				i_4 += ((NI) 1);
			} LA48: ;
		}
	}
	{
		if (!forHcr) goto LA95_;
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	}
	LA95_: ;
	{
		NIM_BOOL T99_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T103_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T109_;
		T99_ = (NIM_BOOL)0;
		T99_ = forHcr;
		if (T99_) goto LA100_;
		T99_ = isGlobalInBlock;
		LA100_: ;
		if (!T99_) goto LA101_;
		T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T103_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 9);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_702));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), hcrCond);
		res_3 = resizeString(res_3, 13);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_703));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA106_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA106_: ;
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T108_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T109_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T108_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T103_, T109_);
		{
			tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA* curr;
			NI i_5;
			NI L;
			NI T111_;
			curr = (tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA*)0;
			i_5 = ((NI) 0);
			T111_ = (hcrGlobals ? hcrGlobals->Sup.len : 0);
			L = T111_;
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T114_;
					NimStringDesc* res_4;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T115_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T116_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T118_;
					if (!(i_5 < L)) goto LA113;
					curr = (&hcrGlobals->data[i_5]);
					T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T114_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
					res_4 = rawNewString(((NI) 80));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), hcrCond);
					res_4 = resizeString(res_4, 22);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_704));
					T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T115_ = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3((*p).module, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T115_);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_378));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*curr).Field0.r);
					res_4 = resizeString(res_4, 10);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_379));
					T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T116_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*curr).Field0);
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T116_);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_380));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*curr).Field1);
					res_4 = resizeString(res_4, 11);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_381));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*curr).Field0.r);
					res_4 = resizeString(res_4, 3);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_705));
					T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T117_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
					T118_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T118_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T117_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T114_, T118_);
					i_5 += ((NI) 1);
				} LA113: ;
			}
		}
	}
	LA101_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__UtJx89cn0a8CNSWWmaj6raA_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				{
					{
						if (!((*(*it)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA8_;
						goto LA5;
					}
					LA8_: ;
					{
						if (!((*(*it)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35))) goto LA12_;
						{
							if (!((*(*(*it))._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA16_;
							genSingleVar__9c6v9b6B8RZkui111YH4cbEw(p, (*it));
						}
						goto LA14_;
						LA16_: ;
						{
							genClosureVar__9c6v9b6B8RZkui111YH4cbEw_2(p, (*it));
						}
						LA14_: ;
					}
					goto LA10_;
					LA12_: ;
					{
						genVarTuple__UtJx89cn0a8CNSWWmaj6raA_10(p, (*it));
					}
					LA10_: ;
				} LA5: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__P8OJ6tb5bbr0Tp2llps5Rw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA e, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* labl, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** branches, NI branchesLen_0) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA x;
	nimZeroMem((void*)(&x), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				NI j;
				NI64 T5_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*b)._kind_6.sons->data[i], (&x));
				T5_ = (NI64)0;
				T5_ = hashString__9acplCwsZ5kwBbm0f7S7DNw((*(*(*p).module).g).config, (*(*b)._kind_6.sons->data[i])._kind_3.strVal);
				j = ((NI) ((NI64)(T5_ & ((NI64) ((branchesLen_0-1))))));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T6_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_498));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T6_);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
				T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T7_ = rdLoc__xidyzuHqIciXbQyEOKahDg(e);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
				res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
				T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T8_ = rdLoc__xidyzuHqIciXbQyEOKahDg(x);
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
				res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_708));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), labl);
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA11_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA11_: ;
				T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T13_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				add__IM4kcMNkkOLJtqdEqSxR8A(&branches[j], T13_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__8mAL9ckajemzgfLPfeZVNoQ_21)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T1_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	NI T8_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA4_: ;
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T6_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T1_, T7_);
	T8_ = (NI)0;
	T8_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, n, d);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d, NI labId, NI until) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lend;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	lend = getLabel__3AsTOpq9crZUYBL9aD1lXBng_5(p);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T11_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
				if (!(res <= until)) goto LA3;
				i = res;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
					if (!(T6_)) goto LA7_;
					T6_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
					LA7_: ;
					if (!T6_) goto LA8_;
					(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
				}
				LA8_: ;
				T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T11_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T11_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(labId + i))));
				T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T12_ = percent___Au81R9a68Rv3gwlPtvDarPg(T11_, 1);
				T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T13_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T12_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T13_);
				{
					NI T18_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T19_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T20_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
					if (!((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA16_;
					T18_ = (NI)0;
					T18_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					exprBlock__8mAL9ckajemzgfLPfeZVNoQ_21(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T18_ - ((NI) 1))], d);
					T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T19_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T20_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T20_[0] = lend;
					T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T21_ = percent___c1f569aWpTd825BTnv9bq4Xg(T20_, 1);
					T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T19_, T22_);
				}
				goto LA14_;
				LA16_: ;
				{
					exprBlock__8mAL9ckajemzgfLPfeZVNoQ_21(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				}
				LA14_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	result = lend;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__re1pwmyeR32ikwnOC3vvzQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NI strings;
	strings = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NI T8_;
					if (!((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA6_;
					T8_ = (NI)0;
					T8_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					strings += (NI)(T8_ - ((NI) 1));
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI bitMask;
		NI T13_;
		tySequence__WwUFq9cJ2xKRlsAWVEHyPRg* branches;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		NI labId;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T25_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T46_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T47_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lend;
		NI T59_;
		if (!(((NI) 8) < strings)) goto LA11_;
		T13_ = (NI)0;
		T13_ = nextPowerOfTwo__v2qC0V55wqa9bmqc7eHTz8A(strings);
		bitMask = (NI)(T13_ - ((NI) 1));
		branches = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*)0;
		branches = (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) newSeq((&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_), ((NI) ((NI)(bitMask + ((NI) 1)))));
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		labId = (*p).labels;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(t);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA16;
					i_3 = i_4;
					(*p).labels += ((NI) 1);
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
						if (!((*(*t)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA19_;
						T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T21_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T22_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T21_);
						T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T23_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T22_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
						genCaseStringBranch__P8OJ6tb5bbr0Tp2llps5Rw(p, (*t)._kind_6.sons->data[i_3], a, T23_, branches->data, (branches ? branches->Sup.len : 0));
					}
					goto LA17_;
					LA19_: ;
					{
					}
					LA17_: ;
					i_4 += ((NI) 1);
				} LA16: ;
			}
		}
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T25_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 8);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_709));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_710));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T26_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T27_);
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_711));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (bitMask)));
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA30_: ;
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T32_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T25_, T33_);
		{
			NI j;
			NI colontmp__3;
			NI T35_;
			NI res_2;
			j = (NI)0;
			colontmp__3 = (NI)0;
			T35_ = ((branches ? branches->Sup.len : 0)-1);
			colontmp__3 = T35_;
			res_2 = ((NI) 0);
			{
				while (1) {
					if (!(res_2 <= colontmp__3)) goto LA37;
					j = res_2;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T43_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
						if (!!((branches->data[j] == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA40_;
						T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T43_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T43_[0] = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg(((NI64) (j)));
						T43_[1] = branches->data[j];
						T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T44_ = percent___hc7hMh137dtaNdd3qw28EQ(T43_, 2);
						T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T45_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T44_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T42_, T45_);
					}
					LA40_: ;
					res_2 += ((NI) 1);
				} LA37: ;
			}
		}
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T46_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T47_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T48_ = percent___BYiowJAm8zF7RBRISElaLg(T47_, 0);
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T49_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T48_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T46_, T49_);
		{
			NI T52_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T55_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T56_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			T52_ = (NI)0;
			T52_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			if (!!(((*(*t)._kind_6.sons->data[(NI)(T52_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85)))) goto LA53_;
			T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T55_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T56_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T56_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T57_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T56_, 1);
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T57_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T55_, T58_);
		}
		LA53_: ;
		T59_ = (NI)0;
		T59_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		lend = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, t, d, ((NI) (labId)), (NI)(T59_ - ((NI) 1)));
		fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lend);
	}
	goto LA9_;
	LA11_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym2138_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lendX60gensym2138_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resX60gensym2140_;
		NI labIdX60gensym2140_;
		nimZeroMem((void*)(&aX60gensym2138_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*t)._kind_6.sons->data[((NI) 0)], (&aX60gensym2138_));
		resX60gensym2140_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		labIdX60gensym2140_ = (*p).labels;
		{
			NI iX60gensym2140_;
			NI colontmp__4;
			NI T62_;
			NI res_3;
			iX60gensym2140_ = (NI)0;
			colontmp__4 = (NI)0;
			T62_ = (NI)0;
			T62_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			colontmp__4 = (NI)(T62_ - ((NI) 1));
			res_3 = ((NI) 1);
			{
				while (1) {
					if (!(res_3 <= colontmp__4)) goto LA64;
					iX60gensym2140_ = res_3;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA xX60gensym2143_;
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA yX60gensym2143_;
						if (!((*(*t)._kind_6.sons->data[iX60gensym2140_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA67_;
						nimZeroMem((void*)(&xX60gensym2143_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						nimZeroMem((void*)(&yX60gensym2143_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						{
							NI iX60gensym2143_;
							NI colontmp__5;
							NI T70_;
							NI i_5;
							iX60gensym2143_ = (NI)0;
							colontmp__5 = (NI)0;
							T70_ = (NI)0;
							T70_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[iX60gensym2140_]);
							colontmp__5 = (NI)(T70_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__5)) goto LA72;
									iX60gensym2143_ = i_5;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T77_;
										NimStringDesc* res_4;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
										if (!((*(*(*t)._kind_6.sons->data[iX60gensym2140_])._kind_6.sons->data[iX60gensym2143_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA75_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*t)._kind_6.sons->data[iX60gensym2140_])._kind_6.sons->data[iX60gensym2143_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2143_));
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*t)._kind_6.sons->data[iX60gensym2140_])._kind_6.sons->data[iX60gensym2143_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2143_));
										T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T77_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_4 = rawNewString(((NI) 80));
										T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T78_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
										T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T79_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T78_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T77_, T79_);
									}
									goto LA73_;
									LA75_: ;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T81_;
										NimStringDesc* res_5;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*t)._kind_6.sons->data[iX60gensym2140_])._kind_6.sons->data[iX60gensym2143_], (&xX60gensym2143_));
										T81_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T81_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_5 = rawNewString(((NI) 80));
										res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
										T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T82_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_498));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T82_);
										res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
										T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T83_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym2138_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T83_);
										res_5 = resizeString(res_5, 2);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
										T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T84_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(xX60gensym2143_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T84_);
										res_5 = resizeString(res_5, 8);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_708));
										T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T85_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
										T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T86_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T85_);
										T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T87_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T86_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T87_);
										res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA90_;
											res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA90_: ;
										T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T92_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
										T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T93_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T92_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T81_, T93_);
									}
									LA73_: ;
									i_5 += ((NI) 1);
								} LA72: ;
							}
						}
					}
					goto LA65_;
					LA67_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T95_;
						tyArray__JiWwrsTRC6xqNlGcBthSVA T96_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T98_;
						T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T95_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T96_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T96_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T97_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T96_, 1);
						T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T98_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T97_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T95_, T98_);
					}
					LA65_: ;
					res_3 += ((NI) 1);
				} LA64: ;
			}
		}
		{
			NI T101_;
			NI T102_;
			NI gotoTargetX60gensym2140_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T105_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T106_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
			NI T109_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T110_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T111_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
			T101_ = (NI)0;
			T101_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			T102_ = (NI)0;
			T102_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			if (!((NI)(T101_ - ((NI) 1)) < (NI)(T102_ - ((NI) 1)))) goto LA103_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2140_ = (*p).labels;
			T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T105_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T106_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2140_)));
			T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T107_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T106_, 1);
			T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T108_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T107_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T105_, T108_);
			T109_ = (NI)0;
			T109_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			resX60gensym2140_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, t, d, ((NI) (labIdX60gensym2140_)), (NI)(T109_ - ((NI) 1)));
			T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T110_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T111_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T111_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2140_)));
			T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T112_ = percent___Au81R9a68Rv3gwlPtvDarPg(T111_, 1);
			T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T113_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T112_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T110_, T113_);
		}
		goto LA99_;
		LA103_: ;
		{
			NI T115_;
			T115_ = (NI)0;
			T115_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			resX60gensym2140_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, t, d, ((NI) (labIdX60gensym2140_)), (NI)(T115_ - ((NI) 1)));
		}
		LA99_: ;
		lendX60gensym2138_ = resX60gensym2140_;
		fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lendX60gensym2138_);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__ACGHJp9bbmHaRpjqO8LXrqA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseStmt) {
{	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(caseStmt);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T4_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
				NI T11_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T4_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA7_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA7_: ;
				T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T10_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T9_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T4_, T10_);
				T11_ = (NI)0;
				T11_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				it = (*caseStmt)._kind_6.sons->data[i];
				{
					NI j;
					NI colontmp__2;
					NI T13_;
					NI i_3;
					j = (NI)0;
					colontmp__2 = (NI)0;
					T13_ = (NI)0;
					T13_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					colontmp__2 = (NI)(T13_ - ((NI) 1));
					i_3 = ((NI) 0);
					{
						while (1) {
							tyObject_Int128__9a9axPfb75jdWY25AamJewkA val;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T20_;
							tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
							if (!(i_3 < colontmp__2)) goto LA15;
							j = i_3;
							{
								if (!((*(*it)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA18_;
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_695), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_717, NIM_FALSE);
								goto BeforeRet_;
							}
							LA18_: ;
							val = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*it)._kind_6.sons->data[j], Max__zlJMNfqX7LwCYj0PF6ncWQ);
							T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
							T20_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
							nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
							T21_[0] = rope__b5mr3rjXEwHVfmNLJr4cBA(val);
							T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T22_ = percent___Yw741acxvsUs9cOX9cuiDj9bw(T21_, 1);
							T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T23_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T22_);
							add__IM4kcMNkkOLJtqdEqSxR8A(T20_, T23_);
							i_3 += ((NI) 1);
						} LA15: ;
					}
				}
				T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T24_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
				genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, T24_);
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__FtWqvDVdWg4sJ9aFlt4ZdKg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(b);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					it = (*b)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						T7_ = (NIM_BOOL)0;
						T7_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44));
						if (!(T7_)) goto LA8_;
						T7_ = (IL64(256) < (NI64)((*(*it)._kind_6.sons->data[((NI) 1)])._kind_1.intVal - (*(*it)._kind_6.sons->data[((NI) 0)])._kind_1.intVal));
						LA8_: ;
						if (!T7_) goto LA9_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA9_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__sCIDQrEETdL3XXbX8Uzgrg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stmtBlock;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				branch = (*n)._kind_6.sons->data[i];
				stmtBlock = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = stmtsContainPragma__QPJXGOVirAPBlaL8RY5bwA(stmtBlock, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 201));
					if (!T6_) goto LA7_;
					result = i;
				}
				goto LA4_;
				LA7_: ;
				{
					if (!!(((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 0))&7U)))!=0))) goto LA10_;
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = ((*branch).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85));
						if (!(T14_)) goto LA15_;
						T14_ = branchHasTooBigRange__FtWqvDVdWg4sJ9aFlt4ZdKg(branch);
						LA15_: ;
						if (!T14_) goto LA16_;
						result = i;
					}
					LA16_: ;
				}
				goto LA4_;
				LA10_: ;
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__8mAL9ckajemzgfLPfeZVNoQ_22)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NI splitPoint;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lend;
	splitPoint = ifSwitchSplitPoint__sCIDQrEETdL3XXbX8Uzgrg(p, n);
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resX60gensym2189_;
		NI labIdX60gensym2189_;
		if (!(((NI) 0) < splitPoint)) goto LA3_;
		resX60gensym2189_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		labIdX60gensym2189_ = (*p).labels;
		{
			NI iX60gensym2189_;
			NI res;
			iX60gensym2189_ = (NI)0;
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= splitPoint)) goto LA7;
					iX60gensym2189_ = res;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA xX60gensym2192_;
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA yX60gensym2192_;
						if (!((*(*n)._kind_6.sons->data[iX60gensym2189_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA10_;
						nimZeroMem((void*)(&xX60gensym2192_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						nimZeroMem((void*)(&yX60gensym2192_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						{
							NI iX60gensym2192_;
							NI colontmp_;
							NI T13_;
							NI i;
							iX60gensym2192_ = (NI)0;
							colontmp_ = (NI)0;
							T13_ = (NI)0;
							T13_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[iX60gensym2189_]);
							colontmp_ = (NI)(T13_ - ((NI) 1));
							i = ((NI) 0);
							{
								while (1) {
									if (!(i < colontmp_)) goto LA15;
									iX60gensym2192_ = i;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T20_;
										NimStringDesc* res_2;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
										if (!((*(*(*n)._kind_6.sons->data[iX60gensym2189_])._kind_6.sons->data[iX60gensym2192_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA18_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*n)._kind_6.sons->data[iX60gensym2189_])._kind_6.sons->data[iX60gensym2192_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2192_));
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*n)._kind_6.sons->data[iX60gensym2189_])._kind_6.sons->data[iX60gensym2192_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2192_));
										T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T20_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_2 = rawNewString(((NI) 80));
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
										T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T21_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T21_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_713));
										T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T22_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(xX60gensym2192_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T22_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_714));
										T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T23_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T23_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_715));
										T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T24_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(yX60gensym2192_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T24_);
										res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_716));
										T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T25_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
										T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T26_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T25_);
										T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T27_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T26_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T27_);
										res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA30_;
											res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA30_: ;
										T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T32_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
										T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T33_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T32_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T20_, T33_);
									}
									goto LA16_;
									LA18_: ;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T35_;
										NimStringDesc* res_3;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*n)._kind_6.sons->data[iX60gensym2189_])._kind_6.sons->data[iX60gensym2192_], (&xX60gensym2192_));
										T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T35_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_3 = rawNewString(((NI) 80));
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
										T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T36_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T36_);
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_430));
										T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T37_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(xX60gensym2192_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T37_);
										res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_716));
										T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T38_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
										T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T39_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T38_);
										T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T40_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T39_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T40_);
										res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA43_;
											res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA43_: ;
										T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T45_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
										T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T46_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T45_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T35_, T46_);
									}
									LA16_: ;
									i += ((NI) 1);
								} LA15: ;
							}
						}
					}
					goto LA8_;
					LA10_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T48_;
						tyArray__JiWwrsTRC6xqNlGcBthSVA T49_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
						T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T48_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T49_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T49_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T50_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T49_, 1);
						T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T51_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T50_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T48_, T51_);
					}
					LA8_: ;
					res += ((NI) 1);
				} LA7: ;
			}
		}
		{
			NI T54_;
			NI gotoTargetX60gensym2189_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T57_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T58_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
			T54_ = (NI)0;
			T54_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(splitPoint < (NI)(T54_ - ((NI) 1)))) goto LA55_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2189_ = (*p).labels;
			T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T57_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T58_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T58_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2189_)));
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T58_, 1);
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T57_, T60_);
			resX60gensym2189_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, n, d, ((NI) (labIdX60gensym2189_)), splitPoint);
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T62_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T62_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2189_)));
			T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T63_ = percent___Au81R9a68Rv3gwlPtvDarPg(T62_, 1);
			T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T64_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T63_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T64_);
		}
		goto LA52_;
		LA55_: ;
		{
			resX60gensym2189_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, n, d, ((NI) (labIdX60gensym2189_)), splitPoint);
		}
		LA52_: ;
		lend = resX60gensym2189_;
	}
	goto LA1_;
	LA3_: ;
	{
		lend = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA1_: ;
	{
		NI T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T72_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T73_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
		NIM_BOOL hasDefault;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T109_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T110_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T112_;
		T69_ = (NI)0;
		T69_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!((NI)(splitPoint + ((NI) 1)) < T69_)) goto LA70_;
		T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T72_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T73_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T73_[0] = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(a);
		T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T74_ = percent___T9caGByKkBhaXSZ6fCJLIdQ(T73_, 1);
		T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T75_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T74_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T72_, T75_);
		hasDefault = NIM_FALSE;
		{
			NI i_2;
			NI colontmp__2;
			NI colontmp__3;
			NI i_3;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__2 = (NI)(splitPoint + ((NI) 1));
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_3 = colontmp__2;
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T94_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T95_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T96_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T98_;
					if (!(i_3 < colontmp__3)) goto LA78;
					i_2 = i_3;
					{
						NIM_BOOL T81_;
						T81_ = (NIM_BOOL)0;
						T81_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
						if (!(T81_)) goto LA82_;
						T81_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
						LA82_: ;
						if (!T81_) goto LA83_;
						(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
					}
					LA83_: ;
					branch = (*n)._kind_6.sons->data[i_2];
					{
						if (!((*branch).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA87_;
						genCaseRange__KUz7NJSCXeUWRl4foF5zfg(p, branch);
					}
					goto LA85_;
					LA87_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T90_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T91_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
						T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T90_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T91_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T92_ = percent___TTRh79a14hh1gb0owIP1Y6Q(T91_, 0);
						T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T93_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T92_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T90_, T93_);
						hasDefault = NIM_TRUE;
					}
					LA85_: ;
					T94_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T94_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(branch);
					exprBlock__8mAL9ckajemzgfLPfeZVNoQ_21(p, T94_, d);
					T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T95_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T96_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T97_ = percent___TmeCjGna9cPfiHHcfqmKXjw(T96_, 0);
					T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T98_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T97_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T95_, T98_);
					i_3 += ((NI) 1);
				} LA78: ;
			}
		}
		{
			NIM_BOOL T101_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T105_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T106_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
			T101_ = (NIM_BOOL)0;
			T101_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 3))&7U)))!=0);
			if (!(T101_)) goto LA102_;
			T101_ = !(hasDefault);
			LA102_: ;
			if (!T101_) goto LA103_;
			T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T105_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T106_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T107_ = percent___JmTWN8YiVKTZuvCYW2XNZA(T106_, 0);
			T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T108_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T107_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T105_, T108_);
		}
		LA103_: ;
		T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T109_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T110_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T111_ = percent___BYiowJAm8zF7RBRISElaLg(T110_, 0);
		T112_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T112_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T111_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T109_, T112_);
	}
	LA70_: ;
	{
		if (!!((lend == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA115_;
		fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lend);
	}
	LA115_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCase__re1pwmyeR32ikwnOC3vvzQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*t)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
	switch ((*T8_).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		genStringCase__re1pwmyeR32ikwnOC3vvzQ_2(p, t, d);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA aX60gensym2228_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* lendX60gensym2228_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resX60gensym2230_;
		NI labIdX60gensym2230_;
		nimZeroMem((void*)(&aX60gensym2228_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*t)._kind_6.sons->data[((NI) 0)], (&aX60gensym2228_));
		resX60gensym2230_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		labIdX60gensym2230_ = (*p).labels;
		{
			NI iX60gensym2230_;
			NI colontmp_;
			NI T12_;
			NI res;
			iX60gensym2230_ = (NI)0;
			colontmp_ = (NI)0;
			T12_ = (NI)0;
			T12_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			colontmp_ = (NI)(T12_ - ((NI) 1));
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA14;
					iX60gensym2230_ = res;
					(*p).labels += ((NI) 1);
					{
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA xX60gensym2233_;
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA yX60gensym2233_;
						if (!((*(*t)._kind_6.sons->data[iX60gensym2230_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA17_;
						nimZeroMem((void*)(&xX60gensym2233_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						nimZeroMem((void*)(&yX60gensym2233_), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						{
							NI iX60gensym2233_;
							NI colontmp__2;
							NI T20_;
							NI i;
							iX60gensym2233_ = (NI)0;
							colontmp__2 = (NI)0;
							T20_ = (NI)0;
							T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[iX60gensym2230_]);
							colontmp__2 = (NI)(T20_ - ((NI) 1));
							i = ((NI) 0);
							{
								while (1) {
									if (!(i < colontmp__2)) goto LA22;
									iX60gensym2233_ = i;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T27_;
										NimStringDesc* res_2;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
										if (!((*(*(*t)._kind_6.sons->data[iX60gensym2230_])._kind_6.sons->data[iX60gensym2233_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA25_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*t)._kind_6.sons->data[iX60gensym2230_])._kind_6.sons->data[iX60gensym2233_])._kind_6.sons->data[((NI) 0)], (&xX60gensym2233_));
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*(*t)._kind_6.sons->data[iX60gensym2230_])._kind_6.sons->data[iX60gensym2233_])._kind_6.sons->data[((NI) 1)], (&yX60gensym2233_));
										T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T27_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_2 = rawNewString(((NI) 80));
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
										T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T28_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym2228_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T28_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_713));
										T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T29_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(xX60gensym2233_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T29_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_714));
										T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T30_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym2228_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T30_);
										res_2 = resizeString(res_2, 4);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_715));
										T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T31_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(yX60gensym2233_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
										res_2 = resizeString(res_2, 7);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_716));
										T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T32_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
										T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T33_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T32_);
										T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T34_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T33_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T34_);
										res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA37_;
											res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA37_: ;
										T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T39_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
										T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T40_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T39_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T27_, T40_);
									}
									goto LA23_;
									LA25_: ;
									{
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T42_;
										NimStringDesc* res_3;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
										initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*t)._kind_6.sons->data[iX60gensym2230_])._kind_6.sons->data[iX60gensym2233_], (&xX60gensym2233_));
										T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T42_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_3 = rawNewString(((NI) 80));
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
										T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T43_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(aX60gensym2228_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T43_);
										res_3 = resizeString(res_3, 4);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_430));
										T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T44_ = rdCharLoc__xidyzuHqIciXbQyEOKahDg_2(xX60gensym2233_);
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T44_);
										res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_716));
										T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T45_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
										T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T46_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429), T45_);
										T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T47_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T46_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T47_);
										res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA50_;
											res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA50_: ;
										T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T52_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
										T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T53_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T52_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T42_, T53_);
									}
									LA23_: ;
									i += ((NI) 1);
								} LA22: ;
							}
						}
					}
					goto LA15_;
					LA17_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T55_;
						tyArray__JiWwrsTRC6xqNlGcBthSVA T56_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
						T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T55_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						nimZeroMem((void*)T56_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T56_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).labels)));
						T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T57_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T56_, 1);
						T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T58_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T57_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T55_, T58_);
					}
					LA15_: ;
					res += ((NI) 1);
				} LA14: ;
			}
		}
		{
			NI T61_;
			NI T62_;
			NI gotoTargetX60gensym2230_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T65_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			NI T69_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T70_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T71_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T73_;
			T61_ = (NI)0;
			T61_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			T62_ = (NI)0;
			T62_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			if (!((NI)(T61_ - ((NI) 1)) < (NI)(T62_ - ((NI) 1)))) goto LA63_;
			(*p).labels += ((NI) 1);
			gotoTargetX60gensym2230_ = (*p).labels;
			T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T65_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T66_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T66_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2230_)));
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = percent___XWz49cQA2QiZaLkqHBU5L3g(T66_, 1);
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T67_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T65_, T68_);
			T69_ = (NI)0;
			T69_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			resX60gensym2230_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, t, d, ((NI) (labIdX60gensym2230_)), (NI)(T69_ - ((NI) 1)));
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T70_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T71_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T71_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (gotoTargetX60gensym2230_)));
			T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T72_ = percent___Au81R9a68Rv3gwlPtvDarPg(T71_, 1);
			T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T73_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T72_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T70_, T73_);
		}
		goto LA59_;
		LA63_: ;
		{
			NI T75_;
			T75_ = (NI)0;
			T75_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			resX60gensym2230_ = genCaseSecondPass__4DRiNj9aN6Z9aXL9bqOB79czGw(p, t, d, ((NI) (labIdX60gensym2230_)), (NI)(T75_ - ((NI) 1)));
		}
		LA59_: ;
		lendX60gensym2228_ = resX60gensym2230_;
		fixLabel__z1hx9axqa9cHsmY7bMeZVSrQ(p, lendX60gensym2228_);
	}
	break;
	default:
	{
		{
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = ((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T79_)) goto LA80_;
			T79_ = (((*(*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0);
			LA80_: ;
			if (!T79_) goto LA81_;
			genGotoForCase__ACGHJp9bbmHaRpjqO8LXrqA(p, t);
		}
		goto LA77_;
		LA81_: ;
		{
			genOrdinalCase__8mAL9ckajemzgfLPfeZVNoQ_22(p, t, d);
		}
		LA77_: ;
	}
	break;
	}
}
static N_INLINE(void, pop__Y36bTNxSoXinCwCTSTCSTgsystem)(tySequence__KjgUMUjT3LUKOFIK4xt5ug** s, tyTuple__FxkU4d1VDodDMc9ah6Mbagw* Result) {
	NI L;
	NI T1_;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	unsureAsgnRef((void**) (&(*Result).Field0), (*s)->data[L].Field0);
	(*Result).Field1 = (*s)->data[L].Field1;
	(*Result).Field2 = (*s)->data[L].Field2;
	unsureAsgnRef((void**) (&(*s)), (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) setLengthSeqV2(&((*s))->Sup, (&NTI__KjgUMUjT3LUKOFIK4xt5ug_), ((NI) (L))));
}
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, NI howManyTrys, NI howManyExcepts) {
	tySequence__KjgUMUjT3LUKOFIK4xt5ug* stack;
	stack = newSeq__uReleM9aRnQZRzdaRfwc5xQ(((NI) 0));
	(*p).withinBlockLeaveActions += ((NI) 1);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				tyTuple__FxkU4d1VDodDMc9ah6Mbagw tryStmt;
				NI T20_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* finallyStmt;
				if (!(res <= howManyTrys)) goto LA3;
				i = res;
				nimZeroMem((void*)(&tryStmt), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
				pop__Y36bTNxSoXinCwCTSTCSTgsystem((&(*p).nestedTryStmts), (&tryStmt));
				{
					if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 1))) goto LA6_;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
						NimStringDesc* res_2;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						if (!!(tryStmt.Field1)) goto LA10_;
						T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						res_2 = rawNewString(((NI) 80));
						T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T13_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_718));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T13_);
						res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA16_;
							res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA16_: ;
						T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T18_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T18_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T12_, T19_);
					}
					LA10_: ;
				}
				LA6_: ;
				stack = (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) incrSeqV3((TGenericSeq*)(stack), (&NTI__KjgUMUjT3LUKOFIK4xt5ug_));
				T20_ = stack->Sup.len++;
				asgnRef((void**) (&stack->data[T20_].Field0), tryStmt.Field0);
				stack->data[T20_].Field1 = tryStmt.Field1;
				stack->data[T20_].Field2 = tryStmt.Field2;
				finallyStmt = tryStmt.Field0;
				{
					if (!!((finallyStmt == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA23_;
					genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*finallyStmt)._kind_6.sons->data[((NI) 0)]);
				}
				LA23_: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
	(*p).withinBlockLeaveActions -= ((NI) 1);
	{
		NI i_2;
		NI colontmp_;
		NI res_3;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(howManyTrys - ((NI) 1));
		res_3 = colontmp_;
		{
			while (1) {
				NI T28_;
				if (!(((NI) 0) <= res_3)) goto LA27;
				i_2 = res_3;
				asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTI__KjgUMUjT3LUKOFIK4xt5ug_)));
				T28_ = (*p).nestedTryStmts->Sup.len++;
				asgnRef((void**) (&(*p).nestedTryStmts->data[T28_].Field0), stack->data[i_2].Field0);
				(*p).nestedTryStmts->data[T28_].Field1 = stack->data[i_2].Field1;
				(*p).nestedTryStmts->data[T28_].Field2 = stack->data[i_2].Field2;
				res_3 -= ((NI) 1);
			} LA27: ;
		}
	}
	{
		if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 3))&7U)))!=0))) goto LA31_;
		{
			NI i_3;
			NI colontmp__2;
			NI res_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = (NI)(howManyExcepts - ((NI) 1));
			res_4 = colontmp__2;
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T36_;
					NimStringDesc* res_5;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
					if (!(((NI) 0) <= res_4)) goto LA35;
					i_3 = res_4;
					T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T36_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_5 = rawNewString(((NI) 80));
					T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T37_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T37_);
					res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
						res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA40_: ;
					T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
					T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T36_, T43_);
					res_4 -= ((NI) 1);
				} LA35: ;
			}
		}
	}
	LA31_: ;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**, X5BX5D___TZRG9c19bQX0slkSQAmDzJZAsystem)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** s, NI sLen_0, NI i) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__QrTB5DOwbDX9bKAW7PNbuJA_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	NI T9_;
	NI T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T27_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T28_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
{	{
		if (!(((*t).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 15))&31U)))!=0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0)) & 7);
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	{
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA7_;
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*t)._kind_6.sons->data[((NI) 0)]);
	}
	LA7_: ;
	T9_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T10_ = (NI)0;
	T10_ = inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2(p);
	blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q(p, T9_, T10_);
	{
		NIM_BOOL T13_;
		NI T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* safePoint;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T19_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		T13_ = (NIM_BOOL)0;
		T14_ = ((*p).finallySafePoints ? (*p).finallySafePoints->Sup.len : 0);
		T13_ = (((NI) 0) < T14_);
		if (!(T13_)) goto LA15_;
		T13_ = !((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 3))&7U)))!=0));
		LA15_: ;
		if (!T13_) goto LA16_;
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T18_ = X5BX5D___TZRG9c19bQX0slkSQAmDzJZAsystem((*p).finallySafePoints->data, ((*p).finallySafePoints ? (*p).finallySafePoints->Sup.len : 0), ((NI) 1));
		safePoint = (*T18_);
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T19_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), safePoint);
		res = resizeString(res, 14);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_720));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T20_);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA23_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA23_: ;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T19_, T26_);
	}
	LA16_: ;
	T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T27_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T28_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T29_ = percent___Kbv8OIo8zpawh7SNMbfgkA(T28_, 0);
	T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T30_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T29_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T27_, T30_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__QrTB5DOwbDX9bKAW7PNbuJA_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	NI idx;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* label;
	NI T20_;
	NI T21_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T22_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T23_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
	idx = (*p).breakIdx;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		sym = (*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!!(((*sym).loc.k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 10)))) goto LA7_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_721));
		}
		LA7_: ;
		idx = (NI)((*sym).position - ((NI) 1));
	}
	goto LA1_;
	LA3_: ;
	{
		{
			while (1) {
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (((NI) 0) <= idx);
				if (!(T12_)) goto LA13_;
				T12_ = !((*p).blocks->data[idx].isLoop);
				LA13_: ;
				if (!T12_) goto LA11;
				idx -= ((NI) 1);
			} LA11: ;
		}
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = (idx < ((NI) 0));
			if (T16_) goto LA17_;
			T16_ = !((*p).blocks->data[idx].isLoop);
			LA17_: ;
			if (!T16_) goto LA18_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*t).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_722), TM__MQdRN7fpbG7rPm4JpVVAhA_723);
		}
		LA18_: ;
	}
	LA1_: ;
	label = assignLabel__mIFKIo7g6Echd7EokLhQegcgen((&(*p).blocks->data[idx]));
	T20_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T21_ = (NI)0;
	T21_ = inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2(p);
	blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q(p, (NI)(T20_ - ((NI) ((*p).blocks->data[idx].nestedTryStmts))), (NI)(T21_ - ((NI) ((*p).blocks->data[idx].nestedExceptStmts))));
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T22_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T23_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T23_[0] = label;
	T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T24_ = percent___c1f569aWpTd825BTnv9bq4Xg(T23_, 1);
	T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T25_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T24_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T22_, T25_);
}
static N_INLINE(void, cow__od9bAwM0gKRf4yeR2rVpdZQcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		cowBracket__UtJx89cn0a8CNSWWmaj6raA_2(p, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, discriminatorTableDecl__WpGsd0DJejVIze0ZXr8L3g_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* d) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T2_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T3_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T4_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_98));
	(void)(T1_);
	tmp = discriminatorTableName__WpGsd0DJejVIze0ZXr8L3g(m, objtype, d);
	nimZeroMem((void*)T2_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T2_[0] = tmp;
	T3_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*m).g).config, (*d).typ);
	T4_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(T3_, IL64(1));
	T2_[1] = rope__b5mr3rjXEwHVfmNLJr4cBA(T4_);
	result = percent___erDe9aYc2BNxzH9brKlmtEBg(T2_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__c1s9cEnyLNclmLP8bBuHmDg)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objtype, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
	NimStringDesc* res_2;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T14_;
	NI64 T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(objtype, IL64(36275087632017680));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, t, (*a.lode).info);
	(void)(T1_);
	{
		NIM_BOOL T4_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).module).declaredThings), (*field).Sup.id);
		if (!!(T4_)) goto LA5_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_298));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = discriminatorTableDecl__WpGsd0DJejVIze0ZXr8L3g_2((*p).module, t, field);
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T8_);
	}
	LA5_: ;
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T9_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_2 = rawNewString(((NI) 80));
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_724));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T10_);
	res_2 = resizeString(res_2, 10);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_725));
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T11_);
	res_2 = resizeString(res_2, 12);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_726));
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = rdLoc__xidyzuHqIciXbQyEOKahDg(tmp);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T12_);
	res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_380));
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = discriminatorTableName__WpGsd0DJejVIze0ZXr8L3g((*p).module, t, field);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T13_);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
	T14_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*p).module).g).config, (*field).typ);
	T15_ = (NI64)0;
	T15_ = toInt64__1szweXXq3RBN50owrYu2Xw(T14_);
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = intLiteral__kQA0lBUvzOSZAw7DHC4Fjg((NI64)(T15_ + IL64(1)));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T16_);
	res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA19_: ;
	T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T22_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T21_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T22_);
}
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__X9cSqNhqEboci9cdmwBMNcBw_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tmp;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dotExpr;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&tmp), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	dotExpr = (*e)._kind_6.sons->data[((NI) 0)];
	{
		if (!((*dotExpr).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46))) goto LA3_;
		dotExpr = (*dotExpr)._kind_6.sons->data[((NI) 0)];
	}
	LA3_: ;
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*e)._kind_6.sons->data[((NI) 0)], (&a));
	T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T5_ = t__XNOXh7uniWNgiq58C9bW49awcgen(a);
	getTemp__VjOFVqypINqQv5C3ECnxbw(p, T5_, (&tmp), NIM_FALSE);
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*e)._kind_6.sons->data[((NI) 1)], (&tmp));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		if (!!((((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0))) goto LA8_;
		field = (*(*dotExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		genDiscriminantCheck__c1s9cEnyLNclmLP8bBuHmDg(p, a, tmp, (*(*dotExpr)._kind_6.sons->data[((NI) 0)]).typ, field);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 48), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_727, NIM_FALSE);
	}
	LA8_: ;
	genAssignment__BtucsTdHw7orsXIL75hNVg(p, a, tmp, 0);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__9ap9b3IFVLSL9b9akVbfMyRxlA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, NIM_BOOL fastAsgn) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*e)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*e)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, e);
		genGotoVar__4xOIY9bgIMy9bAzg2ZyIieBw(p, (*e)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 2))&31U)))!=0);
		if (!(T8_)) goto LA9_;
		T8_ = isDiscriminantField__OTZyO2oJpdYpHVBZuRXuRQ_2((*e)._kind_6.sons->data[((NI) 0)]);
		LA9_: ;
		if (!T8_) goto LA10_;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, e);
		asgnFieldDiscriminant__X9cSqNhqEboci9cdmwBMNcBw_4(p, e);
	}
	goto LA1_;
	LA10_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri;
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		le = (*e)._kind_6.sons->data[((NI) 0)];
		ri = (*e)._kind_6.sons->data[((NI) 1)];
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*le).typ, IL64(36275087638268176));
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T13_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		(void)(T14_);
		initLoc__qlujIAW86QclHYUVxlHRiQ((&a), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0), le, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 9)) & 15);
		a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 10)) & 15);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, le, (&a));
		a.flags &= ~(((NU16)1) << ((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 10)) & 15));
		{
			if (!fastAsgn) goto LA17_;
			a.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 2)) & 15);
		}
		LA17_: ;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, ri);
		loadInto__vkEx8Dn9aiGOI04WjvQIHIwcgen(p, le, ri, (&a));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genAsmOrEmitStmt__53Pwv51Dxuia7o9bQN4K9agw)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, NIM_BOOL isAsmStmt) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* res;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	res = ((NimStringDesc*) NIM_NIL);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		colontmp_ = (*t)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				switch ((*(*it)).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
				{
					res = resizeString(res, ((*(*it))._kind_3.strVal ? (*(*it))._kind_3.strVal->Sup.len : 0) + 0);
appendString(res, (*(*it))._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
					sym = (*(*it))._kind_4.sym;
					{
						tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
						NimStringDesc* T12_;
						if (!((61440 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA9_;
						nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
						initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it), (&a));
						T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T11_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
						T12_ = (NimStringDesc*)0;
						T12_ = dollar___mZ66tEveFIQokq3arf8Klw(T11_);
						res = resizeString(res, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(res, T12_);
					}
					goto LA7_;
					LA9_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
						NimStringDesc* T17_;
						if (!((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7))) goto LA14_;
						T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T16_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						T17_ = (NimStringDesc*)0;
						T17_ = dollar___mZ66tEveFIQokq3arf8Klw(T16_);
						res = resizeString(res, (T17_ ? T17_->Sup.len : 0) + 0);
appendString(res, T17_);
					}
					goto LA7_;
					LA14_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
						NimStringDesc* T25_;
						T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T19_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*sym).typ, IL64(36275087638309136));
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T19_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						(void)(T20_);
						r = (*sym).loc.r;
						{
							if (!(r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA23_;
							r = mangleName__RaNE9b8A430I9bfpgZmdrC1w((*p).module, sym);
							asgnRef((void**) (&(*sym).loc.r), r);
						}
						LA23_: ;
						T25_ = (NimStringDesc*)0;
						T25_ = dollar___mZ66tEveFIQokq3arf8Klw(r);
						res = resizeString(res, (T25_ ? T25_->Sup.len : 0) + 0);
appendString(res, T25_);
					}
					LA7_: ;
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					NimStringDesc* T28_;
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*it)).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
					T28_ = (NimStringDesc*)0;
					T28_ = dollar___mZ66tEveFIQokq3arf8Klw(T27_);
					res = resizeString(res, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(res, T28_);
				}
				break;
				default:
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T30_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
					tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
					NimStringDesc* T33_;
					T30_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T30_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*it)).typ, IL64(36275087638309136));
					T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T31_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, T30_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
					(void)(T31_);
					nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
					initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*it), (&a_2));
					T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T32_ = rdLoc__xidyzuHqIciXbQyEOKahDg(a_2);
					T33_ = (NimStringDesc*)0;
					T33_ = dollar___mZ66tEveFIQokq3arf8Klw(T32_);
					res = resizeString(res, (T33_ ? T33_->Sup.len : 0) + 0);
appendString(res, T33_);
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NIM_BOOL T36_;
		T36_ = (NIM_BOOL)0;
		T36_ = isAsmStmt;
		if (!(T36_)) goto LA37_;
		T36_ = ((CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field21 &((NU8)1<<((NU)(((tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg) 5))&7U)))!=0);
		LA37_: ;
		if (!T36_) goto LA38_;
		{
			NimStringDesc* x;
			NI first;
			NI last;
			NI eolpos;
			x = (NimStringDesc*)0;
			first = ((NI) 0);
			last = ((NI) 0);
			eolpos = ((NI) 0);
			{
				while (1) {
					NI T64_;
					NI j;
					{
						while (1) {
							NIM_BOOL T45_;
							T45_ = (NIM_BOOL)0;
							T45_ = (last < (res ? res->Sup.len : 0));
							if (!(T45_)) goto LA46_;
							T45_ = !((((NU8)(res->data[last])) == ((NU8)(13)) || ((NU8)(res->data[last])) == ((NU8)(10))));
							LA46_: ;
							if (!T45_) goto LA44;
							last += ((NI) 1);
						} LA44: ;
					}
					eolpos = last;
					{
						if (!(last < (res ? res->Sup.len : 0))) goto LA49_;
						{
							if (!((NU8)(res->data[last]) == (NU8)(10))) goto LA53_;
							last += ((NI) 1);
						}
						goto LA51_;
						LA53_: ;
						{
							if (!((NU8)(res->data[last]) == (NU8)(13))) goto LA56_;
							last += ((NI) 1);
							{
								NIM_BOOL T60_;
								T60_ = (NIM_BOOL)0;
								T60_ = (last < (res ? res->Sup.len : 0));
								if (!(T60_)) goto LA61_;
								T60_ = ((NU8)(res->data[last]) == (NU8)(10));
								LA61_: ;
								if (!T60_) goto LA62_;
								last += ((NI) 1);
							}
							LA62_: ;
						}
						goto LA51_;
						LA56_: ;
						LA51_: ;
					}
					LA49_: ;
					T64_ = (NI)0;
					{
						if (!NIM_FALSE) goto LA67_;
						T64_ = (NI)(last - ((NI) 1));
					}
					goto LA65_;
					LA67_: ;
					{
						T64_ = (NI)(eolpos - ((NI) 1));
					}
					LA65_: ;
					x = substr__2yh9cer0ymNRHlOOg8P7IuA(res, first, T64_);
					j = ((NI) 0);
					{
						while (1) {
							NIM_BOOL T72_;
							T72_ = (NIM_BOOL)0;
							T72_ = (j < (x ? x->Sup.len : 0));
							if (!(T72_)) goto LA73_;
							T72_ = (((NU8)(x->data[j])) == ((NU8)(32)) || ((NU8)(x->data[j])) == ((NU8)(9)));
							LA73_: ;
							if (!T72_) goto LA71;
							j += ((NI) 1);
						} LA71: ;
					}
					{
						if (!(j < (x ? x->Sup.len : 0))) goto LA76_;
						{
							if (!(((NU8)(x->data[j])) == ((NU8)(34)) || ((NU8)(x->data[j])) == ((NU8)(58)))) goto LA80_;
							add__yG4AKzsBRS1W4MANDlXQeg(&result, x);
							add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						goto LA78_;
						LA80_: ;
						{
							NimStringDesc* T83_;
							add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_729));
							T83_ = (NimStringDesc*)0;
							T83_ = nsuReplaceStr(x, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_729), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_730));
							add__yG4AKzsBRS1W4MANDlXQeg(&result, T83_);
							add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_731));
						}
						LA78_: ;
					}
					LA76_: ;
					{
						if (!(eolpos == last)) goto LA86_;
						goto LA41;
					}
					LA86_: ;
					first = last;
				}
			} LA41: ;
		}
	}
	goto LA34_;
	LA38_: ;
	{
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		result = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	LA34_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__QrTB5DOwbDX9bKAW7PNbuJA_6)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	s = genAsmOrEmitStmt__53Pwv51Dxuia7o9bQN4K9agw(p, t, NIM_TRUE);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		if (!((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = s;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field17, T5_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], T6_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T9_[0] = s;
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*(*p).module).g).config).cCompiler)- 1].Field17, T9_, 1);
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T10_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T11_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__Y9bFh7BmZkh729bS2kZ5kwnQ_2)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		result = canRaiseDisp__Y9bFh7BmZkh729bS2kZ5kwnQ(p, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			if (!!(result)) goto LA4_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = bodyCanRaise__Y9bFh7BmZkh729bS2kZ5kwnQ_2(p, (*n)._kind_6.sons->data[i]);
							if (!T11_) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = NIM_FALSE;
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA19;
					i_3 = i_4;
					{
						NIM_BOOL T22_;
						T22_ = (NIM_BOOL)0;
						T22_ = bodyCanRaise__Y9bFh7BmZkh729bS2kZ5kwnQ_2(p, (*n)._kind_6.sons->data[i_3]);
						if (!T22_) goto LA23_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA23_: ;
					i_4 += ((NI) 1);
				} LA19: ;
			}
		}
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__re1pwmyeR32ikwnOC3vvzQ_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fin;
	NI lab;
	NIM_BOOL hasExcept;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T12_;
	NI T13_;
	NI T21_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T44_;
	NimStringDesc* res_3;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T51_;
	NI i;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T154_;
	{
		NI T3_;
		NI T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T3_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA4_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		fin = (*t)._kind_6.sons->data[(NI)(T6_ - ((NI) 1))];
	}
	goto LA1_;
	LA4_: ;
	{
		fin = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA1_: ;
	(*p).labels += ((NI) 1);
	lab = (*p).labels;
	hasExcept = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
	{
		if (!hasExcept) goto LA10_;
		(*p).withinTryWithExcept += ((NI) 1);
	}
	LA10_: ;
	nimZeroMem((void*)(&T12_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	T12_.Field0 = fin;
	T12_.Field1 = NIM_FALSE;
	T12_.Field2 = lab;
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTI__KjgUMUjT3LUKOFIK4xt5ug_)));
	T13_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T13_].Field0), T12_.Field0);
	(*p).nestedTryStmts->data[T13_].Field1 = T12_.Field1;
	(*p).nestedTryStmts->data[T13_].Field2 = T12_.Field2;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 4)) & 7);
	{
		NIM_BOOL T16_;
		NIM_BOOL T17_;
		T16_ = (NIM_BOOL)0;
		T17_ = (NIM_BOOL)0;
		T17_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
		T16_ = !(T17_);
		if (!(T16_)) goto LA18_;
		T16_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		LA18_: ;
		if (!T16_) goto LA19_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*t).typ, d, NIM_FALSE);
	}
	LA19_: ;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*t)._kind_6.sons->data[((NI) 0)], d);
	T21_ = (NI)0;
	{
		NIM_BOOL T24_;
		NI T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T29_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		T24_ = (NIM_BOOL)0;
		T25_ = (NI)0;
		T25_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T24_ = (((NI) 1) < T25_);
		if (!(T24_)) goto LA26_;
		T24_ = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
		LA26_: ;
		if (!T24_) goto LA27_;
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T29_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 29);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_732));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA32_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA32_: ;
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T34_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T29_, T35_);
		T21_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	}
	goto LA22_;
	LA27_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T37_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T37_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA40_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA40_: ;
		T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T42_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T37_, T43_);
		T21_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	}
	LA22_: ;
	T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T44_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_3 = rawNewString(((NI) 80));
	res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429));
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) (lab)));
	res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_733));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA47_;
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA47_: ;
	T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T49_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
	T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T50_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T49_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T44_, T50_);
	T51_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
	T51_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T51_).Field1 = NIM_TRUE;
	i = ((NI) 1);
	{
		while (1) {
			NIM_BOOL T54_;
			NI T55_;
			NI nextExcept;
			tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T139_;
			NimStringDesc* res_9;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T140_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T145_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T146_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T147_;
			NimStringDesc* res_10;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T152_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T153_;
			T54_ = (NIM_BOOL)0;
			T55_ = (NI)0;
			T55_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			T54_ = (i < T55_);
			if (!(T54_)) goto LA56_;
			T54_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
			LA56_: ;
			if (!T54_) goto LA53;
			(*p).labels += ((NI) 1);
			nextExcept = (*p).labels;
			T57_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
			T57_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
			(*T57_).Field2 = nextExcept;
			{
				NIM_BOOL T60_;
				T60_ = (NIM_BOOL)0;
				T60_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
				if (!(T60_)) goto LA61_;
				T60_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
				LA61_: ;
				if (!T60_) goto LA62_;
				(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
			}
			LA62_: ;
			{
				NI T66_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T77_;
				NimStringDesc* res_4;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
				NI T84_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T85_;
				NimStringDesc* res_5;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
				T66_ = (NI)0;
				T66_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
				if (!(T66_ == ((NI) 1))) goto LA67_;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T73_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T74_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T75_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
					if (!(((NI) 1) < i)) goto LA71_;
					T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T73_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T74_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T75_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T75_ = percent___22ELRKd9bDuNug6qvIihS3A(T74_, 0);
					T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T76_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T75_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T73_, T76_);
				}
				LA71_: ;
				T77_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T77_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_4 = rawNewString(((NI) 80));
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA80_;
					res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA80_: ;
				T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T82_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
				T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T83_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T82_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T77_, T83_);
				T84_ = (NI)0;
				T84_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T85_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 21);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_734));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA88_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA88_: ;
				T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T90_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
				T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T91_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T90_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T85_, T91_);
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
			}
			goto LA64_;
			LA67_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* orExpr;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T123_;
				NimStringDesc* res_7;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T128_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T129_;
				NI T130_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T131_;
				NimStringDesc* res_8;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T136_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T137_;
				NI T138_;
				orExpr = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T94_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T94_ = (NI)0;
					T94_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T94_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* checkFor;
							NimStringDesc* memberName;
							NimStringDesc* res_6;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T115_;
							if (!(i_2 < colontmp_)) goto LA96;
							j = i_2;
							{
								if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA99_;
								add__yG4AKzsBRS1W4MANDlXQeg(&orExpr, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_284));
							}
							LA99_: ;
							{
								if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA103_;
								checkFor = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ);
							}
							goto LA101_;
							LA103_: ;
							{
								checkFor = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).info);
							}
							LA101_: ;
							{
								NIM_BOOL T108_;
								T108_ = (NIM_BOOL)0;
								T108_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
								if (T108_) goto LA109_;
								T108_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
								LA109_: ;
								if (!T108_) goto LA110_;
								memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_735));
							}
							goto LA106_;
							LA110_: ;
							{
								memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_736));
							}
							LA106_: ;
							res_6 = rawNewString(((NI) 80));
							T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T113_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T113_);
							res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
							T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T114_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_737));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), T114_);
							res_6 = resizeString(res_6, 4);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_738));
							cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_6), memberName);
							res_6 = resizeString(res_6, 2);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), checkFor);
							res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
							T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T115_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
							add__IM4kcMNkkOLJtqdEqSxR8A(&orExpr, T115_);
							i_2 += ((NI) 1);
						} LA96: ;
					}
				}
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T120_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T121_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T122_;
					if (!(((NI) 1) < i)) goto LA118_;
					T120_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T120_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					T121_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T121_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_739));
					T122_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T122_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T121_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T120_, T122_);
				}
				LA118_: ;
				T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T123_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 4);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), orExpr);
				res_7 = resizeString(res_7, 3);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA126_;
					res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA126_: ;
				T128_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T128_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
				T129_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T129_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T128_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T123_, T129_);
				T130_ = (NI)0;
				T130_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				T131_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T131_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_8 = rawNewString(((NI) 80));
				res_8 = resizeString(res_8, 21);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_734));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA134_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA134_: ;
				T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T136_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
				T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T137_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T136_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T131_, T137_);
				T138_ = (NI)0;
				T138_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T138_ - ((NI) 1))], d);
			}
			LA64_: ;
			T139_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T139_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_9 = rawNewString(((NI) 80));
			T140_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T140_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T140_);
			res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA143_;
				res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA143_: ;
			T145_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T145_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
			T146_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T146_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T145_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T139_, T146_);
			T147_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T147_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_10 = rawNewString(((NI) 80));
			res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_429));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_10), ((NI64) (nextExcept)));
			res_10 = resizeString(res_10, 3);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_733));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA150_;
				res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA150_: ;
			T152_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T152_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
			T153_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T153_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T152_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T147_, T153_);
			endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
			i += ((NI) 1);
		} LA53: ;
	}
	nimZeroMem((void*)(&T154_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	pop__Y36bTNxSoXinCwCTSTCSTgsystem((&(*p).nestedTryStmts), (&T154_));
	(void)(T154_);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	{
		NIM_BOOL T157_;
		NI T158_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T162_;
		NimStringDesc* res_11;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T167_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T168_;
		NI T169_;
		T157_ = (NIM_BOOL)0;
		T158_ = (NI)0;
		T158_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T157_ = (i < T158_);
		if (!(T157_)) goto LA159_;
		T157_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107));
		LA159_: ;
		if (!T157_) goto LA160_;
		T162_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T162_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_11 = rawNewString(((NI) 80));
		res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA165_;
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA165_: ;
		T167_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T167_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
		T168_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T168_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T167_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T162_, T168_);
		T169_ = (NI)0;
		T169_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		{
			NIM_BOOL T172_;
			T172_ = (NIM_BOOL)0;
			T172_ = bodyCanRaise__Y9bFh7BmZkh729bS2kZ5kwnQ_2(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
			if (!!(T172_)) goto LA173_;
			genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
		}
		goto LA170_;
		LA173_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T176_;
			NimStringDesc* res_12;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T181_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T182_;
			NimStringDesc* res_13;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T187_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T188_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T189_;
			NimStringDesc* res_14;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T194_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T195_;
			T176_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T176_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			res_12 = rawNewString(((NI) 80));
			res_12 = resizeString(res_12, 21);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_740));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_12), ((NI64) (lab)));
			res_12 = resizeString(res_12, 2);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_394));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA179_;
				res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA179_: ;
			T181_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T181_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
			add__IM4kcMNkkOLJtqdEqSxR8A(T176_, T181_);
			T182_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T182_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_13 = rawNewString(((NI) 80));
			res_13 = resizeString(res_13, 12);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_741));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_13), ((NI64) (lab)));
			res_13 = resizeString(res_13, 35);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_742));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA185_;
				res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA185_: ;
			T187_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T187_ = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
			T188_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T188_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T187_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T182_, T188_);
			genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
			T189_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T189_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_14 = rawNewString(((NI) 80));
			res_14 = resizeString(res_14, 23);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_743));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_14), ((NI64) (lab)));
			res_14 = resizeString(res_14, 2);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_394));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA192_;
				res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA192_: ;
			T194_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T194_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
			T195_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T195_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T194_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T189_, T195_);
		}
		LA170_: ;
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	}
	LA160_: ;
	raiseExit__0dpuY9coTlraj8JXIe2BzVw_2(p);
	{
		if (!hasExcept) goto LA198_;
		(*p).withinTryWithExcept += ((NI) 1);
	}
	LA198_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T22_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		if (!(((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0)) goto LA3_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T9_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T15_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			if (!!((((*p).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 2))&7U)))!=0))) goto LA7_;
			(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 2)) & 7);
			T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T9_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			res = rawNewString(((NI) 80));
			res = resizeString(res, 22);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_752));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA12_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA12_: ;
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(T9_, T14_);
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T15_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_753));
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_754));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T16_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA19_;
				res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA19_: ;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			add__IM4kcMNkkOLJtqdEqSxR8A(T15_, T21_);
		}
		LA7_: ;
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T22_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_755));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T23_);
		res_3 = resizeString(res_3, 15);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_756));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA26_: ;
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T28_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T22_, T29_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__re1pwmyeR32ikwnOC3vvzQ_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NI etmp;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fin;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T17_;
	NI T18_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T46_;
	NimStringDesc* res_5;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T54_;
	NimStringDesc* res_6;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T61_;
	NIM_BOOL hasImportedCppExceptions;
	NI i;
	NIM_BOOL hasIf;
	NIM_BOOL hasElse;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T213_;
	NimStringDesc* res_17;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T218_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T219_;
	NIM_BOOL catchAllPresent;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T287_;
	includeHeader__G5jzmdnwglHVk5qfDcXonA((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_744));
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	(*p).labels += ((NI) 2);
	etmp = (*p).labels;
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T8_ = procSec__kOyJGmZMM2tMgCKSrvUE3g_2cgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 21);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_745));
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (etmp)));
	res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_746));
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(T8_, T9_);
	{
		NI T12_;
		NI T15_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T12_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA13_;
		T15_ = (NI)0;
		T15_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		fin = (*t)._kind_6.sons->data[(NI)(T15_ - ((NI) 1))];
	}
	goto LA10_;
	LA13_: ;
	{
		fin = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA10_: ;
	nimZeroMem((void*)(&T17_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	T17_.Field0 = fin;
	T17_.Field1 = NIM_FALSE;
	T17_.Field2 = ((NI) 0);
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTI__KjgUMUjT3LUKOFIK4xt5ug_)));
	T18_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T18_].Field0), T17_.Field0);
	(*p).nestedTryStmts->data[T18_].Field1 = T17_.Field1;
	(*p).nestedTryStmts->data[T18_].Field2 = T17_.Field2;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T23_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T30_;
		NimStringDesc* res_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		if (!((*t).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154))) goto LA21_;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T23_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		res_2 = resizeString(res_2, 5);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_747));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA26_: ;
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T28_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T23_, T29_);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*t)._kind_6.sons->data[((NI) 0)], d);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T30_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_3 = rawNewString(((NI) 80));
		res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA33_;
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA33_: ;
		T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T35_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T35_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T30_, T36_);
	}
	goto LA19_;
	LA21_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T38_;
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
		NI T45_;
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T38_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 5);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_747));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA41_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA41_: ;
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T44_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T43_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T38_, T44_);
		T45_ = (NI)0;
		T45_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*t)._kind_6.sons->data[((NI) 0)], d);
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	}
	LA19_: ;
	T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T46_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_5 = rawNewString(((NI) 80));
	res_5 = resizeString(res_5, 7);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_748));
	T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T47_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_749));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T47_);
	res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_750));
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_5), ((NI64) ((NI)(((NI) (etmp)) + ((NI) 1)))));
	res_5 = resizeString(res_5, 4);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_751));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA50_;
		res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA50_: ;
	T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T52_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
	T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T53_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T52_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T46_, T53_);
	genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
	T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T54_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_6 = rawNewString(((NI) 80));
	res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111));
	cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_6), ((NI64) (etmp)));
	res_6 = resizeString(res_6, 29);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_757));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
		res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA57_: ;
	T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
	T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T54_, T60_);
	T61_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
	T61_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T61_).Field1 = NIM_TRUE;
	hasImportedCppExceptions = NIM_FALSE;
	i = ((NI) 1);
	hasIf = NIM_FALSE;
	hasElse = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T64_;
			NI T65_;
			T64_ = (NIM_BOOL)0;
			T65_ = (NI)0;
			T65_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			T64_ = (i < T65_);
			if (!(T64_)) goto LA66_;
			T64_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
			LA66_: ;
			if (!T64_) goto LA63;
			{
				NIM_BOOL T69_;
				T69_ = (NIM_BOOL)0;
				T69_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
				if (!(T69_)) goto LA70_;
				T69_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
				LA70_: ;
				if (!T69_) goto LA71_;
				(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
			}
			LA71_: ;
			{
				NI T75_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T86_;
				NimStringDesc* res_7;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
				NI T93_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T94_;
				NimStringDesc* res_8;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T99_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T101_;
				NimStringDesc* res_9;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
				T75_ = (NI)0;
				T75_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
				if (!(T75_ == ((NI) 1))) goto LA76_;
				hasImportedCppExceptions = NIM_TRUE;
				hasElse = NIM_TRUE;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T82_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T83_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
					if (!hasIf) goto LA80_;
					T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T82_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T83_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T84_ = percent___xr7e1yaPtCde5qS79c5DFzg(T83_, 0);
					T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T85_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T84_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T82_, T85_);
				}
				LA80_: ;
				T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T86_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_7 = rawNewString(((NI) 80));
				res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA89_;
					res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA89_: ;
				T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T91_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
				T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T92_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T91_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T86_, T92_);
				T93_ = (NI)0;
				T93_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T94_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_8 = rawNewString(((NI) 80));
				res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111));
				cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_8), ((NI64) (etmp)));
				res_8 = resizeString(res_8, 12);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_746));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA97_;
					res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA97_: ;
				T99_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T99_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
				T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T100_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T99_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T94_, T100_);
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T101_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_9 = rawNewString(((NI) 80));
				T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T102_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_9), T102_);
				res_9 = resizeString(res_9, 3);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA105_;
					res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA105_: ;
				T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T107_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
				T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T108_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T107_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T101_, T108_);
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
			}
			goto LA73_;
			LA76_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* orExpr;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exvar;
				orExpr = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
				exvar = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T111_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T111_ = (NI)0;
					T111_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T111_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeNode;
							if (!(i_2 < colontmp_)) goto LA113;
							j = i_2;
							typeNode = (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j];
							{
								NIM_BOOL T116_;
								T116_ = (NIM_BOOL)0;
								T116_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]);
								if (!T116_) goto LA117_;
								typeNode = (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)];
								exvar = (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j])._kind_6.sons->data[((NI) 2)];
							}
							LA117_: ;
							{
								NIM_BOOL T121_;
								T121_ = (NIM_BOOL)0;
								T121_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A((*typeNode).typ, (*(*(*p).module).g).config);
								if (!T121_) goto LA122_;
								hasImportedCppExceptions = NIM_TRUE;
							}
							goto LA119_;
							LA122_: ;
							{
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* checkFor;
								NimStringDesc* memberName;
								NimStringDesc* res_10;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T141_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T142_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T143_;
								{
									if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA127_;
									add__yG4AKzsBRS1W4MANDlXQeg(&orExpr, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_284));
								}
								LA127_: ;
								{
									if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA131_;
									checkFor = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg((*p).module, (*typeNode).typ);
								}
								goto LA129_;
								LA131_: ;
								{
									checkFor = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, (*typeNode).typ, (*typeNode).info);
								}
								LA129_: ;
								{
									NIM_BOOL T136_;
									T136_ = (NIM_BOOL)0;
									T136_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
									if (T136_) goto LA137_;
									T136_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
									LA137_: ;
									if (!T136_) goto LA138_;
									memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_735));
								}
								goto LA134_;
								LA138_: ;
								{
									memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_736));
								}
								LA134_: ;
								res_10 = rawNewString(((NI) 80));
								T141_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T141_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
								cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T141_);
								res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
								T142_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T142_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_737));
								cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), T142_);
								res_10 = resizeString(res_10, 4);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_738));
								cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_10), memberName);
								res_10 = resizeString(res_10, 2);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
								cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_10), checkFor);
								res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
								T143_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T143_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
								add__IM4kcMNkkOLJtqdEqSxR8A(&orExpr, T143_);
							}
							LA119_: ;
							i_2 += ((NI) 1);
						} LA113: ;
					}
				}
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T184_;
					NimStringDesc* res_14;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T189_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T190_;
					NI T191_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T192_;
					NimStringDesc* res_15;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T193_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T198_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T199_;
					if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA146_;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T152_;
						NimStringDesc* res_11;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T157_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T158_;
						NI T159_;
						if (!hasIf) goto LA150_;
						T152_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T152_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						res_11 = rawNewString(((NI) 80));
						res_11 = resizeString(res_11, 9);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_758));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), orExpr);
						res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA155_;
							res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA155_: ;
						T157_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T157_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
						T158_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T158_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T157_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T152_, T158_);
						T159_ = (NI)0;
						T159_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
					}
					goto LA148_;
					LA150_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T161_;
						NimStringDesc* res_12;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T166_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T167_;
						NI T168_;
						T161_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T161_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						res_12 = rawNewString(((NI) 80));
						res_12 = resizeString(res_12, 4);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), orExpr);
						res_12 = resizeString(res_12, 3);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA164_;
							res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA164_: ;
						T166_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T166_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
						T167_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T167_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T166_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T161_, T167_);
						T168_ = (NI)0;
						T168_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
						hasIf = NIM_TRUE;
					}
					LA148_: ;
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T173_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T174_;
						NimStringDesc* res_13;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T175_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T176_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T177_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T182_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T183_;
						if (!!((exvar == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA171_;
						T173_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T173_ = mangleLocalName__VpV5Cmis02zaNlTmLYJNfQ(p, (*exvar)._kind_4.sym);
						fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*(*exvar)._kind_4.sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1), exvar, T173_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
						T174_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T174_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						res_13 = rawNewString(((NI) 80));
						T175_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T175_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*exvar)._kind_4.sym).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T175_);
						res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
						T176_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T176_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*(*exvar)._kind_4.sym).loc);
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T176_);
						res_13 = resizeString(res_13, 4);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_759));
						T177_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T177_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(((NI) (etmp)) + ((NI) 1)))));
						cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_13), T177_);
						res_13 = resizeString(res_13, 2);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_394));
						{
							if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA180_;
							res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
						}
						LA180_: ;
						T182_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T182_ = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
						T183_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T183_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T182_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T174_, T183_);
					}
					LA171_: ;
					T184_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T184_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_14 = rawNewString(((NI) 80));
					res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111));
					cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_14), ((NI64) (etmp)));
					res_14 = resizeString(res_14, 12);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_746));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA187_;
						res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA187_: ;
					T189_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T189_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
					T190_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T190_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T189_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T184_, T190_);
					T191_ = (NI)0;
					T191_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T191_ - ((NI) 1))], d);
					T192_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T192_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_15 = rawNewString(((NI) 80));
					T193_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T193_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), T193_);
					res_15 = resizeString(res_15, 3);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA196_;
						res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA196_: ;
					T198_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T198_ = rope__yShmEg9cffWxI7s5XzEKBow(res_15);
					T199_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T199_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T198_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T192_, T199_);
					endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
				}
				LA146_: ;
			}
			LA73_: ;
			i += ((NI) 1);
		} LA63: ;
	}
	{
		NIM_BOOL T202_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T206_;
		NimStringDesc* res_16;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T211_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T212_;
		T202_ = (NIM_BOOL)0;
		T202_ = hasIf;
		if (!(T202_)) goto LA203_;
		T202_ = !(hasElse);
		LA203_: ;
		if (!T202_) goto LA204_;
		T206_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T206_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_16 = rawNewString(((NI) 80));
		res_16 = resizeString(res_16, 11);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_760));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA209_;
			res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA209_: ;
		T211_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T211_ = rope__yShmEg9cffWxI7s5XzEKBow(res_16);
		T212_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T212_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T211_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T206_, T212_);
	}
	LA204_: ;
	T213_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T213_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res_17 = rawNewString(((NI) 80));
	res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA216_;
		res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA216_: ;
	T218_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T218_ = rope__yShmEg9cffWxI7s5XzEKBow(res_17);
	T219_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T219_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T218_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T213_, T219_);
	catchAllPresent = NIM_FALSE;
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 3)) & 7);
	{
		if (!hasImportedCppExceptions) goto LA222_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(t);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA226;
					i_3 = i_4;
					{
						if (!!(((*(*t)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87)))) goto LA229_;
						goto LA224;
					}
					LA229_: ;
					{
						NIM_BOOL T233_;
						T233_ = (NIM_BOOL)0;
						T233_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
						if (!(T233_)) goto LA234_;
						T233_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
						LA234_: ;
						if (!T233_) goto LA235_;
						(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
					}
					LA235_: ;
					{
						NI T239_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T242_;
						NimStringDesc* res_18;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T243_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T244_;
						NI T245_;
						T239_ = (NI)0;
						T239_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i_3]);
						if (!(T239_ == ((NI) 1))) goto LA240_;
						T242_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
						T242_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
						res_18 = rawNewString(((NI) 80));
						res_18 = resizeString(res_18, 13);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_761));
						T243_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T243_ = rope__yShmEg9cffWxI7s5XzEKBow(res_18);
						T244_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T244_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T243_);
						add__IM4kcMNkkOLJtqdEqSxR8A(T242_, T244_);
						T245_ = (NI)0;
						T245_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
						genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
						expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 0)], d);
						endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
						catchAllPresent = NIM_TRUE;
					}
					goto LA237_;
					LA240_: ;
					{
						{
							NI j_2;
							NI colontmp__3;
							NI T248_;
							NI i_5;
							j_2 = (NI)0;
							colontmp__3 = (NI)0;
							T248_ = (NI)0;
							T248_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i_3]);
							colontmp__3 = (NI)(T248_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeNode_2;
									if (!(i_5 < colontmp__3)) goto LA250;
									j_2 = i_5;
									typeNode_2 = (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2];
									{
										NIM_BOOL T253_;
										T253_ = (NIM_BOOL)0;
										T253_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2]);
										if (!T253_) goto LA254_;
										typeNode_2 = (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 1)];
										{
											NIM_BOOL T258_;
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exvar_2;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T261_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T262_;
											NimStringDesc* res_19;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T263_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T264_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T269_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T270_;
											NI T271_;
											NI T272_;
											T258_ = (NIM_BOOL)0;
											T258_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A((*typeNode_2).typ, (*(*(*p).module).g).config);
											if (!T258_) goto LA259_;
											exvar_2 = (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 2)];
											T261_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T261_ = mangleLocalName__VpV5Cmis02zaNlTmLYJNfQ(p, (*exvar_2)._kind_4.sym);
											fillLoc__o49bXuxJYpCizOgQ54UViIg((&(*(*exvar_2)._kind_4.sym).loc), ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1), exvar_2, T261_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 2));
											T262_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
											T262_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
											res_19 = rawNewString(((NI) 80));
											res_19 = resizeString(res_19, 7);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_748));
											T263_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T263_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*typeNode_2).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
											cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_19), T263_);
											res_19 = resizeString(res_19, 2);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_762));
											T264_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T264_ = rdLoc__xidyzuHqIciXbQyEOKahDg((*(*exvar_2)._kind_4.sym).loc);
											cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_19), T264_);
											res_19 = resizeString(res_19, 3);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
											{
												if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA267_;
												res_19 = resizeString(res_19, 1);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
											}
											LA267_: ;
											T269_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T269_ = rope__yShmEg9cffWxI7s5XzEKBow(res_19);
											T270_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T270_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T269_);
											add__IM4kcMNkkOLJtqdEqSxR8A(T262_, T270_);
											T271_ = (NI)0;
											T271_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
											genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
											T272_ = (NI)0;
											T272_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i_3]);
											expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[(NI)(T272_ - ((NI) 1))], d);
											endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
										}
										LA259_: ;
									}
									goto LA251_;
									LA254_: ;
									{
										NIM_BOOL T274_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T277_;
										NimStringDesc* res_20;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T278_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T283_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T284_;
										NI T285_;
										NI T286_;
										T274_ = (NIM_BOOL)0;
										T274_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A((*typeNode_2).typ, (*(*(*p).module).g).config);
										if (!T274_) goto LA275_;
										T277_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
										T277_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
										res_20 = rawNewString(((NI) 80));
										res_20 = resizeString(res_20, 7);
appendString(res_20, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_748));
										T278_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T278_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[j_2]).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
										cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_20), T278_);
										res_20 = resizeString(res_20, 4);
appendString(res_20, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_763));
										{
											if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA281_;
											res_20 = resizeString(res_20, 1);
appendString(res_20, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
										}
										LA281_: ;
										T283_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T283_ = rope__yShmEg9cffWxI7s5XzEKBow(res_20);
										T284_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T284_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T283_);
										add__IM4kcMNkkOLJtqdEqSxR8A(T277_, T284_);
										T285_ = (NI)0;
										T285_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
										genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
										T286_ = (NI)0;
										T286_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i_3]);
										expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i_3])._kind_6.sons->data[(NI)(T286_ - ((NI) 1))], d);
										endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
									}
									goto LA251_;
									LA275_: ;
									LA251_: ;
									i_5 += ((NI) 1);
								} LA250: ;
							}
						}
					}
					LA237_: ;
					i_4 += ((NI) 1);
				} LA226: ;
			}
		} LA224: ;
	}
	LA222_: ;
	(*p).flags &= ~(((NU8)1) << ((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 3)) & 7));
	nimZeroMem((void*)(&T287_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	pop__Y36bTNxSoXinCwCTSTCSTgsystem((&(*p).nestedTryStmts), (&T287_));
	(void)(T287_);
	{
		NIM_BOOL T290_;
		NI T291_;
		NI T293_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T311_;
		NimStringDesc* res_23;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T316_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T317_;
		NI T318_;
		NI T319_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T320_;
		NimStringDesc* res_24;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T325_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T326_;
		T290_ = (NIM_BOOL)0;
		T291_ = (NI)0;
		T291_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T290_ = (((NI) 0) < T291_);
		if (!(T290_)) goto LA292_;
		T293_ = (NI)0;
		T293_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T290_ = ((*(*t)._kind_6.sons->data[(NI)(T293_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107));
		LA292_: ;
		if (!T290_) goto LA294_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T300_;
			NimStringDesc* res_21;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T301_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T302_;
			NI T303_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T304_;
			NimStringDesc* res_22;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T309_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T310_;
			if (!!(catchAllPresent)) goto LA298_;
			T300_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T300_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_21 = rawNewString(((NI) 80));
			res_21 = resizeString(res_21, 13);
appendString(res_21, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_761));
			T301_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T301_ = rope__yShmEg9cffWxI7s5XzEKBow(res_21);
			T302_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T302_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T301_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T300_, T302_);
			T303_ = (NI)0;
			T303_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
			genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
			T304_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T304_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_22 = rawNewString(((NI) 80));
			res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_111));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_22), ((NI64) (etmp)));
			res_22 = resizeString(res_22, 29);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_757));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA307_;
				res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA307_: ;
			T309_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T309_ = rope__yShmEg9cffWxI7s5XzEKBow(res_22);
			T310_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T310_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T309_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T304_, T310_);
			endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
		}
		LA298_: ;
		T311_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T311_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_23 = rawNewString(((NI) 80));
		res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA314_;
			res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA314_: ;
		T316_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T316_ = rope__yShmEg9cffWxI7s5XzEKBow(res_23);
		T317_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T317_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T316_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T311_, T317_);
		T318_ = (NI)0;
		T318_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		T319_ = (NI)0;
		T319_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*(*t)._kind_6.sons->data[(NI)(T319_ - ((NI) 1))])._kind_6.sons->data[((NI) 0)]);
		T320_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T320_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_24 = rawNewString(((NI) 80));
		res_24 = resizeString(res_24, 5);
appendString(res_24, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_764));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_24), ((NI64) (etmp)));
		res_24 = resizeString(res_24, 27);
appendString(res_24, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_765));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_24), ((NI64) (etmp)));
		res_24 = resizeString(res_24, 3);
appendString(res_24, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_766));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA323_;
			res_24 = resizeString(res_24, 1);
appendString(res_24, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA323_: ;
		T325_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T325_ = rope__yShmEg9cffWxI7s5XzEKBow(res_24);
		T326_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T326_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T325_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T320_, T326_);
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	}
	LA294_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__re1pwmyeR32ikwnOC3vvzQ_5)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	NIM_BOOL quirkyExceptions;
	NIM_BOOL T8_;
	NIM_BOOL T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* safePoint;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fin;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T94_;
	NI T95_;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T155_;
	NI i;
	tyTuple__FxkU4d1VDodDMc9ah6Mbagw T266_;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
		T3_ = !(T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0));
		LA5_: ;
		if (!T3_) goto LA6_;
		getTemp__VjOFVqypINqQv5C3ECnxbw(p, (*t).typ, d, NIM_FALSE);
	}
	LA6_: ;
	T8_ = (NIM_BOOL)0;
	T8_ = ((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4));
	if (T8_) goto LA9_;
	T10_ = (NIM_BOOL)0;
	T10_ = ((*t).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154));
	if (!(T10_)) goto LA11_;
	T10_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
	LA11_: ;
	T8_ = T10_;
	LA9_: ;
	quirkyExceptions = T8_;
	{
		if (!!(quirkyExceptions)) goto LA14_;
		includeHeader__G5jzmdnwglHVk5qfDcXonA((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_767));
	}
	goto LA12_;
	LA14_: ;
	{
		(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 3)) & 7);
	}
	LA12_: ;
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T17_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_749));
	(void)(T17_);
	safePoint = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T22_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T30_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T80_;
		NimStringDesc* res_7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T85_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
		if (!!(quirkyExceptions)) goto LA20_;
		safePoint = getTempName__ao6gUnuVfQLtZ89c4kaIKfg((*p).module);
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T22_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		res = rawNewString(((NI) 80));
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_768));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T23_);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), safePoint);
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_73));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA26_: ;
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T28_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T22_, T29_);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T30_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T31_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_769));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T31_);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_80));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), safePoint);
		res_2 = resizeString(res_2, 2);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA34_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA34_: ;
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T37_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T36_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T30_, T37_);
		{
			NIM_BOOL T40_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T43_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
			T40_ = (NIM_BOOL)0;
			T40_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*(*p).module).g).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_770));
			if (!T40_) goto LA41_;
			T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T43_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), safePoint);
			res_3 = resizeString(res_3, 17);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_771));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), safePoint);
			res_3 = resizeString(res_3, 10);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_772));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA46_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA46_: ;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T49_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T48_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T43_, T49_);
		}
		goto LA38_;
		LA41_: ;
		{
			NIM_BOOL T51_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T54_;
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			T51_ = (NIM_BOOL)0;
			T51_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*(*p).module).g).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_773));
			if (!T51_) goto LA52_;
			T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T54_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_4 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), safePoint);
			res_4 = resizeString(res_4, 20);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_774));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), safePoint);
			res_4 = resizeString(res_4, 13);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_775));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA57_;
				res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA57_: ;
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T59_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T54_, T60_);
		}
		goto LA38_;
		LA52_: ;
		{
			NIM_BOOL T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T65_;
			NimStringDesc* res_5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
			T62_ = (NIM_BOOL)0;
			T62_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*(*p).module).g).config, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_776));
			if (!T62_) goto LA63_;
			T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T65_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_5 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), safePoint);
			res_5 = resizeString(res_5, 18);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_777));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), safePoint);
			res_5 = resizeString(res_5, 10);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_772));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA68_;
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA68_: ;
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
			T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T71_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T70_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T65_, T71_);
		}
		goto LA38_;
		LA63_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T73_;
			NimStringDesc* res_6;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
			T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T73_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_6 = rawNewString(((NI) 80));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), safePoint);
			res_6 = resizeString(res_6, 17);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_771));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), safePoint);
			res_6 = resizeString(res_6, 10);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_772));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA76_;
				res_6 = resizeString(res_6, 1);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA76_: ;
			T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T78_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T79_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T78_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T73_, T79_);
		}
		LA38_: ;
		T80_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T80_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_7 = rawNewString(((NI) 80));
		res_7 = resizeString(res_7, 4);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), safePoint);
		res_7 = resizeString(res_7, 15);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_778));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA83_;
			res_7 = resizeString(res_7, 1);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA83_: ;
		T85_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T85_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T86_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T85_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T80_, T86_);
	}
	LA20_: ;
	{
		NI T89_;
		NI T92_;
		T89_ = (NI)0;
		T89_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		if (!((*(*t)._kind_6.sons->data[(NI)(T89_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA90_;
		T92_ = (NI)0;
		T92_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		fin = (*t)._kind_6.sons->data[(NI)(T92_ - ((NI) 1))];
	}
	goto LA87_;
	LA90_: ;
	{
		fin = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA87_: ;
	nimZeroMem((void*)(&T94_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	T94_.Field0 = fin;
	T94_.Field1 = quirkyExceptions;
	T94_.Field2 = ((NI) 0);
	asgnRef((void**) (&(*p).nestedTryStmts), (tySequence__KjgUMUjT3LUKOFIK4xt5ug*) incrSeqV3((TGenericSeq*)((*p).nestedTryStmts), (&NTI__KjgUMUjT3LUKOFIK4xt5ug_)));
	T95_ = (*p).nestedTryStmts->Sup.len++;
	asgnRef((void**) (&(*p).nestedTryStmts->data[T95_].Field0), T94_.Field0);
	(*p).nestedTryStmts->data[T95_].Field1 = T94_.Field1;
	(*p).nestedTryStmts->data[T95_].Field2 = T94_.Field2;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*t)._kind_6.sons->data[((NI) 0)], d);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T100_;
		NimStringDesc* res_8;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T107_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T108_;
		NimStringDesc* res_9;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T113_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T115_;
		NimStringDesc* res_10;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T120_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T121_;
		NI T122_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T123_;
		NimStringDesc* res_11;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T124_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T129_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T130_;
		if (!!(quirkyExceptions)) goto LA98_;
		T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T100_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_8 = rawNewString(((NI) 80));
		T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T101_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_718));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), T101_);
		res_8 = resizeString(res_8, 3);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA104_;
			res_8 = resizeString(res_8, 1);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA104_: ;
		T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T106_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
		T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T107_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T106_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T100_, T107_);
		T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T108_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_9 = rawNewString(((NI) 80));
		res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_185));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA111_;
			res_9 = resizeString(res_9, 1);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA111_: ;
		T113_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T113_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
		T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T114_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T113_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T108_, T114_);
		T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T115_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_10 = rawNewString(((NI) 80));
		res_10 = resizeString(res_10, 6);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_779));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA118_;
			res_10 = resizeString(res_10, 1);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA118_: ;
		T120_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T120_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
		T121_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T121_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T120_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T115_, T121_);
		T122_ = (NI)0;
		T122_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T123_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_11 = rawNewString(((NI) 80));
		T124_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T124_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_718));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_11), T124_);
		res_11 = resizeString(res_11, 3);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA127_;
			res_11 = resizeString(res_11, 1);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA127_: ;
		T129_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T129_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
		T130_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T130_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T129_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T123_, T130_);
		genRestoreFrameAfterException__0dpuY9coTlraj8JXIe2BzVw_3(p);
	}
	goto LA96_;
	LA98_: ;
	{
		NIM_BOOL T132_;
		NI T133_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T137_;
		NimStringDesc* res_12;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T138_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T143_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T144_;
		NI T145_;
		T132_ = (NIM_BOOL)0;
		T133_ = (NI)0;
		T133_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T132_ = (((NI) 1) < T133_);
		if (!(T132_)) goto LA134_;
		T132_ = ((*(*t)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
		LA134_: ;
		if (!T132_) goto LA135_;
		T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T137_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_12 = rawNewString(((NI) 80));
		res_12 = resizeString(res_12, 4);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		T138_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T138_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_737));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_12), T138_);
		res_12 = resizeString(res_12, 5);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_780));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA141_;
			res_12 = resizeString(res_12, 1);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA141_: ;
		T143_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T143_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
		T144_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T144_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T143_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T137_, T144_);
		T145_ = (NI)0;
		T145_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	}
	goto LA96_;
	LA135_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T147_;
		NimStringDesc* res_13;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T152_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T153_;
		NI T154_;
		T147_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T147_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_13 = rawNewString(((NI) 80));
		res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA150_;
			res_13 = resizeString(res_13, 1);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA150_: ;
		T152_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T152_ = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
		T153_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T153_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T152_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T147_, T153_);
		T154_ = (NI)0;
		T154_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	}
	LA96_: ;
	T155_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
	T155_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
	(*T155_).Field1 = NIM_TRUE;
	i = ((NI) 1);
	{
		while (1) {
			NIM_BOOL T158_;
			NI T159_;
			T158_ = (NIM_BOOL)0;
			T159_ = (NI)0;
			T159_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
			T158_ = (i < T159_);
			if (!(T158_)) goto LA160_;
			T158_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
			LA160_: ;
			if (!T158_) goto LA157;
			{
				NIM_BOOL T163_;
				T163_ = (NIM_BOOL)0;
				T163_ = ((*d).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 1));
				if (!(T163_)) goto LA164_;
				T163_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*t).typ);
				LA164_: ;
				if (!T163_) goto LA165_;
				(*d).k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0);
			}
			LA165_: ;
			{
				NI T169_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T180_;
				NimStringDesc* res_14;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T185_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T186_;
				NI T187_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T199_;
				NimStringDesc* res_16;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T200_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T205_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T206_;
				T169_ = (NI)0;
				T169_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
				if (!(T169_ == ((NI) 1))) goto LA170_;
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T176_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T177_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T178_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T179_;
					if (!(((NI) 1) < i)) goto LA174_;
					T176_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T176_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					nimZeroMem((void*)T177_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T178_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T178_ = percent___22ELRKd9bDuNug6qvIihS3A(T177_, 0);
					T179_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T179_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T178_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T176_, T179_);
				}
				LA174_: ;
				T180_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T180_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_14 = rawNewString(((NI) 80));
				res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA183_;
					res_14 = resizeString(res_14, 1);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA183_: ;
				T185_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T185_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
				T186_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T186_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T185_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T180_, T186_);
				T187_ = (NI)0;
				T187_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T192_;
					NimStringDesc* res_15;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T197_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T198_;
					if (!!(quirkyExceptions)) goto LA190_;
					T192_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T192_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_15 = rawNewString(((NI) 80));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_15), safePoint);
					res_15 = resizeString(res_15, 12);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_781));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA195_;
						res_15 = resizeString(res_15, 1);
appendString(res_15, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA195_: ;
					T197_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T197_ = rope__yShmEg9cffWxI7s5XzEKBow(res_15);
					T198_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T198_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T197_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T192_, T198_);
				}
				LA190_: ;
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], d);
				T199_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T199_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_16 = rawNewString(((NI) 80));
				T200_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T200_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_16), T200_);
				res_16 = resizeString(res_16, 3);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA203_;
					res_16 = resizeString(res_16, 1);
appendString(res_16, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA203_: ;
				T205_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T205_ = rope__yShmEg9cffWxI7s5XzEKBow(res_16);
				T206_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T206_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T205_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T199_, T206_);
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
			}
			goto LA167_;
			LA170_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* orExpr;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T238_;
				NimStringDesc* res_18;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T243_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T244_;
				NI T245_;
				NI T257_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T258_;
				NimStringDesc* res_20;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T259_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T264_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T265_;
				orExpr = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
				{
					NI j;
					NI colontmp_;
					NI T209_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T209_ = (NI)0;
					T209_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T209_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* checkFor;
							NimStringDesc* memberName;
							NimStringDesc* res_17;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T228_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T229_;
							tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T230_;
							if (!(i_2 < colontmp_)) goto LA211;
							j = i_2;
							{
								if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA214_;
								add__yG4AKzsBRS1W4MANDlXQeg(&orExpr, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_284));
							}
							LA214_: ;
							{
								if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA218_;
								checkFor = genTypeInfo2Name__HPYuz9bvVOGBv0EUX9c74xhg((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ);
							}
							goto LA216_;
							LA218_: ;
							{
								checkFor = genTypeInfoV1__BeEYMOjEPJinzbFpsfTaZg_2((*p).module, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).typ, (*(*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]).info);
							}
							LA216_: ;
							{
								NIM_BOOL T223_;
								T223_ = (NIM_BOOL)0;
								T223_ = ((*(*(*(*p).module).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
								if (T223_) goto LA224_;
								T223_ = (((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
								LA224_: ;
								if (!T223_) goto LA225_;
								memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_735));
							}
							goto LA221_;
							LA225_: ;
							{
								memberName = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_736));
							}
							LA221_: ;
							res_17 = rawNewString(((NI) 80));
							T228_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T228_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_512));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_17), T228_);
							res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
							T229_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T229_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_737));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_17), T229_);
							res_17 = resizeString(res_17, 4);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_738));
							cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_17), memberName);
							res_17 = resizeString(res_17, 2);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
							cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_17), checkFor);
							res_17 = resizeString(res_17, 1);
appendString(res_17, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_50));
							T230_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
							T230_ = rope__yShmEg9cffWxI7s5XzEKBow(res_17);
							add__IM4kcMNkkOLJtqdEqSxR8A(&orExpr, T230_);
							i_2 += ((NI) 1);
						} LA211: ;
					}
				}
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T235_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T236_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T237_;
					if (!(((NI) 1) < i)) goto LA233_;
					T235_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T235_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					T236_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T236_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_739));
					T237_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T237_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T236_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T235_, T237_);
				}
				LA233_: ;
				T238_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T238_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_18 = rawNewString(((NI) 80));
				res_18 = resizeString(res_18, 4);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_18), orExpr);
				res_18 = resizeString(res_18, 3);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_712));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA241_;
					res_18 = resizeString(res_18, 1);
appendString(res_18, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA241_: ;
				T243_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T243_ = rope__yShmEg9cffWxI7s5XzEKBow(res_18);
				T244_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T244_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T243_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T238_, T244_);
				T245_ = (NI)0;
				T245_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T250_;
					NimStringDesc* res_19;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T255_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T256_;
					if (!!(quirkyExceptions)) goto LA248_;
					T250_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T250_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					res_19 = rawNewString(((NI) 80));
					cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_19), safePoint);
					res_19 = resizeString(res_19, 12);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_781));
					{
						if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA253_;
						res_19 = resizeString(res_19, 1);
appendString(res_19, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					}
					LA253_: ;
					T255_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T255_ = rope__yShmEg9cffWxI7s5XzEKBow(res_19);
					T256_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T256_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T255_);
					add__IM4kcMNkkOLJtqdEqSxR8A(T250_, T256_);
				}
				LA248_: ;
				T257_ = (NI)0;
				T257_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
				expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T257_ - ((NI) 1))], d);
				T258_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T258_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_20 = rawNewString(((NI) 80));
				T259_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T259_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_719));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_20), T259_);
				res_20 = resizeString(res_20, 3);
appendString(res_20, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA262_;
					res_20 = resizeString(res_20, 1);
appendString(res_20, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA262_: ;
				T264_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T264_ = rope__yShmEg9cffWxI7s5XzEKBow(res_20);
				T265_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T265_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T264_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T258_, T265_);
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
			}
			LA167_: ;
			i += ((NI) 1);
		} LA157: ;
	}
	nimZeroMem((void*)(&T266_), sizeof(tyTuple__FxkU4d1VDodDMc9ah6Mbagw));
	pop__Y36bTNxSoXinCwCTSTCSTgsystem((&(*p).nestedTryStmts), (&T266_));
	(void)(T266_);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	{
		NIM_BOOL T269_;
		NI T270_;
		NI T274_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T275_;
		NimStringDesc* res_21;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T280_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T281_;
		NI T282_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T298_;
		T269_ = (NIM_BOOL)0;
		T270_ = (NI)0;
		T270_ = len__P89cqdlERShb9alU3iC0yj8wast(t);
		T269_ = (i < T270_);
		if (!(T269_)) goto LA271_;
		T269_ = ((*(*t)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107));
		LA271_: ;
		if (!T269_) goto LA272_;
		asgnRef((void**) (&(*p).finallySafePoints), (tySequence__WwUFq9cJ2xKRlsAWVEHyPRg*) incrSeqV3((TGenericSeq*)((*p).finallySafePoints), (&NTI__WwUFq9cJ2xKRlsAWVEHyPRg_)));
		T274_ = (*p).finallySafePoints->Sup.len++;
		asgnRef((void**) (&(*p).finallySafePoints->data[T274_]), safePoint);
		T275_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T275_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_21 = rawNewString(((NI) 80));
		res_21 = resizeString(res_21, 1);
appendString(res_21, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA278_;
			res_21 = resizeString(res_21, 1);
appendString(res_21, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA278_: ;
		T280_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T280_ = rope__yShmEg9cffWxI7s5XzEKBow(res_21);
		T281_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T281_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T280_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T275_, T281_);
		T282_ = (NI)0;
		T282_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*(*t)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T285_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T287_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T290_;
			NimStringDesc* res_22;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T291_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T296_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T297_;
			T285_ = (NIM_BOOL)0;
			T285_ = !(quirkyExceptions);
			if (!(T285_)) goto LA286_;
			T287_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T287_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*(*p).module).g).graph, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_782));
			T285_ = !((T287_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA286_: ;
			if (!T285_) goto LA288_;
			T290_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T290_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_22 = rawNewString(((NI) 80));
			res_22 = resizeString(res_22, 4);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_22), safePoint);
			res_22 = resizeString(res_22, 14);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_720));
			T291_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T291_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_782));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_22), T291_);
			res_22 = resizeString(res_22, 3);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA294_;
				res_22 = resizeString(res_22, 1);
appendString(res_22, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA294_: ;
			T296_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T296_ = rope__yShmEg9cffWxI7s5XzEKBow(res_22);
			T297_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T297_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T296_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T290_, T297_);
		}
		LA288_: ;
		endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
		T298_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T298_ = pop__9c4Y4hTtvRqjj2EC8KP9aqDAsystem((&(*p).finallySafePoints));
		(void)(T298_);
	}
	LA272_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T303_;
		NimStringDesc* res_23;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T304_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T309_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T310_;
		if (!!(quirkyExceptions)) goto LA301_;
		T303_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T303_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_23 = rawNewString(((NI) 80));
		res_23 = resizeString(res_23, 4);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_224));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_23), safePoint);
		res_23 = resizeString(res_23, 14);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_720));
		T304_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T304_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_783));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_23), T304_);
		res_23 = resizeString(res_23, 3);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA307_;
			res_23 = resizeString(res_23, 1);
appendString(res_23, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA307_: ;
		T309_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T309_ = rope__yShmEg9cffWxI7s5XzEKBow(res_23);
		T310_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T310_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T309_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T303_, T310_);
	}
	LA301_: ;
}
static N_INLINE(void, genSimpleBlock__RH6PUsmPRE4ftBMagpWhBQcgen)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stmts) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T1_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	NI T8_;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA4_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA4_: ;
	T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T6_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T6_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T1_, T7_);
	T8_ = (NI)0;
	T8_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, stmts);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
}
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__0dpuY9coTlraj8JXIe2BzVw_4)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T8_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* finallyBlock;
		tyTuple__FxkU4d1VDodDMc9ah6Mbagw* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3)));
		if (!(T4_)) goto LA5_;
		T6_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
		T4_ = (((NI) 0) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T8_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
		T8_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
		T3_ = (*T8_).Field1;
		LA7_: ;
		if (!T3_) goto LA9_;
		T11_ = (tyTuple__FxkU4d1VDodDMc9ah6Mbagw*)0;
		T11_ = X5BX5D___X6aCqErYyvvzizP8PaBpFQsystem((*p).nestedTryStmts->data, ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0), ((NI) 1));
		finallyBlock = (*T11_).Field0;
		{
			if (!!((finallyBlock == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA14_;
			genSimpleBlock__RH6PUsmPRE4ftBMagpWhBQcgen(p, (*finallyBlock)._kind_6.sons->data[((NI) 0)]);
		}
		LA14_: ;
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__QrTB5DOwbDX9bKAW7PNbuJA_7)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* gotoInstr;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* e;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		if (!!(((*(*t)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, (*t)._kind_6.sons->data[((NI) 0)], (&a));
		finallyActions__0dpuY9coTlraj8JXIe2BzVw_4(p);
		e = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg((*p).module, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		(void)(T5_);
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*t)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
		{
			NI T10_;
			if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2))) goto LA8_;
			T10_ = (NI)0;
			T10_ = inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2(p);
			blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q(p, ((NI) 0), T10_);
		}
		LA8_: ;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
		{
			NIM_BOOL T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T16_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			T13_ = (NIM_BOOL)0;
			T13_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A(typ, (*(*(*p).module).g).config);
			if (!T13_) goto LA14_;
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T16_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T17_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T17_[0] = e;
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = percent___ddrHnMlEhcHznkXv27msmQ(T17_, 1);
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T18_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T16_, T19_);
		}
		goto LA11_;
		LA14_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T21_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			NimStringDesc* T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
			NI T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T21_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res = rawNewString(((NI) 80));
			T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T22_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_784));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T22_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_138));
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_749));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T23_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_785));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), e);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*(*typ).sym).name).s);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T24_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T25_ = (NimStringDesc*)0;
			{
				if (!!(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA28_;
				T25_ = copyString((*(*(*p).prc).name).s);
			}
			goto LA26_;
			LA28_: ;
			{
				T25_ = copyString((*(*(*(*p).module).module).name).s);
			}
			LA26_: ;
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T25_);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T31_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T32_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*(*p).module).g).config, (*t).info);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T32_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_46));
			T33_ = (NI)0;
			T33_ = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs((*t).info);
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), ((NI64) (T33_)));
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_157));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA36_;
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA36_: ;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T39_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T38_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T21_, T39_);
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T44_;
				NimStringDesc* res_2;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
				if (!(((*(*(*(*p).module).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA42_;
				T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T44_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res_2 = rawNewString(((NI) 80));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), e);
				res_2 = resizeString(res_2, 11);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_259));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA47_;
					res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA47_: ;
				T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T49_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
				T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T50_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T49_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T44_, T50_);
			}
			LA42_: ;
		}
		LA11_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		finallyActions__0dpuY9coTlraj8JXIe2BzVw_4(p);
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T56_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			if (!((*(*(*(*p).module).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2))) goto LA54_;
			T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T56_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			nimZeroMem((void*)T57_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = percent___B0OBOTOJQENvDd71LJ9b19bw(T57_, 0);
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T58_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T56_, T59_);
		}
		goto LA52_;
		LA54_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T61_;
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T61_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			res_3 = rawNewString(((NI) 80));
			T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T62_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*p).module, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_783));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T62_);
			res_3 = resizeString(res_3, 3);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
			{
				if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA65_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA65_: ;
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T67_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T61_, T68_);
		}
		LA52_: ;
	}
	LA1_: ;
	gotoInstr = raiseInstr__3AsTOpq9crZUYBL9aD1lXBng_4(p);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T73_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T74_;
		if (!!((gotoInstr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA71_;
		T73_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T73_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T74_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T74_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, gotoInstr);
		add__IM4kcMNkkOLJtqdEqSxR8A(T73_, T74_);
	}
	LA71_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__t9a9a9bxmaOztYOfsfhQUOXXw_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg, determineSection__3f2MBweHSQI3C7jDZiYA2Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg result;
	result = (tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg)0;
	result = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8);
	{
		NIM_BOOL T3_;
		NI T4_;
		NimStringDesc* sec;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (((NI) 1) <= T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*n)._kind_6.sons->data[((NI) 0)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
		LA5_: ;
		if (!T3_) goto LA6_;
		sec = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_3.strVal;
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_786));
			if (!T10_) goto LA11_;
			result = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4);
		}
		goto LA8_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_787));
			if (!T14_) goto LA15_;
			result = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10);
		}
		goto LA8_;
		LA15_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = nsuStartsWith(sec, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_788));
			if (!T18_) goto LA19_;
			result = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1);
		}
		goto LA8_;
		LA19_: ;
		LA8_: ;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genEmit__QrTB5DOwbDX9bKAW7PNbuJA_8)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	s = genAsmOrEmitStmt__53Pwv51Dxuia7o9bQN4K9agw(p, (*t)._kind_6.sons->data[((NI) 1)], NIM_FALSE);
	{
		tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg section;
		if (!((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		section = determineSection__3f2MBweHSQI3C7jDZiYA2Q((*t)._kind_6.sons->data[((NI) 1)]);
		genCLineDir__8gOq38UiI9arVxZ9at35m22Q(&(*(*p).module).s[(section)- 0], (*t).info, (*(*(*p).module).g).config);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).module).s[(section)- 0], s);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T6_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, s);
		add__IM4kcMNkkOLJtqdEqSxR8A(T6_, T7_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPragma__UtJx89cn0a8CNSWWmaj6raA_11)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T5_;
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				T5_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
				T5_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw((*it));
				switch (T5_) {
				case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 211):
				{
					genEmit__QrTB5DOwbDX9bKAW7PNbuJA_8(p, (*it));
				}
				break;
				case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 203):
				{
					tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T8_;
					p_2 = newProc__r9c9cj4fW68RhY7ht9btSvB8w(((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (*p).module);
					(*p_2).options = ((*p_2).options & ~ 655360);
					genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p_2, (*(*it))._kind_6.sons->data[((NI) 1)]);
					T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
					T8_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p_2, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
					asgnRef((void**) (&(*(*p_2).module).injectStmt), (*T8_));
				}
				break;
				default:
				{
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__QrTB5DOwbDX9bKAW7PNbuJA_9)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	NI oldBreakIdxX60gensym1967_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* forLoopVar;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA rangeA;
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA rangeB;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T17_;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
	(*p).withinLoop += ((NI) 1);
	genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, t);
	oldBreakIdxX60gensym1967_ = (*p).breakIdx;
	forLoopVar = (*(*t)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	nimZeroMem((void*)(&rangeA), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	nimZeroMem((void*)(&rangeB), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	assignLocalVar__UtJx89cn0a8CNSWWmaj6raA(p, (*t)._kind_6.sons->data[((NI) 0)]);
	call = (*t)._kind_6.sons->data[((NI) 1)];
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*call)._kind_6.sons->data[((NI) 1)], (&rangeA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*call)._kind_6.sons->data[((NI) 2)], (&rangeB));
	{
		NI T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T6_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
		if (!(T3_ == ((NI) 4))) goto LA4_;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T6_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T7_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T7_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*forLoopVar).loc);
		T7_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(rangeA);
		T7_[2] = rdLoc__xidyzuHqIciXbQyEOKahDg(rangeB);
		T8_ = (NimStringDesc*)0;
		T8_ = getStr__P2DOsHG6Jk4Siab3L2qwUg((*call)._kind_6.sons->data[((NI) 3)]);
		T7_[3] = rope__yShmEg9cffWxI7s5XzEKBow(T8_);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___yhJ9aDxHfJqHvWO0i6N9bukQ(T7_, 4);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T9_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T6_, T10_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA step;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T12_;
		tyArray__duFhZXIIlrbrM62cWjNekg T13_;
		NimStringDesc* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		nimZeroMem((void*)(&step), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*call)._kind_6.sons->data[((NI) 3)], (&step));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T12_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		nimZeroMem((void*)T13_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T13_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg((*forLoopVar).loc);
		T13_[1] = rdLoc__xidyzuHqIciXbQyEOKahDg(rangeA);
		T13_[2] = rdLoc__xidyzuHqIciXbQyEOKahDg(rangeB);
		T13_[3] = rdLoc__xidyzuHqIciXbQyEOKahDg(step);
		T14_ = (NimStringDesc*)0;
		T14_ = getStr__P2DOsHG6Jk4Siab3L2qwUg((*call)._kind_6.sons->data[((NI) 4)]);
		T13_[4] = rope__yShmEg9cffWxI7s5XzEKBow(T14_);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = percent___MLJpsW0DAZYB8lAgq09cUjg(T13_, 5);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T12_, T16_);
	}
	LA1_: ;
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T17_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	res = rawNewString(((NI) 80));
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
	{
		if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA20_;
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA20_: ;
	T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T22_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T23_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T22_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T17_, T23_);
	(*p).breakIdx = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
	(*p).blocks->data[(*p).breakIdx].isLoop = NIM_TRUE;
	genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, (*t)._kind_6.sons->data[((NI) 2)]);
	endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
	(*p).breakIdx = oldBreakIdxX60gensym1967_;
	(*p).withinLoop -= ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genState__UtJx89cn0a8CNSWWmaj6raA_12)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n0;
	{
		NI T3_;
		NimStringDesc* argX60gensym1657_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 1)))) goto LA4_;
		argX60gensym1657_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_789);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1657_, TM__MQdRN7fpbG7rPm4JpVVAhA_789);
	}
	LA4_: ;
	n0 = (*n)._kind_6.sons->data[((NI) 0)];
	{
		NI64 idx;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T10_;
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		if (!((*n0).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA8_;
		idx = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_1.intVal;
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T10_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res = rawNewString(((NI) 80));
		res = resizeString(res, 5);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_790));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res), idx);
		res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_791));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA13_;
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA13_: ;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T10_, T16_);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T20_;
		NimStringDesc* res_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		if (!((*n0).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20))) goto LA18_;
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T20_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		res_2 = rawNewString(((NI) 80));
		cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_2), (*n0)._kind_3.strVal);
		res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_791));
		{
			if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA23_;
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA23_: ;
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T25_);
		add__IM4kcMNkkOLJtqdEqSxR8A(T20_, T26_);
	}
	goto LA6_;
	LA18_: ;
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__UtJx89cn0a8CNSWWmaj6raA_13)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T1_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T5_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	NI T9_;
	NI T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T11_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA statesCounter;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* prefix;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T37_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T38_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T39_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T1_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T2_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T2_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___T9caGByKkBhaXSZ6fCJLIdQ(T2_, 1);
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T3_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T1_, T4_);
	(*p).flags |= ((NU8)1)<<((((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0)) & 7);
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T5_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T6_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T7_ = percent___8tWfSjtTOlDafxpQPvChAA(T6_, 0);
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T7_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T5_, T8_);
	T9_ = ((*p).nestedTryStmts ? (*p).nestedTryStmts->Sup.len : 0);
	T10_ = (NI)0;
	T10_ = inExceptBlockLen__1ygdb876UM9astcNUXtgUBQ_2(p);
	blockLeaveActions__e09bgD1fQnMSV07ItnToC3Q(p, T9_, T10_);
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T11_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T12_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = percent___xKLwwPkFSVy2Dtn9cuJ78xw(T12_, 0);
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T13_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T11_, T14_);
	statesCounter = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*(*p).module).g).config, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
	{
		NIM_BOOL T17_;
		NI T18_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NI)0;
		T18_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T17_ = (((NI) 2) <= T18_);
		if (!(T17_)) goto LA19_;
		T17_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
		LA19_: ;
		if (!T17_) goto LA20_;
		statesCounter = getInt__Ml9bTZ5dXYSLBfnGRkErokw((*n)._kind_6.sons->data[((NI) 1)]);
	}
	LA20_: ;
	{
		NIM_BOOL T24_;
		NI T25_;
		T24_ = (NIM_BOOL)0;
		T25_ = (NI)0;
		T25_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T24_ = (T25_ == ((NI) 3));
		if (!(T24_)) goto LA26_;
		T24_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20));
		LA26_: ;
		if (!T24_) goto LA27_;
		prefix = rope__yShmEg9cffWxI7s5XzEKBow((*(*n)._kind_6.sons->data[((NI) 2)])._kind_3.strVal);
	}
	goto LA22_;
	LA27_: ;
	{
		prefix = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_792));
	}
	LA22_: ;
	{
		NI64 i;
		NI64 colontmp_;
		NI64 res;
		i = (NI64)0;
		colontmp_ = (NI64)0;
		colontmp_ = toInt64__1szweXXq3RBN50owrYu2Xw(statesCounter);
		res = IL64(0);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T33_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T34_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T35_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
				if (!(res <= colontmp_)) goto LA32;
				i = res;
				T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T33_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				nimZeroMem((void*)T34_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T34_[0] = prefix;
				T34_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(i);
				T35_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T35_ = percent___hdRijZdoPR3UGq9aUw2zFDQ(T34_, 2);
				T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T36_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T35_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T33_, T36_);
				res += ((NI) 1);
			} LA32: ;
		}
	}
	T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
	T37_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
	nimZeroMem((void*)T38_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T39_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T39_ = percent___BYiowJAm8zF7RBRISElaLg(T38_, 0);
	T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T40_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T39_);
	add__IM4kcMNkkOLJtqdEqSxR8A(T37_, T40_);
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__8mAL9ckajemzgfLPfeZVNoQ_23)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	initLoc__qlujIAW86QclHYUVxlHRiQ(d, ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 6), n, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA3_;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], (&a));
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		unsureAsgnRef((void**) (&(*d).r), percent___ZjQc8bFVF8ePFYxjN0iVVg(T5_, 1));
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T7_;
		initLocExpr__9biTBaXPz9cezuLjjWw9cSEGw_2(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		nimZeroMem((void*)T7_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T7_[0] = rdLoc__xidyzuHqIciXbQyEOKahDg(a);
		unsureAsgnRef((void**) (&(*d).r), percent___SiqB8gWmdYKb4vtgqYrrMA(T7_, 1));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, expr__8mAL9ckajemzgfLPfeZVNoQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* d) {
	(*p).currLineInfo = (*n).info;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		sym = (*n)._kind_4.sym;
		switch ((*sym).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
		{
			{
				if (!!(((536870928 & (*sym).flags) == 0))) goto LA5_;
				fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw((*p).module, n);
				genProcPrototype__TAVDUakAwQnRHDK9cFe6L7g((*p).module, sym);
			}
			goto LA3_;
			LA5_: ;
			{
				genProc__HbYPOpwLApFuBkISFGrmEQ((*p).module, sym);
			}
			LA3_: ;
			putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
		{
			{
				NimStringDesc* T13_;
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA11_;
				T13_ = (NimStringDesc*)0;
				T13_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + 48);
appendString(T13_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_351));
appendString(T13_, (*(*sym).name).s);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*p).module).g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__MQdRN7fpbG7rPm4JpVVAhA_352, NIM_FALSE);
			}
			LA11_: ;
			genProc__HbYPOpwLApFuBkISFGrmEQ((*p).module, sym);
			{
				NIM_BOOL T16_;
				NimStringDesc* T20_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
				if (T16_) goto LA17_;
				T16_ = ((*sym).loc.lode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				LA17_: ;
				if (!T16_) goto LA18_;
				T20_ = (NimStringDesc*)0;
				T20_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + 20);
appendString(T20_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_353));
appendString(T20_, (*(*sym).name).s);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T20_, TM__MQdRN7fpbG7rPm4JpVVAhA_354);
			}
			LA18_: ;
			putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
		{
			{
				NIM_BOOL T24_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
				T24_ = (NIM_BOOL)0;
				T24_ = isSimpleConst__y9bTRtTAknVsv9apXKbpJYJA((*sym).typ);
				if (!T24_) goto LA25_;
				T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T27_ = genLiteral__qifZy01sZ5OX01eT5FP76w(p, (*sym).ast, (*sym).typ);
				putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T27_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 1));
			}
			goto LA22_;
			LA25_: ;
			{
				genComplexConst__ARtcpl8G0t9cQCPr2Np8Srw(p, sym, d);
			}
			LA22_: ;
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20):
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*sym).position)));
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T30_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
		{
			{
				if (!!(((67108872 & (*sym).flags) == 0))) goto LA34_;
				genVarPrototype__t9a9a9bxmaOztYOfsfhQUOXXw_2((*p).module, n);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T40_;
					if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA38_;
					T40_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T40_ = astdef__PBkjYIaAGbtrZ8DiUArHcw(sym);
					genSingleVar__T7FeUoHVfLrGm0JydrFabA(p, sym, n, T40_);
				}
				LA38_: ;
			}
			LA34_: ;
			{
				NIM_BOOL T43_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
				NimStringDesc* T48_;
				NimStringDesc* T49_;
				T43_ = (NIM_BOOL)0;
				T43_ = ((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
				if (T43_) goto LA44_;
				T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T45_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
				T43_ = (T45_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA44_: ;
				if (!T43_) goto LA46_;
				T48_ = (NimStringDesc*)0;
				T49_ = (NimStringDesc*)0;
				T49_ = nimIntToStr((*sym).Sup.id);
				T48_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T49_ ? T49_->Sup.len : 0) + 20);
appendString(T48_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_420));
appendString(T48_, (*(*sym).name).s);
appendString(T48_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
appendString(T48_, T49_);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T48_, TM__MQdRN7fpbG7rPm4JpVVAhA_421);
			}
			LA46_: ;
			{
				if (!(((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0)) goto LA52_;
				accessThreadLocalVar__IpGUPLhMYizrVHs0OdHySA(p, sym);
				{
					NIM_BOOL T56_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
					T56_ = (NIM_BOOL)0;
					T56_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*(*p).module).g).config);
					if (!T56_) goto LA57_;
					T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T59_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_369), (*sym).loc.r);
					putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, (*sym).loc.lode, T59_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
				}
				goto LA54_;
				LA57_: ;
				{
					putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
				}
				LA54_: ;
			}
			goto LA50_;
			LA52_: ;
			{
				putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
			}
			LA50_: ;
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5):
		{
			{
				NIM_BOOL T65_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T67_;
				NimStringDesc* T70_;
				NimStringDesc* T71_;
				T65_ = (NIM_BOOL)0;
				T65_ = ((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
				if (T65_) goto LA66_;
				T67_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T67_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
				T65_ = (T67_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA66_: ;
				if (!T65_) goto LA68_;
				T70_ = (NimStringDesc*)0;
				T71_ = (NimStringDesc*)0;
				T71_ = nimIntToStr((*sym).Sup.id);
				T70_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T71_ ? T71_->Sup.len : 0) + 21);
appendString(T70_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_422));
appendString(T70_, (*(*sym).name).s);
appendString(T70_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
appendString(T70_, T71_);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T70_, TM__MQdRN7fpbG7rPm4JpVVAhA_423);
			}
			LA68_: ;
			putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
		{
			{
				NIM_BOOL T75_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T77_;
				NimStringDesc* T80_;
				NimStringDesc* T81_;
				T75_ = (NIM_BOOL)0;
				T75_ = ((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
				if (T75_) goto LA76_;
				T77_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T77_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*sym).loc);
				T75_ = (T77_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA76_: ;
				if (!T75_) goto LA78_;
				T80_ = (NimStringDesc*)0;
				T81_ = (NimStringDesc*)0;
				T81_ = nimIntToStr((*sym).Sup.id);
				T80_ = rawNewString(((*(*sym).name).s ? (*(*sym).name).s->Sup.len : 0) + (T81_ ? T81_->Sup.len : 0) + 22);
appendString(T80_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_424));
appendString(T80_, (*(*sym).name).s);
appendString(T80_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
appendString(T80_, T81_);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T80_, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			}
			LA78_: ;
			putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym).loc);
		}
		break;
		default:
		{
			NimStringDesc* T83_;
			T83_ = (NimStringDesc*)0;
			T83_ = rawNewString((reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_)) ? reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_))->Sup.len : 0) + 22);
appendString(T83_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_426));
appendString(T83_, reprEnum((NI)(*sym).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
appendString(T83_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_427));
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T83_, TM__MQdRN7fpbG7rPm4JpVVAhA_428);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		{
			NIM_BOOL T87_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
			T87_ = (NIM_BOOL)0;
			T87_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			if (!!(T87_)) goto LA88_;
			T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T90_ = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, n);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T90_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		LA88_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
		T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T92_ = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, n);
		putDataIntoDest__fYECstGN5jPehhn5p8Iclg(p, d, n, T92_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
		T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T94_ = genLiteral__NYI5fC69aIqZGRakncXv9cNQ_2(p, n);
		putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T94_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
		genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, n);
		op = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
			if (!((*n).typ == 0)) goto LA98_;
			nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			{
				NIM_BOOL T102_;
				T102_ = (NIM_BOOL)0;
				T102_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T102_)) goto LA103_;
				T102_ = !(((*(*op)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
				LA103_: ;
				if (!T102_) goto LA104_;
				genMagicExpr__TU9cJnldbmGa9bZDxaR6I4tg(p, n, (&a), (*(*op)._kind_4.sym).magic);
			}
			goto LA100_;
			LA104_: ;
			{
				genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, n, (&a));
			}
			LA100_: ;
		}
		goto LA96_;
		LA98_: ;
		{
			{
				NIM_BOOL T110_;
				T110_ = (NIM_BOOL)0;
				T110_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T110_)) goto LA111_;
				T110_ = !(((*(*op)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
				LA111_: ;
				if (!T110_) goto LA112_;
				genMagicExpr__TU9cJnldbmGa9bZDxaR6I4tg(p, n, d, (*(*op)._kind_4.sym).magic);
			}
			goto LA108_;
			LA112_: ;
			{
				genCall__BKdMcfvryaJLplX0oFPcAQ_8(p, n, d);
			}
			LA108_: ;
		}
		LA96_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	{
		{
			NIM_BOOL T118_;
			NI T120_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T123_;
			T118_ = (NIM_BOOL)0;
			T118_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
			if (!(T118_)) goto LA119_;
			T120_ = (NI)0;
			T120_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T118_ = !((T120_ == ((NI) 0)));
			LA119_: ;
			if (!T118_) goto LA121_;
			T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T123_ = genSetNode__NYI5fC69aIqZGRakncXv9cNQ_3(p, n);
			putIntoDest__6NyA5DzsDGY17BhjidN65Q(p, d, n, T123_, ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0));
		}
		goto LA116_;
		LA121_: ;
		{
			genSetConstr__BKdMcfvryaJLplX0oFPcAQ_20(p, n, d);
		}
		LA116_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		{
			NIM_BOOL T128_;
			NI T130_;
			T128_ = (NIM_BOOL)0;
			T128_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
			if (!(T128_)) goto LA129_;
			T130_ = (NI)0;
			T130_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T128_ = !((T130_ == ((NI) 0)));
			LA129_: ;
			if (!T128_) goto LA131_;
			exprComplexConst__8mAL9ckajemzgfLPfeZVNoQ_8(p, n, d);
		}
		goto LA126_;
		LA131_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T134_;
			T134_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T134_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
			if (!((*T134_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))) goto LA135_;
			genSeqConstr__8mAL9ckajemzgfLPfeZVNoQ_6(p, n, d);
		}
		goto LA126_;
		LA135_: ;
		{
			genArrayConstr__8mAL9ckajemzgfLPfeZVNoQ_9(p, n, d);
		}
		LA126_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		{
			NIM_BOOL T141_;
			NIM_BOOL T142_;
			NI T145_;
			T141_ = (NIM_BOOL)0;
			T142_ = (NIM_BOOL)0;
			T142_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T142_)) goto LA143_;
			T142_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA143_: ;
			T141_ = T142_;
			if (!(T141_)) goto LA144_;
			T145_ = (NI)0;
			T145_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T141_ = (T145_ == ((NI) 2));
			LA144_: ;
			if (!T141_) goto LA146_;
			genClosure__8mAL9ckajemzgfLPfeZVNoQ_10(p, n, d);
		}
		goto LA139_;
		LA146_: ;
		{
			NIM_BOOL T149_;
			NI T151_;
			T149_ = (NIM_BOOL)0;
			T149_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
			if (!(T149_)) goto LA150_;
			T151_ = (NI)0;
			T151_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T149_ = !((T151_ == ((NI) 0)));
			LA150_: ;
			if (!T149_) goto LA152_;
			exprComplexConst__8mAL9ckajemzgfLPfeZVNoQ_8(p, n, d);
		}
		goto LA139_;
		LA152_: ;
		{
			genTupleConstr__8mAL9ckajemzgfLPfeZVNoQ_11(p, n, d);
		}
		LA139_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	{
		genObjConstr__BKdMcfvryaJLplX0oFPcAQ_21(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		genCast__BKdMcfvryaJLplX0oFPcAQ_22(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		genConv__BKdMcfvryaJLplX0oFPcAQ_23(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	{
		genAddr__BKdMcfvryaJLplX0oFPcAQ_24(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		genBracketExpr__8mAL9ckajemzgfLPfeZVNoQ_12(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		genDeref__BKdMcfvryaJLplX0oFPcAQ_26(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		genRecordField__BKdMcfvryaJLplX0oFPcAQ_27(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		genCheckedRecordField__BKdMcfvryaJLplX0oFPcAQ_28(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	{
		genBlock__8mAL9ckajemzgfLPfeZVNoQ_13(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		genStmtListExpr__8mAL9ckajemzgfLPfeZVNoQ_14(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		genStmtList__UtJx89cn0a8CNSWWmaj6raA_7(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	{
		genIf__8mAL9ckajemzgfLPfeZVNoQ_15(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)], d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	{
		downConv__8mAL9ckajemzgfLPfeZVNoQ_16(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	{
		upConv__8mAL9ckajemzgfLPfeZVNoQ_17(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	{
		genRangeChck__8mAL9ckajemzgfLPfeZVNoQ_18(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71):
	{
		convStrToCStr__8mAL9ckajemzgfLPfeZVNoQ_19(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72):
	{
		convCStrToStr__8mAL9ckajemzgfLPfeZVNoQ_20(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym_2;
		sym_2 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		genProc__HbYPOpwLApFuBkISFGrmEQ((*p).module, sym_2);
		{
			NIM_BOOL T176_;
			NimStringDesc* T180_;
			T176_ = (NIM_BOOL)0;
			T176_ = ((*sym_2).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
			if (T176_) goto LA177_;
			T176_ = ((*sym_2).loc.lode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			LA177_: ;
			if (!T176_) goto LA178_;
			T180_ = (NimStringDesc*)0;
			T180_ = rawNewString(((*(*sym_2).name).s ? (*(*sym_2).name).s->Sup.len : 0) + 20);
appendString(T180_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_353));
appendString(T180_, (*(*sym_2).name).s);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T180_, TM__MQdRN7fpbG7rPm4JpVVAhA_684);
		}
		LA178_: ;
		putLocIntoDest__SkhzpH2DDHJ7pbmCpsHIPg(p, d, (*sym_2).loc);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	{
		genClosure__8mAL9ckajemzgfLPfeZVNoQ_10(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		genWhileStmt__QrTB5DOwbDX9bKAW7PNbuJA_3(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		genVarStmt__UtJx89cn0a8CNSWWmaj6raA_9(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_706), TM__MQdRN7fpbG7rPm4JpVVAhA_707);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		genCase__re1pwmyeR32ikwnOC3vvzQ(p, n, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		genReturnStmt__QrTB5DOwbDX9bKAW7PNbuJA_4(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		genBreakStmt__QrTB5DOwbDX9bKAW7PNbuJA_5(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	{
		cow__od9bAwM0gKRf4yeR2rVpdZQcgen(p, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 15))&31U)))!=0))) goto LA193_;
			genAsgn__9ap9b3IFVLSL9b9akVbfMyRxlA(p, n, NIM_FALSE);
		}
		LA193_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		cow__od9bAwM0gKRf4yeR2rVpdZQcgen(p, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			if (!!((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 15))&31U)))!=0))) goto LA198_;
			genAsgn__9ap9b3IFVLSL9b9akVbfMyRxlA(p, n, !(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))));
		}
		LA198_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex;
		ex = (*n)._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T205_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T206_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T207_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T208_;
			if (!!(((*ex).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA203_;
			genLineDir__QrTB5DOwbDX9bKAW7PNbuJA_2(p, n);
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
			initLocExprSingleUse__9biTBaXPz9cezuLjjWw9cSEGw(p, ex, (&a_2));
			T205_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T205_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			T206_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T206_ = amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_728), a_2.r);
			T207_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T207_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T206_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_705));
			T208_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T208_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T207_);
			add__IM4kcMNkkOLJtqdEqSxR8A(T205_, T208_);
		}
		LA203_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89):
	{
		genAsmStmt__QrTB5DOwbDX9bKAW7PNbuJA_6(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		switch ((*(*(*(*p).module).g).config).exc) {
		case ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3):
		{
			genTryGoto__re1pwmyeR32ikwnOC3vvzQ_3(p, n, d);
		}
		break;
		case ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2):
		{
			genTryCpp__re1pwmyeR32ikwnOC3vvzQ_4(p, n, d);
		}
		break;
		default:
		{
			genTrySetjmp__re1pwmyeR32ikwnOC3vvzQ_5(p, n, d);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		genRaiseStmt__QrTB5DOwbDX9bKAW7PNbuJA_7(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	{
		genTypeSection__t9a9a9bxmaOztYOfsfhQUOXXw_3((*p).module, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 117):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 119):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 120):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		genPragma__UtJx89cn0a8CNSWWmaj6raA_11(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 91):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T219_;
		T219_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T219_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		expr__8mAL9ckajemzgfLPfeZVNoQ(p, T219_, d);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
			if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA223_;
			prc = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				NIM_BOOL T227_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T228_;
				T227_ = (NIM_BOOL)0;
				T228_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T228_ = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(prc);
				T227_ = ((*T228_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
				if (!(T227_)) goto LA229_;
				T227_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0));
				LA229_: ;
				if (!T227_) goto LA230_;
				{
					NIM_BOOL T234_;
					NIM_BOOL T235_;
					NIM_BOOL T237_;
					T234_ = (NIM_BOOL)0;
					T235_ = (NIM_BOOL)0;
					T235_ = ((262272 & (*prc).flags) == 128);
					if (T235_) goto LA236_;
					T237_ = (NIM_BOOL)0;
					T237_ = (((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7))&63U)))!=0);
					if (!(T237_)) goto LA238_;
					T237_ = (((*prc).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5))&15U)))!=0);
					LA238_: ;
					T235_ = T237_;
					LA236_: ;
					T234_ = T235_;
					if (T234_) goto LA239_;
					T234_ = ((*prc).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
					LA239_: ;
					if (!T234_) goto LA240_;
					genProc__HbYPOpwLApFuBkISFGrmEQ((*p).module, prc);
				}
				LA240_: ;
			}
			LA230_: ;
		}
		LA223_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		genParForStmt__QrTB5DOwbDX9bKAW7PNbuJA_9(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 157):
	{
		genState__UtJx89cn0a8CNSWWmaj6raA_12(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	{
		(*p).splitDecls += ((NI) 1);
		genGotoState__UtJx89cn0a8CNSWWmaj6raA_13(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 158):
	{
		genBreakState__8mAL9ckajemzgfLPfeZVNoQ_23(p, n, d);
	}
	break;
	default:
	{
		NimStringDesc* T247_;
		T247_ = (NimStringDesc*)0;
		T247_ = rawNewString((reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 25);
appendString(T247_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_426));
appendString(T247_, reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
appendString(T247_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_793));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, (*n).info, T247_, TM__MQdRN7fpbG7rPm4JpVVAhA_794);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genStmts__QrTB5DOwbDX9bKAW7PNbuJA)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t) {
	tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA a;
	NIM_BOOL isPush;
	nimZeroMem((void*)(&a), sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA));
	isPush = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2((*(*(*p).module).g).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 82));
	{
		if (!isPush) goto LA3_;
		pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*(*p).module).g).config, (*t).info, ((NimStringDesc*) NIM_NIL));
	}
	LA3_: ;
	expr__8mAL9ckajemzgfLPfeZVNoQ(p, t, (&a));
	{
		if (!isPush) goto LA7_;
		popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*(*p).module).g).config);
	}
	LA7_: ;
	{
		NimStringDesc* argX60gensym3101_;
		if (!!(((71 &((NU16)1<<((NU)(a.k)&15U)))!=0))) goto LA11_;
		argX60gensym3101_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__MQdRN7fpbG7rPm4JpVVAhA_795);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*p).module).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3101_, TM__MQdRN7fpbG7rPm4JpVVAhA_795);
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__fTdzF9aUiQk4rKtSH3doafQ)(tyObject_TCProc__g7nhmFb7KltrkyRKuP8k2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL* inInitGuard) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						addHcrInitGuards__fTdzF9aUiQk4rKtSH3doafQ(p, child, inInitGuard);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL stmtShouldExecute;
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100));
		if (T10_) goto LA11_;
		T10_ = (((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 20))&31U)))!=0);
		LA11_: ;
		stmtShouldExecute = T10_;
		{
			if (!(*inInitGuard)) goto LA14_;
			{
				if (!stmtShouldExecute) goto LA18_;
				endBlock__0dpuY9coTlraj8JXIe2BzVw(p);
				(*inInitGuard) = NIM_FALSE;
			}
			LA18_: ;
		}
		goto LA12_;
		LA14_: ;
		{
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T25_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T28_;
				NimStringDesc* res;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
				NI T35_;
				if (!!(stmtShouldExecute)) goto LA23_;
				T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T25_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T26_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_8));
				T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T27_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T26_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T25_, T27_);
				T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
				T28_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata(p, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
				res = rawNewString(((NI) 80));
				res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_9));
				{
					if (!!((((*(*(*(*p).module).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA31_;
					res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA31_: ;
				T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T33_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
				T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T34_ = indentLine__5PupwEBrKjp65kTtpnAp9bQ(p, T33_);
				add__IM4kcMNkkOLJtqdEqSxR8A(T28_, T34_);
				T35_ = (NI)0;
				T35_ = startBlockInternal__1ygdb876UM9astcNUXtgUBQ(p);
				(*inInitGuard) = NIM_TRUE;
			}
			LA23_: ;
		}
		LA12_: ;
		genStmts__QrTB5DOwbDX9bKAW7PNbuJA(p, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__mtin0JSWMFuuGt6GFCQvbg)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedN;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!(b == ((tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	m = ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) (b));
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		T7_ = (NIM_BOOL)0;
		T7_ = skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses((*(*m).g).config, n);
		if (T7_) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses((*(*m).g).graph, (*m).module);
		T7_ = !(T9_);
		LA8_: ;
		if (!T7_) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	(*(*m).initProc).options = initProcOptions__qttThLa3xHNEeApwU61sZA(m);
	transformedN = transformStmt__o9bTtoSsaDmuiyVzV15dOyg_2((*(*m).g).graph, (*m).module, n);
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41))&63U)))!=0)) goto LA14_;
		transformedN = injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ((*(*m).g).graph, (*m).module, transformedN);
	}
	LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T18_) goto LA19_;
		addHcrInitGuards__fTdzF9aUiQk4rKtSH3doafQ((*m).initProc, transformedN, (&(*m).inHcrInitGuard));
	}
	goto LA16_;
	LA19_: ;
	{
		genProcBody__IroqGJs3T8by0fVw4XMZJg((*m).initProc, transformedN);
	}
	LA16_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__f8dWe5MYj8ZjDSubo9c6jOg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m;
	tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* mm;
	NI T86_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!(b == ((tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	m = ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) (b));
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA7_;
		{
			NIM_BOOL T11_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3));
			if (!(T11_)) goto LA12_;
			T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T13_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA(graph, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_796));
			T11_ = !((T13_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA12_: ;
			if (!T11_) goto LA14_;
			T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T16_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_796));
			(void)(T16_);
		}
		LA14_: ;
		{
			if (!((384 & (*(*(*m).g).config).globalOptions) == 0)) goto LA19_;
			{
				NI i;
				NI colontmp_;
				NI T22_;
				NI res;
				i = (NI)0;
				colontmp_ = (NI)0;
				T22_ = (((*graph).globalDestructors ? (*graph).globalDestructors->Sup.len : 0)-1);
				colontmp_ = T22_;
				res = colontmp_;
				{
					while (1) {
						if (!(((NI) 0) <= res)) goto LA24;
						i = res;
						add__P8dDSotTW25BkfbyspojGg(n, (*graph).globalDestructors->data[i]);
						res -= ((NI) 1);
					} LA24: ;
				}
			}
		}
		LA19_: ;
	}
	LA7_: ;
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses((*(*m).g).config, n);
		if (!T27_) goto LA28_;
		goto BeforeRet_;
	}
	LA28_: ;
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses(graph, (*m).module);
		if (!T32_) goto LA33_;
		{
			if (!!((n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA37_;
			(*(*m).initProc).options = initProcOptions__qttThLa3xHNEeApwU61sZA(m);
			genProcBody__IroqGJs3T8by0fVw4XMZJg((*m).initProc, n);
		}
		LA37_: ;
		{
			NIM_BOOL T41_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			T41_ = (NIM_BOOL)0;
			T41_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!T41_) goto LA42_;
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_797));
			(void)(T44_);
			{
				if (!(*m).inHcrInitGuard) goto LA47_;
				endBlock__0dpuY9coTlraj8JXIe2BzVw((*m).initProc);
			}
			LA47_: ;
		}
		LA42_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* disp;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA51_;
			{
				NIM_BOOL T55_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T61_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				T55_ = (NIM_BOOL)0;
				T55_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T55_) goto LA56_;
				T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T58_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_285));
				(void)(T58_);
				T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T59_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_289));
				(void)(T59_);
				T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T60_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_297));
				(void)(T60_);
				T61_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T61_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_798));
				(void)(T61_);
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_799));
				(void)(T62_);
			}
			LA56_: ;
			{
				NIM_BOOL T65_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
				T65_ = (NIM_BOOL)0;
				T65_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28)));
				if (!(T65_)) goto LA66_;
				T65_ = !(((*(*(*m).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 1)));
				LA66_: ;
				if (!T65_) goto LA67_;
				T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T69_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_800));
				(void)(T69_);
			}
			LA67_: ;
			{
				NIM_BOOL T72_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T76_;
				T72_ = (NIM_BOOL)0;
				T72_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*m).g).config);
				if (!(T72_)) goto LA73_;
				T72_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28)));
				LA73_: ;
				if (!T72_) goto LA74_;
				T76_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T76_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_801));
				(void)(T76_);
			}
			LA74_: ;
			{
				NI T79_;
				T79_ = ((*(*m).g).forwardedProcs ? (*(*m).g).forwardedProcs->Sup.len : 0);
				if (!(T79_ == ((NI) 0))) goto LA80_;
				(*m).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 5)) & 7);
			}
			LA80_: ;
			disp = generateMethodDispatchers__7t0GJlNQwZyLt0Kz3RhRdw(graph);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
				x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i_2;
					NI colontmp__2;
					NI i_3;
					i_2 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(disp);
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < colontmp__2)) goto LA85;
							i_2 = i_3;
							x = (*disp)._kind_6.sons->data[i_2];
							genProcAux__HbYPOpwLApFuBkISFGrmEQ_4(m, (*x)._kind_4.sym);
							i_3 += ((NI) 1);
						} LA85: ;
					}
				}
			}
		}
		LA51_: ;
	}
	LA33_: ;
	mm = m;
	asgnRef((void**) (&(*(*m).g).modulesClosed), (tySequence__SHVxAqOYtIy7teT1q4s0zQ*) incrSeqV3((TGenericSeq*)((*(*m).g).modulesClosed), (&NTI__SHVxAqOYtIy7teT1q4s0zQ_)));
	T86_ = (*(*m).g).modulesClosed->Sup.len++;
	asgnRef((void**) (&(*(*m).g).modulesClosed->data[T86_]), mm);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI L;
	NI T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__PBGOqkExHgxzX6Rn0nJkYg)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g) {
	{
		while (1) {
			NI T3_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ms;
			tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m;
			T3_ = ((*g).forwardedProcs ? (*g).forwardedProcs->Sup.len : 0);
			if (!(((NI) 0) < T3_)) goto LA2;
			prc = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*g).forwardedProcs));
			ms = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(prc);
			m = (*g).modules->data[(*ms).position];
			{
				NimStringDesc* T8_;
				if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0)) goto LA6_;
				T8_ = (NimStringDesc*)0;
				T8_ = rawNewString(((*(*prc).name).s ? (*(*prc).name).s->Sup.len : 0) + 17);
appendString(T8_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_802));
appendString(T8_, (*(*prc).name).s);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*m).g).config, (*prc).info, T8_, TM__MQdRN7fpbG7rPm4JpVVAhA_803);
			}
			LA6_: ;
			genProcNoForward__HbYPOpwLApFuBkISFGrmEQ_3(m, prc);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSomeNameForModule__JBd7XGjgK9ab0QMtKIFvb8Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T6_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* T5_;
		if (!((49152 & (*m).flags) == 0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*(*m).owner).name).s);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T5_);
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
	}
	LA3_: ;
	T6_ = (NimStringDesc*)0;
	T6_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*m).name).s);
	add__yG4AKzsBRS1W4MANDlXQeg(&result, T6_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getSomeInitName__E8VUcJLPfNp8S9aZKgHijew)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* suffix) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!!(T3_)) goto LA4_;
		result = getSomeNameForModule__JBd7XGjgK9ab0QMtKIFvb8Q((*m).module);
	}
	LA4_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, suffix);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getInitName__ao6gUnuVfQLtZ89c4kaIKfg_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA3_;
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_804));
	}
	goto LA1_;
	LA3_: ;
	{
		result = getSomeInitName__E8VUcJLPfNp8S9aZKgHijew(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_805));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getHcrInitName__ao6gUnuVfQLtZ89c4kaIKfg_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = getSomeInitName__E8VUcJLPfNp8S9aZKgHijew(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_819));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, hcrGetProcLoadCode__uWPA1lTRrPufWdliMF9aGrg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NimStringDesc* sym, NimStringDesc* prefix, NimStringDesc* handle, NimStringDesc* getProcFunc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
	NimStringDesc* extname;
	NimStringDesc* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__duFhZXIIlrbrM62cWjNekg T10_;
	NimStringDesc* T11_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	prc = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*m).g).graph, sym);
	fillProcLoc__t9a9a9bxmaOztYOfsfhQUOXXw(m, (*(*prc).ast)._kind_6.sons->data[((NI) 0)]);
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString((prefix ? prefix->Sup.len : 0) + (sym ? sym->Sup.len : 0) + 0);
appendString(T1_, prefix);
appendString(T1_, sym);
	extname = T1_;
	tmp = mangleDynLibProc__MkmvPNwLUVhzodPsMjdbJw(prc);
	asgnRef((void**) (&(*prc).loc.r), tmp);
	asgnRef((void**) (&(*(*prc).typ).sym), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	{
		NIM_BOOL T4_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*m).declaredThings), (*prc).Sup.id);
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = (*prc).loc.r;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = t__XNOXh7uniWNgiq58C9bW49awcgen((*prc).loc);
		T7_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, T8_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___E9bSTz8DQ4tgiLV9avQjFgFA(T7_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 10))- 0], T9_);
	}
	LA5_: ;
	nimZeroMem((void*)T10_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
	T10_[0] = tmp;
	T10_[1] = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*prc).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	T10_[2] = rope__yShmEg9cffWxI7s5XzEKBow(getProcFunc);
	T10_[3] = rope__yShmEg9cffWxI7s5XzEKBow(handle);
	T11_ = (NimStringDesc*)0;
	T11_ = rawNewString((prefix ? prefix->Sup.len : 0) + (sym ? sym->Sup.len : 0) + 0);
appendString(T11_, prefix);
appendString(T11_, sym);
	T10_[4] = makeCString__vQJydtKy4Nf6bXPYtbmjtg(T11_);
	result = percent___3CQpPXVDiNqC3jKO8Juliw(T10_, 5);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getDatInitName__ao6gUnuVfQLtZ89c4kaIKfg_6)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = getSomeInitName__E8VUcJLPfNp8S9aZKgHijew(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_824));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__7ll08CGQoDzh9cxhZCroU4w_2)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NIM_BOOL moduleDatInitRequired;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* prc;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	NimStringDesc* T2_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T19_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
	moduleDatInitRequired = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T2_ = (NimStringDesc*)0;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T5_) goto LA6_;
		T2_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_806));
	}
	goto LA3_;
	LA6_: ;
	{
		T2_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_807));
	}
	LA3_: ;
	T1_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T2_);
	T1_[1] = getDatInitName__ao6gUnuVfQLtZ89c4kaIKfg_6(m);
	prc = percent___2Ixv9aZ9bvpNaVAVzYBJlUPg(T1_, 2);
	genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_808), ((NI) 999999), (*(*m).g).config);
	{
		tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg i;
		NI res;
		i = (tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg)0;
		res = ((NI) 14);
		{
			while (1) {
				if (!(res <= ((NI) 18))) goto LA11;
				i = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) (res));
				{
					NI T14_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
					T14_ = (NI)0;
					T14_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(i)- 0]);
					if (!!((T14_ == ((NI) 0)))) goto LA15_;
					moduleDatInitRequired = NIM_TRUE;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = genSectionStart__KYNwN8RXzjqIkzxFSwHsxw(i, (*(*m).g).config);
					add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T17_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*m).s[(i)- 0]);
					T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T18_ = genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2(i, (*(*m).g).config);
					add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T18_);
				}
				LA15_: ;
				res += ((NI) 1);
			} LA11: ;
		}
	}
	nimZeroMem((void*)T19_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T20_ = percent___4L62Yp9bLO2ZDcvBG9bSvP9bw(T19_, 0);
	add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T20_);
	{
		if (!moduleDatInitRequired) goto LA23_;
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 13))- 0], prc);
	}
	LA23_: ;
}
static N_INLINE(NU64, hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes)(NU64 a, NU64 b) {
	NU64 result;
	NU64 aH;
	NU64 aL;
	NU64 bH;
	NU64 bL;
	NU64 rHH;
	NU64 rHL;
	NU64 rLH;
	NU64 rLL;
	NU64 t;
	NU64 c;
	NU64 lo;
	NU64 T6_;
	NU64 hi;
{	result = (NU64)0;
	aH = (NU64)((NU64)(a) >> (NU64)(((NI) 32)));
	aL = (NU64)(a & 4294967295ULL);
	bH = (NU64)((NU64)(b) >> (NU64)(((NI) 32)));
	bL = (NU64)(b & 4294967295ULL);
	rHH = (NU64)((NU64)(aH) * (NU64)(bH));
	rHL = (NU64)((NU64)(aH) * (NU64)(bL));
	rLH = (NU64)((NU64)(aL) * (NU64)(bH));
	rLL = (NU64)((NU64)(aL) * (NU64)(bL));
	t = (NU64)((NU64)(rLL) + (NU64)((NU64)((NU64)(rHL) << (NU64)(((NI) 32)))));
	{
		if (!((NU64)(t) < (NU64)(rLL))) goto LA3_;
		c = 1ULL;
	}
	goto LA1_;
	LA3_: ;
	{
		c = 0ULL;
	}
	LA1_: ;
	lo = (NU64)((NU64)(t) + (NU64)((NU64)((NU64)(rLH) << (NU64)(((NI) 32)))));
	T6_ = (NU64)0;
	{
		if (!((NU64)(lo) < (NU64)(t))) goto LA9_;
		T6_ = 1ULL;
	}
	goto LA7_;
	LA9_: ;
	{
		T6_ = 0ULL;
	}
	LA7_: ;
	c += T6_;
	hi = (NU64)((NU64)((NU64)((NU64)((NU64)((NU64)(rHH) + (NU64)((NU64)((NU64)(rHL) >> (NU64)(((NI) 32)))))) + (NU64)((NU64)((NU64)(rLH) >> (NU64)(((NI) 32)))))) + (NU64)(c));
	result = (NU64)(hi ^ lo);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLo__wWqo9alrSZddOyokrApfNaQhashes)(NU64 a, NU64 b) {
	NU64 result;
	result = (NU64)0;
	result = hiXorLoFallback64__wWqo9alrSZddOyokrApfNaQ_2hashes(a, b);
	return result;
}
static N_INLINE(NI, hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes)(NU64 x) {
	NI result;
	NU64 T1_;
	NU64 T2_;
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__wWqo9alrSZddOyokrApfNaQhashes(11562461410679940143ULL, (NU64)(x ^ 16646288086500911323ULL));
	T2_ = (NU64)0;
	T2_ = hiXorLo__wWqo9alrSZddOyokrApfNaQhashes(T1_, 16952864883938283885ULL);
	result = ((NI) (T2_));
	return result;
}
static N_INLINE(NI, hash__ixIcN23Rzgwj4rjH9cMHDWQhashes)(NI32 x) {
	NI result;
	result = (NI)0;
	result = hashWangYi1__AN9c8V1UY1ZE7b8ldNRftRQhashes(((NU64) (x)));
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__5Qpmu5QqwDY0esVXn6wf7wtables)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
static N_INLINE(NI, nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables)(NI h, NI maxHash) {
	NI result;
	result = (NI)0;
	result = (NI)((NI)(h + ((NI) 1)) & maxHash);
	return result;
}
static N_INLINE(NI, rawGet__QnNqXOulpiE3rTDm0rj6bgtables)(tyObject_Table__fdKWDDO1P17zvuQPReVgRA t, NI32 key, NI* hc) {
	NI result;
	NI h;
	NI T10_;
{	result = (NI)0;
	(*hc) = hash__ixIcN23Rzgwj4rjH9cMHDWQhashes(key);
	{
		if (!((*hc) == ((NI) 0))) goto LA3_;
		(*hc) = ((NI) 314159265);
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (t.data ? t.data->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		result = ((NI) -1);
		goto BeforeRet_;
	}
	LA8_: ;
	T10_ = ((t.data ? t.data->Sup.len : 0)-1);
	h = (NI)((*hc) & T10_);
	{
		while (1) {
			NIM_BOOL T13_;
			NI T20_;
			T13_ = (NIM_BOOL)0;
			T13_ = isFilled__5Qpmu5QqwDY0esVXn6wf7wtables(t.data->data[h].Field0);
			if (!T13_) goto LA12;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = (t.data->data[h].Field0 == (*hc));
				if (!(T16_)) goto LA17_;
				T16_ = (t.data->data[h].Field1 == key);
				LA17_: ;
				if (!T16_) goto LA18_;
				result = h;
				goto BeforeRet_;
			}
			LA18_: ;
			T20_ = ((t.data ? t.data->Sup.len : 0)-1);
			h = nextTry__rkF6R1GhqjFh3qSAPaT2Cwtables(h, T20_);
		} LA12: ;
	}
	result = (NI)(((NI) -1) - h);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__9aldr9cciNpmwLn9bc4Nq2PGQ)(tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g, tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* init;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* datInit;
{	init = getInitName__ao6gUnuVfQLtZ89c4kaIKfg_4(m);
	datInit = getDatInitName__ao6gUnuVfQLtZ89c4kaIKfg_6(m);
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* hcrModuleMeta;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* systemModulePath;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mainModulePath;
		NI hcX60gensym6184_;
		NI indexX60gensym6184_;
		NIM_BOOL hasKeyX60gensym6184_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T27_;
		tyArray__qtqsWM5aXmcpMIVmvq3kAA T28_;
		NimStringDesc* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		hcrModuleMeta = percent___k9bgPIs43oLgxnk1l4TNQaw(T6_, 0);
		systemModulePath = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*(*g).modules->data[(*(*(*g).graph).config).m.systemFileIdx]).module);
		mainModulePath = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*m).module);
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA9_;
			nimZeroMem((void*)T11_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T11_[0] = systemModulePath;
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = percent___5MqeIopvDuA9aozxL79cQ88g(T11_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&hcrModuleMeta, T12_);
		}
		LA9_: ;
		hcX60gensym6184_ = (NI)0;
		indexX60gensym6184_ = rawGet__QnNqXOulpiE3rTDm0rj6bgtables((*(*g).graph).importDeps, ((NI32) ((*(*m).module).position)), (&hcX60gensym6184_));
		hasKeyX60gensym6184_ = (((NI) 0) <= indexX60gensym6184_);
		{
			tySequence__48JTohSgTy339bRxHzUD8KA** deps;
			if (!hasKeyX60gensym6184_) goto LA15_;
			deps = (&(*(*g).graph).importDeps.data->data[indexX60gensym6184_].Field2);
			{
				NI32* curr;
				NI i;
				NI L;
				NI T18_;
				curr = (NI32*)0;
				i = ((NI) 0);
				T18_ = ((*deps) ? (*deps)->Sup.len : 0);
				L = T18_;
				{
					while (1) {
						tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
						if (!(i < L)) goto LA20;
						curr = (&(*deps)->data[i]);
						nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
						T21_[0] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*(*g).modules->data[(*curr)]).module);
						T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T22_ = percent___5MqeIopvDuA9aozxL79cQ88g(T21_, 1);
						add__IM4kcMNkkOLJtqdEqSxR8A(&hcrModuleMeta, T22_);
						i += ((NI) 1);
					} LA20: ;
				}
			}
		}
		LA15_: ;
		nimZeroMem((void*)T23_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = percent___Zp9bMZDO5tEkvVLTxiKsBkA(T23_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&hcrModuleMeta, T24_);
		nimZeroMem((void*)T25_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = percent___j5FZyaqnqjc2dcsUkAp28Q(T25_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&hcrModuleMeta, T26_);
		nimZeroMem((void*)T27_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		nimZeroMem((void*)T28_, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
		sigHash__mSn9a9aX0NBzWqerwPW0qRww_2((*m).module, T28_);
		T29_ = (NimStringDesc*)0;
		T29_ = dollar___0A9bslyIJ49bWrftLGh13rvg(T28_);
		T27_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T29_);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = percent___EbvvG9awBeRKzx8xuBIb7TA(T27_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&hcrModuleMeta, T30_);
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T35_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T37_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T39_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T41_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T49_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T51_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T53_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* osModulePath;
			NimStringDesc* T55_;
			NimStringDesc* T56_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T57_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T59_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T61_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA33_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, hcrModuleMeta);
			nimZeroMem((void*)T35_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T36_ = percent___9a8besSQa09cOOt9b9cgdVwY9aQ(T35_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T36_);
			nimZeroMem((void*)T37_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T37_[0] = init;
			T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T38_ = percent___oVKF7oq59cRGAaMpvWzNWbw(T37_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T38_);
			nimZeroMem((void*)T39_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T39_[0] = datInit;
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = percent___oVKF7oq59cRGAaMpvWzNWbw(T39_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T40_);
			nimZeroMem((void*)T41_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T41_[0] = getHcrInitName__ao6gUnuVfQLtZ89c4kaIKfg_5(m);
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = percent___7ru3bwKuSx4Sc8ilsBmX3g(T41_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T42_);
			nimZeroMem((void*)T43_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = percent___MDIdJXTVckPj57aO7LMVgw(T43_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T44_);
			nimZeroMem((void*)T45_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T45_[0] = init;
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = percent___vQDE0VOBftnrpkVsM9cme4w(T45_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModInit, T46_);
			nimZeroMem((void*)T47_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T47_[0] = mainModulePath;
			T47_[1] = systemModulePath;
			T47_[2] = datInit;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = percent___9bmR9bM9b0qqEqU0QJKnmLQnA(T47_, 3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).otherModsInit, T48_);
			nimZeroMem((void*)T49_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T49_[0] = getHcrInitName__ao6gUnuVfQLtZ89c4kaIKfg_5(m);
			T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T50_ = percent___88tWbH31SmOWJjgJ7RnfHA(T49_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T50_);
			nimZeroMem((void*)T51_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T51_[0] = mainModulePath;
			T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T52_ = percent___t1CB59bEwlxfHZhNwNNz1bw(T51_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T52_);
			nimZeroMem((void*)T53_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T54_ = percent___YbLM7ZajsWOFLl4iSo0Krg(T53_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T54_);
			T55_ = (NimStringDesc*)0;
			T55_ = dollar___mZ66tEveFIQokq3arf8Klw(systemModulePath);
			T56_ = (NimStringDesc*)0;
			T56_ = nsuReplaceStr(T55_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_825), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_826));
			osModulePath = rope__yShmEg9cffWxI7s5XzEKBow(T56_);
			nimZeroMem((void*)T57_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T57_[0] = osModulePath;
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = percent___t1CB59bEwlxfHZhNwNNz1bw(T57_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T58_);
			add__yG4AKzsBRS1W4MANDlXQeg(&(*g).mainDatInit, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_827));
			add__yG4AKzsBRS1W4MANDlXQeg(&(*g).mainDatInit, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_828));
			nimZeroMem((void*)T59_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T59_[0] = osModulePath;
			T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T60_ = percent___rH7Ns9bqAnnfkukwBIlz9bKg(T59_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T60_);
			nimZeroMem((void*)T61_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T61_[0] = osModulePath;
			T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T62_ = percent___zx9ctq3Ffe9aysjoWhZOzevQ(T61_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T62_);
			add__yG4AKzsBRS1W4MANDlXQeg(&(*g).mainDatInit, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_829));
			add__yG4AKzsBRS1W4MANDlXQeg(&(*g).mainDatInit, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_830));
		}
		goto LA31_;
		LA33_: ;
		{
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], hcrModuleMeta);
		}
		LA31_: ;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NI T66_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T69_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T71_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
		T66_ = (NI)0;
		T66_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 13))- 0]);
		if (!(((NI) 0) < T66_)) goto LA67_;
		nimZeroMem((void*)T69_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T69_[0] = datInit;
		T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T70_ = percent___T9a21DAzFCa3OqRooKKtkqw(T69_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T70_);
		nimZeroMem((void*)T71_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T71_[0] = datInit;
		T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T72_ = percent___vQDE0VOBftnrpkVsM9cme4w(T71_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T72_);
	}
	LA67_: ;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA75_;
		{
			NIM_BOOL T79_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T84_;
			T79_ = (NIM_BOOL)0;
			T79_ = emulatedThreadVars__7uEG6ZwO4OOj3nQvIat2mwcgen((*(*m).g).config);
			if (!(T79_)) goto LA80_;
			T79_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28)));
			LA80_: ;
			if (!T79_) goto LA81_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
			T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T83_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_801));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T83_);
			res = resizeString(res, 4);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_831));
			T84_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T84_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T84_);
		}
		LA81_: ;
		{
			NIM_BOOL T87_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
			T87_ = (NIM_BOOL)0;
			T87_ = !(((*(*(*m).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28)));
			if (!(T87_)) goto LA88_;
			T87_ = !(((50 &((NU16)1<<((NU)((*(*(*m).g).config).selectedGC)&15U)))!=0));
			LA88_: ;
			if (!T87_) goto LA89_;
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
			T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T91_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_800));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T91_);
			res_2 = resizeString(res_2, 18);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_832));
			T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T92_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, T92_);
		}
		LA89_: ;
	}
	LA75_: ;
	{
		NI T95_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T98_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T99_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* initCall;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T100_;
		T95_ = (NI)0;
		T95_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0]);
		if (!(((NI) 0) < T95_)) goto LA96_;
		nimZeroMem((void*)T98_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T98_[0] = init;
		T99_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T99_ = percent___T9a21DAzFCa3OqRooKKtkqw(T98_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModProcs, T99_);
		nimZeroMem((void*)T100_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T100_[0] = init;
		initCall = percent___vQDE0VOBftnrpkVsM9cme4w(T100_, 1);
		{
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA103_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainModInit, initCall);
		}
		goto LA101_;
		LA103_: ;
		{
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA106_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).mainDatInit, initCall);
		}
		goto LA101_;
		LA106_: ;
		{
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*g).otherModsInit, initCall);
		}
		LA101_: ;
	}
	LA96_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__7ll08CGQoDzh9cxhZCroU4w)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NIM_BOOL moduleInitRequired;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* initname;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* prc;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	NimStringDesc* T2_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T115_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T116_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T225_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T226_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T227_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T228_;
	moduleInitRequired = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
	initname = getInitName__ao6gUnuVfQLtZ89c4kaIKfg_4(m);
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T2_ = (NimStringDesc*)0;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T5_) goto LA6_;
		T2_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_806));
	}
	goto LA3_;
	LA6_: ;
	{
		T2_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_807));
	}
	LA3_: ;
	T1_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T2_);
	T1_[1] = initname;
	prc = percent___2Ixv9aZ9bvpNaVAVzYBJlUPg(T1_, 2);
	genCLineDir__W2V1U5l2z2M9c2i5Phjz9cow(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_808), ((NI) 999999), (*(*m).g).config);
	{
		if (!(((NI) 0) < (*m).typeNodes)) goto LA11_;
		{
			NIM_BOOL T15_;
			NimStringDesc* res;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
			NimStringDesc* res_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			T15_ = (NIM_BOOL)0;
			T15_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
			if (!T15_) goto LA16_;
			res = rawNewString(((NI) 80));
			res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_98));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T18_);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_809));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), (*m).typeNodesName);
			res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_350));
			T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T19_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T19_);
			res_2 = rawNewString(((NI) 80));
			res_2 = resizeString(res_2, 19);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_810));
			T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T20_ = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*m).module);
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), T20_);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_378));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*m).typeNodesName);
			res_2 = resizeString(res_2, 1);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_3));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_2), ((NI64) ((*m).typeNodes)));
			res_2 = resizeString(res_2, 22);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_811));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_2), ((NI64) ((*m).typeNodes)));
			res_2 = resizeString(res_2, 17);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_812));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*m).typeNodesName);
			res_2 = resizeString(res_2, 3);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_705));
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T21_);
		}
		goto LA13_;
		LA16_: ;
		{
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 7);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_98));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), T23_);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), (*m).typeNodesName);
			res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
			cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_3), ((NI64) ((*m).typeNodes)));
			res_3 = resizeString(res_3, 2);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_189));
			{
				if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA26_;
				res_3 = resizeString(res_3, 1);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
			}
			LA26_: ;
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T28_);
		}
		LA13_: ;
	}
	LA11_: ;
	{
		NimStringDesc* res_4;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
		if (!(((NI) 0) < (*m).nimTypes)) goto LA31_;
		res_4 = rawNewString(((NI) 80));
		res_4 = resizeString(res_4, 7);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_23));
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_97));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), T33_);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_13));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*m).nimTypesName);
		res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_120));
		cgFormatValue__RNvA2HiiC5vvtIhzsLpc8g((&res_4), ((NI64) ((*m).nimTypes)));
		res_4 = resizeString(res_4, 2);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_189));
		{
			if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA36_;
			res_4 = resizeString(res_4, 1);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
		}
		LA36_: ;
		T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T38_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 14))- 0], T38_);
	}
	LA31_: ;
	{
		NIM_BOOL T41_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T44_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
		T41_ = (NIM_BOOL)0;
		T41_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T41_) goto LA42_;
		nimZeroMem((void*)T44_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T44_[0] = getModuleDllPath__RaNE9b8A430I9bfpgZmdrC1w_3(m, (*m).module);
		T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T45_ = percent___HoXSbgR7plMG7Fef0fcy9aw(T44_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T45_);
	}
	LA42_: ;
	{
		NIM_BOOL T48_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T49_;
		NI T50_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T52_;
		NI T53_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T58_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T113_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
		T48_ = (NIM_BOOL)0;
		T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T49_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		T50_ = (NI)0;
		T50_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T49_));
		T48_ = (((NI) 0) < T50_);
		if (T48_) goto LA51_;
		T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T52_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T53_ = (NI)0;
		T53_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T52_));
		T48_ = (((NI) 0) < T53_);
		LA51_: ;
		if (!T48_) goto LA54_;
		nimZeroMem((void*)T56_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = percent___H1Ma2EXqegHnMqzJZ4SA1g(T56_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T57_);
		nimZeroMem((void*)T58_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T59_ = percent___jpXTCDNVjIi5r4hbHN5SVQ(T58_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T59_);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T62_;
			NI T63_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T70_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T71_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
			T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T62_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			T63_ = (NI)0;
			T63_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T62_));
			if (!(((NI) 0) < T63_)) goto LA64_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA68_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
			}
			LA68_: ;
			T70_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T70_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T70_);
			T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T71_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T71_));
			T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T72_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T72_);
			{
				if (!NIM_FALSE) goto LA75_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
			}
			LA75_: ;
		}
		LA64_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T79_;
			NI T80_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T88_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T89_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
			T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T79_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			T80_ = (NI)0;
			T80_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T79_));
			if (!(((NI) 0) < T80_)) goto LA81_;
			moduleInitRequired = NIM_TRUE;
			{
				NIM_BOOL T85_;
				T85_ = (NIM_BOOL)0;
				T85_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T85_) goto LA86_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
			}
			LA86_: ;
			T88_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T88_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T88_);
			T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T89_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T89_));
			T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T90_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T90_);
			{
				NIM_BOOL T93_;
				T93_ = (NIM_BOOL)0;
				T93_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T93_) goto LA94_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
			}
			LA94_: ;
		}
		LA81_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T98_;
			NI T99_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T107_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T108_;
			T98_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T98_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			T99_ = (NI)0;
			T99_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T98_));
			if (!(((NI) 0) < T99_)) goto LA100_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA104_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
			}
			LA104_: ;
			T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T106_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T106_);
			T107_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T107_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).preInitProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T107_));
			T108_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T108_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T108_);
			{
				if (!NIM_FALSE) goto LA111_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
			}
			LA111_: ;
		}
		LA100_: ;
		nimZeroMem((void*)T113_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T114_ = percent___g9b9arp3BWCGRHDe21SJso6w(T113_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T114_);
	}
	LA54_: ;
	nimZeroMem((void*)T115_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T116_ = percent___H1Ma2EXqegHnMqzJZ4SA1g(T115_, 0);
	add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T116_);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T119_;
		NI T120_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T127_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T128_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T129_;
		T119_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T119_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		T120_ = (NI)0;
		T120_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T119_));
		if (!(((NI) 0) < T120_)) goto LA121_;
		moduleInitRequired = NIM_TRUE;
		{
			if (!NIM_FALSE) goto LA125_;
			add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
		}
		LA125_: ;
		T127_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T127_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0), (*(*m).g).config);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T127_);
		T128_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T128_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0));
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T128_));
		T129_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T129_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 0), (*(*m).g).config);
		add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T129_);
		{
			if (!NIM_FALSE) goto LA132_;
			add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
		}
		LA132_: ;
	}
	LA121_: ;
	{
		NIM_BOOL T136_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T137_;
		NI T138_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T140_;
		NI T141_;
		T136_ = (NIM_BOOL)0;
		T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T137_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
		T138_ = (NI)0;
		T138_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T137_));
		T136_ = (((NI) 0) < T138_);
		if (T136_) goto LA139_;
		T140_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
		T140_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
		T141_ = (NI)0;
		T141_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T140_));
		T136_ = (((NI) 0) < T141_);
		LA139_: ;
		if (!T136_) goto LA142_;
		moduleInitRequired = NIM_TRUE;
		{
			NIM_BOOL T146_;
			T146_ = (NIM_BOOL)0;
			T146_ = (((*(*m).initProc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0);
			if (!(T146_)) goto LA147_;
			T146_ = !((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 2))&7U)))!=0));
			LA147_: ;
			if (!T146_) goto LA148_;
			(*m).flags |= ((NU8)1)<<((((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 2)) & 7);
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T154_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T155_;
				if (!!((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 0))&7U)))!=0))) goto LA152_;
				procname = makeCString__vQJydtKy4Nf6bXPYtbmjtg((*(*(*m).module).name).s);
				T154_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T154_ = quotedFilename__2Kbe7lBq9cqJa8J9cn4WRepg((*(*m).g).config, (*(*m).module).info);
				T155_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T155_ = initFrame__hSB0mXJGcFil9bvrhp0Qm5g((*m).initProc, procname, T154_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T155_);
			}
			goto LA150_;
			LA152_: ;
			{
				tyArray__qTjAvTvKF9anytN1At69aJMQ T157_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T158_;
				nimZeroMem((void*)T157_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T158_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T158_ = percent___jpXTCDNVjIi5r4hbHN5SVQ(T157_, 0);
				add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T158_);
			}
			LA150_: ;
		}
		LA148_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T161_;
			NI T162_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T170_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T171_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T172_;
			T161_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T161_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			T162_ = (NI)0;
			T162_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T161_));
			if (!(((NI) 0) < T162_)) goto LA163_;
			moduleInitRequired = NIM_TRUE;
			{
				NIM_BOOL T167_;
				T167_ = (NIM_BOOL)0;
				T167_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T167_) goto LA168_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
			}
			LA168_: ;
			T170_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T170_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T170_);
			T171_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T171_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1));
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T171_));
			T172_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T172_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 1), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T172_);
			{
				NIM_BOOL T175_;
				T175_ = (NIM_BOOL)0;
				T175_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
				if (!T175_) goto LA176_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
			}
			LA176_: ;
		}
		LA163_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T180_;
			NI T181_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T188_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** T189_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T190_;
			T180_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T180_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			T181_ = (NI)0;
			T181_ = len__9b0YRltzV3kNSE9aQTsG82wg((*T180_));
			if (!(((NI) 0) < T181_)) goto LA182_;
			moduleInitRequired = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA186_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_813));
			}
			LA186_: ;
			T188_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T188_ = genSectionStart__otaTb0ytiYCWgsXTIvijfg(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T188_);
			T189_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA**)0;
			T189_ = s__kOyJGmZMM2tMgCKSrvUE3gcgendata((*m).initProc, ((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2));
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, (*T189_));
			T190_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T190_ = genSectionEnd__otaTb0ytiYCWgsXTIvijfg_2(((tyEnum_TCProcSection__0r9aIOfveOcxZqJ7OwbI2gg) 2), (*(*m).g).config);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T190_);
			{
				if (!NIM_FALSE) goto LA193_;
				add__yG4AKzsBRS1W4MANDlXQeg(&prc, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_814));
			}
			LA193_: ;
		}
		LA182_: ;
		{
			tyArray__qTjAvTvKF9anytN1At69aJMQ T199_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T200_;
			if (!(((*(*m).initProc).flags &((NU8)1<<((NU)(((tyEnum_TCProcFlag__LgBeaca7tT1nUR7RL1RjPQ) 0))&7U)))!=0)) goto LA197_;
			nimZeroMem((void*)T199_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T200_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T200_ = percent___Mb9ccCVvEQ2RaqUK5tbPQ2w(T199_, 0);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T200_);
		}
		LA197_: ;
		{
			NIM_BOOL T203_;
			T203_ = (NIM_BOOL)0;
			T203_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
			if (!(T203_)) goto LA204_;
			T203_ = ((*(*(*m).g).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 3));
			LA204_: ;
			if (!T203_) goto LA205_;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T209_;
				NimStringDesc* res_5;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T212_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T217_;
				T209_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T209_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*m).g).graph, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_796));
				if (!!((T209_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA210_;
				res_5 = rawNewString(((NI) 80));
				res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
				T212_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T212_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg(m, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_796));
				cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), T212_);
				res_5 = resizeString(res_5, 3);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_268));
				{
					if (!!((((*(*(*m).g).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0))) goto LA215_;
					res_5 = resizeString(res_5, 1);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
				}
				LA215_: ;
				T217_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T217_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
				add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T217_);
			}
			LA210_: ;
		}
		LA205_: ;
		{
			NIM_BOOL T220_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T224_;
			T220_ = (NIM_BOOL)0;
			T220_ = (((*(*m).initProc).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0);
			if (!(T220_)) goto LA221_;
			T220_ = !((((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 0))&7U)))!=0));
			LA221_: ;
			if (!T220_) goto LA222_;
			T224_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T224_ = deinitFrame__3AsTOpq9crZUYBL9aD1lXBng_3((*m).initProc);
			add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T224_);
		}
		LA222_: ;
	}
	LA142_: ;
	nimZeroMem((void*)T225_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T226_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T226_ = percent___g9b9arp3BWCGRHDe21SJso6w(T225_, 0);
	add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T226_);
	nimZeroMem((void*)T227_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T228_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T228_ = percent___4L62Yp9bLO2ZDcvBG9bSvP9bw(T227_, 0);
	add__IM4kcMNkkOLJtqdEqSxR8A(&prc, T228_);
	{
		NIM_BOOL T231_;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ* procsToLoad;
		NimStringDesc* T234_;
		NimStringDesc* T235_;
		NimStringDesc* T236_;
		NimStringDesc* T237_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T238_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T239_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T253_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T254_;
		T231_ = (NIM_BOOL)0;
		T231_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T231_) goto LA232_;
		procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) newSeq((&NTI__sM4lkSb7zS6F7OVMvW9cffQ_), 4);
		T234_ = (NimStringDesc*)0;
		T234_ = procsToLoad->data[0]; procsToLoad->data[0] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_815));
		if (T234_) nimGCunrefNoCycle(T234_);
		T235_ = (NimStringDesc*)0;
		T235_ = procsToLoad->data[1]; procsToLoad->data[1] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_816));
		if (T235_) nimGCunrefNoCycle(T235_);
		T236_ = (NimStringDesc*)0;
		T236_ = procsToLoad->data[2]; procsToLoad->data[2] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_817));
		if (T236_) nimGCunrefNoCycle(T236_);
		T237_ = (NimStringDesc*)0;
		T237_ = procsToLoad->data[3]; procsToLoad->data[3] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_818));
		if (T237_) nimGCunrefNoCycle(T237_);
		nimZeroMem((void*)T238_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T238_[0] = getHcrInitName__ao6gUnuVfQLtZ89c4kaIKfg_5(m);
		T239_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T239_ = percent___MCSdS9cTdQvttqiM9azLzkDg(T238_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], T239_);
		{
			NI T244_;
			NimStringDesc* T245_;
			NI T246_;
			NimStringDesc* T247_;
			if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA242_;
			procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(procsToLoad), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
			T244_ = procsToLoad->Sup.len++;
			T245_ = (NimStringDesc*)0;
			T245_ = procsToLoad->data[T244_]; procsToLoad->data[T244_] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_820));
			if (T245_) nimGCunrefNoCycle(T245_);
			procsToLoad = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(procsToLoad), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
			T246_ = procsToLoad->Sup.len++;
			T247_ = (NimStringDesc*)0;
			T247_ = procsToLoad->data[T246_]; procsToLoad->data[T246_] = copyStringRC1(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_821));
			if (T247_) nimGCunrefNoCycle(T247_);
		}
		LA242_: ;
		{
			NimStringDesc** curr;
			NI i;
			NI L;
			NI T249_;
			curr = (NimStringDesc**)0;
			i = ((NI) 0);
			T249_ = (procsToLoad ? procsToLoad->Sup.len : 0);
			L = T249_;
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T252_;
					if (!(i < L)) goto LA251;
					curr = (&procsToLoad->data[i]);
					T252_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T252_ = hcrGetProcLoadCode__uWPA1lTRrPufWdliMF9aGrg(m, (*curr), ((NimStringDesc*) NIM_NIL), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_822), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_823));
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], T252_);
					i += ((NI) 1);
				} LA251: ;
			}
		}
		nimZeroMem((void*)T253_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T254_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T254_ = percent___4L62Yp9bLO2ZDcvBG9bSvP9bw(T253_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], T254_);
	}
	LA232_: ;
	{
		NIM_CHAR i_2;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* el;
		NIM_CHAR i_3;
		i_2 = (NIM_CHAR)0;
		el = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		i_3 = 48;
		{
			if (!((NU8)(((NIM_CHAR) (((NU8)(i_3))))) <= (NU8)(57))) goto LA258_;
			{
				while (1) {
					i_2 = i_3;
					el = (*m).extensionLoaders[(((NU8)(i_3)))- 48];
					{
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* ex;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T266_;
						if (!!((el == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA264_;
						nimZeroMem((void*)T266_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T266_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((NI)(((NU8)(i_2)) - ((NI) 48)))));
						T266_[1] = el;
						ex = percent___w50CkyHBltcyR8rWxttZCg(T266_, 2);
						moduleInitRequired = NIM_TRUE;
						add__IM4kcMNkkOLJtqdEqSxR8A(&prc, ex);
					}
					LA264_: ;
					{
						if (!((NU8)(57) <= (NU8)(((NIM_CHAR) (((NU8)(i_3))))))) goto LA269_;
						goto LA260;
					}
					LA269_: ;
					i_3 += ((NI) 1);
				}
			} LA260: ;
		}
		LA258_: ;
	}
	{
		NIM_BOOL T273_;
		T273_ = (NIM_BOOL)0;
		T273_ = moduleInitRequired;
		if (T273_) goto LA274_;
		T273_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
		LA274_: ;
		if (!T273_) goto LA275_;
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], prc);
	}
	LA275_: ;
	genDatInitCode__7ll08CGQoDzh9cxhZCroU4w_2(m);
	{
		NIM_BOOL T279_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T282_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T283_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T284_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T285_;
		T279_ = (NIM_BOOL)0;
		T279_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		if (!T279_) goto LA280_;
		nimZeroMem((void*)T282_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T283_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T283_ = percent___fmEfDTfNDkVDxWi9c0O6D2g(T282_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], T283_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], (*m).hcrCreateTypeInfosProc);
		nimZeroMem((void*)T284_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T285_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T285_ = percent___4L62Yp9bLO2ZDcvBG9bSvP9bw(T284_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0], T285_);
	}
	LA280_: ;
	registerModuleToMain__9aldr9cciNpmwLn9bc4Nq2PGQ((*m).g, m);
}
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__MFyPdYFFCqzDX9cGGcC0rbA)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check) {
	tyArray__qtqsWM5aXmcpMIVmvq3kAA sig;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	nimZeroMem((void*)sig, sizeof(tyArray__qtqsWM5aXmcpMIVmvq3kAA));
	hashType__UdooXLclXL8uld7qLI5JRw(t, 2, sig);
	result = cacheGetType__2wgznvEs9bt7XaKJgVohBCw((*m).typeCache, sig);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T5_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, t, check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		(void)(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 2);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_833));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_834));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T7_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_835));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
		res = resizeString(res, 12);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_836));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_834));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T8_);
		res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_837));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
		res = resizeString(res, 19);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_838));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), result);
		res = resizeString(res, 19);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_839));
		T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, (*T9_).sons->data[((NI) 0)], check, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T10_);
		res = resizeString(res, 24);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_840));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_834));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T11_);
		res = resizeString(res, 13);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_841));
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 4))- 0], T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__7ll08CGQoDzh9cxhZCroU4w_3)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	NI i;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	i = ((NI) 0);
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	{
		while (1) {
			NI T3_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			T3_ = ((*m).typeStack ? (*m).typeStack->Sup.len : 0);
			if (!(i < T3_)) goto LA2;
			t = (*m).typeStack->data[i];
			{
				NIM_BOOL T6_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
				if (!(T6_)) goto LA7_;
				T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
				T6_ = ((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
				LA7_: ;
				if (!T6_) goto LA9_;
				seqV2ContentType__MFyPdYFFCqzDX9cGGcC0rbA(m, t, (&check));
			}
			goto LA4_;
			LA9_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
				T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T12_ = getTypeDescAux__oxUl9b4hsZj9baTa2FjjXA4Q(m, t, (&check), ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				(void)(T12_);
			}
			LA4_: ;
			i += ((NI) 1);
		} LA2: ;
	}
	asgnRef((void**) (&(*m).typeStack), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) setLengthSeqV2(&((*m).typeStack)->Sup, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_), ((NI) 0)));
}
static N_NIMCALL(void, Marker_tyRef__UjwNQwrGjW3X9ahveEH9bnWA)(void* p, NI op) {
	tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw* a;
	a = (tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*)p;
	nimGCvisit((void*)(*a).m1, op);
}
N_LIB_PRIVATE N_CLOSURE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, loadLib__NbMtJSxAjvelhGqZMFvydw)(NimStringDesc* handle, NimStringDesc* name, void* ClE_0) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw* colonenvP_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NimStringDesc* res;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	colonenvP_ = (tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*) ClE_0;
	prc = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*(*colonenvP_).m1).g).graph, name);
	n = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*(*(*prc).annex).path)._kind_3.strVal);
	(*n).info = (*(*(*prc).annex).path).info;
	res = rawNewString(((NI) 80));
	res = resizeString(res, 7);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_843));
	cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res), handle);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_72));
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*colonenvP_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_285));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T1_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw((*colonenvP_).m1, n);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T2_);
	res = resizeString(res, 6);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_844));
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*colonenvP_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_289));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T3_);
	res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_51));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = genStringLiteral__SO73hKlDdl5sMaSHTbOJLw((*colonenvP_).m1, n);
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T4_);
	res = resizeString(res, 3);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_705));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = rope__yShmEg9cffWxI7s5XzEKBow(res);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, closeNamespaceNim__EBP36f89alKNeO11l19ca8RQ)(void) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_183));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, openNamespaceNim__h7k639c1gj2MLT300oN1wwg)(NimStringDesc* namespace_0) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_874));
	add__yG4AKzsBRS1W4MANDlXQeg(&result, namespace_0);
	add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_875));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__7ll08CGQoDzh9cxhZCroU4w_4)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw* colonenv_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* preMainCode;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* initStackBottomCall;
	NimStringDesc* res_2;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
	colonenv_ = (tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*)0;
	colonenv_ = (tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*) newObj((&NTI__UjwNQwrGjW3X9ahveEH9bnWA_), sizeof(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw));
	(*colonenv_).Sup.m_type = (&NTI__IDX4istqRyOZp3l6j9aUesw_);
	asgnRef((void**) (&(*colonenv_).m1), m);
	preMainCode = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		tyProc__G7yv7dCrMxuDBcXNy2RR1w T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyProc__G7yv7dCrMxuDBcXNy2RR1w T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__a2BRACVCGIuooKjHNmoLsA((*colonenv_).m1);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)(&T6_), sizeof(tyProc__G7yv7dCrMxuDBcXNy2RR1w));
		T6_.ClP_0 = loadLib__NbMtJSxAjvelhGqZMFvydw; T6_.ClE_0 = colonenv_;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = T6_.ClE_0? T6_.ClP_0(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_845), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_816), T6_.ClE_0):((TM__MQdRN7fpbG7rPm4JpVVAhA_846)(T6_.ClP_0))(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_845), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_816));
		add__IM4kcMNkkOLJtqdEqSxR8A(&preMainCode, T7_);
		add__yG4AKzsBRS1W4MANDlXQeg(&preMainCode, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_847));
		nimZeroMem((void*)(&T8_), sizeof(tyProc__G7yv7dCrMxuDBcXNy2RR1w));
		T8_.ClP_0 = loadLib__NbMtJSxAjvelhGqZMFvydw; T8_.ClE_0 = colonenv_;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = T8_.ClE_0? T8_.ClP_0(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_848), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_849), T8_.ClE_0):((TM__MQdRN7fpbG7rPm4JpVVAhA_850)(T8_.ClP_0))(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_848), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_849));
		add__IM4kcMNkkOLJtqdEqSxR8A(&preMainCode, T9_);
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = hcrGetProcLoadCode__uWPA1lTRrPufWdliMF9aGrg((*colonenv_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_849), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_851), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_848), ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_297));
		add__IM4kcMNkkOLJtqdEqSxR8A(&preMainCode, T10_);
		add__yG4AKzsBRS1W4MANDlXQeg(&preMainCode, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_852));
		add__yG4AKzsBRS1W4MANDlXQeg(&preMainCode, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_853));
		add__yG4AKzsBRS1W4MANDlXQeg(&preMainCode, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_854));
	}
	goto LA1_;
	LA4_: ;
	{
		add__yG4AKzsBRS1W4MANDlXQeg(&preMainCode, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_855));
	}
	LA1_: ;
	{
		NIM_BOOL T14_;
		T14_ = (NIM_BOOL)0;
		T14_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 2));
		if (!(T14_)) goto LA15_;
		T14_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
		LA15_: ;
		if (!T14_) goto LA16_;
		includeHeader__G5jzmdnwglHVk5qfDcXonA((*colonenv_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_856));
	}
	goto LA12_;
	LA16_: ;
	{
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 25))) goto LA19_;
		includeHeader__G5jzmdnwglHVk5qfDcXonA((*colonenv_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_857));
	}
	goto LA12_;
	LA19_: ;
	LA12_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28));
		if (T23_) goto LA24_;
		T23_ = ((*(*(*(*colonenv_).m1).g).config).selectedGC == ((tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw) 1));
		LA24_: ;
		if (!T23_) goto LA25_;
		initStackBottomCall = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) NIM_NIL));
	}
	goto LA21_;
	LA25_: ;
	{
		NimStringDesc* res;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		res = rawNewString(((NI) 80));
		res = resizeString(res, 1);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_7));
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = cgsym__arLmPq9aJc9b7GpWTbo6dvHg((*colonenv_).m1, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_800));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res), T28_);
		res = resizeString(res, 18);
appendString(res, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_832));
		initStackBottomCall = rope__yShmEg9cffWxI7s5XzEKBow(res);
	}
	LA21_: ;
	(*(*colonenv_).m1).labels += ((NI) 1);
	res_2 = rawNewString(((NI) 80));
	res_2 = resizeString(res_2, 41);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_858));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*(*(*colonenv_).m1).g).otherModsInit);
	res_2 = resizeString(res_2, 177);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_859));
	cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_2), (*(*(*colonenv_).m1).g).mainDatInit);
	res_2 = resizeString(res_2, 16);
appendString(res_2, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
	T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T29_ = rope__yShmEg9cffWxI7s5XzEKBow(res_2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T29_);
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 2));
		if (!(T32_)) goto LA33_;
		T32_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
		LA33_: ;
		if (!T32_) goto LA34_;
		{
			NimStringDesc* res_3;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
			if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0)) goto LA38_;
			res_3 = rawNewString(((NI) 80));
			res_3 = resizeString(res_3, 50);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_861));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), (*(*(*colonenv_).m1).g).mainModInit);
			res_3 = resizeString(res_3, 65);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_862));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), preMainCode);
			res_3 = resizeString(res_3, 23);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_3), initStackBottomCall);
			res_3 = resizeString(res_3, 16);
appendString(res_3, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
			T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T40_ = rope__yShmEg9cffWxI7s5XzEKBow(res_3);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T40_);
		}
		goto LA36_;
		LA38_: ;
		{
			NimStringDesc* res_4;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T42_;
			res_4 = rawNewString(((NI) 80));
			res_4 = resizeString(res_4, 50);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_861));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), (*(*(*colonenv_).m1).g).mainModInit);
			res_4 = resizeString(res_4, 78);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_864));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), preMainCode);
			res_4 = resizeString(res_4, 23);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
			cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_4), initStackBottomCall);
			res_4 = resizeString(res_4, 16);
appendString(res_4, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
			T42_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T42_ = rope__yShmEg9cffWxI7s5XzEKBow(res_4);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T42_);
		}
		LA36_: ;
	}
	goto LA30_;
	LA34_: ;
	{
		NimStringDesc* res_5;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 25))) goto LA44_;
		res_5 = rawNewString(((NI) 80));
		res_5 = resizeString(res_5, 139);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_865));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), (*(*(*colonenv_).m1).g).mainModInit);
		res_5 = resizeString(res_5, 65);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_862));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), preMainCode);
		res_5 = resizeString(res_5, 23);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_5), initStackBottomCall);
		res_5 = resizeString(res_5, 16);
appendString(res_5, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
		T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T46_ = rope__yShmEg9cffWxI7s5XzEKBow(res_5);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T46_);
	}
	goto LA30_;
	LA44_: ;
	{
		NimStringDesc* res_6;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T50_;
		if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7))&63U)))!=0)) goto LA48_;
		res_6 = rawNewString(((NI) 80));
		res_6 = resizeString(res_6, 50);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_861));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), (*(*(*colonenv_).m1).g).mainModInit);
		res_6 = resizeString(res_6, 78);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_864));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), preMainCode);
		res_6 = resizeString(res_6, 23);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_6), initStackBottomCall);
		res_6 = resizeString(res_6, 16);
appendString(res_6, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
		T50_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T50_ = rope__yShmEg9cffWxI7s5XzEKBow(res_6);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T50_);
	}
	goto LA30_;
	LA48_: ;
	{
		NimStringDesc* res_7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
		if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28))) goto LA52_;
		res_7 = rawNewString(((NI) 80));
		res_7 = resizeString(res_7, 50);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_861));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), (*(*(*colonenv_).m1).g).mainModInit);
		res_7 = resizeString(res_7, 65);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_862));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), preMainCode);
		res_7 = resizeString(res_7, 23);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_7), initStackBottomCall);
		res_7 = resizeString(res_7, 16);
appendString(res_7, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
		T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T54_ = rope__yShmEg9cffWxI7s5XzEKBow(res_7);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T54_);
	}
	goto LA30_;
	LA52_: ;
	{
		NimStringDesc* res_8;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		res_8 = rawNewString(((NI) 80));
		res_8 = resizeString(res_8, 50);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_861));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), (*(*(*colonenv_).m1).g).mainModInit);
		res_8 = resizeString(res_8, 65);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_862));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), preMainCode);
		res_8 = resizeString(res_8, 23);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_863));
		cgFormatValue__Y5Z2edcOkLU40pY0g7QXlQ((&res_8), initStackBottomCall);
		res_8 = resizeString(res_8, 16);
appendString(res_8, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_860));
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = rope__yShmEg9cffWxI7s5XzEKBow(res_8);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T56_);
	}
	LA30_: ;
	{
		if (!!((((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 20))&63U)))!=0))) goto LA59_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
			if (!(((NI) 0) < ((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace ? (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace->Sup.len : 0))) goto LA63_;
			T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T65_ = closeNamespaceNim__EBP36f89alKNeO11l19ca8RQ();
			T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T66_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T65_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_866));
			T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T67_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T66_, (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace);
			T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T68_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T67_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_350));
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T68_);
		}
		LA63_: ;
		{
			NIM_BOOL T71_;
			T71_ = (NIM_BOOL)0;
			T71_ = ((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 2));
			if (!(T71_)) goto LA72_;
			T71_ = !((((*(*(*(*colonenv_).m1).g).config).globalOptions & 640) == 0));
			LA72_: ;
			if (!T71_) goto LA73_;
			{
				NimStringDesc* res_9;
				NimStringDesc* T79_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
				if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 9))&63U)))!=0)) goto LA77_;
				res_9 = rawNewString(((NI) 80));
				res_9 = resizeString(res_9, 176);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_867));
				T79_ = (NimStringDesc*)0;
				{
					NIM_BOOL T82_;
					T82_ = (NIM_BOOL)0;
					T82_ = hcrOn__a2BRACVCGIuooKjHNmoLsA((*colonenv_).m1);
					if (!T82_) goto LA83_;
					T79_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
				}
				goto LA80_;
				LA83_: ;
				{
					T79_ = ((NimStringDesc*) NIM_NIL);
				}
				LA80_: ;
				cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_9), T79_);
				res_9 = resizeString(res_9, 23);
appendString(res_9, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_868));
				T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T86_ = rope__yShmEg9cffWxI7s5XzEKBow(res_9);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T86_);
			}
			goto LA75_;
			LA77_: ;
			{
				NimStringDesc* res_10;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T88_;
				res_10 = rawNewString(((NI) 80));
				res_10 = resizeString(res_10, 167);
appendString(res_10, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_869));
				T88_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T88_ = rope__yShmEg9cffWxI7s5XzEKBow(res_10);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T88_);
			}
			LA75_: ;
		}
		goto LA69_;
		LA73_: ;
		{
			NimStringDesc* res_11;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
			if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 25))) goto LA90_;
			res_11 = rawNewString(((NI) 80));
			res_11 = resizeString(res_11, 268);
appendString(res_11, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_870));
			T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T92_ = rope__yShmEg9cffWxI7s5XzEKBow(res_11);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T92_);
		}
		goto LA69_;
		LA90_: ;
		{
			NimStringDesc* res_12;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
			if (!(((*(*(*(*colonenv_).m1).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7))&63U)))!=0)) goto LA94_;
			res_12 = rawNewString(((NI) 80));
			res_12 = resizeString(res_12, 69);
appendString(res_12, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_871));
			T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T96_ = rope__yShmEg9cffWxI7s5XzEKBow(res_12);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T96_);
		}
		goto LA69_;
		LA94_: ;
		{
			NimStringDesc* res_13;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
			if (!((*(*(*(*colonenv_).m1).g).config).target.targetOS == ((tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ) 28))) goto LA98_;
			res_13 = rawNewString(((NI) 80));
			res_13 = resizeString(res_13, 43);
appendString(res_13, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_872));
			T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T100_ = rope__yShmEg9cffWxI7s5XzEKBow(res_13);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T100_);
		}
		goto LA69_;
		LA98_: ;
		{
			NimStringDesc* res_14;
			NimStringDesc* T102_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T109_;
			res_14 = rawNewString(((NI) 80));
			res_14 = resizeString(res_14, 114);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_873));
			T102_ = (NimStringDesc*)0;
			{
				NIM_BOOL T105_;
				T105_ = (NIM_BOOL)0;
				T105_ = hcrOn__a2BRACVCGIuooKjHNmoLsA((*colonenv_).m1);
				if (!T105_) goto LA106_;
				T102_ = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_45));
			}
			goto LA103_;
			LA106_: ;
			{
				T102_ = ((NimStringDesc*) NIM_NIL);
			}
			LA103_: ;
			cgFormatValue__GOaK9aDgu4cLOYhocodpf3Q((&res_14), T102_);
			res_14 = resizeString(res_14, 23);
appendString(res_14, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_868));
			T109_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T109_ = rope__yShmEg9cffWxI7s5XzEKBow(res_14);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T109_);
		}
		LA69_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T114_;
			if (!(((NI) 0) < ((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace ? (*(*(*(*colonenv_).m1).g).config).cppCustomNamespace->Sup.len : 0))) goto LA112_;
			T114_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T114_ = openNamespaceNim__h7k639c1gj2MLT300oN1wwg((*(*(*(*colonenv_).m1).g).config).cppCustomNamespace);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*colonenv_).m1).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T114_);
		}
		LA112_: ;
	}
	LA59_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__7ll08CGQoDzh9cxhZCroU4w_5)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	{
		NimStringDesc* externc;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		if (!!(((*(*m).g).nimtv == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*(*(*m).g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
			if (T7_) goto LA8_;
			T7_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			externc = copyString(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_347));
		}
		goto LA5_;
		LA9_: ;
		{
			externc = ((NimStringDesc*) NIM_NIL);
		}
		LA5_: ;
		nimZeroMem((void*)T12_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T12_[0] = rope__yShmEg9cffWxI7s5XzEKBow(externc);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = percent___Y4DThr9bpMbmoKpvgT1rYwg(T12_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 11))- 0], T13_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getCopyright__t9c9byVBpvEfissxdPQCEZLw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 4))&63U)))!=0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_876));
		result = percent___j6hWzb1y4ej13yZg5WynCQ(T5_, 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T7_;
		NimStringDesc* T8_;
		nimZeroMem((void*)T7_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T7_[0] = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_876));
		T7_[1] = rope__yShmEg9cffWxI7s5XzEKBow(OS__Jx0qy9c9bSo4fGkMxUfUaAaw[((*conf).target.targetOS)- 1].Field0);
		T7_[2] = rope__yShmEg9cffWxI7s5XzEKBow(CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.targetCPU)- 1].Field0);
		T7_[3] = rope__yShmEg9cffWxI7s5XzEKBow(CC__78I18QZNZFIv9ah7oETc0jg[((*conf).cCompiler)- 1].Field0);
		T8_ = (NimStringDesc*)0;
		T8_ = getCompileCFileCmd__uOCPoEVtEQdC7k9cm7JeVsw(conf, cfile, NIM_FALSE, NIM_FALSE);
		T7_[4] = rope__yShmEg9cffWxI7s5XzEKBow(T8_);
		result = percent___7GaivGwvdxlAsVH2IdyT2Q(T7_, 5);
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, addNimDefines__jVBximZchOMC4kzSRdtvHgcgen)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** result, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyArray__JiWwrsTRC6xqNlGcBthSVA T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	nimZeroMem((void*)T1_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T1_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (CPU__uYXopJX8pM87pQDCtmgWfQ[((*conf).target.targetCPU)- 1].Field1)));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = percent___YfbBxPLyPvVS6F2y9bSUFIA(T1_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(result, T2_);
	{
		if (!(((NI) 0) < ((*conf).cppCustomNamespace ? (*conf).cppCustomNamespace->Sup.len : 0))) goto LA5_;
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_878));
		add__yG4AKzsBRS1W4MANDlXQeg(result, (*conf).cppCustomNamespace);
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA(conf, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_879));
		if (!T9_) goto LA10_;
		add__yG4AKzsBRS1W4MANDlXQeg(result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_880));
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getFileHeader__t9c9byVBpvEfissxdPQCEZLw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = getCopyright__t9c9byVBpvEfissxdPQCEZLw_2(conf, cfile);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w(conf);
		if (!T3_) goto LA4_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_877));
	}
	LA4_: ;
	addNimDefines__jVBximZchOMC4kzSRdtvHgcgen(&result, conf);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__7ll08CGQoDzh9cxhZCroU4w_6)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*m).g).nimtv == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*m).flags &((NU8)1<<((NU)(((tyEnum_CodegenFlag__9c7EibnXBApMXwrQsaaMb6Q) 1))&7U)))!=0);
		if (T5_) goto LA6_;
		T5_ = (((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0);
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** t;
			NI i;
			NI L;
			NI T10_;
			t = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i = ((NI) 0);
			T10_ = ((*(*m).g).nimtvDeps ? (*(*m).g).nimtvDeps->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
					if (!(i < L)) goto LA12;
					t = &(*(*m).g).nimtvDeps->data[i];
					T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T13_ = getTypeDesc__iIMq9aNL1HScA9cVz83avtdg(m, (*t), ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
					(void)(T13_);
					i += ((NI) 1);
				} LA12: ;
			}
		}
		finishTypeDescriptions__7ll08CGQoDzh9cxhZCroU4w_3(m);
		nimZeroMem((void*)T14_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T14_[0] = (*(*m).g).nimtv;
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = percent___OBvl4G6evYkvK9b9bClFGqNw(T14_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 5))- 0], T15_);
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__7ll08CGQoDzh9cxhZCroU4w_7)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_881));
	{
		NimStringDesc** it;
		NI i;
		NI L;
		NI T2_;
		it = (NimStringDesc**)0;
		i = ((NI) 0);
		T2_ = ((*m).headerFiles ? (*m).headerFiles->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = (&(*m).headerFiles->data[i]);
				{
					NimStringDesc* T9_;
					NimStringDesc* T10_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
					if (!((NU8)((*it)->data[((NI) 0)]) == (NU8)(35))) goto LA7_;
					T9_ = (NimStringDesc*)0;
					T10_ = (NimStringDesc*)0;
					T10_ = nsuReplaceChar((*it), 96, 34);
					T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 1);
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_10));
					T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T11_ = rope__yShmEg9cffWxI7s5XzEKBow(T9_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0], T11_);
				}
				goto LA5_;
				LA7_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
					if (!!((((NU8)((*it)->data[((NI) 0)])) == ((NU8)(34)) || ((NU8)((*it)->data[((NI) 0)])) == ((NU8)(60))))) goto LA13_;
					nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T15_[0] = rope__yShmEg9cffWxI7s5XzEKBow((*it));
					T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T16_ = percent___pHsLkkx9bTDctZjmJqwCYRA(T15_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0], T16_);
				}
				goto LA5_;
				LA13_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T18_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
					nimZeroMem((void*)T18_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T18_[0] = rope__yShmEg9cffWxI7s5XzEKBow((*it));
					T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T19_ = percent___ksH6NowTz9bh4eMOdyaiR1w(T18_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0], T19_);
				}
				LA5_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0], ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_882));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genModule__EFwkiA59cPQJZpsz0yL8eHQ)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NIM_BOOL moduleIsEmpty;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	moduleIsEmpty = NIM_TRUE;
	result = getFileHeader__t9c9byVBpvEfissxdPQCEZLw((*(*m).g).config, cfile);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = genMergeInfo__T0VHRXp9cMnXMqYxgPwvmXw(m);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T1_);
	generateThreadLocalStorage__7ll08CGQoDzh9cxhZCroU4w_6(m);
	generateHeaders__7ll08CGQoDzh9cxhZCroU4w_7(m);
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = genSectionStart__KYNwN8RXzjqIkzxFSwHsxw(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1), (*(*m).g).config);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T2_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1))- 0]);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA5_;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = openNamespaceNim__h7k639c1gj2MLT300oN1wwg((*(*(*m).g).config).cppCustomNamespace);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T7_);
	}
	LA5_: ;
	T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T8_ = genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1), (*(*m).g).config);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T8_);
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = genSectionStart__KYNwN8RXzjqIkzxFSwHsxw(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2), (*(*m).g).config);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T9_);
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2))- 0]);
		if (!(((NI) 0) < T12_)) goto LA13_;
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2))- 0]);
	}
	goto LA10_;
	LA13_: ;
	{
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_883));
	}
	LA10_: ;
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 2), (*(*m).g).config);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T16_);
	{
		tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg i;
		NI res;
		i = (tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg)0;
		res = ((NI) 3);
		{
			while (1) {
				if (!(res <= ((NI) 11))) goto LA19;
				i = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) (res));
				{
					NI T22_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					T22_ = (NI)0;
					T22_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(i)- 0]);
					if (!(((NI) 0) < T22_)) goto LA23_;
					moduleIsEmpty = NIM_FALSE;
					T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T25_ = genSectionStart__KYNwN8RXzjqIkzxFSwHsxw(i, (*(*m).g).config);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T25_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(i)- 0]);
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2(i, (*(*m).g).config);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T26_);
				}
				LA23_: ;
				res += ((NI) 1);
			} LA19: ;
		}
	}
	{
		NI T29_;
		T29_ = (NI)0;
		T29_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0]);
		if (!(((NI) 0) < T29_)) goto LA30_;
		moduleIsEmpty = NIM_FALSE;
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0]);
	}
	LA30_: ;
	{
		NIM_BOOL T34_;
		NI T35_;
		T34_ = (NIM_BOOL)0;
		T35_ = (NI)0;
		T35_ = len__9b0YRltzV3kNSE9aQTsG82wg((*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 13))- 0]);
		T34_ = (((NI) 0) < T35_);
		if (T34_) goto LA36_;
		T34_ = hcrOn__a2BRACVCGIuooKjHNmoLsA(m);
		LA36_: ;
		if (!T34_) goto LA37_;
		moduleIsEmpty = NIM_FALSE;
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 13))- 0]);
	}
	LA37_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T43_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA41_;
		T43_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T43_ = closeNamespaceNim__EBP36f89alKNeO11l19ca8RQ();
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T43_);
	}
	LA41_: ;
	{
		if (!moduleIsEmpty) goto LA46_;
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA46_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__H4aCBrBgfkxUNX78oimi1g)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cfile) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!((((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 1))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses((*(*m).g).graph, (*m).module);
			if (!!(T7_)) goto LA8_;
			result = NIM_FALSE;
		}
		goto LA5_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = equalsFile__Wiam9c8x73Mtmbj0r4Ppikg(code, cfile.cname);
			if (!!(T11_)) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(code, cfile.cname);
				if (!!(T16_)) goto LA17_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), cfile.cname, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_884, NIM_FALSE);
			}
			LA17_: ;
			result = NIM_TRUE;
		}
		goto LA5_;
		LA12_: ;
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = nosfileExists(cfile.obj);
			if (!(T20_)) goto LA21_;
			T20_ = nosfileNewer(cfile.obj, cfile.cname);
			LA21_: ;
			if (!T20_) goto LA22_;
			result = NIM_FALSE;
		}
		goto LA5_;
		LA22_: ;
		{
			result = NIM_TRUE;
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(code, cfile.cname);
			if (!!(T28_)) goto LA29_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), cfile.cname, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_885, NIM_FALSE);
		}
		LA29_: ;
		result = NIM_TRUE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeModule__ZCCFqS1YhEjeMHLdSMM8xg)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m, NIM_BOOL pending) {
	NimStringDesc* cfile;
	cfile = getCFile__bmANOnd5oQhXRrTCn9a8S4g(m);
	{
		NIM_BOOL T3_;
		tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cf;
		NimStringDesc* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
		T3_ = (NIM_BOOL)0;
		T3_ = NIM_TRUE;
		if (T3_) goto LA4_;
		T3_ = (((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 1))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = moduleHasChanged__nJ9czoaD1xFoTuiaDFAAiaApasses((*(*m).g).graph, (*m).module);
			if (!T9_) goto LA10_;
			genInitCode__7ll08CGQoDzh9cxhZCroU4w(m);
			finishTypeDescriptions__7ll08CGQoDzh9cxhZCroU4w_3(m);
			{
				if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA14_;
				genMainProc__7ll08CGQoDzh9cxhZCroU4w_4(m);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 8))- 0], (*(*m).g).mainModProcs);
				generateThreadVarsSize__7ll08CGQoDzh9cxhZCroU4w_5(m);
			}
			LA14_: ;
		}
		LA10_: ;
		nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		cf.nimname = copyString((*(*(*m).module).name).s);
		cf.cname = copyString(cfile);
		T16_ = (NimStringDesc*)0;
		T16_ = toObjFile__GMjJ0d3khWrmxAqhh9anEsw((*(*m).g).config, cfile);
		cf.obj = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*m).g).config, T16_, NIM_TRUE);
		cf.flags = 0;
		code = genModule__EFwkiA59cPQJZpsz0yL8eHQ(m, cf);
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = !((code == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
			if (T19_) goto LA20_;
			T19_ = !(((*(*(*m).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ) 0)));
			LA20_: ;
			if (!T19_) goto LA21_;
			{
				NIM_BOOL T25_;
				T25_ = (NIM_BOOL)0;
				T25_ = shouldRecompile__H4aCBrBgfkxUNX78oimi1g(m, code, cf);
				if (!!(T25_)) goto LA26_;
				cf.flags = 1;
			}
			LA26_: ;
			addFileToCompile__0nANBPjKLpImf3GNXBeQ2Q((*(*m).g).config, cf);
		}
		LA21_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T29_;
		NIM_BOOL T30_;
		tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cf_2;
		NimStringDesc* T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code_2;
		T29_ = (NIM_BOOL)0;
		T30_ = (NIM_BOOL)0;
		T30_ = pending;
		if (!(T30_)) goto LA31_;
		T30_ = mergeRequired__X8MaNNxDVB7fxLVXrvJcFw(m);
		LA31_: ;
		T29_ = T30_;
		if (!(T29_)) goto LA32_;
		T29_ = !((((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0));
		LA32_: ;
		if (!T29_) goto LA33_;
		nimZeroMem((void*)(&cf_2), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		nimZeroMem((void*)(&cf_2), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		cf_2.nimname = copyString((*(*(*m).module).name).s);
		cf_2.cname = copyString(cfile);
		T35_ = (NimStringDesc*)0;
		T35_ = toObjFile__GMjJ0d3khWrmxAqhh9anEsw((*(*m).g).config, cfile);
		cf_2.obj = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*m).g).config, T35_, NIM_TRUE);
		cf_2.flags = 0;
		mergeFiles__l8sH9bHsXY4q3tbS3srelEw(cfile, m);
		genInitCode__7ll08CGQoDzh9cxhZCroU4w(m);
		finishTypeDescriptions__7ll08CGQoDzh9cxhZCroU4w_3(m);
		code_2 = genModule__EFwkiA59cPQJZpsz0yL8eHQ(m, cf_2);
		{
			if (!!((code_2 == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA38_;
			{
				NIM_BOOL T42_;
				T42_ = (NIM_BOOL)0;
				T42_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(code_2, cfile);
				if (!!(T42_)) goto LA43_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), cfile, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_886, NIM_FALSE);
			}
			LA43_: ;
			addFileToCompile__0nANBPjKLpImf3GNXBeQ2Q((*(*m).g).config, cf_2);
		}
		LA38_: ;
	}
	goto LA1_;
	LA33_: ;
	{
		tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cf_3;
		NimStringDesc* T46_;
		nimZeroMem((void*)(&cf_3), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		nimZeroMem((void*)(&cf_3), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
		cf_3.nimname = copyString((*(*(*m).module).name).s);
		cf_3.cname = copyString(cfile);
		T46_ = (NimStringDesc*)0;
		T46_ = toObjFile__GMjJ0d3khWrmxAqhh9anEsw((*(*m).g).config, cfile);
		cf_3.obj = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*m).g).config, T46_, NIM_TRUE);
		cf_3.flags = 0;
		{
			NIM_BOOL T49_;
			T49_ = (NIM_BOOL)0;
			T49_ = nosfileExists(cf_3.obj);
			if (!!(T49_)) goto LA50_;
			cf_3.flags = 1;
		}
		LA50_: ;
		addFileToCompile__0nANBPjKLpImf3GNXBeQ2Q((*(*m).g).config, cf_3);
	}
	LA1_: ;
	close__yy9bzEsQhd9bXopz79cWnxXdw((&(*m).ndi), (*(*m).g).config);
}
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__7ll08CGQoDzh9cxhZCroU4w_8)(tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* guard;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T2_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T3_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T22_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T29_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
	nimZeroMem((void*)T1_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T1_[0] = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_876));
	result = percent___y39ant8iE9bjKB0kbkRCAibQ(T1_, 1);
	nimZeroMem((void*)T2_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	nimZeroMem((void*)(&T3_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw((*m).filename, (&T3_));
	T2_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T3_.Field1);
	guard = percent___RKXvZR1cmZW5dfjtFQCG3g(T2_, 1);
	nimZeroMem((void*)T4_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T4_[0] = guard;
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = percent___nEA33x9cMfuJw3ZiGbn25iw(T4_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T5_);
	addNimDefines__jVBximZchOMC4kzSRdtvHgcgen(&result, (*(*m).g).config);
	generateHeaders__7ll08CGQoDzh9cxhZCroU4w_7(m);
	generateThreadLocalStorage__7ll08CGQoDzh9cxhZCroU4w_6(m);
	{
		tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg i;
		NI res;
		i = (tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg)0;
		res = ((NI) 1);
		{
			while (1) {
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
				if (!(res <= ((NI) 11))) goto LA8;
				i = ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) (res));
				T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T9_ = genSectionStart__KYNwN8RXzjqIkzxFSwHsxw(i, (*(*m).g).config);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T9_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(i)- 0]);
				T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T10_ = genSectionEnd__KYNwN8RXzjqIkzxFSwHsxw_2(i, (*(*m).g).config);
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T10_);
				{
					NIM_BOOL T13_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					T13_ = (NIM_BOOL)0;
					T13_ = (((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0));
					if (!(T13_)) goto LA14_;
					T13_ = (i == ((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 1));
					LA14_: ;
					if (!T13_) goto LA15_;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = openNamespaceNim__h7k639c1gj2MLT300oN1wwg((*(*(*m).g).config).cppCustomNamespace);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T17_);
				}
				LA15_: ;
				res += ((NI) 1);
			} LA8: ;
		}
	}
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*m).s[(((tyEnum_TCFileSection__NR9cMDOmG9cHJhM0tCKvXNzg) 12))- 0]);
	{
		if (!(((*(*(*m).g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 7))&63U)))!=0)) goto LA20_;
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__MQdRN7fpbG7rPm4JpVVAhA_21));
	}
	LA20_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T23_ = percent___0xK6HolrLvVFWil73hZYbA(T22_, 0);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T23_);
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
		if (!(((NI) 0) < ((*(*(*m).g).config).cppCustomNamespace ? (*(*(*m).g).config).cppCustomNamespace->Sup.len : 0))) goto LA26_;
		T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T28_ = closeNamespaceNim__EBP36f89alKNeO11l19ca8RQ();
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T28_);
	}
	LA26_: ;
	nimZeroMem((void*)T29_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T29_[0] = guard;
	T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T30_ = percent___Z2c9cvs0wVVVqTEZ3Qwe9bfw(T29_, 1);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T30_);
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = writeRope__LLRRC42xWBSkxzV9bsPu7lA(result, (*m).filename);
		if (!!(T33_)) goto LA34_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*m).g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 3), (*m).filename, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__MQdRN7fpbG7rPm4JpVVAhA_887, NIM_FALSE);
	}
	LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__f9b9ctpv6DQPmjwWpbkP6UPw)(RootObj* backend, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config) {
	tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA* g;
	g = ((tyObject_BModuleListcolonObjectType___CpP4eJLbv5ZwofQXpESuGA*) (backend));
	asgnRef((void**) (&(*g).config), config);
	genForwardedProcs__PBGOqkExHgxzX6Rn0nJkYg(g);
	{
		tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow* m;
		m = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*)0;
		{
			tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow** m_2;
			NI i;
			NI L;
			NI T3_;
			m_2 = (tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow**)0;
			i = ((NI) 0);
			T3_ = ((*g).modulesClosed ? (*g).modulesClosed->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					if (!(i < L)) goto LA5;
					m_2 = &(*g).modulesClosed->data[i];
					m = (*m_2);
					writeModule__ZCCFqS1YhEjeMHLdSMM8xg(m, NIM_TRUE);
					i += ((NI) 1);
				} LA5: ;
			}
		}
	}
	writeMapping__LBHXhYTVO2vldQU4a5LZ9aQ(config, (*g).mapping);
	{
		if (!!(((*g).generatedHeader == ((tyObject_TCGen__9cG6VsX22pOhho6kxyhFVow*) NIM_NIL)))) goto LA8_;
		writeHeader__7ll08CGQoDzh9cxhZCroU4w_8((*g).generatedHeader);
	}
	LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_cgenDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__MQdRN7fpbG7rPm4JpVVAhA_701_2[2];
static TNimNode* TM__MQdRN7fpbG7rPm4JpVVAhA_842_2[2];
static TNimNode TM__MQdRN7fpbG7rPm4JpVVAhA_0[6];

/* section: NIM_merge_TYPE_INIT3 */
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.size = sizeof(tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA);
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.align = NIM_ALIGNOF(tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA);
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.kind = 18;
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.base = 0;
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.flags = 2;
TM__MQdRN7fpbG7rPm4JpVVAhA_701_2[0] = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[1];
TM__MQdRN7fpbG7rPm4JpVVAhA_0[1].kind = 1;
TM__MQdRN7fpbG7rPm4JpVVAhA_0[1].offset = offsetof(tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA, Field0);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[1].typ = (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[1].name = "Field0";
TM__MQdRN7fpbG7rPm4JpVVAhA_701_2[1] = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[2];
TM__MQdRN7fpbG7rPm4JpVVAhA_0[2].kind = 1;
TM__MQdRN7fpbG7rPm4JpVVAhA_0[2].offset = offsetof(tyTuple__9cSd9cjH9cnPQaBRO0ioKSxRA, Field1);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[2].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[2].name = "Field1";
TM__MQdRN7fpbG7rPm4JpVVAhA_0[0].len = 2; TM__MQdRN7fpbG7rPm4JpVVAhA_0[0].kind = 2; TM__MQdRN7fpbG7rPm4JpVVAhA_0[0].sons = &TM__MQdRN7fpbG7rPm4JpVVAhA_701_2[0];
NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_.node = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[0];
NTI__sno9c9bXUVS2CqhtWOJadaCw_.size = sizeof(tySequence__sno9c9bXUVS2CqhtWOJadaCw*);
NTI__sno9c9bXUVS2CqhtWOJadaCw_.align = NIM_ALIGNOF(tySequence__sno9c9bXUVS2CqhtWOJadaCw*);
NTI__sno9c9bXUVS2CqhtWOJadaCw_.kind = 24;
NTI__sno9c9bXUVS2CqhtWOJadaCw_.base = (&NTI__9cSd9cjH9cnPQaBRO0ioKSxRA_);
NTI__sno9c9bXUVS2CqhtWOJadaCw_.flags = 2;
NTI__sno9c9bXUVS2CqhtWOJadaCw_.marker = Marker_tySequence__sno9c9bXUVS2CqhtWOJadaCw;
NTI__IDX4istqRyOZp3l6j9aUesw_.size = sizeof(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw);
NTI__IDX4istqRyOZp3l6j9aUesw_.align = NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw);
NTI__IDX4istqRyOZp3l6j9aUesw_.kind = 17;
NTI__IDX4istqRyOZp3l6j9aUesw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__MQdRN7fpbG7rPm4JpVVAhA_842_2[0] = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[4];
TM__MQdRN7fpbG7rPm4JpVVAhA_0[4].kind = 1;
TM__MQdRN7fpbG7rPm4JpVVAhA_0[4].offset = offsetof(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw, colonstate_);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[4].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[4].name = ":state";
TM__MQdRN7fpbG7rPm4JpVVAhA_842_2[1] = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[5];
TM__MQdRN7fpbG7rPm4JpVVAhA_0[5].kind = 1;
TM__MQdRN7fpbG7rPm4JpVVAhA_0[5].offset = offsetof(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw, m1);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[5].typ = (&NTI__NkKlBfvvsMUW70DxvxLVIg_);
TM__MQdRN7fpbG7rPm4JpVVAhA_0[5].name = "m1";
TM__MQdRN7fpbG7rPm4JpVVAhA_0[3].len = 2; TM__MQdRN7fpbG7rPm4JpVVAhA_0[3].kind = 2; TM__MQdRN7fpbG7rPm4JpVVAhA_0[3].sons = &TM__MQdRN7fpbG7rPm4JpVVAhA_842_2[0];
NTI__IDX4istqRyOZp3l6j9aUesw_.node = &TM__MQdRN7fpbG7rPm4JpVVAhA_0[3];
NTI__UjwNQwrGjW3X9ahveEH9bnWA_.size = sizeof(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*);
NTI__UjwNQwrGjW3X9ahveEH9bnWA_.align = NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___IDX4istqRyOZp3l6j9aUesw*);
NTI__UjwNQwrGjW3X9ahveEH9bnWA_.kind = 22;
NTI__UjwNQwrGjW3X9ahveEH9bnWA_.base = (&NTI__IDX4istqRyOZp3l6j9aUesw_);
NTI__UjwNQwrGjW3X9ahveEH9bnWA_.marker = Marker_tyRef__UjwNQwrGjW3X9ahveEH9bnWA;
}

