/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tySequence__1I3cxybVrOXM64KW2dfERQ tySequence__1I3cxybVrOXM64KW2dfERQ;
typedef struct tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ;
typedef struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA;
typedef struct tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ;
typedef struct tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tySequence__0dpGN6F4ocevqUQGsaf41w tySequence__0dpGN6F4ocevqUQGsaf41w;
typedef struct tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ;
typedef struct tySequence__P9bWebqKHkrGHwy9aZW9bw0TA tySequence__P9bWebqKHkrGHwy9aZW9bw0TA;
typedef struct tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w;
typedef struct tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw;
typedef struct tyTuple__jdFwpivBCgGar3GHRE8kKQ tyTuple__jdFwpivBCgGar3GHRE8kKQ;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__ZtAk5YtH0VW1iPowvxePrg tyTuple__ZtAk5YtH0VW1iPowvxePrg;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg;
typedef struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA;
typedef struct tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw;
typedef struct tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ;
typedef struct tyObject_HSlice__fqLtJsaN5foHLgxLTScotw tyObject_HSlice__fqLtJsaN5foHLgxLTScotw;
typedef struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA;
typedef struct tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw;
typedef struct tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA;
typedef struct tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw;
typedef struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ;
typedef NU8 tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* resultSym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* selfSym;
NI nestedLoopCounter;
NI nestedBlockCounter;
NI inTryStmt;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* next;
NIM_BOOL mappingExists;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q mapping;
tySequence__1I3cxybVrOXM64KW2dfERQ* caseContext;
};
typedef NU8 tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA;
struct tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA {
NI h;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
};
typedef NU8 tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg;
struct tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ {
tyObject_TIdentIter__Oi4goG2ACEsy9cyTe6OCPrA it;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
tyEnum_TOverloadIterMode__xCku9a0wtzKQQBbzX1t6btg mode;
NI symChoiceIndex;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg inSymChoice;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NU8 tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw[21];
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__E1tCxfqiw3fNnaaIR5Kn2A[2];
typedef NU8 tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw;
typedef NU8 tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA;
typedef NU8 tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA;
typedef NU8 tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
typedef NU8 tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg;
typedef NU8 tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w;
struct tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ {
tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w kind;
NI arg;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formal;
};
struct tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA {
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
NI exactMatches;
NI genericMatches;
NI subtypeMatches;
NI intConvMatches;
NI convMatches;
tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg state;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* calleeSym;
NI calleeScope;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q bindings;
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
NIM_BOOL baseTypeMatch;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag fauxMatch;
NIM_BOOL genericConverter;
NIM_BOOL coerceDistincts;
NIM_BOOL typedescMatched;
NIM_BOOL isNoCall;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* inferredTypes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NI inheritancePenalty;
tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ firstMismatch;
NIM_BOOL diagnosticsEnabled;
};
struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* candidateType;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* prev;
NI depth;
};
struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw {
NI depthLevel;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* parent;
};
struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* concreteTypes;
NI compilesId;
};
struct tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg {
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ* typeMap;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMap;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q localCache;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
NIM_BOOL allowMetaTypes;
NIM_BOOL skipTypedesc;
NIM_BOOL isReturnType;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
NI recursionLimit;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg;
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
typedef NU8 tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw[37];
typedef NU8 tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__T6RKPw8xfAeNaoei9aZGzXg[3];
struct tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ firstMismatch;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NIM_BOOL enabled;
};
struct tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
NI Field1;
};
typedef NU8 tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg;
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tyArray__o8KQyTFgNQGvsJZYtdEsgA[8192];
struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw {
tyArray__o8KQyTFgNQGvsJZYtdEsgA buckets;
NI wordCounter;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idAnon;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* idDelegator;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* emptyIdent;
};
struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w {
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA defaultCC;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* dynlib;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* otherPragmas;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
};
struct tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w {
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg toMixin;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg toBind;
NIM_BOOL cursorInBody;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* bracketExpr;
};
typedef NU8 tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA;
typedef NU8 tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA;
struct tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ {
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q topLayer;
tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ* nextLayer;
};
struct tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw {
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg toBind;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg toMixin;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg toInject;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
NIM_BOOL cursorInBody;
NI scopeN;
NI noGenSym;
NI inTemplateHeader;
};
struct tyTuple__jdFwpivBCgGar3GHRE8kKQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
NIM_BOOL Field1;
};
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg;
typedef NU8 tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tySet_tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg[34];
typedef NU8 tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag;
typedef NU8 tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ;
typedef NU8 tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg;
typedef NU8 tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ;
typedef NU8 tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA;
struct tyTuple__ZtAk5YtH0VW1iPowvxePrg {
tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw Field0;
NimStringDesc* Field1;
};
typedef NU8 tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w;
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
typedef NimStringDesc* tyArray__nr38yHugp0nuiB6VarJGiw[2];
struct tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg {
  RootObj Sup;
NI colonstate_;
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c1;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope2;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
void* ClE_0;
} tyProc__5QC9cKfPJmKuW0XbCTd8ylA;
struct tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg {
  RootObj Sup;
NI colonstate_;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig1;
};
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* procSym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fresh, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam, void* ClE_0);
void* ClE_0;
} tyProc__ZB008LFGdRYy2vj1OH1xuQ;
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__rF9caJawfOjYTjsgLVUSGFA_335) (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* procSym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fresh, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__rF9caJawfOjYTjsgLVUSGFA_336) (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* procSym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fresh, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam);
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
typedef NU8 tyEnum_ViewTypeKind__3S4FAWaxPP9ahVaUnMsznog;
typedef NU tyArray__VqSA39cBDWnwnJySTumCdjw[8];
struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ {
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* next;
NI key;
tyArray__VqSA39cBDWnwnJySTumCdjw bits;
};
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
struct tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr;
NIM_BOOL needsFullInit;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* missingFields;
};
typedef NU8 tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ;
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NI Field1;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__voNMFnIDThVNu9afe2zfZWA[5];
typedef NU8 tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw;
struct tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ {
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw a;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw b;
};
struct tyObject_HSlice__fqLtJsaN5foHLgxLTScotw {
tyObject_Int128__9a9axPfb75jdWY25AamJewkA a;
tyObject_Int128__9a9axPfb75jdWY25AamJewkA b;
};
struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA {
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b;
};
typedef NimStringDesc* tyArray__Q6RksR9bl1dCf8jl3HeN9bXg[8];
typedef NU8 tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw;
typedef NU8 tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw;
typedef N_CLOSURE_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, TM__rF9caJawfOjYTjsgLVUSGFA_629) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef NU8 tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__cypz0nHJsd9cnKgpO7fP5hQ[1];
struct tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw {
  RootObj Sup;
NI colonstate_;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genericType1;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, void* ClE_0);
void* ClE_0;
} tyProc__9c12O79biRoLGSQrMfBJEQDg;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_722) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_723) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_724) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_727) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_734) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_739) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_740) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_741) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_743) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
struct tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tupleType;
NI tupleIndex;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
NIM_BOOL replaceByFieldName;
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
};
struct tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw {
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m;
};
typedef NU8 tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg;
struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg {
NI h;
};
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__rF9caJawfOjYTjsgLVUSGFA_876) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
typedef N_CLOSURE_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, TM__rF9caJawfOjYTjsgLVUSGFA_877) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__rF9caJawfOjYTjsgLVUSGFA_878) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA* slots;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentException;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q currentLineInfo;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__0dpGN6F4ocevqUQGsaf41w {
  TGenericSeq Sup;
  tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ data[SEQ_DECL_SIZE];
};
struct tySequence__P9bWebqKHkrGHwy9aZW9bw0TA {
  TGenericSeq Sup;
  tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__1I3cxybVrOXM64KW2dfERQ {
  TGenericSeq Sup;
  tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*, newContext__dfWKKRV6rIabJ2ctPOd59aA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstExpr__7YxUILpPxooC5qqa89a54dw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprWithType__vJZwz9bfROKrfrtM50y74CQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprCheck__vJZwz9bfROKrfrtM50y74CQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpr__vJZwz9bfROKrfrtM50y74CQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, suggestExpr__wb6KhAx6bZ5NV37kY4bXJw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ flags);
N_LIB_PRIVATE N_NIMCALL(void, semCaptureSym__h6aJJZj4uWFwM8eXN4VDAw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symChoice__ce08GbPIDAcM29cbr3lVUxg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA r, NIM_BOOL isField);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initOverloadIter__yTTeeqtnENsm0xyCro9a61w)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, markUsed__QlWTWY7567sCdiTkeUTTDA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeS__xb5E2cGIynZweqWlCP8Tig)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
static N_INLINE(void, markIndirect__OGrPg9bGc5rou9aBRgLK606Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeVarType__45x39aIZGLTdqqo59b4NHvLw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSym__20OKsvfFnNZXONk4IBzYgg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getGenSym__pT6glwCH57hiSrY6Jp4rug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, inlineConst__a1Z9a4khB42QCtmKBL9cckKAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, base__PfgI9ap7WOnsRfFV4znQ27w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NI, requiredParams__knh7oe6js9clE7mbQBo9aJGA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalMacroCall__6SgKdna0C4CEFxNnRELlUg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NI* templInstCounter, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAfterMacroCall__Hw66264lMkoOE49a7wqbwsQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* macroResult, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, idSynchronizationPoint__o9blMKDNUEgfiqOxiffy8Tw)(NI idRange);
N_LIB_PRIVATE N_NIMCALL(void, resetSemFlag__sIxO9bj7Xwv3qFTK7z9b5jSg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmt__vJZwz9bfROKrfrtM50y74CQ_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprNoType__7YxUILpPxooC5qqa89a54dw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg note);
N_LIB_PRIVATE N_NIMCALL(void, discardCheck__tp7yV6CFb40nVuGT1TBFpw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, implicitlyDiscardable__OiccTa3ruRNl9anoSqZh2Sg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCallExpr__CZaoTkWCFI9acor4BmYF3Yw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeNode__O8zf75mcUwo9cfPQUQRaEug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__EezdXeDvu4rB7fR84AJZgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI length, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeof__O8zf75mcUwo9cfPQUQRaEug_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*, openScope__HbQKk9aDdsJVs9bASTXwa5Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__TX9bi5b9bIHR13FiwHwV59a4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, fixupTypeOf__3zDDdB9b7Qt20FH75Al61MA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typExpr);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, assignType__RDstL9c8H9bSHUphDz0iB0hg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semAnonTuple__O8zf75mcUwo9cfPQUQRaEug_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semRangeAux__O8zf75mcUwo9cfPQUQRaEug_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, errorType__9aXTnVBVS5pbBC3zrwMhttg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, copyType__4O4aYoscFPo2FRSh4rP9ayg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL keepId);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__3isNyHKb0U1OCnClmflXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrdinalType__6euCPZwUsyXzP1vAm4IthA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL allowEnumWithHoles);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnresolvedSym__J1LR9bIUh18t4XFDmYEYBYw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__aVxWxXLmf103vwE8uZ9cXRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Drn1sJCJSwUUo03qKJigUw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA, classify__x3IKzrz1VNvfZbypScSTXg)(NF x);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA, weakLeValue__u0tFw6hmOCjNH0Gl9c619aMw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, freshType__MYPl0kqQUBUN3G45LDt6rwsem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* res, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeExpr__O8zf75mcUwo9cfPQUQRaEug_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeExpr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeAndType__9b4dTSY3d7uIjSch9cj9cGP1w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeOrType__9b4dTSY3d7uIjSch9cj9cGP1w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeNotType__UPDD9aO4WRk8hLMnfpJZudg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semAnyRef__WkfdPzqjIHjpNCHcK8ViDg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newConstraint__QGpv9bqfXWWeJjJoCL6cRRA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k);
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI length, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semObjectNode__T23bTYnaXqU9cKlZ7Ag9bdBg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, NIM_BOOL isInheritable);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipGenericInvocation__un0CMx5e9axSJU0IN3TyTiwsem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj);
N_LIB_PRIVATE N_NIMCALL(void, addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype, NIM_BOOL hasCaseFields);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstBoolExpr__7YxUILpPxooC5qqa89a54dw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, forceBool__7YxUILpPxooC5qqa89a54dw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitNode__3gQ9buvlr7tPLmWwfmGV7fw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, indexTypesMatch__8llRCFM4VdmgY27XJn2sRA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__rFFaxk6TYVlvnKNibvVmkg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, paramTypesMatch__MkZIYaWSL2Febv66liB9aIA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argOrig);
N_LIB_PRIVATE N_NIMCALL(void, instGenericConvertersArg__OiEXsRRJbWjgfYLWIAKYYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, generateInstance__Bbmaz5QjetnTaor7LYngPg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
static N_INLINE(NIM_BOOL, isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, copySym__lIu8wX6Beq6dBJgESOFFjg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA*, new__BiEKflRN9azaxRNwAA9br7uA)(void);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__K5M5T7J9c0H7M5ahfeRl8xw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, addDecl__aPXKqZJT9c7r7gT8X3uZAHw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, rawPushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
N_LIB_PRIVATE N_NIMCALL(void, instantiateProcType__1PhCjyNxyOAJRoRgfsrJDQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ*, initLayeredTypeMap__B4ANHmRtTNsf0tY0IplCpw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt);
N_LIB_PRIVATE N_NIMCALL(void, initTypeVars__EZn0NSR9cUjgZYKdEVkzwaA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ* typeMap, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, instCopyType__cNsAY9aO2v1oTCPqZyHga1w_5)(tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg* cl, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, replaceTypeVarsT__cNsAY9aO2v1oTCPqZyHga1w)(tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg* cl, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, replaceTypeVarsN__TMTYUYo5YIKojKgBmj9boOQ)(tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg* cl, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI start);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, referencesAnotherParam__cvWGVSvD9adrttq7iqjO7wA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, errorNode__g3ODV709caO5lfQfPGeUxSQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitNodePostMatch__t9cW9ai7WILQBcTRPAW4swfA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, changeType__sF9cXBCC3k8saS0PTBUB9b8A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* newType, NIM_BOOL check);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, elemType__PfgI9ap7WOnsRfFV4znQ27w_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSymFromList__aHh3vzt6upPNMkKnONiMRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, NI start);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___xL5gyZrjbGMarSdRAXOo9ag_3)(NI64 a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___nr9cP9b0OL9cabygV9bo19cJgZA_3)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lastOrd__hjogdnp59cMX1rwmjikBhqw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimInt64ToStr)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, floatRangeCheck__RTbq1U5r9aGXeN20T54YASg)(NF x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimFloatToStr)(NF f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipHiddenSubConv__BH9abOhPX8pH0DnEWlRxmlw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elem, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, eraseVoidParams__w2l6CVu9bYn8M06fJcMTkHw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, skipIntLiteralParams__w2l6CVu9bYn8M06fJcMTkHw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, genericCacheGet__yrVWUjVCLM4qNMOOOoQryQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA entry, NI id);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameInstantiation__bGmhq9bb8pFOkYidfiwlp5w)(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA a, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, compareTypes__oyXq5u7iL4RjsT9bovvTE9cg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y, tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg cmp, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(void, rawHandleSelf__jWGpC0lY8vG9b1MhOYJ9cFiQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableIncl__4C9ciVlXutN6a0CSSeSkVDA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(void, makeInstPair__OBM04JqIpDFmR9bhgy9ckD3w)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst, tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, pragma__m5gdSrENJIwAi9aMdDiUT9bg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(void, instantiateBody__6k2yIpmfdYEOM5RXDFvgYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig);
N_LIB_PRIVATE N_NIMCALL(void, maybeAddResult__8H5d8d9cPCfbpMuDrerQMeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(void, addResult__n01jThJgoOr9aRxjZW5y9c7g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(void, addParamOrResult__pceuJlMM5di29a5a9cxxzXSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, findEnforcedStaticType__9cRlRlKvV58Tq3YoHJJi1Rw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysSym__9bvw79ck1FDiWpnBYh88rEfw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
static N_INLINE(NIM_BOOL, isInlineIterator__EhCVbB6PynSh7XFAFVMiJAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x);
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__anELyz7VLsjbCIoxLpxbfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, RootObj* val);
N_LIB_PRIVATE N_NIMCALL(void, freshGenSyms__sniSZ3lXmsiJXk4n7qLgPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* symMap);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcBody__7YxUILpPxooC5qqa89a54dw_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, fixNilType__NRIJDWZtATzMum7OEjYC2g_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsgn__mkzYzG9avRzHz5NmIFyZdRg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ mode);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, builtinFieldAccess__vJZwz9bfROKrfrtM50y74CQ_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryReadingTypeField__6Ix9awqI9ax7ryNwTnzhRziw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeDesc__BhLel1oiCddEysrc3uc6iQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryReadingGenericParam__L5Nhi0f3LeGUlYzLEKJ7lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, readTypeParameter__mu5r1rtNM9aogbn9cBVgqt3A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* paramName, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, linkTo__Lxy1G9c1I40y65cWkoPnssA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTypeExpr__OiccTa3ruRNl9anoSqZh2Sg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** check);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createSetType__rwLVyLHZXgxsg41zHjQWfg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeDeref__wWBimsBS4M6UZBvTRDlQTQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, propertyWriteAccess__LlYuhVuv4UT9crSsgDzV0sQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeI__L1Xluv2iZ8cHbWec9bBiiaw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, resolveOverloads__deoiEhU508ju9btmg2AXeFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tySequence__0dpGN6F4ocevqUQGsaf41w** errors, NIM_BOOL errorsEnabled, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(void, semOpAux__NRIJDWZtATzMum7OEjYC2g_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initialBinding, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* best, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* alt, tySequence__0dpGN6F4ocevqUQGsaf41w** errors, NIM_BOOL diagnosticsFlag, NIM_BOOL errorsEnabled);
N_LIB_PRIVATE N_NIMCALL(NI, lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw)(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__KpVjtqarjr9c7ddovPDNqvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, NIM_BOOL diagnosticsEnabled);
N_LIB_PRIVATE N_NIMCALL(void, determineType__PSSiITp8zAUcZ8z1k5AMLA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcAux__HtuGXsziiAueY6wARBVVAA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg phase);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcAnnotation__Uz9bZ6N7ZeTxuwI9b9cYeOeYw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prc, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyExcept__fBlFhtX9baijQaFTBKid83w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalTemplate__MnrgLhOl4U6sn3rRD19cz9bA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tmpl, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genSymOwner, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NI* instID, NIM_BOOL fromHlo);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentWithPragma__gSt4lwrAK8GOXOIIBgGsog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw allowed);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw allowed);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSymG__z0Xq7x7aKOzONyxr8mX73A)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStr__QHyA5kxlk0TZf3p6IbMdtA)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getLineInfo__oiqk14Y4OLEhcR9bJBpfCag_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(void, suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** usageSym, NIM_BOOL isDecl);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setGenericParamsMisc__7YxUILpPxooC5qqa89a54dw_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericParamList__00ZJT6x0WT6z8eBqr79cipw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGenericConstraints__XPC0ita29a0P9cMGViV9aayYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, semParamList__HJ2sXcKFjirzvqsZjMcpTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semProcTypeNode__ZVaxL1YkeVlGuk9csaO0Z2w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, NIM_BOOL isType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newProcType__5gg5mq4XYRQKbAkdLMpzGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, lastOptionEntry__SQasfuhUR9aUpH0EyW9aFezg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semParamType__JfIbex3lv6r6Ex7T9a9cADuw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** constraint);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semNodeKindConstraints__h4580wUcWriTu1bx3JdXfA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI start);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMagic__aafCJ57RxmXkzBZMJ1lSSQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasPragma__oSJ8Ge9caDJrmJG9brFCzlOg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw pragma);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmt__7YxUILpPxooC5qqa89a54dw_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmt__aVtCjYVuHV1t3poDWh43wA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lookup__aVtCjYVuHV1t3poDWh43wA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipAlias__5qYRPQsu9attXO2xg5lnFVQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmtSymbol__q2u7Xlf0LOsIed6IkVg52g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, NIM_BOOL fromDotExpr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fuzzyLookup__AtVxV9cBv7sgERvmPI9aqfnA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx, NIM_BOOL* isMacro);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Jp5sb3DT9aETEb2x58UOk6g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDot__9bgrXSJFYUNpBL6r2Dw4dwQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMixinStmt__gk1t9bC9cmwHRhVJXF0sVfqA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* toMixin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBindStmt__9askHuPxNsdv5Fi00VcmrXQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* toBind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx);
N_LIB_PRIVATE N_NIMCALL(void, addTempDecl__XjZLpvNqVUTx1J6TXREPBQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSymS__z0Xq7x7aKOzONyxr8mX73A_2)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getIdentNode__7YxUILpPxooC5qqa89a54dw_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, liftParamType__IED6yzEuxOVbtiDk639cvjw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw procKind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType, NimStringDesc* paramName, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL anon);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeClass, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* typId, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, NimStringDesc* paramName);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, instGenericContainer__sJO8n9aXqgecj24tOSPjmow)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* header, NIM_BOOL allowMetaTypes);
N_LIB_PRIVATE N_NIMCALL(void, transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPattern__7YxUILpPxooC5qqa89a54dw_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, flattenStmts__qsyX8NJX39ctdwAi4rC8W1g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPatternBody__DuioLh4uofptxEKissr2sw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleSym__bk0oScE0sXzp15PuTrbg3w)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newParam__bk0oScE0sXzp15PuTrbg3w_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, expectParam__DuioLh4uofptxEKissr2sw_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stupidStmtListExpr__9cP6JNeOKqczaXCI4Zo4SBQ_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, searchForProc__onRsQxI12p1JaTFcIxF6cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyTuple__jdFwpivBCgGar3GHRE8kKQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__HcojHyPBYsbchSQtmBqThg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas);
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__m38oZS3DB39a2RtTLWidA5w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q conflictsWith);
N_LIB_PRIVATE N_NIMCALL(void, addGenericParamListToScope__NRIJDWZtATzMum7OEjYC2g_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addParams__XjZLpvNqVUTx1J6TXREPBQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
static N_INLINE(NIM_BOOL, importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, semOverride__8H5d8d9cPCfbpMuDrerQMeQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, bindTypeHook__tGevY34EeRmY9bzfs7irrbQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, canonType__ZcD0zNCGO9bcEV34hRXFEJA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, prevDestructor__ROJgPFH7qSpxtHsXsMs9bTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevOp, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cursorInProc__2z69cmDyuoRHwZ79bXIom4jw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cursorInProcAux__2z69cmDyuoRHwZ79bXIom4jw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg, inCheckpoint__39cgIJElcz9arpbYiRwV2TVw)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q current, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos);
N_LIB_PRIVATE N_NIMCALL(void, semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasObjParam__J1LR9bIUh18t4XFDmYEYBYw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, methodDef__NKjYu87vB0uQmGRMfpDEBQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL fromCache);
N_LIB_PRIVATE N_NIMCALL(void, pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
static N_INLINE(void, paramsTypeCheck__X9cjeXk0ogla5nWLtx0FEkAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, typeAllowed__M8lM58Zr3lmYhlOsJv89cVw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hloBody__7YxUILpPxooC5qqa89a54dw_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hlo__7YxUILpPxooC5qqa89a54dw_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, applyPatterns__7YxUILpPxooC5qqa89a54dw_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, applyRule__ZQ863YHaqTVgTAf1B1grTA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalPattern__bbosmif5uBCIMfZ0A73vOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, afterCallActions__Qn3T9bt6Cg4I7XaYRMg219aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, semFinishOperands__wb6KhAx6bZ5NV37kY4bXJw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, activate__NRIJDWZtATzMum7OEjYC2g_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isArrayConstr__crbaOhZgTohCnKAdtWPkSQsem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag, isAssignable__ASvZU4uIBad6J9b9cMoLNFvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag, isAssignable__H8ClJSBthN45fIRKmjWHMQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, analyseIfAddressTaken__7YxUILpPxooC5qqa89a54dw_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderNotLValue__vfKkxNGxagsG9czCdz2IAEQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, magicsAfterOverloadResolution__vJZwz9bfROKrfrtM50y74CQ_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAddrArg__kiPmghV1gaPm718CtGyhQw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makePtrType__PDWeh9cjpi22xXdNggYvsWA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeOf__7YxUILpPxooC5qqa89a54dw_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrGet__vJZwz9bfROKrfrtM50y74CQ_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSubscript__vJZwz9bfROKrfrtM50y74CQ_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDeref__7YxUILpPxooC5qqa89a54dw_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semStaticType__DMAavRw02YcIRkO3yZ1XeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* childNode, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA onError);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___xL5gyZrjbGMarSdRAXOo9ag)(NI64 a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__TIX0sFuRf3uBpOBltYp7bw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSymGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericSym__aK9ce4VwkiusXxioJ5dzs5w_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__BdjBO3HF6dSjQEzna7SJ1A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, typeRel__3a3tkQB9aY8V2J9acM5cZ6nA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aOrig, tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericInstError__7YxUILpPxooC5qqa89a54dw_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symNodeFromType__MpkaQE9aiK11PxY8aspzYDw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symFromType__xO2UfktRDKCUWUorFz9cLYA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, bracketNotFoundError__NRIJDWZtATzMum7OEjYC2g_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, notFoundError__3yYIcS0VQPQvrknpxFc7TQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__0dpGN6F4ocevqUQGsaf41w* errors);
N_LIB_PRIVATE N_NIMCALL(void, presentFailedCandidates__DzsD9bOR72VurwdjRilOhmA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__0dpGN6F4ocevqUQGsaf41w* errors, tyTuple__ZtAk5YtH0VW1iPowvxePrg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, describeArgs__cCrxh8TxJsIrMINltM1ovw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI startIdx, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, setLengthStr)(NimStringDesc* s, NI newLen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer, NIM_BOOL getDeclarationPath);
N_LIB_PRIVATE N_NIMCALL(void, effectProblem__3uc8nf1Yi57kIzOPCNU9caA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, NimStringDesc** result, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ, compatibleEffects__jMDzK5tLgCQpWKRW9azac5w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
N_LIB_PRIVATE N_NIMCALL(void, sort__QeVk9c1PKgtuLn69cFZt89cSg)(NimStringDesc** a, NI aLen_0, tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA order);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrPut__vJZwz9bfROKrfrtM50y74CQ_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsgnOpr__7YxUILpPxooC5qqa89a54dw_18)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semShallowCopy__vJZwz9bfROKrfrtM50y74CQ_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIsPartOf__vJZwz9bfROKrfrtM50y74CQ_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w, isPartOf__1otDDZAmvFsmbqPyFytXFg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__161i7kexvUAISxPtGBRWYw)(NI arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeTraits__7YxUILpPxooC5qqa89a54dw_19)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalTypeTrait__J9a21UTKN4zETETiDQaaUMw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* traitCall, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* operand, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* context);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, toNode__pidBpg4XuuDNdF3NVODN6A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__aSykZlHQuGR9almJ1ehcUew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw, parseEnum__ASE7k7bSFM18MJ5iPda8rQ)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getTypeDescNode__PDBS7GU6I7t8evrM8dmPkA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStr__8clA3iQh1Lbc5cnapppbXQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, uninstantiate__9cRlRlKvV58Tq3YoHJJi1Rw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNodeT__9cl7myBS6dfbP30fsccozTQ)(NimStringDesc* strVal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semInstantiationInfo__7YxUILpPxooC5qqa89a54dw_20)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__a4cQxFar9atOGMK9b4U0EEVA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getInfoContext__TXxF2CG3kwLqptPWf0kC9aQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI index);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOrd__7YxUILpPxooC5qqa89a54dw_21)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__1szweXXq3RBN50owrYu2Xw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NI64 first, NI64 last, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOf__7YxUILpPxooC5qqa89a54dw_22)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, commonSuperclass__CFsXKWHnV1O9asJrtw08whA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLowHigh__7e8kUc3a9a4gEAcnG7wUcyQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBindSym__7YxUILpPxooC5qqa89a54dw_23)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isCompileTimeProc__Ye2MiAptq3GrXxTQeyXNeA_2ast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDynamicBindSym__7YxUILpPxooC5qqa89a54dw_24)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__IqGNbqKVyQ9b9an5n9bN8QJsQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, setupGlobalCtx__41qwP9bj6cfy3VehAu9aAFvw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph);
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__KnNoqgKj9bmG2p3f4SLNFqA)(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* c, NimStringDesc* name, tyProc__5QC9cKfPJmKuW0XbCTd8ylA callback);
N_LIB_PRIVATE N_CLOSURE(void, bindSymWrapper__Yigy4cCtqH652LhibVuvOA)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__Adyk89aSgmLp9bDuSV0Va03A)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, opBindSym__WI1aMJFzyk8ggPo9bdhAVJw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI isMixin, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getNode__DuJnnnM0aSaXeDv118rkUw)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI i);
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__VJ5Unk9bDoOAoLiZLdhb9b1Q)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyProc__RcJNn9bSvWdJgUmA1O6sbHA, getPlugin__CPe4POy5nrj1aG8wD32ycw)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, whereToBindTypeHook__ZcD0zNCGO9bcEV34hRXFEJA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, turnFinalizerIntoDestructor__ZI4mbm59aB4PCl4xGhxV09bw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_NIMCALL(void, Marker_tyRef__NaDYkbcAjZXYRP9arR0vzYg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeVarType__1XhuXEO6E22P9aDkvWkNrHQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transform__jpL3B9a76sXjWDD2lkGF2ew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* procSym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fresh, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTypeOrNil__3isNyHKb0U1OCnClmflXSg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newProcType__9bgJAAoskVeu3l1AHMmz9adg)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, addParam__MnxL8SpIj0v6dB7M1prhCw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* procType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semUnown__7YxUILpPxooC5qqa89a54dw_25)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, unownedType__ZcD0zNCGO9bcEV34hRXFEJA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tySequence__Ef05srmQTDulnBdXR4Ja6Q*, newSeq__g2qIn6210g4boJ9cN37Mg3Q)(NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semQuantifier__7YxUILpPxooC5qqa89a54dw_26)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOld__7YxUILpPxooC5qqa89a54dw_27)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkIsolate__ZXNCKm9cN9beZ9cx11s9c1Qypw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalAtCompileTime__7YxUILpPxooC5qqa89a54dw_28)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstExpr__A7gcXCy5E3uGBy5F37NoHA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalStaticExpr__ajRaPV9aInq6ZNnUYn0DaVw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* eOrig);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCycle__OiccTa3ruRNl9anoSqZh2Sg_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, annotateType__zBoL79cc9cORdBkTIEpbntbg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalConstExpr__P8uF2QSxl7YdNpBnl0Ybqg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, trackProc__P9bJkIGwY9beKGfhhcBedbpg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body);
N_LIB_PRIVATE N_NIMCALL(void, fixupInstantiatedSymbols__PSSiITp8zAUcZ8z1k5AMLA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
static N_INLINE(void, popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, semBorrow__OGQY86R2SObbzHiM7l0Jxg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchForBorrowProc__4pWHBKQGe6fnkUK3uFl6xQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* startScope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, baseOfDistinct__PfgI9ap7WOnsRfFV4znQ27w_4)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, sideEffectsCheck__PSSiITp8zAUcZ8z1k5AMLA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, matches__BxEsf1Gt7Hq3usrwPERzyA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NI, cmpCandidates__K2h4nBXAyIEnS4gvLx162g)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b);
N_LIB_PRIVATE N_NIMCALL(tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*, initCandidateSymbols__6M9chcVQEVQseAfXvR9bENIw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initialBinding, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* best, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* alt, tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, NIM_BOOL diagnostics);
static N_NIMCALL(void, Marker_tySequence__P9bWebqKHkrGHwy9aZW9bw0TA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, insert__k2dh9aOATKmq7LxvapyA7CA)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* item, NI i);
N_LIB_PRIVATE N_NIMCALL(void, delete__TgBXLpGAm0rF5SZ3bkKUbg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** x, NI i);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___txCax6HTxTvaDY9bSHIRipg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** b, NI bLen_0);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMsgDiagnostic__9a9cj3QUHlIK9ah21FZrVSRgw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSymRepr__q0Idm3DQlYmoqr1FN0Wn2g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameMethodDispatcher__J29brquhJ05YcB0AjRLYFEg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semResolvedCall__tI9alV34Tv2MGPKAeQ6xsmw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, instGenericConvertersSons__DyVfh0xLvP9cQgsc36rPgEA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x);
N_LIB_PRIVATE N_NIMCALL(void, updateDefaultParams__eSEQYRkB13fhZ9c33IzktDQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call);
static N_INLINE(NIM_BOOL, canDeref__crbaOhZgTohCnKAdtWPkSQ_2sem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryDeref__wWBimsBS4M6UZBvTRDlQTQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, errorSym__CLMmoDuBHkJLvNsKvljGNw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, dotTransformation__7YxUILpPxooC5qqa89a54dw_29)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowerTupleUnpackingForAsgn__8A4G64HByteFanrMUexmNw_3)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, cmpTypes__6LyhcPFOyQXLaZFXoqJM1w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(void, typeMismatch__1xxyFIws27lai2cG4n31Ow)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
N_LIB_PRIVATE N_NIMCALL(void, borrowCheck__J1O6ZLf1JD7YcSRxfw8Usg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
static N_INLINE(NIM_BOOL, scopedLifetime__Ht8IGDD0esJjGANh4G2DZwsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getRoot__WJ80zbTOky5IFknpruSGag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL followDeref);
static N_INLINE(NIM_BOOL, escapes__cZ8gUfmyb9cMvgwP1Q5K9bbAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, goodLineInfo__eFiXGzEcaqcZ648kwvI9a9ag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
static N_INLINE(void, asgnToResultVar__h9b9cHg6rgpKzNHniS8pqoyAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(tyEnum_ViewTypeKind__3S4FAWaxPP9ahVaUnMsznog, classifyViewType__mrAxDuBowGCWq5wvtjg9bxA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isLent);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, exprRoot__XD7qSmhHQJchscUPfXW57g)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, createDocLink__pWiLD3R2s41obcTDlPhj9cA)(NimStringDesc* urlSuffix);
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, finishMethod__PSSiITp8zAUcZ8z1k5AMLA_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, assign__9aeoXSYLtfdHDeDWcO9bHVbg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* dest, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* src);
N_LIB_PRIVATE N_NIMCALL(void, semRecordCase__b2sT4Mx5xMcD0WzRKPqmPA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lengthOrd__hjogdnp59cMX1rwmjikBhqw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, semCaseBranch__v9aNPEhC9bTKfOzSbulyV4jw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch, NI branchIndex, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered);
static N_INLINE(NIM_BOOL, isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCaseBranchRange__0knXB2kLqr5zutyOXWu8Rg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBranchRange__j3LbHf9bqKk6Mw4S3FFgkVQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConvTakeType__BH9abOhPX8pH0DnEWlRxmlw_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, emptyRange__tlIBRycg3YyKwtO2aPbGGg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, minus___Sp7OcCEIFoBYolB6PB1fAg_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, plus___hiijuMqvH9aC9aKmwIYuqUAA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, plus___Sp7OcCEIFoBYolB6PB1fAg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(void, delSon__oU9bKATaboy8iUhv0r9bMBPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI idx);
N_LIB_PRIVATE N_NIMCALL(void, inc__Glh2geFlMs9aE78UZ1JZGAA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA* a, NU32 y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, deduplicate__npqksG7nXsyGRBfJK1db1g)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCaseBranchSetElem__0knXB2kLqr5zutyOXWu8Rg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered);
N_LIB_PRIVATE N_NIMCALL(void, checkForOverlap__72gDnaHzi4O4sp9av09bP7vw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, NI currentEx, NI branchIndex);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, overlap__tlIBRycg3YyKwtO2aPbGGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___7c5Zw7H31uJfWmmhZe9aEqw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toCover__VyVU6SDhkTqKxSsQUZSePg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, shl__al6Zjboz2CA0pIDMg9a9cJFw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatMissingEnums__zUJc3JNayUkQ8i11jOQJeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderAsType__jONWMAXSsSmnBgUvyxg7Hw)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* vals, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__Jx9cyf9byen4PwchGOyl5LUg)(NimStringDesc** s, NIM_CHAR x);
static N_INLINE(NI, len__litHeZeW9bpJugmXT0ufvwgintsets)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s);
static N_INLINE(void, minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s1, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s2, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, difference__jhF9cCHu5ggiDdc87e1wx3g)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s1, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s2, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, genericShallowAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, computeRequiresInit__p5rbEi9c5JmURA4qGF6bxhg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, initConstrContext__RYPHxM9aTf8uWaAnZ0rNc2A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ, semConstructTypeAux__sAwB0gQrQ1keYlqxdq08bQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ, semConstructFields__uWuMnWjhYSs5k358Hz7X7w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw)(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ* existing, tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ newStatus);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsRecList, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr);
N_LIB_PRIVATE N_NIMCALL(void, invalidObjConstr__NRIJDWZtATzMum7OEjYC2g_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstrField__dYxITD6gRULNORUNQ6Cc9cg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprFlagDispatched__vJZwz9bfROKrfrtM50y74CQ_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryConstExpr__7YxUILpPxooC5qqa89a54dw_30)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipHidden__BH9abOhPX8pH0DnEWlRxmlw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, findUsefulCaseContext__0hNT3646PPGbJcsdagLbHg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* discrimator, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result);
N_LIB_PRIVATE N_NIMCALL(void, branchVals__XK56AwQllxmCRE7fuCvRCQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseNode, NI caseIdx, NIM_BOOL isStmtBranch, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, excl__jENnK9c9bPE73pKmo2vYjpqg_2)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, caseBranchMatchesExpr__2m1qzNtSRcrBCjT714EGTA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matched);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(void, collectMissingFields__R8ignHxUaQZzB8x7tzNkEg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsRecList, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntLit__TuFlkTIoJNHT6fCcycYtSw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI64 value);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, pickCaseBranch__XwTdxP6ATUC1LHA9bBiTnDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matched);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeof2__O8zf75mcUwo9cfPQUQRaEug_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semWhen__5C4HPXQuhxlMYIzPbe36lg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL semCheck);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookUp__CLMmoDuBHkJLvNsKvljGNw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, commonType__hfwrZ5ThSx8sbABQFEwdHg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semTypeIdent__AO57Q9bSpsZiuv7kwwoM7yw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pickSym__SVsbCvrhrWQIRF0pM3cw5Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kinds, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags);
N_LIB_PRIVATE N_NIMCALL(void, reset__2DpKIamrWIkCdM4vNi0Xcw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj);
N_LIB_PRIVATE N_NIMCALL(void, transitionNoneToSym__ZdMf7vswMpd0Pc5oB9aS4og)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symFromExpectedTypeNode__AO57Q9bSpsZiuv7kwwoM7yw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semArray__O8zf75mcUwo9cfPQUQRaEug_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semArrayIndex__aJQEuszymrhDdKaEXWG3Vg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeRangeWithStaticExpr__D2YW7F23KYvdV39aTScM3IQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semContainer__9c9cJm09bVJhp6JDeDwpDcllw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NimStringDesc* kindStr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(void, semContainerArg__tX9cFHLAurfZYsTsUVxevYw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* kindStr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semRange__O8zf75mcUwo9cfPQUQRaEug_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semSet__O8zf75mcUwo9cfPQUQRaEug_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semOrdinal__O8zf75mcUwo9cfPQUQRaEug_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semVarargs__O8zf75mcUwo9cfPQUQRaEug_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTuple__O8zf75mcUwo9cfPQUQRaEug_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTupleRecursive__YPjOkGV9axAnGR3UfLeWZ1g_12)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGeneric__nGXSqtv2avLRNyfQXJjLWw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGenericParamInInvocation__aJQEuszymrhDdKaEXWG3Vg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__Jb9ck8uy9aKqJSHdNSzDJAJQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds, NI maxIters);
N_LIB_PRIVATE N_NIMCALL(void, semObjectTypeForInheritedGenericInst__ZPW6MqdUk6rECHJvUIgrnA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, recomputeFieldPositions__XUkgGL16NQZcptTJ0lg7nQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj, NI* currPosition);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeClass__O8zf75mcUwo9cfPQUQRaEug_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(void, add__9a8CdZqChTyqzq5bpSL3TzA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeWithModifier__YyNjY7O2UpEApULCS9ctQYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag modifier, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConceptBody__7YxUILpPxooC5qqa89a54dw_31)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semVarOutType__kPfUv0X9aI6AfGcdSb9aYz9cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semDistinct__O8zf75mcUwo9cfPQUQRaEug_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semProcTypeWithScope__HVX0MCOg4yL8PRkNzdiEmQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, applyTypeSectionPragmas__n3MU2Z4B9cngRayLYQCel5A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* operand);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTreeWithoutNode__aN5jlv83QmlsI1PY356I2w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* skippedNode);
N_LIB_PRIVATE N_NIMCALL(void, setEffectsForProcType__anXKpeIcfo8QOiHQxzurxw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semEnum__O8zf75mcUwo9cfPQUQRaEug_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__tyTgUybFIoow4CX2l5beug)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumField__qTKM3Dk2MEIWKGK9aoCIRwg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n, NIM_BOOL onConflictKeepOld);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semStmtListType__O8zf75mcUwo9cfPQUQRaEug_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semBlockType__O8zf75mcUwo9cfPQUQRaEug_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
N_LIB_PRIVATE N_NIMCALL(void, instAllTypeBoundOp__Qpi3NgGJ9aSfcPm9cZqhFJUg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, newIdTable__Vn79aD3eLpwW0W0F5ymtWkw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapInComesFrom__Cb09cvJMrK2DzloKNIynCQQ)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res);
N_LIB_PRIVATE N_NIMCALL(void, setIntLitType__JsZMQGDyZXnGr9cg0jxXW0w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFieldAccess__vJZwz9bfROKrfrtM50y74CQ_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConv__7YxUILpPxooC5qqa89a54dw_32)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStaticExpr__7YxUILpPxooC5qqa89a54dw_33)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, maybeLiftType__K7SXxqU6fIMYb9b4D3wV5CQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** t, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedSym__iY9a3KG6T9aTt3fJH8J6BrJQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, inferWithMetatype__2aIGqt1c0rX64kF16cP4Pw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, NIM_BOOL coerceDistincts);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw, checkConvertible__wqYfe9cPnmcuZgfMqqBjkkA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetTyp, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw, checkConversionBetweenObjects__IxznSNSPzSVAXeEIIkymSA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* castDest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src, NI pointers);
static N_INLINE(NIM_BOOL, contains__zYqwL8gLoyye80MYuubU4Qsystem)(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ s, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw value);
static N_INLINE(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ, dotdot___zEl0oB35FYImlhRYJ1IWBwsystem)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw a, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw b);
static N_INLINE(NIM_BOOL, contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
static N_INLINE(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw, dotdot___SGmrVHErX3j2AKHYB8sGjgsystem)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
static N_INLINE(NIM_BOOL, contains__JskUST5Zl4jxh9cOha2CJ8Qsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, NI64 value);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___nr9cP9b0OL9cabygV9bo19cJgZA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value);
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___W2wbDjPGDCaBwLQM6yLUQg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__dgNNhprrT2HlJglL2Nc3EA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semObjConstr__vJZwz9bfROKrfrtM50y74CQ_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, listSymbolNames__8Z1zCwaGnI7ov1q9bc6s4uQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** symbols, NI symbolsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMagic__NYxU2DkHA0Gt5fsL9bYZdog_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDefined__7YxUILpPxooC5qqa89a54dw_34)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__jkXTnxDf8MX1Pmks3s0XxA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setMs__YdV8xmi8UjdS8ox7bsgtGw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDeclared__ssxiU9aPj4i6xXfLbEm3Reg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL onlyCurrentScope);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookUpForDeclared__ejqqZ7JpeaJqZ9aJjvnjSXw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL onlyCurrentScope);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, localSearchInScope__Drn1sJCJSwUUo03qKJigUw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCompiles__vJZwz9bfROKrfrtM50y74CQ_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryExpr__vJZwz9bfROKrfrtM50y74CQ_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(NI, getInfoContextLen__QY5gXnIUBOUa79b5tGece0A)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, trackStmt__QaQdy9beybDhOWYNIJD0SGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isTopLevel);
N_LIB_PRIVATE N_NIMCALL(void, setInfoContextLen__JRH1QeGlTzlBOChAZ7bvoQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI L);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIs__vJZwz9bfROKrfrtM50y74CQ_18)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, fixupStaticType__NRIJDWZtATzMum7OEjYC2g_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeTypeSymNode__L4oMECPyC3ttpx9cr0kf9a9bw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, isOpImpl__vJZwz9bfROKrfrtM50y74CQ_19)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpandToAst__QP3kds6GlqvnvsFXvC0yvw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* magicSym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpandToAst__7YxUILpPxooC5qqa89a54dw_35)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semQuoteAst__7YxUILpPxooC5qqa89a54dw_36)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectString__zUJc3JNayUkQ8i11jOQJeQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, newSeq__rWQEUE6RvOVfamepP2TwPw)(NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newAnonSym__w5lZcsHUDOEnXuinSWI8ww)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, processQuotations__JHIMJhmDecu8Q5MfBu4NEQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, NimStringDesc* op, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** quotes, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** ids);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newProcNode__g5PEkYP0A0RT03uHbJ6wKQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pattern, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptions);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplateDef__7YxUILpPxooC5qqa89a54dw_37)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodyDirty__DuioLh4uofptxEKissr2sw_3)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBody__DuioLh4uofptxEKissr2sw_4)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplSymbol__v9aCQGt9cWiikzASIttxYkOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isField);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUse__k3cqh606mJPYNzLXdtZjIg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodySons__DuioLh4uofptxEKissr2sw_5)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, openScope__v8rOnBcZIF3O8b3uSd4HeA)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__v8rOnBcZIF3O8b3uSd4HeA_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodyScope__DuioLh4uofptxEKissr2sw_6)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw, symBinding__lRF6a2VbcNtMQTglYy3orA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichKeyword__sZUQNPhNGEM8MllfcWvRiw)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, onlyReplaceParams__DuioLh4uofptxEKissr2sw_7)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getIdentNode__DuioLh4uofptxEKissr2sw_8)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isTemplParam__XVOXP9ay7a7Pj2tMnC3DpKQsem)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newGenSym__pZY5bxiuLRGzLAtcZwPJyQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c);
N_LIB_PRIVATE N_NIMCALL(void, semTemplSomeDecl__7l8P1u9cbRbmxfIqmTswe6Q)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, NI start);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRoutineInTemplName__DuioLh4uofptxEKissr2sw_9)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRunnableExamples__CZaoTkWCFI9acor4BmYF3Yw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, symTabReplace__mq4tDXMjV9aoOV0jJhDFqKA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevSym, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newSym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createMagic__MzNJxZ0htpjW89c9b2wBN5rQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw, spawnResult__115WOpmSjJFT089amuDIXdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL inParallel);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createFlowVar__FNAdkkRAZAzuZfvQrY8ffg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, instantiateCreateFlowVarCall__xO2UfktRDKCUWUorFz9cLYA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSizeof__7YxUILpPxooC5qqa89a54dw_38)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIndirectOp__vJZwz9bfROKrfrtM50y74CQ_20)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, bracketedMacro__B9cQwIphxB9aXLurrc1x2XhQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, setGenericParams__NRIJDWZtATzMum7OEjYC2g_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, resolveIndirectCall__Ue9bfKSqSYcEhUFt1R9cJKjw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__GPx9buyQn9cq0nARN4Amyarw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, overloadedCallOpr__7YxUILpPxooC5qqa89a54dw_39)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldBeBracketExpr__OiccTa3ruRNl9anoSqZh2Sg_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, hoistParamsUsedInDefault__sVX3UeeBXUbUHp9a9cEcpxCw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** letSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** defExpr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeIT__iShdzoe9aISfAzry2HqGKqg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrayAccess__vJZwz9bfROKrfrtM50y74CQ_21)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg, checkPar__l5Y3wSn9c2wuzfpP3PtAptA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTupleConstr__vJZwz9bfROKrfrtM50y74CQ_22)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTuplePositionsConstr__vJZwz9bfROKrfrtM50y74CQ_23)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTupleFieldsConstr__vJZwz9bfROKrfrtM50y74CQ_24)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSetConstr__7YxUILpPxooC5qqa89a54dw_40)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrayConstr__vJZwz9bfROKrfrtM50y74CQ_25)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLambda__vJZwz9bfROKrfrtM50y74CQ_26)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCast__7YxUILpPxooC5qqa89a54dw_41)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCastable__4z4DAkBJVF6o4ot6RWH9cXw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isFinal__YPjOkGV9axAnGR3UfLeWZ1g_5)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NI64, computeSize__vCG1GF2Iu043oALVyuJfOw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIf__vJZwz9bfROKrfrtM50y74CQ_27)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, commonType__wEK756YRi9c3lsyIxi9aFXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTableConstr__7YxUILpPxooC5qqa89a54dw_43)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBlock__vJZwz9bfROKrfrtM50y74CQ_29)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmtList__vJZwz9bfROKrfrtM50y74CQ_30)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnresolvedStatic__aVxWxXLmf103vwE8uZ9cXRw_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, inferConceptStaticParam__C0PRtNs0w318DTgRD2xT9cg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* inferred, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRaise__7YxUILpPxooC5qqa89a54dw_44)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__dZW9czpRSiiVl9cyT6tyk84A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isException__YPjOkGV9axAnGR3UfLeWZ1g_13)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semVarOrLet__9aaeuZC3SovMoEd6yN1pUdg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symkind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLowerLetVarCustomPragma__YnGuZwNZgNND9bMHSc9cGxzQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, suggestStmt__wb6KhAx6bZ5NV37kY4bXJw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasEmpty__7NKj1MHAV0sRlpGa31vf8w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, newSons__Bu9cqnssJjx4jfWBeiR9albg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI length);
N_LIB_PRIVATE N_NIMCALL(void, addToVarSection__rATgbLzWCudr6icucCz5hA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* identDefs);
N_LIB_PRIVATE N_NIMCALL(void, fillPartialObject__kJjN1gd8ISazJd7RmyND3A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, findShadowedVar__X80n25ArIa9aG019bZhPbmzw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(void, setVarType__2vD75zhrXW5EMFzUU9a9cEUQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, defaultConstructionError__SDnpDS6VfoCU9aBUYR8UoFg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, checkNilable__L1S5GkGOJih9bnTgycxmzAQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, astdef__PBkjYIaAGbtrZ8DiUArHcw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, setupCompileTimeVar__zQ7dn9aEDgIq1IbBIE9cxsxg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConst__7YxUILpPxooC5qqa89a54dw_45)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitRemoveHiddenConv__wMJQkaeAPG0iIuqYsMdZgQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNode__FUOXigLcQdNOaWKUo0hkTg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NF floatVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeSection__7YxUILpPxooC5qqa89a54dw_46)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, typeSectionLeftSidePass__NRIJDWZtATzMum7OEjYC2g_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, typeDefLeftSidePass__Sbx6MQrOoMPnRUYXOXA3NA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeSection, NI i);
N_LIB_PRIVATE N_NIMCALL(void, typeSectionRightSidePass__NRIJDWZtATzMum7OEjYC2g_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, typeSectionTypeName__7YxUILpPxooC5qqa89a54dw_47)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, processMagicType__gPoEwHdu4chIAfwrKhjTjA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m);
N_LIB_PRIVATE N_NIMCALL(void, setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NI size);
N_LIB_PRIVATE N_NIMCALL(void, setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NI size);
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__Nm9cs6Kn6ltGLynV4vNsRgw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, checkCovariantParamsUsages__fJHDVHP75aONSHseylETAw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genericType);
static N_NIMCALL(void, Marker_tyRef__hW0nFkOHm9b8Hn43XRoDtzQ)(void* p, NI op);
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, typeSectionFinalPass__NRIJDWZtATzMum7OEjYC2g_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, safeSkipTypes__qgwlffIIb2pFkSZek4igDA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(void, checkConstructedType__09chTcGpP9cwUssGPOfkWIGw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, checkForMetaFields__NRIJDWZtATzMum7OEjYC2g_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, checkMeta__ZPW6MqdUk6rECHJvUIgrnA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDiscard__7YxUILpPxooC5qqa89a54dw_48)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semWhile__vJZwz9bfROKrfrtM50y74CQ_31)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTry__vJZwz9bfROKrfrtM50y74CQ_32)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toObject__IIQZtbSxQZOu2WmBJ9bnpCg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toRef__IIQZtbSxQZOu2WmBJ9bnpCg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBreakOrContinue__7YxUILpPxooC5qqa89a54dw_49)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFor__vJZwz9bfROKrfrtM50y74CQ_33)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleForLoopMacro__vJZwz9bfROKrfrtM50y74CQ_34)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleStmtMacro__15J7kYDEVfuA6C4REjC7dA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* selector, NimStringDesc* magicType, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprNoDeref__vJZwz9bfROKrfrtM50y74CQ_35)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrivalStmtExpr__OiccTa3ruRNl9anoSqZh2Sg_6)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semForVars__vJZwz9bfROKrfrtM50y74CQ_36)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semForFields__7e8kUc3a9a4gEAcnG7wUcyQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, instFieldLoopBody__NWigU6dr5apz5g827GjO4w)(tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forLoop);
N_LIB_PRIVATE N_NIMCALL(void, semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ)(tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forLoop, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__aOnJJ9cXkOooTyUuLmnc09bw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__3PkUvehQ5keciM9cue9ayMTw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kinds);
static N_INLINE(NIM_BOOL, isClosureIterator__EhCVbB6PynSh7XFAFVMiJA_3ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, implicitIterator__p09bRKOzs8qJ4GcAQ9czOv9bQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NimStringDesc* it, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCase__vJZwz9bfROKrfrtM50y74CQ_37)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, pushCaseContext__Hz1YayV9c9aSkUcvf7h2lHXQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseNode);
N_LIB_PRIVATE N_NIMCALL(void, popCaseContext__9aY89b9aR25iMJ8fPdM84CvQg_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleCaseStmtMacro__vJZwz9bfROKrfrtM50y74CQ_38)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(void, setCaseContextIdx__jiOUhpYURJJFfrdMgAQxPQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NI idx);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semReturn__7YxUILpPxooC5qqa89a54dw_50)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semUsing__7YxUILpPxooC5qqa89a54dw_51)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsm__7YxUILpPxooC5qqa89a54dw_52)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, pragmaAsm__BMqa01f86BatswrKktaxCw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsmOrEmit__7on6juYQ5yDeHojpmzlBFg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* con, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_CHAR marker);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semYield__7YxUILpPxooC5qqa89a54dw_53)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, semYieldVarResult__RmzIhIZBxhW1YDiKMLOGcQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* restype);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIterator__7YxUILpPxooC5qqa89a54dw_54)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProc__7YxUILpPxooC5qqa89a54dw_55)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFunc__7YxUILpPxooC5qqa89a54dw_56)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMethod__7YxUILpPxooC5qqa89a54dw_57)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getDispatcher__L29cJgZ3WUDC7PfTSciv49cw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConverterDef__7YxUILpPxooC5qqa89a54dw_58)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__ymX9afTGg7YU9b9aXV3gliVtA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conv);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMacroDef__7YxUILpPxooC5qqa89a54dw_59)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalImport__xmufAMBjGiK9cy1UljniTyg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalImportExcept__xmufAMBjGiK9cy1UljniTyg_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalFrom__xmufAMBjGiK9cy1UljniTyg_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalInclude__7YxUILpPxooC5qqa89a54dw_60)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, incMod__AE9a7ubTroOu3uw1tThDp7g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* includeStmtResult);
N_LIB_PRIVATE N_NIMCALL(NI32, checkModuleName__fDy39b69bb9cFVEyPkMJp3GTg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL doLocalError);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExport__7YxUILpPxooC5qqa89a54dw_61)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExportExcept__7YxUILpPxooC5qqa89a54dw_62)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, readExceptSet__t9cI0oYChx2XYqk1hhh0lvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPragmaBlock__7YxUILpPxooC5qqa89a54dw_63)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, setLine__eTuk9brfDSpx17jJ53NDUag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStaticStmt__7YxUILpPxooC5qqa89a54dw_64)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, evalStaticStmt__4ISne8kQ4QKaNjEY5dqxUg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___59bygf5b7AsTVb9a1lVM66oA)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOperand__vJZwz9bfROKrfrtM50y74CQ_39)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semInferredLambda__s5ZNJifOyxLa9bFOCUqHCXg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, replaceTypesInBody__JQMwbj1fgdFwBCg7mhUBRQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL allowMetaTypes);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, instTypeBoundOp__Kdk4BCAjDmsFKO9cO4U4ccw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
N_LIB_PRIVATE N_NIMCALL(NI*, new__wSSF51wLRD8g2UFxfG6Hvg)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmtAndGenerateGenerics__7YxUILpPxooC5qqa89a54dw_65)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportSystemStmt__Py1GUj7PccyIa3ac40A6MA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyTree__OiccTa3ruRNl9anoSqZh2Sg_7)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbols__9bonb4OC5BOScb4pv7w7J1Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fromMod);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAllTypeSections__7YxUILpPxooC5qqa89a54dw_66)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, gatherStmts__9a9a1Ojxj7NR51moAUvzAVIw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hloStmt__7YxUILpPxooC5qqa89a54dw_67)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, buildEchoStmt__7YxUILpPxooC5qqa89a54dw_68)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, appendToModule__T4o9clzgbAgGY4ORbfP6LmQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, recoverContext__Zisdl5hRh5Vv9bXMXRnK8QA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
static N_INLINE(Exception*, getCurrentException)(void);
static N_INLINE(NIM_BOOL, isObjWithCache)(TNimType* obj, TNimType* subclass, TNimType** cache);
N_LIB_PRIVATE N_NOINLINE(NIM_BOOL, isObjSlowPath__H8B7g6iFRPI5Em52KFoD6w)(TNimType* obj, TNimType* subclass, TNimType** cache);
N_LIB_PRIVATE N_NIMCALL(void, suggestSentinel__9bcrXlTwB3ELAkoCqH9bihfA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, reportUnusedModules__Zisdl5hRh5Vv9bXMXRnK8QA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, addCodeForGenerics__NRIJDWZtATzMum7OEjYC2g_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_2, "sem.myOpen", 10);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_4, "/home/runner/work/nightlies/nightlies/nim/compiler/sem.nim", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_3 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 507),
((NI) 30)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_5, "constant of type \'", 18);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_6, "\' has no value", 14);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_8, "/home/runner/work/nightlies/nightlies/nim/compiler/semexprs.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_7 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 97),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_9, "recursive dependency: \'$1\'", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_10 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 462),
((NI) 15)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_11, "\'$1\' has unspecified generic parameters", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_12 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 468),
((NI) 15)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_13, "template instantiation too nested", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_14 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 400),
((NI) 15)}
;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__rF9caJawfOjYTjsgLVUSGFA_15 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x04,
0x02, 0x00, 0xe0, 0x11, 0x02, 0x0c, 0x01, 0xc0,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_16, "expression \'", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_17, "\' is of type \'", 14);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_18, "\' and has to be used (or discarded)", 35);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_19, "; start of expression here: ", 28);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_20, "; for a function call use ()", 28);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_22, "/home/runner/work/nightlies/nightlies/nim/compiler/semstmts.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_21 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 151),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_23, "type expected", 13);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_25, "/home/runner/work/nightlies/nightlies/nim/compiler/semtypes.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_24 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 430),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_26, "[]", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_27, "range is empty", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_28 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 224),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_29, "type mismatch", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_30 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 239),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_31, "ordinal or float type expected", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_32 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 242),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_33, "enum \'$1\' has holes", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_34 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 244),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_35, "NaN is not a valid start or end for a range", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_36 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 255),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_37 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 258),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_38, "invalid type", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_39 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1720),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_40, "expected type, but got: ", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_41 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1519),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_42, "|", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_43 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1731),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_44 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1734),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_45, "Invalid syntax. When used with a type, \'not\' can be followed on"
"ly by \'nil\'", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_46 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1746),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_47, "enable the \'not nil\' annotation with {.experimental: \"notnil\".}", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_48 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1749),
((NI) 22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_49 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1781),
((NI) 22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_50 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1786),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_51, "cannot inherit from a type that is not an object type", 53);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_52 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 856),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_53 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 868),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_54, "addInheritedFieldsAux", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_55 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 815),
((NI) 42)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_56, "addInheritedFieldsAux(record case branch)", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_57 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 821),
((NI) 25)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_58, "addInheritedFieldsAux()", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_59 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 828),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_60, "inheritance only works with non-final objects; for ", 51);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_61, " to be inheritable it must be \'object of RootObj\' instead of \'o"
"bject\'", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_62 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 872),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_63, "semObjectNode", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_64 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 877),
((NI) 40)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_65, "expression has no type: ", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_66 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 91),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_67, "(", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_68, ", ", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_69, ")", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_71, "/home/runner/work/nightlies/nightlies/nim/compiler/seminst.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_70 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 328),
((NI) 17)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_72, "generic instantiation too nested", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_73 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 331),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_74 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 350),
((NI) 17)}
;
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_75 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 61),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_76 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 63),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_77, "cannot instantiate: \'$1\'", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_78 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 77),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_79 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 80),
((NI) 16)}
;
extern TNimType NTI__GJ8qR6LTU9bYLzfOArsHTSg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_80 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 271),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_81, "no tuple type for constructor", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_82 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 514),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_83, "invalid tuple constructor", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_84 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 520),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_85, "unknown identifier: ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_86 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 525),
((NI) 23)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_87, "cannot convert ", 15);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_88, " to ", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_89 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 543),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_90, "cannot convert \'$1\' to \'$2\'", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_91 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 547),
((NI) 16)}
;
extern TNimType NTI__DXS6mEo7PVUFJkirsQ9bNQA_;
extern TNimType NTI__jWKvSdankQPoT5bw9cBU9aiw_;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_92 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x0c, 0x40, 0xfd, 0x63, 0x7f, 0xbf, 0x00,
0xc6, 0xfc, 0x1f, 0x00, 0x02, 0x84, 0x03, 0x68,
0x0c, 0xc0, 0x90, 0x24, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_93, "NimNode", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_94, "incorrect result proc symbol", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_95 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1447),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_96, "result", 6);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_97, "value of type \'$1\' has to be used (or discarded)", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_98 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 128),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_99, "semstmts.nim(1509, 14) `r[0].kind == nkSym` ", 44);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_100, "semstmts.nim(1518, 14) `result != nil` ", 39);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_101, "cannot use symbol of kind \'$1\' as a \'$2\'", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_102 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 206),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_103, "\'$1\' is only allowed at top level", 33);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_104, "export", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_105 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 483),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_106, "invalid visibility: \'$1\'", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_107 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 485),
((NI) 20)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_108 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x18, 0xec, 0x31, 0x00, 0xa0, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x02, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x01}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_109 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x04, 0x18, 0xec, 0x63, 0x02, 0xa7, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60,
0x00, 0xc0, 0xc4, 0x02, 0x00, 0x44, 0x00, 0x01,
0x00, 0x20, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_110 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x04, 0x07, 0xec, 0x63, 0x02, 0xa6, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xc0, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_111, "in", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_112, "the \'$1\' modifier can be used only with imported types", 54);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_113 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 2122),
((NI) 24)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_114, "{}", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_115, "\'", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_116, "\' is only allowed in templates and macros or magic procs", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_117 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1218),
((NI) 20)}
;
extern NIM_CONST tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw OverloadableSyms__yJfP9bpZPSQn9bPO6KCo08fQ;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_118, "{}=", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_119, "[]=", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_120, "cannot infer the type of parameter \'", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_121 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1236),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_122, "\':\' expected", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_123 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1260),
((NI) 27)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_124 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_125, "typeless parameters are obsolete", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_126 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1274),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_127, ":type", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_128, "the macro body cannot be compiled, because the parameter \'$1\' h"
"as a generic type", 80);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_129 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1039),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_130, "typedesc", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_131, "type", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_132, "illegal recursion in type \'$1\'", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_133 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1079),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_134 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_71),
((NI) 178),
((NI) 17)}
;
extern TNimType NTI__zSq8dodcWpSdfE0WaiBU9cw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_135 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1120),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_136, "attempt to redefine: \'", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_137 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1286),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_138, "`typed` will change its meaning in future versions of Nim. `voi"
"d` or no return type declaration at all has the same meaning as "
"the current meaning of `typed` as return type declaration.", 185);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_139 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1308),
((NI) 11)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_140, "return type \'", 13);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_141, "\' is only valid for macros and templates", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_142 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1316),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_143, "invalid expression", 18);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_145, "/home/runner/work/nightlies/nightlies/nim/compiler/semtempl.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_144 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 722),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_146 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 707),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_147 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 732),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_148 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 734),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_149, "*", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_150, "**", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_151, "~", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_152, "a pattern cannot be empty", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_153 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 804),
((NI) 16)}
;
static NIM_CONST tyTuple__jdFwpivBCgGar3GHRE8kKQ TM__rF9caJawfOjYTjsgLVUSGFA_154 = {((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL),
NIM_FALSE}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_155, "pragmas are only allowed in the header of a proc; redefinition "
"of $1", 68);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_156, "\' from ", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_157 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1947),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_158, "semProcAux", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_159 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1968),
((NI) 46)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_160, "=destroy", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_161, "deepcopy", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_162, "=deepcopy", 9);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_163, "=", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_164, "=copy", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_165, "=sink", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_166, "=trace", 6);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_167, "=dispose", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_168, "cannot bind another \'", 21);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_169, "\' to: ", 6);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_170, "; previous declaration was constructed here implicitly: ", 56);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_171, "; previous declaration was here: ", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_172 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1667),
((NI) 12)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_173, "type bound operation `", 22);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_174, "` can be defined only in the same module with its type (", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_175 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1703),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_176, "signature for \'", 15);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_177, "\' must be proc[T: object](x: var T)", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_178 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1706),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_179, "cannot bind another \'deepCopy\' to: ", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_180 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1730),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_181, "cannot bind \'deepCopy\' to: ", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_182 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1733),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_183 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1737),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_184, "signature for \'deepCopy\' must be proc[T: ptr|ref](x: T): T", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_185 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1741),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_186 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1775),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_187, "\' must be proc[T: object](x: var T; y: T)", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_188 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1780),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_189, "\'destroy\' or \'deepCopy\' expected for \'override\'", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_190 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1788),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_192, ".", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_193, ".()", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_194, ".=", 2);
static NIM_CONST tyArray__24KAM9afIUgUaqBaEBB6r9bg TM__rF9caJawfOjYTjsgLVUSGFA_191 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_192),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_193),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_194)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_195, "the overloaded ", 15);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_196, " operator has to be enabled with {.experimental: \"dotOperators\""
".}", 65);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_197 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1979),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_198, "()", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_199, " operator has to be enabled with {.experimental: \"callOperator\""
".}", 65);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_200 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1982),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_201, "implementation of \'$1\' is not allowed", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_202 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1988),
((NI) 16)}
;
extern TNimType NTI__MvZmat48bhe9b6x9aUD58D5Q_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_203, "generic methods are deprecated", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_204 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1830),
((NI) 11)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_205, "\'method\' needs a parameter that has an object type", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_206 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1840),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_207, "invalid type: \'$1\' for $2", 25);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_208, ". Did you mean to call the $1 with \'()\'\?", 40);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_209, "invalid type: \'$1\' in this context: \'$2\' for $3", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_210 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 243),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_212, "/home/runner/work/nightlies/nightlies/nim/compiler/hlo.nim", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_211 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_212),
((NI) 48),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_213 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_212),
((NI) 15),
((NI) 17)}
;
static NIM_CONST tySet_tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg TM__rF9caJawfOjYTjsgLVUSGFA_214 = {
0x00, 0x00, 0x20, 0x60, 0x07, 0x03, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x38, 0x46, 0x30, 0x08, 0x00, 0x00, 0x00, 0x00,
0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_215, "for a \'var\' type a variable needs to be passed; but \'$1\' is imm"
"utable", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_216 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 722),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_217, "address of \'$1\' may not escape its stack frame", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_218 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 729),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_219 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 674),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_220, "analyseIfAddressTaken", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_221 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 688),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_222, "expression has no address", 25);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_224, "/home/runner/work/nightlies/nightlies/nim/compiler/semmagic.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_223 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 21),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_225, "expression has no address; maybe use \'unsafeAddr\'", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_226 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 23),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_227, "unsafeAddr", 10);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_228, "typeof: cannot evaluate \'mode\' parameter at compile-time", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_229 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 31),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_230, "can\'t compute offsetof on this ast", 34);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_232, "/home/runner/work/nightlies/nightlies/nim/compiler/sizealignoff"
"setimpl.nim", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_231 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_232),
((NI) 493),
((NI) 16)}
;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Max__zlJMNfqX7LwCYj0PF6ncWQ;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_233, "invalid index value for tuple subscript", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_234 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1510),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_235, "cannot instantiate: \'", 21);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_236, "\'; got ", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_237, " typeof(s) but expected ", 24);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_239, "/home/runner/work/nightlies/nightlies/nim/compiler/semcall.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_238 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 650),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_240 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 608),
((NI) 12)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_241, "AnonType", 8);
extern TNimType NTI__0dpGN6F4ocevqUQGsaf41w_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_242, "could not resolve: ", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_243 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 310),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_244 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 283),
((NI) 15)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_245, "expression \'$1\' cannot be called", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_246 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 286),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_247, "\012", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_248, "  first type mismatch at position: ", 35);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_249, "\012  unknown named parameter", 26);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_250, "\012  unknown named parameter: ", 28);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_251, "\012  named param already provided: ", 33);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_252, "\012  positional param was already given as named param", 52);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_253, "\012  extra argument given", 23);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_254, "\012  missing parameter: ", 22);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_255, "semcall.nim(228, 18) `nArg != nil` ", 35);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_256, "semcall.nim(230, 18) `err.firstMismatch.formal != nil` ", 55);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_257, "\012  required type for ", 21);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_258, ": ", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_259, "\012  but expression \'", 19);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_260, "\' is immutable, not \'var\'", 25);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_261, "\' is of type: ", 14);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_262, "semcall.nim(249, 20) `wanted != nil` ", 37);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_263, "\012  This expression is not GC-safe. Annotate the proc with {.gcs"
"afe.} to get extended error information.", 103);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_264, "\012  This expression can have side effects. Annotate the proc wit"
"h {.noSideEffect.} to get extended error information.", 116);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_265, "\012  The `.raises` requirements differ.", 37);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_266, "\012  The `.raises` requirements differ. Annotate the proc with {."
"raises: [].} to get extended error information.", 110);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_267, "\012  The `.tags` requirements differ.", 35);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_268, "\012  The `.tags` requirements differ. Annotate the proc with {.ta"
"gs: [].} to get extended error information.", 106);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_269, "\012  The `.locks` requirements differ. Annotate the proc with {.l"
"ocks: 0.} to get extended error information.", 107);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_270, " other mismatching symbols have been suppressed; compile with -"
"-showAllMismatches:on to see them\012", 97);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_271, "maybe misplaced space between ", 30);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_272, " and \'(\' \012", 10);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_273, "type mismatch: got <", 20);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_274, "\012but expected one of: \012", 23);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_275, "\012expression: ", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_276 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 295),
((NI) 12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_277 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 209),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_278 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 129),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_279, "or", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_280, "and", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_281, "not", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_282, "typeToString", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_283, "name", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_284, "$", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_285, "arity", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_286, "genericHead", 11);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_287, "stripGenericParams", 18);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_288, "supportsCopyMem", 15);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_289, "isNamedTuple", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_290, "tupleLen", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_291, "distinctBase", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_292, "expected generic type, got: type $2 of kind $1", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_293 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 174),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_294, "distinctBase expects a distinct type as argument. The given typ"
"e was ", 69);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_295 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 199),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_296, "unknown trait: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_297 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 203),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_298, "integer literal expected", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_299 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 80),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_300, "command line", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_301, "\?\?\?", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_302, "ordinal type expected", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_303 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 228),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_304, "\'of\' takes object types", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_305 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 334),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_306 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 336),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_307 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 345),
((NI) 15)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_308, "\'$1\' cannot be of this subtype", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_309 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 352),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_310 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 354),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_311, "\'of\' takes 2 arguments", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_312 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 359),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_313, "\'$1\' expects a type or value", 28);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_314, "low", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_315, "high", 4);
N_LIB_PRIVATE NIM_CONST tyArray__nr38yHugp0nuiB6VarJGiw opToStr__x47hvY2ezR4p9cvQjupSCVQ = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_314),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_315)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_316 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 356),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_317, "invalid argument for: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_318 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 373),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_319, "string literal expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_320 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 237),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_321, "constant expression expected", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_322 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 243),
((NI) 14)}
;
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__LF0eKAnygFo4etNDdpTetg_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTI__EjEifkTC8tg9afiUW4StSSA_;
extern TNimType NTI__N89ckikRqMir57209a3tEeqw_;
N_LIB_PRIVATE TNimType NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_324, "bindSymImpl", 11);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_325, "string or ident node expected", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_326 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 261),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_327 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 265),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_328, "cannot find plugin ", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_329 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 521),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_330, "finalizer must be a direct reference to a proc", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_331 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 528),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_332 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 535),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_333 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 540),
((NI) 20)}
;
N_LIB_PRIVATE TNimType NTI__UaUb9bgQbqCS7gyXItZuJNg_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__NaDYkbcAjZXYRP9arR0vzYg_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_337, "<quantifier> \'in\' <range> expected", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_338 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 454),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_339, "\'old\' takes a parameter name", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_340 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 462),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_341, " does not belong to ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_342 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 464),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_343 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 566),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_344 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 569),
((NI) 12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_345 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 572),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_346, "expression cannot be isolated: ", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_347 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_224),
((NI) 575),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg TM__rF9caJawfOjYTjsgLVUSGFA_348 = {
0xe1, 0x00, 0x00, 0xe0, 0xf0, 0xcf, 0xff, 0xf7,
0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xf0, 0x3f,
0xf8, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_349, "cannot evaluate \'$1\'", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_350 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 812),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_351, "the resulting AST is cyclic and cannot be processed further", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_352 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 299),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_353, " --> \'", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_354 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_212),
((NI) 31),
((NI) 11)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_355, "return type \'auto\' cannot be used in forward declarations", 57);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_356 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2027),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_357, "implementation of \'$1\' expected", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_358 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2030),
((NI) 31)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_359, "no symbol to borrow from found", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_360 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1441),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_361, "\'.closure\' calling convention for top level routines is invalid", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_362 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2048),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_363 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
extern TNimType NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_;
N_LIB_PRIVATE TNimType NTI__K9bYwLtGKmFQYg8TwmqoG3Q_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__P9bWebqKHkrGHwy9aZW9bw0TA_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_365 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 385),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_366, "\012  found \'$1\' of kind \'$2\'", 26);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_367, " for type ", 10);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_368, "undeclared field: \'$1\'", 22);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_369, " ", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_370, "attempting to call undeclared routine: \'$1\'", 43);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_371, "attempting to call routine: \'$1\'$2", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_372 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 414),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_373 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 418),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_374 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 428),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_375, "ambiguous call", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_376 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 433),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_377, "ambiguous call; both $1 and $2 match for: $3", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_378 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 442),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_379, "Non-matching candidates for ", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_380 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 574),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_381 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_239),
((NI) 549),
((NI) 25)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_382, "semOverloadedCallAnalyseEffects", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_383 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 852),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_384, "recursion is not supported in iterators: \'$1\'", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_385 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 859),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_386, "expression has no type", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_387 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1713),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_388, "\'$1\' cannot be assigned to", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_389 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1718),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_390 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1734),
((NI) 25)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_391, "cannot return an owned pointer as an unowned pointer; use \'owne"
"d(", 65);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_392, ")\' as the return type", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_393 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1647),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_394, "assignment produces a dangling ref: the unowned ref lives longe"
"r than the owned ref", 83);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_395 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1650),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_396, "\'$1\' escapes its stack frame; context: \'$2\'; see $3", 51);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_397, "var_t_return.html", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_398 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1577),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_399, "\'$1\' is not the first parameter; context: \'$2\'; see $3", 54);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_400 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1580),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_401 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1595),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_402 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1597),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_403, "cannot infer the return type of \'$1\'", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_404 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1804),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_405 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1808),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_406 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 487),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_407, "semRecordCase: discriminant is no symbol", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_408 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 664),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_409, "selector must be of an ordinal type, float", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_410 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 682),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_411, "low(", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_412, ") must be 0 for discriminant", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_413 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 684),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_414, "len($1) must be less than 32768", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_415 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 687),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_416 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 526),
((NI) 35)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_417, "duplicate case label", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_418 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 514),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_419 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 699),
((NI) 15)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_420, "not all cases are covered; missing: $1", 38);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_421, "{", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_422, "omitted $1 values...", 20);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_423, "}", 1);
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_424 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 706),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_425, "not all cases are covered", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_426 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 709),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_427, "initialization not allowed here", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_428 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 766),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_429 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 769),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_430 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 793),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_431 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 804),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_432, "dummy", 5);
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_433 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x14, 0x00, 0xec, 0xff, 0x0a, 0xa6, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x00,
0xc4, 0xc0, 0x02, 0x19, 0x00, 0x04, 0x00, 0x00,
0x00, 0x03, 0x00, 0x60, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_435, "/home/runner/work/nightlies/nightlies/nim/compiler/semobjconstr"
".nim", 67);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_434 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 179),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_436, "incorrect object construction syntax; use a space after the col"
"on", 65);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_437 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 52),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_438, "incorrect object construction syntax", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_439 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 54),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_440, "semobjconstr.nim(132, 14) `recList.kind == nkRecList` ", 54);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_441, "The fields \'$1\' and \'$2\' cannot be initialized together, becaus"
"e they are from conflicting branches in the case object.", 119);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_442 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 190),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_443, "the field \'$1\' is not accessible.", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_444 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 74),
((NI) 16)}
;
extern TNimType NTI__IxbcvonC7TQkv166Uvdu1g_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_446, "branch initialization with a runtime discriminator only support"
"s ordinal types with 2^16 elements or less.", 106);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_447 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 233),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_448, "cannot prove that it\'s safe to initialize $1 with the runtime v"
"alue for the discriminator \'$2\' ", 95);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_449 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 201),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_450, "possible values $2 are in conflict with discriminator values fo"
"r selected object branch $1.", 91);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_451 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 247),
((NI) 35)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_452, "runtime discriminator must be immutable if branch fields are in"
"itialized, a \'let\' binding is required.", 102);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_453 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 252),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_454, "branch initialization with a runtime discriminator is not suppo"
"rted inside of an `elif` branch.", 95);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_455 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 256),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_456 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 265),
((NI) 33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_457 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 283),
((NI) 35)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_458, "a case selecting discriminator \'$1\' with value \'$2\' appears in "
"the object construction, but the field(s) $3 are in conflict wit"
"h this value.", 140);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_459 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 285),
((NI) 28)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_460 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 323),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_461, "type \'$1 void\' is not allowed", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_462 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 913),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_463, "region needs to be an object type", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_464 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 928),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_465, "region for pointer types is deprecated", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_466 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 931),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_467, "typeof", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_468 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1675),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_469, "owned", 5);
extern TNimType NTI__AgIT5feFR9a9aoVjv9cx2rOtg_;
extern TNimType NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_470 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 386),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_471 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 400),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_472 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 410),
((NI) 47)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_473, "identifier expected", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_474 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 425),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_475 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1653),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_476, "Array length can\'t be negative, but was ", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_477 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 297),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_478 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 305),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_479 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 310),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_480 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 339),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_481 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 341),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_482, "array expects two type parameters", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_483 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 351),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_484, "\'$1\' is not a concrete type", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_485 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 175),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_486, "\'$1\' expects one type parameter", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_487 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 178),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_488, "openarray", 9);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_489, "UncheckedArray", 14);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_490, "..<", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_491, "range types need to be constructed with \'..\', \'..<\' is not supp"
"orted", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_492 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 280),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_493, "expected range", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_494 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 282),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_495, "range", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_496 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 285),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_497 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 164),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_498, "set is too large", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_499 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 166),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_500, "set", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_501 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 168),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_502 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 360),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_503, "ordinal", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_504 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 363),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_505, "seq", 3);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_506, "varargs", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_507 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 194),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_508, "type \'var var\' is not allowed", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_509 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1842),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_510 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 448),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_511 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 451),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_512 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 458),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_513 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 466),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_514, "cannot instantiate the \'$1\' $2", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_515 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1408),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_516 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1421),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_517, "no generic parameters allowed for $1", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_518 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1433),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_519, "cannot instantiate ", 19);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_520, "\012got: <", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_521, ">\012but expected: <", 17);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_522, ">", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_523 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1444),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_524 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1465),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_525 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1475),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_526, "object", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_527 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1395),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_528, "inheritance only works with non-final objects", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_529 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1402),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_530, "object constructor needs an object type; for named arguments us"
"e \'=\' instead of \':\'", 83);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_531 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1852),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_532 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1858),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_533 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1874),
((NI) 38)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_534 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1877),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_535 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1899),
((NI) 25)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_536, "type expected, but symbol \'$1\' has no type.", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_537 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1914),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_538, "type expected, but got symbol \'$1\' of kind \'$2\'", 47);
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_539 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1916),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_540 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1577),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_541 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 202),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_542, "semtypes.nim(1615, 22) `r[0].kind == nkSym` ", 44);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_543, "semtypes.nim(1620, 27) `false` cannot happen", 44);
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_544 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x08, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00,
0x80, 0xfc, 0x1f, 0x00, 0x00, 0x84, 0x03, 0x00,
0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_545 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x84, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_546, "inheritance only works with an enum", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_547 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 74),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_548 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_549, "ordinal type expected; given: ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_550 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 100),
((NI) 24)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_551 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 104),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_552, "wrong number of variables", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_553 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 106),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_554 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 112),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_555, "invalid order in enum \'$1\'", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_556 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 118),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_557, "type expected, but got: ", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_558 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 1952),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_559 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 425),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_560 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 476),
((NI) 11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_561 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1206),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_562, "illegal context for \'nimvm\' magic", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_563 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1210),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_564, "semexprs.nim(1251, 22) `f == s` ", 32);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_565, "bind is deprecated", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_566 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2701),
((NI) 11)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_567, "a type conversion takes exactly one argument", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_568 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 244),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_569 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 252),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_570 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 832),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_571, ":anon", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_572, "object construction uses \':\', not \'=\'", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_573 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 286),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_574 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 313),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_575, "illegal conversion from \'$1\' to \'$2\'", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_576 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 317),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_577, " can\'t be converted to ", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_578 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 322),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_579, "object constructor needs an object type", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_580 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 374),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_581 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 386),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_582, "The $1 type requires the following fields to be initialized: $2"
".", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_583 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 398),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_584, "field initialized twice: \'$1\'", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_585 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 417),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_586 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 420),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_587, "identifier expected, but got: ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_588 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1896),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_590, "\'is\' operator takes 2 arguments", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_591 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 441),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_592 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 392),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_593, "closure", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_594, "iterator", 8);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_595, "expected a template that takes ", 31);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_596, " arguments", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_597 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1962),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_598, "ambiguous symbol in \'getAst\' context: ", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_599 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1964),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_600, "getAst takes a call, but got ", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_601 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1974),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_602 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1976),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_603, "\'quote\' expects 1 or 2 arguments", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_604 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2019),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_605 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1930),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_606, "``", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_607, "block", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_608 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2034),
((NI) 14)}
;
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_609, "untyped", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_610, "!=", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_611, ">=", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_612, "incl", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_613, "excl", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_614, "notin", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_615, "isnot", 5);
N_LIB_PRIVATE NIM_CONST tyArray__Q6RksR9bl1dCf8jl3HeN9bXg names__yCnDYwFZyTz3YBJ4ma9adZQ = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_610),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_611),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_522),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_612),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_613),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_111),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_614),
((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_615)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_616, "vm", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_617, "stackTrace", 10);
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_618 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x01, 0x02, 0x00, 0xa0, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
0x00, 0xc0, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_619 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 662),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_620 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_145),
((NI) 664),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_621, "newIdentNode", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_622, "getAst", 6);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_623, "use the {.experimental.} pragma to enable \'parallel\'", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_624 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2227),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_625, "FlowVar", 7);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_626, "nimCreateFlowVar", 16);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_627, "system needs: nimCreateFlowVar", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_628 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2157),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_630, "sizeof", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_631 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2175),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_632 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 946),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_633, ">\012but expected one of: \012", 24);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_634, " = ", 3);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_635 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 970),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_636, ":tmp", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_637, "named expression expected", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_638 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2444),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_639, "named expression not allowed here", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_640 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2448),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_641, "Mixing types and values in tuples is not allowed.", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_642 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2568),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_643 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2461),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_644, "typedesc not allowed as tuple field.", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_645 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2466),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_646 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2385),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_647, "expected ordinal value for array ", 33);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_648, "index, got \'$1\'", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_649 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 578),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_650, "size of array exceeds range of index ", 37);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_651, "type \'$1\' by $2 elements", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_652 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 595),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_653, "invalid order in array constructor", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_654 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 603),
((NI) 20)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_655 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x08, 0x00, 0xec, 0x61, 0x3f, 0x01, 0x00,
0x40, 0xfc, 0x1f, 0x00, 0x00, 0x84, 0x03, 0x00,
0x00, 0x00, 0x90, 0x04, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_656 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1574),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_657, "A nested proc can have generic parameters only when it is used "
"as an operand to another routine and the types of the generic pa"
"ramers can be inferred from the expected signature.", 178);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_658 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1584),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_659 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1587),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_660, "cannot cast to a non concrete type: \'$1\'", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_661 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 341),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_662, "expression cannot be cast to ", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_663 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 346),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_664, "==", 2);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_665, "cannot infer the concept parameter \'%s\', due to a type mismatch"
". attempt to equate \'%s\' and \'%s\'.", 97);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_666 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2227),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_667, "concept predicate failed", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_668 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2264),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_669 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2284),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_670, "only a \'ref object\' can be raised", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_671 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1024),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_672, "raised object of type $1 does not inherit from Exception", 56);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_673 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1026),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_674, "semstmts.nim(464, 14) `nodePragma.kind in {nkIdent, nkAccQuoted"
"}` ", 66);
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_675, "cannot infer the type of the $1", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_676 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 520),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_677, "\'$1\' doesn\'t have a concrete type, due to unspecified generic p"
"arameters.", 73);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_678 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 522),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_679, "tuple", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_680 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 544),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_681 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 546),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_682 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 556),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_683, "implicit object field construction requires a .partial object, "
"but got ", 71);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_684 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 422),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_685, "nkDotNode requires 2 children", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_686 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 425),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_687, "_", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_688 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 578),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_689, "a thread var cannot be initialized explicitly; this would only "
"run for the main thread", 86);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_690 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 581),
((NI) 44)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_691, "inconsistent typing for reintroduced symbol \'", 45);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_692, "\': previous type was: ", 22);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_693, "; new type is: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_694 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 429),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_695, "The $1 type doesn\'t have a default value. The following fields "
"must be initialized: $2.", 87);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_696 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_435),
((NI) 364),
((NI) 12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_697 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 341),
((NI) 13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_698 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 343),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_699, "\'let\' symbol requires an initialization", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_700 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 620),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_701 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 626),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_702 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 293),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_703 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 665),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_704 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 675),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_705 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 677),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_706, "unknown package name: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_707 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1054),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_708, " is not a type that can be forwarded", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_709 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1069),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_710, "only top level types in a package can be \'package\'", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_711 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1087),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_712, "cannot complete type \'", 22);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_713, "\' twice; previous type completion was here: ", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_714 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1095),
((NI) 22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_715 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1196),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_716, "auto", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_717, "lent", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_718, "sink", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_719 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 2055),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_720 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_25),
((NI) 2056),
((NI) 18)}
;
N_LIB_PRIVATE TNimType NTI__GnXaFIlVxvDpiKnOUsLlMw_;
N_LIB_PRIVATE TNimType NTI__hW0nFkOHm9b8Hn43XRoDtzQ_;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_725, "non-invariant type param used in a proc type: ", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_726 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1145),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_728, "covariant param \'", 17);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_729, "\' used in a non-covariant position", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_730 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1156),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_731, "contravariant param \'", 21);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_732, "\' used in a non-contravariant position", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_733 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1164),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_735, "non-invariant type parameters cannot be used with types such \'", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_736 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1170),
((NI) 11)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_737, "non-invariant type parameters are not supported in concepts", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_738 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1172),
((NI) 11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_742 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1182),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_744, "{.exportc.} not allowed for type aliases", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_745 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1265),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_746, "only a \'distinct\' type can borrow `.`", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_747 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1268),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_748 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1275),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_749 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1276),
((NI) 21)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_750, ":ObjectType", 11);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_751, "\'$1\' is not a concrete type; for a callback without parameters "
"use \'proc()\'", 75);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_752 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1300),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_753 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1303),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_754 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1322),
((NI) 19)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_755, "statement returns no value that can be discarded", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_756 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 48),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_757, "illegal discard proc, did you mean: ", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_758 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 51),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_759 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 193),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_760, "exception already handled", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_761 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 196),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_762, "Mix of imported and native exception types is not allowed in on"
"e except branch", 78);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_763 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 248),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_764, "Only one finally is allowed after all other branches", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_765 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 252),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_766, "Only one general except clause is allowed after more specific e"
"xceptions", 72);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_767 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 260),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_768, "invalid control flow: $1", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_769 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 72),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_770, "\'continue\' cannot have a label", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_771 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 74),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_772 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 76),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_773 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 845),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_774, "ForLoopStmt", 11);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_775, "expression \'$1\' has no type (or is ambiguous)", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_776 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 87),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_777 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 728),
((NI) 20)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_778 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_779 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 754),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_780 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 756),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_781 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 772),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_782, "true", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_783, "system needs: \'true\'", 20);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_785, "/home/runner/work/nightlies/nightlies/nim/compiler/semfields.ni"
"m", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_784 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_785),
((NI) 111),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_786 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_785),
((NI) 121),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_787, "no object or tuple type", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_788 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_785),
((NI) 127),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_789, "Field", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_790, "\'continue\' not supported in a \'fields\' loop", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_791 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_785),
((NI) 53),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_792, "parallel \'fields\' iterator does not work for \'case\' objects", 59);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_793 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_785),
((NI) 81),
((NI) 16)}
;
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__rF9caJawfOjYTjsgLVUSGFA_794 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_795, "items", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_796, "pairs", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_797, "iterator within for loop context expected", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_798 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 920),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_799, "match", 5);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_800, "selector must be of an ordinal type, float or string", 52);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_801 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 958),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_802 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 986),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_803 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 995),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_804 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 998),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_805, "no return type declared", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_806 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1766),
((NI) 18)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_807, "\'return\' not allowed here", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_808 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1773),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_809, "using", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_810 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 363),
((NI) 34)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_811, "\'using\' section must have a type", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_812 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 379),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_813, "\'using\' sections cannot contain assignments", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_814 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 382),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_815, "\'yield\' only allowed in an iterator", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_816 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1843),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_817, "semYield", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_818 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1851),
((NI) 39)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_819, "tuple constructor", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_820 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1832),
((NI) 20)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_821, "current routine cannot return an expression", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_822 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1861),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_823, "yield statement must yield a value", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_824 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1863),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_825 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x80, 0x00, 0x00, 0x80, 0x00, 0xe0, 0xf3,
0x7f, 0x00, 0x80, 0xff, 0xb9, 0x43, 0x3c, 0x93,
0x13, 0x1f, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00,
0x02, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_826 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x04, 0x00, 0xec, 0x63, 0x0d, 0xa0, 0x00,
0x40, 0xfc, 0x1f, 0x00, 0x00, 0x84, 0x03, 0x00,
0x0c, 0xc0, 0x00, 0x04, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_827, "iterator needs a return type", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_828 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2070),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_829 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2079),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_830 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x0c, 0x40, 0xfd, 0x63, 0x7f, 0xaf, 0x00,
0xc6, 0xfc, 0x1f, 0x00, 0x02, 0x84, 0x03, 0x68,
0x0c, 0xc0, 0x90, 0x24, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_831, "method", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_832 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2091),
((NI) 34)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_833 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x0c, 0x40, 0xf9, 0x63, 0x7f, 0xbf, 0x00,
0xc6, 0xfc, 0x1f, 0x00, 0x02, 0x84, 0x03, 0x68,
0x0c, 0xc0, 0x90, 0x24, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_834, "converter", 9);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_835 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2112),
((NI) 34)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_836, "$1 needs a return type", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_837 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2123),
((NI) 28)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_838, "a converter takes exactly one argument", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_839 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2124),
((NI) 27)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_840 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x04, 0x00, 0xed, 0x63, 0x04, 0xa6, 0x00,
0x40, 0xfc, 0x1f, 0x00, 0x02, 0x00, 0x00, 0x00,
0x08, 0xc0, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_841 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2144),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_842, "import", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_843 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2871),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_844 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2874),
((NI) 36)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_845, "from", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_846 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2877),
((NI) 36)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_847, "/", 1);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_848, "Cannot use \'", 12);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_849, "\' in \'include\'.", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_850 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2162),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_851 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 2150),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_852 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2883),
((NI) 36)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_853, "cannot export: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_854 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2537),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_855, "; enum field cannot be exported individually", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_856 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2552),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_857 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2886),
((NI) 36)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_858, "The export/except syntax expects a module name", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_859 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2514),
((NI) 14)}
;
static NIM_CONST tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw TM__rF9caJawfOjYTjsgLVUSGFA_860 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x08,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_861, "defer statement not supported at top level", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_862 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2894),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_863, "\'defer\' takes a \'void\' expression", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_864 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2897),
((NI) 16)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_865, "invalid expression: ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_866 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 2905),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_867 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 70),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_868 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 78),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_869 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 349),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_870 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 358),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_871 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 361),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_872 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 56),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_873 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 61),
((NI) 14)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_874, "cannot infer type of parameter: ", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_875 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1614),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_879 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_22),
((NI) 1371),
((NI) 22)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_880, "echo", 4);
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_881, "system needs: echo", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_882 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_8),
((NI) 1018),
((NI) 14)}
;
extern TNimType NTI__cDtWY9cE7zf8BAC5QcEZZkQ_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_885 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 622),
((NI) 13)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_886, "n is not nil", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_887 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 633),
((NI) 17)}
;
STRING_LITERAL(TM__rF9caJawfOjYTjsgLVUSGFA_888, "no code for ", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__rF9caJawfOjYTjsgLVUSGFA_889 = {((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_4),
((NI) 500),
((NI) 21)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
static TNimType* Nim_OfCheck_CACHE885[2];

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T4_)) goto LA5_;
			result = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag((*n)._kind_6.sons->data[((NI) 0)]);
			goto BeforeRet_;
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		{
			NI T10_;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 1) < T10_)) goto LA11_;
			result = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag((*n)._kind_6.sons->data[((NI) 1)]);
			goto BeforeRet_;
		}
		LA11_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	result = (*n).info;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symChoice__ce08GbPIDAcM29cbr3lVUxg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA r, NIM_BOOL isField) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a;
	tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
	NI i;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	a = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
	i = ((NI) 0);
	a = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, n);
	{
		while (1) {
			if (!!((a == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				if (!!(((*a).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA5_;
				i += ((NI) 1);
				{
					if (!(((NI) 1) < i)) goto LA9_;
					goto LA1;
				}
				LA9_: ;
			}
			LA5_: ;
			a = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, n);
		} LA2: ;
	} LA1: ;
	info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = (i <= ((NI) 1));
		if (!(T13_)) goto LA14_;
		T13_ = !((r == ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2)));
		LA14_: ;
		if (!T13_) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = !(isField);
			if (T19_) goto LA20_;
			T19_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0));
			LA20_: ;
			if (!T19_) goto LA21_;
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, info);
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, s);
		}
		goto LA17_;
		LA21_: ;
		{
			result = n;
		}
		LA17_: ;
	}
	goto LA11_;
	LA15_: ;
	{
		tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T32_;
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = (r == ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0));
			if (T27_) goto LA28_;
			T27_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45));
			LA28_: ;
			if (!T27_) goto LA29_;
			kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56);
		}
		goto LA25_;
		LA29_: ;
		{
			kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57);
		}
		LA25_: ;
		T32_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T32_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(kind, info, T32_);
		a = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, n);
		{
			while (1) {
				if (!!((a == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA34;
				{
					NIM_BOOL T37_;
					NIM_BOOL T39_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
					T37_ = (NIM_BOOL)0;
					T37_ = !(((*a).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
					if (!(T37_)) goto LA38_;
					T39_ = (NIM_BOOL)0;
					T39_ = !(isField);
					if (T39_) goto LA40_;
					T39_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0));
					LA40_: ;
					T37_ = T39_;
					LA38_: ;
					if (!T37_) goto LA41_;
					(*a).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
					markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw(c, a);
					T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T43_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(a, info);
					add__P8dDSotTW25BkfbyspojGg(result, T43_);
				}
				LA41_: ;
				a = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, n);
			} LA34: ;
		}
	}
	LA11_: ;
	return result;
}
static N_INLINE(void, markIndirect__OGrPg9bGc5rou9aBRgLK606Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		if (!((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA3_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 17)) & 63);
	}
	LA3_: ;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, inlineConst__a1Z9a4khB42QCtmKBL9cckKAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*s).ast);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(result == 0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T6_ = (NimStringDesc*)0;
		T6_ = typeToString__QlvraUan7WbHowhAbvDvdA((*s).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 32);
appendString(T5_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_5));
appendString(T5_, T6_);
appendString(T5_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_6));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_7, NIM_FALSE);
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s);
	}
	goto LA1_;
	LA3_: ;
	{
		asgnRef((void**) (&(*result).typ), (*s).typ);
		(*result).info = (*n).info;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, resetSemFlag__sIxO9bj7Xwv3qFTK7z9b5jSg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	(*n).flags &= ~(((NU32)1) << ((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7)) & 31));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				resetSemFlag__sIxO9bj7Xwv3qFTK7z9b5jSg((*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, implicitlyDiscardable__OiccTa3ruRNl9anoSqZh2Sg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	NIM_BOOL T3_;
	NIM_BOOL T5_;
	NIM_BOOL T6_;
	result = (NIM_BOOL)0;
	n_2 = n;
	{
		while (1) {
			if (!((TM__rF9caJawfOjYTjsgLVUSGFA_15[(NU)((*n_2).kind)>>3] &(1U<<((NU)((*n_2).kind)&7U)))!=0)) goto LA2;
			n_2 = lastSon__UPSW0jLTX5qJL51YMUAHgw(n_2);
		} LA2: ;
	}
	T3_ = (NIM_BOOL)0;
	T3_ = ((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111));
	if (T3_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T6_ = (NIM_BOOL)0;
	T6_ = isCallExpr__CZaoTkWCFI9acor4BmYF3Yw_2(n_2);
	if (!(T6_)) goto LA7_;
	T6_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	LA7_: ;
	T5_ = T6_;
	if (!(T5_)) goto LA8_;
	T5_ = (((*(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0);
	LA8_: ;
	T3_ = T5_;
	LA4_: ;
	result = T3_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, discardCheck__tp7yV6CFb40nVuGT1TBFpw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
		if (T3_) goto LA4_;
		T3_ = ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = !(((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T9_)) goto LA10_;
		T9_ = !(((IL64(-9223372036854775680) &((NU64)1<<((NU)((*(*result).typ).kind)&63U)))!=0));
		LA10_: ;
		if (!T9_) goto LA11_;
		{
			NIM_BOOL T15_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
			T15_ = (NIM_BOOL)0;
			T15_ = implicitlyDiscardable__OiccTa3ruRNl9anoSqZh2Sg(result);
			if (!T15_) goto LA16_;
			n = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114), (*result).info, ((NI) 1));
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), result);
		}
		goto LA13_;
		LA16_: ;
		{
			NIM_BOOL T19_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
			NimStringDesc* s;
			NimStringDesc* T25_;
			NimStringDesc* T26_;
			NimStringDesc* T27_;
			T19_ = (NIM_BOOL)0;
			T19_ = !(((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50)));
			if (!(T19_)) goto LA20_;
			T19_ = !(((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 18)));
			LA20_: ;
			if (!T19_) goto LA21_;
			n_2 = result;
			{
				while (1) {
					if (!((TM__rF9caJawfOjYTjsgLVUSGFA_15[(NU)((*n_2).kind)>>3] &(1U<<((NU)((*n_2).kind)&7U)))!=0)) goto LA24;
					n_2 = lastSon__UPSW0jLTX5qJL51YMUAHgw(n_2);
				} LA24: ;
			}
			T25_ = (NimStringDesc*)0;
			T26_ = (NimStringDesc*)0;
			T26_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n_2);
			T27_ = (NimStringDesc*)0;
			T27_ = typeToString__QlvraUan7WbHowhAbvDvdA((*result).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T25_ = rawNewString((T26_ ? T26_->Sup.len : 0) + (T27_ ? T27_->Sup.len : 0) + 61);
appendString(T25_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_16));
appendString(T25_, T26_);
appendString(T25_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_17));
appendString(T25_, T27_);
appendString(T25_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_18));
			s = T25_;
			{
				NIM_BOOL T30_;
				NimStringDesc* T34_;
				NimStringDesc* T35_;
				T30_ = (NIM_BOOL)0;
				T30_ = !(((*result).info.line == (*n_2).info.line));
				if (T30_) goto LA31_;
				T30_ = !(((*result).info.fileIndex == (*n_2).info.fileIndex));
				LA31_: ;
				if (!T30_) goto LA32_;
				T34_ = (NimStringDesc*)0;
				T35_ = (NimStringDesc*)0;
				T35_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, (*result).info);
				T34_ = rawNewString((T35_ ? T35_->Sup.len : 0) + 28);
appendString(T34_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_19));
appendString(T34_, T35_);
				s = resizeString(s, (T34_ ? T34_->Sup.len : 0) + 0);
appendString(s, T34_);
			}
			LA32_: ;
			{
				if (!((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25))) goto LA38_;
				s = resizeString(s, 28);
appendString(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_20));
			}
			LA38_: ;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_21, NIM_FALSE);
		}
		goto LA13_;
		LA21_: ;
		LA13_: ;
	}
	LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprNoType__7YxUILpPxooC5qqa89a54dw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL isPush;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	isPush = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2((*(*c).graph).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 82));
	{
		if (!isPush) goto LA3_;
		pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*n).info, ((NimStringDesc*) NIM_NIL));
	}
	LA3_: ;
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, 64);
	discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, result, 0);
	{
		if (!isPush) goto LA7_;
		popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmt__vJZwz9bfROKrfrtM50y74CQ_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0))) goto LA3_;
		result = semExprNoType__7YxUILpPxooC5qqa89a54dw_2(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, flags);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixupTypeOf__3zDDdB9b7Qt20FH75Al61MA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typExpr) {
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
		if (!!((prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, (*typExpr).typ, NIM_TRUE);
		asgnRef((void**) (&(*result).sym), (*prev).sym);
		assignType__RDstL9c8H9bSHUphDz0iB0hg(prev, result);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeof__O8zf75mcUwo9cfPQUQRaEug_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	t = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 4);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	fixupTypeOf__3zDDdB9b7Qt20FH75Al61MA(c, prev, t);
	result = (*t).typ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(kind, c);
	}
	goto LA1_;
	LA3_: ;
	{
		result = prev;
		{
			if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30))) goto LA8_;
			(*result).kind = kind;
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semAnonTuple__O8zf75mcUwo9cfPQUQRaEug_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_24, NIM_FALSE);
	}
	LA4_: ;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), prev, c);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T10_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, it, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T10_);
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
	}
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((IL64(70866960384) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = copyType__4O4aYoscFPo2FRSh4rP9ayg(t, (*t).owner, NIM_FALSE);
		asgnRef((void**) (&(*result).n), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	goto LA1_;
	LA5_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnresolvedSym__J1LR9bIUh18t4XFDmYEYBYw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4));
	{
		NIM_BOOL T3_;
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T10_;
		NIM_BOOL T13_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(result);
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 27))&63U)))!=0);
		if (T8_) goto LA9_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		if (!(T10_)) goto LA11_;
		T10_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw((*s).typ);
		LA11_: ;
		T8_ = T10_;
		LA9_: ;
		T7_ = T8_;
		if (T7_) goto LA12_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		if (!(T13_)) goto LA14_;
		T13_ = !((((*(*s).typ).flags & 100663296) == 0));
		LA14_: ;
		T7_ = T13_;
		LA12_: ;
		result = T7_;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = isUnresolvedSym__J1LR9bIUh18t4XFDmYEYBYw((*n)._kind_4.sym);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		sym = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
		{
			if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA5_;
			result = isUnresolvedSym__J1LR9bIUh18t4XFDmYEYBYw(sym);
			goto BeforeRet_;
		}
		goto LA3_;
		LA5_: ;
		{
			result = NIM_FALSE;
			goto BeforeRet_;
		}
		LA3_: ;
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA11;
					i = i_2;
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ(c, (*n)._kind_6.sons->data[i]);
						if (!T14_) goto LA15_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA15_: ;
					i_2 += ((NI) 1);
				} LA11: ;
			}
		}
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semRangeAux__O8zf75mcUwo9cfPQUQRaEug_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw range;
	tyArray__E1tCxfqiw3fNnaaIR5Kn2A rangeT;
	NIM_BOOL hasUnknownTypes;
	NIM_BOOL T12_;
	NIM_BOOL T13_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 3), (*(*c).graph).config);
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), prev, c);
	asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), (*n).info));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T1_);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		if (T4_) goto LA5_;
		T4_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		LA5_: ;
		if (!T4_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_27), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_28, NIM_FALSE);
	}
	LA6_: ;
	nimZeroMem((void*)range, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	range[(((NI) 0))- 0] = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 256);
	range[(((NI) 1))- 0] = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 2)], 256);
	nimZeroMem((void*)rangeT, sizeof(tyArray__E1tCxfqiw3fNnaaIR5Kn2A));
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
				if (!(res <= ((NI) 1))) goto LA10;
				i = res;
				T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*range[(i)- 0]).typ, IL64(1152921504606846976));
				rangeT[(i)- 0] = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T11_);
				res += ((NI) 1);
			} LA10: ;
		}
	}
	T12_ = (NIM_BOOL)0;
	T13_ = (NIM_BOOL)0;
	T13_ = (((NI) 0) < (*c).inGenericContext);
	if (!(T13_)) goto LA14_;
	T13_ = ((*rangeT[(((NI) 0))- 0]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61));
	LA14_: ;
	T12_ = T13_;
	if (T12_) goto LA15_;
	T12_ = ((*rangeT[(((NI) 1))- 0]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61));
	LA15_: ;
	hasUnknownTypes = T12_;
	{
		if (!!(hasUnknownTypes)) goto LA18_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T22_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
			NIM_BOOL T24_;
			T22_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T22_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(rangeT[(((NI) 0))- 0], 1048576);
			T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T23_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(rangeT[(((NI) 1))- 0], 1048576);
			T24_ = (NIM_BOOL)0;
			T24_ = sameType__3isNyHKb0U1OCnClmflXSg(T22_, T23_, 0);
			if (!!(T24_)) goto LA25_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_29), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_30, NIM_FALSE);
		}
		goto LA20_;
		LA25_: ;
		{
			NIM_BOOL T28_;
			NIM_BOOL T29_;
			NIM_BOOL T30_;
			T28_ = (NIM_BOOL)0;
			T29_ = (NIM_BOOL)0;
			T30_ = (NIM_BOOL)0;
			T30_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(rangeT[(((NI) 0))- 0], NIM_FALSE);
			T29_ = !(T30_);
			if (!(T29_)) goto LA31_;
			T29_ = !(((IL64(1030792151040) &((NU64)1<<((NU)((*rangeT[(((NI) 0))- 0]).kind)&63U)))!=0));
			LA31_: ;
			T28_ = T29_;
			if (T28_) goto LA32_;
			T28_ = ((*rangeT[(((NI) 0))- 0]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
			LA32_: ;
			if (!T28_) goto LA33_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_31), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_32, NIM_FALSE);
		}
		goto LA20_;
		LA33_: ;
		{
			NIM_BOOL T36_;
			NimStringDesc* T39_;
			NimStringDesc* T40_;
			T36_ = (NIM_BOOL)0;
			T36_ = enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3(rangeT[(((NI) 0))- 0]);
			if (!T36_) goto LA37_;
			T39_ = (NimStringDesc*)0;
			T39_ = typeToString__QlvraUan7WbHowhAbvDvdA(rangeT[(((NI) 0))- 0], ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T40_ = (NimStringDesc*)0;
			T40_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_33), T39_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T40_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_34, NIM_FALSE);
		}
		goto LA20_;
		LA37_: ;
		LA20_: ;
	}
	LA18_: ;
	{
		NI i_2;
		NI res_2;
		i_2 = (NI)0;
		res_2 = ((NI) 0);
		{
			while (1) {
				if (!(res_2 <= ((NI) 1))) goto LA43;
				i_2 = res_2;
				{
					NIM_BOOL T46_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T49_;
					T46_ = (NIM_BOOL)0;
					T46_ = hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ(c, range[(i_2)- 0]);
					if (!T46_) goto LA47_;
					T49_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T49_ = makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ(c, range[(i_2)- 0]);
					add__P8dDSotTW25BkfbyspojGg((*result).n, T49_);
					(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
				}
				goto LA44_;
				LA47_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T51_;
					T51_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T51_ = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, range[(i_2)- 0]);
					add__P8dDSotTW25BkfbyspojGg((*result).n, T51_);
				}
				LA44_: ;
				res_2 += ((NI) 1);
			} LA43: ;
		}
	}
	{
		NIM_BOOL T54_;
		NIM_BOOL T55_;
		tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA T57_;
		NIM_BOOL T59_;
		tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA T61_;
		T54_ = (NIM_BOOL)0;
		T55_ = (NIM_BOOL)0;
		T55_ = ((*(*(*result).n)._kind_6.sons->data[((NI) 0)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*(*(*result).n)._kind_6.sons->data[((NI) 0)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
		if (!(T55_)) goto LA56_;
		T57_ = (tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA)0;
		T57_ = classify__x3IKzrz1VNvfZbypScSTXg((*(*(*result).n)._kind_6.sons->data[((NI) 0)])._kind_2.floatVal);
		T55_ = (T57_ == ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 4));
		LA56_: ;
		T54_ = T55_;
		if (T54_) goto LA58_;
		T59_ = (NIM_BOOL)0;
		T59_ = ((*(*(*result).n)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*(*(*result).n)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
		if (!(T59_)) goto LA60_;
		T61_ = (tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA)0;
		T61_ = classify__x3IKzrz1VNvfZbypScSTXg((*(*(*result).n)._kind_6.sons->data[((NI) 1)])._kind_2.floatVal);
		T59_ = (T61_ == ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 4));
		LA60_: ;
		T54_ = T59_;
		LA58_: ;
		if (!T54_) goto LA62_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_35), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_36, NIM_FALSE);
	}
	LA62_: ;
	{
		tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA T66_;
		T66_ = (tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA)0;
		T66_ = weakLeValue__u0tFw6hmOCjNH0Gl9c619aMw((*(*result).n)._kind_6.sons->data[((NI) 0)], (*(*result).n)._kind_6.sons->data[((NI) 1)]);
		if (!(T66_ == ((tyEnum_TImplication__t4F29a8ejY1DFQTYTML9c9byA) 1))) goto LA67_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_27), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_37, NIM_FALSE);
	}
	LA67_: ;
	asgnRef((void**) (&(*result).sons->data[((NI) 0)]), rangeT[(((NI) 0))- 0]);
	return result;
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, freshType__MYPl0kqQUBUN3G45LDt6rwsem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* res, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(prev == 0)) goto LA3_;
		result = copyType__4O4aYoscFPo2FRSh4rP9ayg(res, (*res).owner, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		result = res;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeExpr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((1073898496 &((NU64)1<<((NU)((*typeExpr).kind)&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = !((prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, typeExpr, NIM_TRUE);
		asgnRef((void**) (&(*result).sym), (*prev).sym);
		assignType__RDstL9c8H9bSHUphDz0iB0hg(prev, result);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeExpr__O8zf75mcUwo9cfPQUQRaEug_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	n_2 = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 256);
	{
		if (!((*(*n_2).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA3_;
		result = base__PfgI9ap7WOnsRfFV4znQ27w((*n_2).typ);
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !((prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = !(((*prev).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA8_: ;
			if (!T7_) goto LA9_;
			{
				if (!((*result).sym == 0)) goto LA13_;
				asgnRef((void**) (&(*result).sym), (*prev).sym);
				asgnRef((void**) (&(*(*result).sym).typ), result);
			}
			goto LA11_;
			LA13_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* alias;
				alias = maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg(c, result, prev);
				{
					if (!!((alias == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA18_;
					result = alias;
				}
				LA18_: ;
			}
			LA11_: ;
		}
		LA9_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T21_;
		NimStringDesc* T22_;
		T21_ = (NimStringDesc*)0;
		T22_ = (NimStringDesc*)0;
		T22_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n_2, 0);
		T21_ = rawNewString((T22_ ? T22_->Sup.len : 0) + 24);
appendString(T21_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_40));
appendString(T21_, T22_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_41, NIM_FALSE);
		result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newConstraint__QGpv9bqfXWWeJjJoCL6cRRA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51), c);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(k, c);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T1_);
	return result;
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipGenericInvocation__un0CMx5e9axSJU0IN3TyTiwsem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = t;
	{
		if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA3_;
		result = (*result).sons->data[((NI) 0)];
	}
	LA3_: ;
	{
		while (1) {
			if (!((IL64(105553122561040) &((NU64)1<<((NU)((*result).kind)&63U)))!=0)) goto LA6;
			result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
		} LA6: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA4_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_54), TM__rF9caJawfOjYTjsgLVUSGFA_55);
		}
		LA4_: ;
		addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug(c, check, pos, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					switch ((*(*n)._kind_6.sons->data[i]).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
						T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T10_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i]);
						addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug(c, check, pos, T10_);
					}
					break;
					default:
					{
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_56), TM__rF9caJawfOjYTjsgLVUSGFA_57);
					}
					break;
					}
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 140):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI colontmp__3;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__2 = ((NI) (((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86))));
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = colontmp__2;
			{
				while (1) {
					if (!(i_4 < colontmp__3)) goto LA15;
					i_3 = i_4;
					addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug(c, check, pos, (*n)._kind_6.sons->data[i_3]);
					i_4 += ((NI) 1);
				} LA15: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		incl__jENnK9c9bPE73pKmo2vYjpqg(check, (*(*(*n)._kind_4.sym).name).Sup.id);
		(*pos) += ((NI) 1);
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_58), TM__rF9caJawfOjYTjsgLVUSGFA_59);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj) {
	{
		NIM_BOOL T3_;
		NI T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__5mJADrRYkP3r9auuiuDZN9cQast(obj);
		T3_ = (((NI) 0) < T4_);
		if (!(T3_)) goto LA5_;
		T3_ = !(((*obj).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA5_: ;
		if (!T3_) goto LA6_;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipGenericInvocation__un0CMx5e9axSJU0IN3TyTiwsem((*obj).sons->data[((NI) 0)]);
		addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg(c, check, pos, T8_);
	}
	LA6_: ;
	addInheritedFieldsAux__ACSQTAVDG480Jn3p3wc7ug(c, check, pos, (*obj).n);
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_67));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*(*c).currentScope).depthLevel <= ((NI) 2));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, rawPushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* x;
	x = (tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*)0;
	x = (tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) newObj((&NTI__GJ8qR6LTU9bYLzfOArsHTSg_), sizeof(tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ));
	asgnRef((void**) (&(*x).owner), owner);
	asgnRef((void**) (&(*x).next), (*c).p);
	asgnRef((void**) (&(*c).p), x);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, referencesAnotherParam__cvWGVSvD9adrttq7iqjO7wA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T5_;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*n)._kind_4.sym).owner == p);
		LA6_: ;
		result = T5_;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = referencesAnotherParam__cvWGVSvD9adrttq7iqjO7wA((*n)._kind_6.sons->data[i], p);
						if (!T13_) goto LA14_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, changeType__sF9cXBCC3k8saS0PTBUB9b8A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* newType, NIM_BOOL check) {
{	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T5_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(newType);
					changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, (*n)._kind_6.sons->data[i], T5_, check);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tup;
		tup = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(newType, IL64(70368744187920));
		{
			if (!!(((*tup).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)))) goto LA9_;
			{
				if (!((*tup).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA13_;
				goto BeforeRet_;
			}
			LA13_: ;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_81), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_82, NIM_FALSE);
		}
		goto LA7_;
		LA9_: ;
		{
			NIM_BOOL T16_;
			NI T17_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NI)0;
			T17_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T16_ = (((NI) 0) < T17_);
			if (!(T16_)) goto LA18_;
			T16_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
			LA18_: ;
			if (!T16_) goto LA19_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
						if (!(i_4 < colontmp__2)) goto LA23;
						i_3 = i_4;
						m = (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 0)];
						{
							if (!!(((*m).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA26_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*m).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_83), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_84, NIM_FALSE);
							goto BeforeRet_;
						}
						LA26_: ;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
							if (!!(((*tup).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA30_;
							f = getSymFromList__aHh3vzt6upPNMkKnONiMRw((*tup).n, (*(*m)._kind_4.sym).name, ((NI) 0));
							{
								NimStringDesc* T36_;
								if (!(f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA34_;
								T36_ = (NimStringDesc*)0;
								T36_ = rawNewString(((*(*(*m)._kind_4.sym).name).s ? (*(*(*m)._kind_4.sym).name).s->Sup.len : 0) + 20);
appendString(T36_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_85));
appendString(T36_, (*(*(*m)._kind_4.sym).name).s);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*m).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T36_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_86, NIM_FALSE);
								goto BeforeRet_;
							}
							LA34_: ;
							changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 1)], (*f).typ, check);
						}
						goto LA28_;
						LA30_: ;
						{
							changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 1)], (*tup).sons->data[i_3], check);
						}
						LA28_: ;
						i_4 += ((NI) 1);
					} LA23: ;
				}
			}
		}
		goto LA7_;
		LA19_: ;
		{
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA41;
						i_5 = i_6;
						changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, (*n)._kind_6.sons->data[i_5], (*tup).sons->data[i_5], check);
						i_6 += ((NI) 1);
					} LA41: ;
				}
			}
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		{
			NIM_BOOL T45_;
			NIM_BOOL T46_;
			NIM_BOOL T49_;
			NI64 value;
			T45_ = (NIM_BOOL)0;
			T46_ = (NIM_BOOL)0;
			T46_ = check;
			if (!(T46_)) goto LA47_;
			T46_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15)));
			LA47_: ;
			T45_ = T46_;
			if (!(T45_)) goto LA48_;
			T49_ = (NIM_BOOL)0;
			T49_ = sameType__3isNyHKb0U1OCnClmflXSg((*n).typ, newType, 0);
			T45_ = !(T49_);
			LA48_: ;
			if (!T45_) goto LA50_;
			value = (*n)._kind_1.intVal;
			{
				NIM_BOOL T54_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T55_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T57_;
				NimStringDesc* T60_;
				NimStringDesc* T61_;
				NimStringDesc* T62_;
				T54_ = (NIM_BOOL)0;
				T55_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, newType);
				T54_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(value, T55_);
				if (T54_) goto LA56_;
				T57_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, newType);
				T54_ = lt___nr9cP9b0OL9cabygV9bo19cJgZA_3(T57_, value);
				LA56_: ;
				if (!T54_) goto LA58_;
				T60_ = (NimStringDesc*)0;
				T61_ = (NimStringDesc*)0;
				T61_ = nimInt64ToStr(value);
				T62_ = (NimStringDesc*)0;
				T62_ = typeToString__QlvraUan7WbHowhAbvDvdA(newType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T60_ = rawNewString((T61_ ? T61_->Sup.len : 0) + (T62_ ? T62_->Sup.len : 0) + 19);
appendString(T60_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_87));
appendString(T60_, T61_);
appendString(T60_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_88));
appendString(T60_, T62_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T60_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_89, NIM_FALSE);
			}
			LA58_: ;
		}
		LA50_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		{
			NIM_BOOL T66_;
			NIM_BOOL T68_;
			tyArray__Re75IspeoxXy2oCZHwcRrA T71_;
			NimStringDesc* T72_;
			T66_ = (NIM_BOOL)0;
			T66_ = check;
			if (!(T66_)) goto LA67_;
			T68_ = (NIM_BOOL)0;
			T68_ = floatRangeCheck__RTbq1U5r9aGXeN20T54YASg((*n)._kind_2.floatVal, newType);
			T66_ = !(T68_);
			LA67_: ;
			if (!T66_) goto LA69_;
			nimZeroMem((void*)T71_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T71_[0] = nimFloatToStr((*n)._kind_2.floatVal);
			T71_[1] = typeToString__QlvraUan7WbHowhAbvDvdA(newType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T72_ = (NimStringDesc*)0;
			T72_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_90), T71_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T72_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_91, NIM_FALSE);
		}
		LA69_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	asgnRef((void**) (&(*n).typ), newType);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitNodePostMatch__t9cW9ai7WILQBcTRPAW4swfA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = skipConv__BH9abOhPX8pH0DnEWlRxmlw(arg);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*formal).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6)));
		LA4_: ;
		if (!T3_) goto LA5_;
		changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, x, formal, NIM_TRUE);
	}
	LA5_: ;
	result = arg;
	result = skipHiddenSubConv__BH9abOhPX8pH0DnEWlRxmlw_2(result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, instantiateProcType__1PhCjyNxyOAJRoRgfsrJDQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ* typeMap;
	tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg cl;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* originalParams;
	pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, info, ((NimStringDesc*) NIM_NIL));
	typeMap = initLayeredTypeMap__B4ANHmRtTNsf0tY0IplCpw(pt);
	nimZeroMem((void*)(&cl), sizeof(tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg));
	initTypeVars__EZn0NSR9cUjgZYKdEVkzwaA(c, typeMap, info, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (&cl));
	result = instCopyType__cNsAY9aO2v1oTCPqZyHga1w_5((&cl), (*prc).typ);
	originalParams = (*result).n;
	asgnRef((void**) (&(*result).n), shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(originalParams));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(result);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeToFit;
				NIM_BOOL needsStaticSkipping;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 1) < i)) goto LA6_;
					resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2((&cl.symMap));
					resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2((&cl.localCache));
				}
				LA6_: ;
				typeToFit = (*result).sons->data[i];
				needsStaticSkipping = ((*(*result).sons->data[i]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61));
				asgnRef((void**) (&(*result).sons->data[i]), replaceTypeVarsT__cNsAY9aO2v1oTCPqZyHga1w((&cl), (*result).sons->data[i]));
				{
					if (!needsStaticSkipping) goto LA10_;
					asgnRef((void**) (&(*result).sons->data[i]), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*result).sons->data[i], IL64(1152921504606846976)));
				}
				LA10_: ;
				{
					NIM_BOOL T14_;
					NIM_BOOL T15_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
					T14_ = (NIM_BOOL)0;
					T15_ = (NIM_BOOL)0;
					T15_ = !(((*typeToFit).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
					if (T15_) goto LA16_;
					T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T17_ = base__PfgI9ap7WOnsRfFV4znQ27w(typeToFit);
					T15_ = !(((*T17_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
					LA16_: ;
					T14_ = T15_;
					if (!(T14_)) goto LA18_;
					T14_ = !(((*typeToFit).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60)));
					LA18_: ;
					if (!T14_) goto LA19_;
					typeToFit = (*result).sons->data[i];
				}
				LA19_: ;
				{
					NimStringDesc* argX60gensym184_;
					if (!!(((*(*originalParams)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA23_;
					argX60gensym184_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_80);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym184_, TM__rF9caJawfOjYTjsgLVUSGFA_80);
				}
				LA23_: ;
				oldParam = (*(*originalParams)._kind_6.sons->data[i])._kind_4.sym;
				param = copySym__lIu8wX6Beq6dBJgESOFFjg(oldParam);
				asgnRef((void**) (&(*param).owner), prc);
				asgnRef((void**) (&(*param).typ), (*result).sons->data[i]);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* converted;
					if (!!(((*oldParam).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA27_;
					def = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*oldParam).ast);
					{
						if (!((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27))) goto LA31_;
						{
							NI i_3;
							NI colontmp__2;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(def);
							i_4 = ((NI) 1);
							{
								while (1) {
									if (!(i_4 < colontmp__2)) goto LA35;
									i_3 = i_4;
									asgnRef((void**) (&(*def)._kind_6.sons->data[i_3]), replaceTypeVarsN__TMTYUYo5YIKojKgBmj9boOQ((&cl), (*def)._kind_6.sons->data[i_3], ((NI) 0)));
									i_4 += ((NI) 1);
								} LA35: ;
							}
						}
					}
					LA31_: ;
					def = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, def, 0);
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T38_;
						NIM_BOOL T39_;
						T38_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T38_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
						T39_ = (NIM_BOOL)0;
						T39_ = referencesAnotherParam__cvWGVSvD9adrttq7iqjO7wA(def, T38_);
						if (!T39_) goto LA40_;
						(*def).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19)) & 31);
					}
					LA40_: ;
					converted = indexTypesMatch__8llRCFM4VdmgY27XJn2sRA(c, typeToFit, (*def).typ, def);
					{
						if (!(converted == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA44_;
						asgnRef((void**) (&(*param).ast), errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, def));
					}
					goto LA42_;
					LA44_: ;
					{
						asgnRef((void**) (&(*param).ast), fitNodePostMatch__t9cW9ai7WILQBcTRPAW4swfA(c, typeToFit, converted));
					}
					LA42_: ;
					asgnRef((void**) (&(*param).typ), (*result).sons->data[i]);
				}
				LA27_: ;
				asgnRef((void**) (&(*(*result).n)._kind_6.sons->data[i]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(param));
				propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, (*result).sons->data[i], NIM_TRUE);
				addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, param);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2((&cl.symMap));
	resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2((&cl.localCache));
	cl.isReturnType = NIM_TRUE;
	asgnRef((void**) (&(*result).sons->data[((NI) 0)]), replaceTypeVarsT__cNsAY9aO2v1oTCPqZyHga1w((&cl), (*result).sons->data[((NI) 0)]));
	cl.isReturnType = NIM_FALSE;
	asgnRef((void**) (&(*(*result).n)._kind_6.sons->data[((NI) 0)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*originalParams)._kind_6.sons->data[((NI) 0)]));
	{
		if (!!(((*result).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA49_;
		propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, (*result).sons->data[((NI) 0)], NIM_TRUE);
	}
	LA49_: ;
	eraseVoidParams__w2l6CVu9bYn8M06fJcMTkHw(result);
	skipIntLiteralParams__w2l6CVu9bYn8M06fJcMTkHw_2(result);
	asgnRef((void**) (&(*prc).typ), result);
	popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameInstantiation__bGmhq9bb8pFOkYidfiwlp5w)(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA a, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI T4_;
		T3_ = (a.concreteTypes ? a.concreteTypes->Sup.len : 0);
		T4_ = (b.concreteTypes ? b.concreteTypes->Sup.len : 0);
		if (!(T3_ == T4_)) goto LA5_;
		{
			NI i;
			NI colontmp_;
			NI T8_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T8_ = ((a.concreteTypes ? a.concreteTypes->Sup.len : 0)-1);
			colontmp_ = T8_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA10;
					i = res;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = compareTypes__oyXq5u7iL4RjsT9bovvTE9cg(a.concreteTypes->data[i], b.concreteTypes->data[i], ((tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg) 0), 36);
						if (!!(T13_)) goto LA14_;
						goto BeforeRet_;
					}
					LA14_: ;
					res += ((NI) 1);
				} LA10: ;
			}
		}
		result = NIM_TRUE;
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, genericCacheGet__yrVWUjVCLM4qNMOOOoQryQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym, tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA entry, NI id) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA** inst;
		tySequence__DXS6mEo7PVUFJkirsQ9bNQA* colontmp_;
		NI i;
		NI L;
		NI T2_;
		inst = (tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA**)0;
		colontmp_ = (tySequence__DXS6mEo7PVUFJkirsQ9bNQA*)0;
		colontmp_ = (*genericSym)._kind_2.procInstCache;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				inst = &colontmp_->data[i];
				{
					NIM_BOOL T7_;
					NIM_BOOL T8_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NIM_BOOL)0;
					T8_ = ((*(*inst)).compilesId == ((NI) 0));
					if (T8_) goto LA9_;
					T8_ = ((*(*inst)).compilesId == id);
					LA9_: ;
					T7_ = T8_;
					if (!(T7_)) goto LA10_;
					T7_ = sameInstantiation__bGmhq9bb8pFOkYidfiwlp5w(entry, (*(*inst)));
					LA10_: ;
					if (!T7_) goto LA11_;
					result = (*(*inst)).sym;
					goto BeforeRet_;
				}
				LA11_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f) {
	NIM_BOOL result;
	NI fmoduleId;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(f);
	fmoduleId = (*T1_).Sup.id;
	T2_ = (NIM_BOOL)0;
	T2_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0);
	if (T2_) goto LA3_;
	T2_ = (fmoduleId == (*(*c).module).Sup.id);
	LA3_: ;
	result = T2_;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** module;
		NI i;
		NI L;
		NI T5_;
		module = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		T5_ = ((*c).friendModules ? (*c).friendModules->Sup.len : 0);
		L = T5_;
		{
			while (1) {
				if (!(i < L)) goto LA7;
				module = &(*c).friendModules->data[i];
				{
					if (!(fmoduleId == (*(*module)).Sup.id)) goto LA10_;
					result = NIM_TRUE;
					goto LA4;
				}
				LA10_: ;
				i += ((NI) 1);
			} LA7: ;
		}
	} LA4: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g(c, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T8_)) goto LA9_;
			addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g(c, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA9_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA13;
					i_3 = i_4;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
						if (!((*(*n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85) || (*(*n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88))) goto LA16_;
						T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T18_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
						addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g(c, T18_);
					}
					LA16_: ;
					i_4 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
		f = (*n)._kind_4.sym;
		{
			NIM_BOOL T22_;
			NIM_BOOL T26_;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*f).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
			if (!(T22_)) goto LA23_;
			T22_ = fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch(c, f);
			LA23_: ;
			if (!T22_) goto LA24_;
			T26_ = (NIM_BOOL)0;
			T26_ = strTableIncl__4C9ciVlXutN6a0CSSeSkVDA((&(*(*c).currentScope).symbols), f, NIM_TRUE);
			(*f).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
		}
		LA24_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, rawHandleSelf__jWGpC0lY8vG9b1MhOYJ9cFiQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*c).selfName == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((258048 &((NU32)1<<((NU)((*owner).kind)&31U)))!=0);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !(((*owner).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA6_: ;
		if (!T3_) goto LA7_;
		params = (*(*owner).typ).n;
		{
			NI T11_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* arg;
			T11_ = (NI)0;
			T11_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
			if (!(((NI) 1) < T11_)) goto LA12_;
			arg = (*(*params)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
				if (!((*(*arg).name).Sup.id == (*(*c).selfName).Sup.id)) goto LA16_;
				asgnRef((void**) (&(*(*c).p).selfSym), arg);
				(*arg).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34)) & 63);
				t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*(*c).p).selfSym).typ, IL64(36275087638309136));
				{
					while (1) {
						if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA19;
						addObjFieldsToLocalScope__NRIJDWZtATzMum7OEjYC2g(c, (*t).n);
						{
							if (!((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA22_;
							goto LA18;
						}
						LA22_: ;
						t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(36275087638268176));
					} LA19: ;
				} LA18: ;
			}
			LA16_: ;
		}
		LA12_: ;
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, findEnforcedStaticType__9cRlRlKvV58Tq3YoHJJi1Rw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA7_;
		result = t;
		goto BeforeRet_;
	}
	LA7_: ;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56))) goto LA11_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** s;
			NI i;
			NI L;
			NI T14_;
			s = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i = ((NI) 0);
			T14_ = ((*t).sons ? (*t).sons->Sup.len : 0);
			L = T14_;
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
					if (!(i < L)) goto LA16;
					s = &(*t).sons->data[i];
					t_2 = findEnforcedStaticType__9cRlRlKvV58Tq3YoHJJi1Rw((*s));
					{
						if (!!((t_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA19_;
						result = t_2;
						goto BeforeRet_;
					}
					LA19_: ;
					i += ((NI) 1);
				} LA16: ;
			}
		}
	}
	LA11_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addParamOrResult__pceuJlMM5di29a5a9cxxzXSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* staticType;
		if (!(kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17))) goto LA3_;
		staticType = findEnforcedStaticType__9cRlRlKvV58Tq3YoHJJi1Rw((*param).typ);
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a;
			if (!!((staticType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA7_;
			a = copySym__lIu8wX6Beq6dBJgESOFFjg(param);
			asgnRef((void**) (&(*a).typ), base__PfgI9ap7WOnsRfFV4znQ27w(staticType));
			addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, a);
		}
		goto LA5_;
		LA7_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* nn;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a_2;
			nn = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*c).graph, (*param).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_93));
			a_2 = copySym__lIu8wX6Beq6dBJgESOFFjg(param);
			asgnRef((void**) (&(*a_2).typ), (*nn).typ);
			addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, a_2);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0)) goto LA13_;
			{
				if (!((*param).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA17_;
				asgnRef((void**) (&(*param).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
			}
			LA17_: ;
		}
		goto LA11_;
		LA13_: ;
		{
			addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, param);
		}
		LA11_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addResult__n01jThJgoOr9aRxjZW5y9c7g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw owner) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (owner == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
		if (T3_) goto LA4_;
		T3_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NI T10_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T9_ = (((NI) 7) < T10_);
			if (!(T9_)) goto LA11_;
			T9_ = !(((*n)._kind_6.sons->data[((NI) 7)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA11_: ;
			if (!T9_) goto LA12_;
			{
				NIM_BOOL T16_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T18_;
				T16_ = (NIM_BOOL)0;
				T16_ = !(((*(*(*n)._kind_6.sons->data[((NI) 7)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11)));
				if (T16_) goto LA17_;
				T18_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T18_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
				T16_ = !(((*(*(*n)._kind_6.sons->data[((NI) 7)])._kind_4.sym).owner == T18_));
				LA17_: ;
				if (!T16_) goto LA19_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_94), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_95, NIM_FALSE);
			}
			LA19_: ;
			asgnRef((void**) (&(*(*c).p).resultSym), (*(*n)._kind_6.sons->data[((NI) 7)])._kind_4.sym);
		}
		goto LA7_;
		LA12_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T22_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T23_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
			T22_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T22_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96));
			T23_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T23_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
			s = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11), T22_, T23_, (*n).info, 0);
			asgnRef((void**) (&(*s).typ), t);
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
			asgnRef((void**) (&(*(*c).p).resultSym), s);
			T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T24_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*c).p).resultSym);
			add__P8dDSotTW25BkfbyspojGg(n, T24_);
		}
		LA7_: ;
		addParamOrResult__pceuJlMM5di29a5a9cxxzXSQ(c, (*(*c).p).resultSym, owner);
	}
	LA5_: ;
}
static N_INLINE(NIM_BOOL, isInlineIterator__EhCVbB6PynSh7XFAFVMiJAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T2_)) goto LA3_;
	T2_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !(((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, maybeAddResult__8H5d8d9cPCfbpMuDrerQMeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* resultType;
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17))) goto LA3_;
		resultType = sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ((*c).graph, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_93));
		addResult__n01jThJgoOr9aRxjZW5y9c7g(c, n, resultType, (*s).kind);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*(*s).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T6_)) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = isInlineIterator__EhCVbB6PynSh7XFAFVMiJAast((*s).typ);
		T6_ = !(T8_);
		LA7_: ;
		if (!T6_) goto LA9_;
		addResult__n01jThJgoOr9aRxjZW5y9c7g(c, n, (*(*s).typ).sons->data[((NI) 0)], (*s).kind);
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, freshGenSyms__sniSZ3lXmsiJXk4n7qLgPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* symMap) {
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T7_;
		RootObj* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		s = (*n)._kind_4.sym;
		T7_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T7_ = &s->Sup;
		T8_ = (RootObj*)0;
		T8_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*symMap), T7_);
		x = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) (T8_));
		{
			if (!!((x == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA11_;
			asgnRef((void**) (&(*n)._kind_4.sym), x);
		}
		goto LA9_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T18_;
			RootObj* T19_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((*(*s).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 24));
			LA15_: ;
			if (!T14_) goto LA16_;
			x = copySym__lIu8wX6Beq6dBJgESOFFjg(s);
			asgnRef((void**) (&(*x).owner), owner);
			T18_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
			T18_ = &s->Sup;
			T19_ = (RootObj*)0;
			T19_ = &x->Sup.Sup;
			idTablePut__anELyz7VLsjbCIoxLpxbfQ(symMap, T18_, T19_);
			asgnRef((void**) (&(*n)._kind_4.sym), x);
		}
		goto LA9_;
		LA16_: ;
		LA9_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA23;
					i = i_2;
					freshGenSyms__sniSZ3lXmsiJXk4n7qLgPw((*n)._kind_6.sons->data[i], owner, orig, symMap);
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	LA1_: ;
}
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((IL64(-9223372036854775680) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) <= (*n).kind);
	if (!(T1_)) goto LA2_;
	T1_ = ((*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixNilType__NRIJDWZtATzMum7OEjYC2g_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isAtom__ORlI8o1EUYdPqjuTcBWx1Aast(n);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NimStringDesc* T12_;
			NimStringDesc* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)));
			if (!(T8_)) goto LA9_;
			T8_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA9_: ;
			if (!T8_) goto LA10_;
			T12_ = (NimStringDesc*)0;
			T12_ = typeToString__QlvraUan7WbHowhAbvDvdA((*n).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T13_ = (NimStringDesc*)0;
			T13_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_97), T12_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_98, NIM_FALSE);
		}
		LA10_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA15_;
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 115));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA20;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						fixNilType__NRIJDWZtATzMum7OEjYC2g_2(c, it);
						i_2 += ((NI) 1);
					} LA20: ;
				}
			}
		}
	}
	goto LA1_;
	LA15_: ;
	LA1_: ;
	asgnRef((void**) (&(*n).typ), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, readTypeParameter__mu5r1rtNM9aogbn9cBVgqt3A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* paramName, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((IL64(13510798882111488) &((NU64)1<<((NU)((*typ).kind)&63U)))!=0)) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* statement;
			statement = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*typ).n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						statement = (*(*typ).n)._kind_6.sons->data[i];
						switch ((*statement).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
						{
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
								def = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								{
									NI i_3;
									NI colontmp__2;
									NI i_4;
									i_3 = (NI)0;
									colontmp__2 = (NI)0;
									colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(statement);
									i_4 = ((NI) 0);
									{
										while (1) {
											if (!(i_4 < colontmp__2)) goto LA13;
											i_3 = i_4;
											def = (*statement)._kind_6.sons->data[i_3];
											{
												tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* foundType;
												tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T18_;
												tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T19_;
												if (!((*(*(*(*def)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id == (*paramName).Sup.id)) goto LA16_;
												foundType = makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, (*(*def)._kind_6.sons->data[((NI) 2)]).typ);
												T18_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
												T18_ = copySym__lIu8wX6Beq6dBJgESOFFjg((*(*def)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
												T19_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
												T19_ = linkTo__Lxy1G9c1I40y65cWkoPnssA(T18_, foundType);
												result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T19_, info);
												goto BeforeRet_;
											}
											LA16_: ;
											i_4 += ((NI) 1);
										} LA13: ;
									}
								}
							}
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
						{
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def_2;
								def_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								{
									NI i_5;
									NI colontmp__3;
									NI i_6;
									i_5 = (NI)0;
									colontmp__3 = (NI)0;
									colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(statement);
									i_6 = ((NI) 0);
									{
										while (1) {
											if (!(i_6 < colontmp__3)) goto LA24;
											i_5 = i_6;
											def_2 = (*statement)._kind_6.sons->data[i_5];
											{
												if (!((*(*(*(*def_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).Sup.id == (*paramName).Sup.id)) goto LA27_;
												result = (*def_2)._kind_6.sons->data[((NI) 2)];
												goto BeforeRet_;
											}
											LA27_: ;
											i_6 += ((NI) 1);
										} LA24: ;
									}
								}
							}
						}
						break;
						default:
						{
						}
						break;
						}
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tbody;
		if (!!(((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52)))) goto LA32_;
		{
			if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54))) goto LA36_;
			ty = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3((*typ).sons->data[((NI) 1)]);
		}
		goto LA34_;
		LA36_: ;
		{
			ty = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(typ);
		}
		LA34_: ;
		tbody = (*ty).sons->data[((NI) 0)];
		{
			NI s;
			NI colontmp__4;
			NI T40_;
			NI i_7;
			s = (NI)0;
			colontmp__4 = (NI)0;
			T40_ = (NI)0;
			T40_ = len__5mJADrRYkP3r9auuiuDZN9cQast(tbody);
			colontmp__4 = (NI)(T40_ - ((NI) 1));
			i_7 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tParam;
					if (!(i_7 < colontmp__4)) goto LA42;
					s = i_7;
					tParam = (*tbody).sons->data[s];
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rawTyp;
						if (!((*(*(*tParam).sym).name).Sup.id == (*paramName).Sup.id)) goto LA45_;
						rawTyp = (*ty).sons->data[(NI)(s + ((NI) 1))];
						{
							if (!((*rawTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA49_;
							{
								if (!!(((*rawTyp).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA53_;
								result = (*rawTyp).n;
								goto BeforeRet_;
							}
							goto LA51_;
							LA53_: ;
							{
								result = (*(*c).graph).emptyNode;
								goto BeforeRet_;
							}
							LA51_: ;
						}
						goto LA47_;
						LA49_: ;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* foundTyp;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T57_;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T58_;
							foundTyp = makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, rawTyp);
							T57_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T57_ = copySym__lIu8wX6Beq6dBJgESOFFjg((*tParam).sym);
							T58_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T58_ = linkTo__Lxy1G9c1I40y65cWkoPnssA(T57_, foundTyp);
							result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T58_, info);
							goto BeforeRet_;
						}
						LA47_: ;
					}
					LA45_: ;
					i_7 += ((NI) 1);
				} LA42: ;
			}
		}
	}
	LA32_: ;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryReadingGenericParam__L5Nhi0f3LeGUlYzLEKJ7lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	{
		result = readTypeParameter__mu5r1rtNM9aogbn9cBVgqt3A(c, t, i, (*n).info);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
			if (!(result == (*(*c).graph).emptyNode)) goto LA4_;
			result = n;
			T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T6_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
			asgnRef((void**) (&(*n).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T6_));
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		{
			if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0)) goto LA10_;
			result = readTypeParameter__mu5r1rtNM9aogbn9cBVgqt3A(c, t, i, (*n).info);
		}
		goto LA8_;
		LA10_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
			T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T13_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
			asgnRef((void**) (&(*n).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T13_));
			result = n;
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
		T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T15_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		asgnRef((void**) (&(*n).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T15_));
		result = n;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryReadingTypeField__6Ix9awqI9ax7ryNwTnzhRziw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty_2;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	ty_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(246290619301904));
	switch ((*ty_2).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
		f = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		{
			while (1) {
				if (!!((ty_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3;
				f = getSymFromList__aHh3vzt6upPNMkKnONiMRw((*ty_2).n, i, ((NI) 0));
				{
					if (!!((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
					goto LA2;
				}
				LA6_: ;
				ty_2 = (*ty_2).sons->data[((NI) 0)];
			} LA3: ;
		} LA2: ;
		{
			if (!!((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10_;
			result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f);
			(*result).info = (*n).info;
			asgnRef((void**) (&(*result).typ), ty_2);
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, f);
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			NIM_BOOL T15_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
			T15_ = (NIM_BOOL)0;
			T15_ = !(((*ty_2).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T15_)) goto LA16_;
			T15_ = ((*(*ty_2).n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138));
			LA16_: ;
			if (!T15_) goto LA17_;
			field = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*ty_2).n, i);
			{
				if (!!((field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA21_;
				asgnRef((void**) (&(*n).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, (*field).typ));
				result = n;
			}
			LA21_: ;
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
		T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T24_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(ty_2);
		result = tryReadingTypeField__6Ix9awqI9ax7ryNwTnzhRziw(c, n, i, T24_);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA27_;
			result = tryReadingGenericParam__L5Nhi0f3LeGUlYzLEKJ7lw(c, n, i, ty_2);
		}
		LA27_: ;
	}
	break;
	default:
	{
		result = tryReadingGenericParam__L5Nhi0f3LeGUlYzLEKJ7lw(c, n, i, ty_2);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTypeExpr__OiccTa3ruRNl9anoSqZh2Sg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createSetType__rwLVyLHZXgxsg41zHjQWfg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19), c);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, baseType, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** check) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	switch ((*r).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, (*r)._kind_6.sons->data[i], field, check);
					{
						if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* setType;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(r, ((NI) 2), (*(*c).graph).config);
		{
			if (!!(((*(*r)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(r, (*(*c).graph).config);
		}
		LA12_: ;
		result = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, (*r)._kind_6.sons->data[((NI) 0)], field, check);
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
			goto BeforeRet_;
		}
		LA16_: ;
		setType = createSetType__rwLVyLHZXgxsg41zHjQWfg(c, (*(*r)._kind_6.sons->data[((NI) 0)]).typ);
		s = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39), (*r).info, setType);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(r);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					if (!(i_4 < colontmp__2)) goto LA20;
					i_3 = i_4;
					it = (*r)._kind_6.sons->data[i_3];
					switch ((*it).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
						T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T22_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
						result = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, T22_, field, check);
						{
							if (!(result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA25_;
							{
								NI j;
								NI colontmp__3;
								NI T28_;
								NI i_5;
								j = (NI)0;
								colontmp__3 = (NI)0;
								T28_ = (NI)0;
								T28_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								colontmp__3 = (NI)(T28_ - ((NI) 1));
								i_5 = ((NI) 0);
								{
									while (1) {
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
										if (!(i_5 < colontmp__3)) goto LA30;
										j = i_5;
										T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T31_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*it)._kind_6.sons->data[j]);
										add__P8dDSotTW25BkfbyspojGg(s, T31_);
										i_5 += ((NI) 1);
									} LA30: ;
								}
							}
						}
						goto LA23_;
						LA25_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* inExpr;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T42_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
							{
								if (!((*check) == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA35_;
								unsureAsgnRef((void**) (&(*check)), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46), (*n).info));
								add__P8dDSotTW25BkfbyspojGg((*check), (*(*c).graph).emptyNode);
							}
							LA35_: ;
							s = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39), (*n).info, setType);
							{
								NI j_2;
								NI colontmp__4;
								NI T38_;
								NI i_6;
								j_2 = (NI)0;
								colontmp__4 = (NI)0;
								T38_ = (NI)0;
								T38_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
								colontmp__4 = (NI)(T38_ - ((NI) 1));
								i_6 = ((NI) 0);
								{
									while (1) {
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T41_;
										if (!(i_6 < colontmp__4)) goto LA40;
										j_2 = i_6;
										T41_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T41_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*it)._kind_6.sons->data[j_2]);
										add__P8dDSotTW25BkfbyspojGg(s, T41_);
										i_6 += ((NI) 1);
									} LA40: ;
								}
							}
							T42_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T42_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
							inExpr = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T42_);
							T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T43_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*(*c).graph).opContains, (*n).info);
							add__P8dDSotTW25BkfbyspojGg(inExpr, T43_);
							add__P8dDSotTW25BkfbyspojGg(inExpr, s);
							T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T44_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*r)._kind_6.sons->data[((NI) 0)]);
							add__P8dDSotTW25BkfbyspojGg(inExpr, T44_);
							add__P8dDSotTW25BkfbyspojGg((*check), inExpr);
							goto BeforeRet_;
						}
						LA23_: ;
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T46_;
						T46_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T46_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
						result = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, T46_, field, check);
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* inExpr_2;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T55_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T56_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T57_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* notExpr;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T58_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T59_;
							if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA49_;
							{
								if (!((*check) == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA53_;
								unsureAsgnRef((void**) (&(*check)), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46), (*n).info));
								add__P8dDSotTW25BkfbyspojGg((*check), (*(*c).graph).emptyNode);
							}
							LA53_: ;
							T55_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T55_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
							inExpr_2 = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T55_);
							T56_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T56_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*(*c).graph).opContains, (*n).info);
							add__P8dDSotTW25BkfbyspojGg(inExpr_2, T56_);
							add__P8dDSotTW25BkfbyspojGg(inExpr_2, s);
							T57_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T57_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*r)._kind_6.sons->data[((NI) 0)]);
							add__P8dDSotTW25BkfbyspojGg(inExpr_2, T57_);
							T58_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T58_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
							notExpr = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T58_);
							T59_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T59_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*(*c).graph).opNot, (*n).info);
							add__P8dDSotTW25BkfbyspojGg(notExpr, T59_);
							add__P8dDSotTW25BkfbyspojGg(notExpr, inExpr_2);
							add__P8dDSotTW25BkfbyspojGg((*check), notExpr);
							goto BeforeRet_;
						}
						LA49_: ;
					}
					break;
					default:
					{
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(it, (*(*c).graph).config);
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			if (!((*(*(*r)._kind_4.sym).name).Sup.id == (*field).Sup.id)) goto LA64_;
			result = (*r)._kind_4.sym;
		}
		LA64_: ;
	}
	break;
	default:
	{
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeDeref__wWBimsBS4M6UZBvTRDlQTQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	t = (*n).typ;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((IL64(13510798882111488) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		t = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
	}
	LA5_: ;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(105553116268560));
	result = n;
	{
		if (!((IL64(140737496743936) &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA9_;
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65), (*n).info, (*t).sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, n);
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(105553116268560));
	}
	LA9_: ;
	{
		while (1) {
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseTyp;
			if (!((6291456 &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA12;
			a = result;
			baseTyp = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65), (*n).info, baseTyp);
			add__P8dDSotTW25BkfbyspojGg(result, a);
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(baseTyp, IL64(105553116268560));
		} LA12: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, builtinFieldAccess__vJZwz9bfROKrfrtM50y74CQ_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* check;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, 7);
	{
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		{
			if (!((520256 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA7_;
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA11_;
				result = semSym__20OKsvfFnNZXONk4IBzYgg(c, n, s, flags);
			}
			LA11_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*(*n)._kind_6.sons->data[((NI) 1)]).info, s);
			result = semSym__20OKsvfFnNZXONk4IBzYgg(c, n, s, flags);
		}
		LA5_: ;
		goto BeforeRet_;
	}
	LA3_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], (flags | 256)));
	i = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], n);
	ty = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
	f = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA16_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
			T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T20_ = base__PfgI9ap7WOnsRfFV4znQ27w(ty);
			if (!((*T20_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA21_;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T25_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
				T25_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T25_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
				if (!!(((*T25_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)))) goto LA26_;
				T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T28_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
				asgnRef((void**) (&(*n).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T28_));
				result = n;
				goto BeforeRet_;
			}
			goto LA23_;
			LA26_: ;
			{
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				goto BeforeRet_;
			}
			LA23_: ;
		}
		goto LA18_;
		LA21_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
			T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T31_ = base__PfgI9ap7WOnsRfFV4znQ27w(ty);
			result = tryReadingTypeField__6Ix9awqI9ax7ryNwTnzhRziw(c, n, i, T31_);
			goto BeforeRet_;
		}
		LA18_: ;
	}
	goto LA14_;
	LA16_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = isTypeExpr__OiccTa3ruRNl9anoSqZh2Sg_2((*n)._kind_6.sons->data[((NI) 0)]);
		if (!T33_) goto LA34_;
		result = tryReadingTypeField__6Ix9awqI9ax7ryNwTnzhRziw(c, n, i, ty);
		goto BeforeRet_;
	}
	goto LA14_;
	LA34_: ;
	LA14_: ;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = ((IL64(13510798882111488) &((NU64)1<<((NU)((*ty).kind)&63U)))!=0);
		if (!(T38_)) goto LA39_;
		T38_ = (((*ty).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
		LA39_: ;
		if (!T38_) goto LA40_;
		ty = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(ty);
	}
	LA40_: ;
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, IL64(246290619303952));
	{
		while (1) {
			if (!(((*ty).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 32))&63U)))!=0)) goto LA43;
			ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, 8192);
		} LA43: ;
	}
	check = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA46_;
		{
			while (1) {
				check = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				f = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, (*ty).n, i, &check);
				{
					if (!!((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA52_;
					goto LA48;
				}
				LA52_: ;
				{
					if (!((*ty).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA56_;
					goto LA48;
				}
				LA56_: ;
				ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*ty).sons->data[((NI) 0)], IL64(36275087638268176));
			}
		} LA48: ;
		{
			NIM_BOOL visibilityCheckNeeded;
			if (!!((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA60_;
			{
				NIM_BOOL T64_;
				T64_ = (NIM_BOOL)0;
				T64_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T64_)) goto LA65_;
				T64_ = ((*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym == f);
				LA65_: ;
				if (!T64_) goto LA66_;
				visibilityCheckNeeded = NIM_FALSE;
			}
			goto LA62_;
			LA66_: ;
			{
				visibilityCheckNeeded = NIM_TRUE;
			}
			LA62_: ;
			{
				NIM_BOOL T71_;
				T71_ = (NIM_BOOL)0;
				T71_ = !(visibilityCheckNeeded);
				if (T71_) goto LA72_;
				T71_ = fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch(c, f);
				LA72_: ;
				if (!T71_) goto LA73_;
				markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*(*n)._kind_6.sons->data[((NI) 1)]).info, f);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), makeDeref__wWBimsBS4M6UZBvTRDlQTQ((*n)._kind_6.sons->data[((NI) 0)]));
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f));
				asgnRef((void**) (&(*n).typ), (*f).typ);
				{
					if (!(check == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA77_;
					result = n;
				}
				goto LA75_;
				LA77_: ;
				{
					asgnRef((void**) (&(*check)._kind_6.sons->data[((NI) 0)]), n);
					asgnRef((void**) (&(*check).typ), (*n).typ);
					result = check;
				}
				LA75_: ;
			}
			LA73_: ;
		}
		LA60_: ;
	}
	goto LA44_;
	LA46_: ;
	{
		NIM_BOOL T81_;
		T81_ = (NIM_BOOL)0;
		T81_ = ((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
		if (!(T81_)) goto LA82_;
		T81_ = !(((*ty).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA82_: ;
		if (!T81_) goto LA83_;
		f = getSymFromList__aHh3vzt6upPNMkKnONiMRw((*ty).n, i, ((NI) 0));
		{
			if (!!((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA87_;
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*(*n)._kind_6.sons->data[((NI) 1)]).info, f);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), makeDeref__wWBimsBS4M6UZBvTRDlQTQ((*n)._kind_6.sons->data[((NI) 0)]));
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f));
			asgnRef((void**) (&(*n).typ), (*f).typ);
			result = n;
		}
		LA87_: ;
	}
	goto LA44_;
	LA83_: ;
	LA44_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA91_;
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(246290619301904));
		result = tryReadingGenericParam__L5Nhi0f3LeGUlYzLEKJ7lw(c, n, i, t);
	}
	LA91_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, semOpAux__NRIJDWZtATzMum7OEjYC2g_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T6_;
					NI T8_;
					tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T11_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33));
					if (!(T6_)) goto LA7_;
					T8_ = (NI)0;
					T8_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					T6_ = (T8_ == ((NI) 2));
					LA7_: ;
					if (!T6_) goto LA9_;
					info = (*(*a)._kind_6.sons->data[((NI) 0)]).info;
					T11_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
					T11_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*a)._kind_6.sons->data[((NI) 0)], a);
					asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T11_, info));
					asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*a)._kind_6.sons->data[((NI) 1)], 256));
					asgnRef((void**) (&(*a).typ), (*(*a)._kind_6.sons->data[((NI) 1)]).typ);
				}
				goto LA4_;
				LA9_: ;
				{
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, a, 256));
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyExcept__fBlFhtX9baijQaFTBKid83w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	{
		NI j;
		NI colontmp_;
		NI i_2;
		j = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				j = i_2;
				{
					if (!!((j == i))) goto LA6_;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[j]);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, s);
	pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*n).info, (*(*s).name).s);
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = evalTemplate__MnrgLhOl4U6sn3rRD19cz9bA(n, s, T1_, (*(*c).graph).config, (*c).cache, (*c).templInstCounter, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 16))&31U)))!=0));
	{
		if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 13))&31U)))!=0))) goto LA4_;
		result = semAfterMacroCall__Hw66264lMkoOE49a7wqbwsQ(c, n, result, s, flags);
	}
	LA4_: ;
	popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
	(*result).info = info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcAnnotation__Uz9bZ6N7ZeTxuwI9b9cYeOeYw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prc, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	n = (*prc)._kind_6.sons->data[((NI) 4)];
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
					it = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T13_;
						NI T15_;
						T13_ = (NIM_BOOL)0;
						T13_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T13_)) goto LA14_;
						T15_ = (NI)0;
						T15_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						T13_ = (((NI) 1) <= T15_);
						LA14_: ;
						if (!T13_) goto LA16_;
						key = (*it)._kind_6.sons->data[((NI) 0)];
					}
					goto LA11_;
					LA16_: ;
					{
						key = it;
					}
					LA11_: ;
					{
						tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T21_;
						T21_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
						T21_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(it);
						if (!!((T21_ == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 0)))) goto LA22_;
						goto LA10;
					}
					goto LA19_;
					LA22_: ;
					{
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
						ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, key, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T27_;
							T27_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T27_ = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).userPragmas, ident);
							if (!!((T27_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA28_;
							goto LA10;
						}
						goto LA25_;
						LA28_: ;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
							sym = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
							{
								NIM_BOOL T33_;
								T33_ = (NIM_BOOL)0;
								T33_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
								if (!(T33_)) goto LA34_;
								T33_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0);
								LA34_: ;
								if (!T33_) goto LA35_;
								goto LA10;
							}
							LA35_: ;
						}
						LA25_: ;
					}
					LA19_: ;
					x = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*key).info);
					add__P8dDSotTW25BkfbyspojGg(x, key);
					{
						NIM_BOOL T39_;
						NI T41_;
						T39_ = (NIM_BOOL)0;
						T39_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T39_)) goto LA40_;
						T41_ = (NI)0;
						T41_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						T39_ = (((NI) 1) < T41_);
						LA40_: ;
						if (!T39_) goto LA42_;
						{
							NI i_3;
							NI colontmp__2;
							NI i_4;
							i_3 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(it);
							i_4 = ((NI) 1);
							{
								while (1) {
									if (!(i_4 < colontmp__2)) goto LA46;
									i_3 = i_4;
									add__P8dDSotTW25BkfbyspojGg(x, (*it)._kind_6.sons->data[i_3]);
									i_4 += ((NI) 1);
								} LA46: ;
							}
						}
					}
					LA42_: ;
					asgnRef((void**) (&(*prc)._kind_6.sons->data[((NI) 4)]), copyExcept__fBlFhtX9baijQaFTBKid83w(n, i));
					{
						NIM_BOOL T49_;
						NI T51_;
						T49_ = (NIM_BOOL)0;
						T49_ = !(((*(*prc)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
						if (!(T49_)) goto LA50_;
						T51_ = (NI)0;
						T51_ = len__P89cqdlERShb9alU3iC0yj8wast((*prc)._kind_6.sons->data[((NI) 4)]);
						T49_ = (T51_ == ((NI) 0));
						LA50_: ;
						if (!T49_) goto LA52_;
						asgnRef((void**) (&(*prc)._kind_6.sons->data[((NI) 4)]), (*(*c).graph).emptyNode);
					}
					LA52_: ;
					add__P8dDSotTW25BkfbyspojGg(x, prc);
					r = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, x, x, 393216, 262144);
					{
						if (!(r == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA56_;
						asgnRef((void**) (&(*prc)._kind_6.sons->data[((NI) 4)]), n);
						goto LA10;
					}
					LA56_: ;
					{
						if (!!(((*(*r)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA60_;
						failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_99));
					}
					LA60_: ;
					m = (*(*r)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
					switch ((*m).kind) {
					case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
					{
						result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, r, r, m, 0);
					}
					break;
					case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
					{
						result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, r, m, 0);
					}
					break;
					default:
					{
						asgnRef((void**) (&(*prc)._kind_6.sons->data[((NI) 4)]), n);
						goto LA10;
					}
					break;
					}
					{
						if (!!(!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))) goto LA67_;
						failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_100));
					}
					LA67_: ;
					{
						NIM_BOOL T71_;
						NIM_BOOL T72_;
						T71_ = (NIM_BOOL)0;
						T72_ = (NIM_BOOL)0;
						T72_ = ((*result).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) && (*result).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52) || (*result).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) && (*result).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159));
						if (!(T72_)) goto LA73_;
						T72_ = ((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						LA73_: ;
						T71_ = T72_;
						if (!(T71_)) goto LA74_;
						T71_ = !(((*(*result)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
						LA74_: ;
						if (!T71_) goto LA75_;
						pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym, (*result)._kind_6.sons->data[((NI) 4)], validPragmas, NIM_FALSE);
					}
					LA75_: ;
					goto BeforeRet_;
				} LA10: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSymG__z0Xq7x7aKOzONyxr8mX73A)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		result = (*n)._kind_4.sym;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T9_;
			NimStringDesc* T10_;
			if (!!(((*result).kind == kind || (*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5)))) goto LA7_;
			nimZeroMem((void*)T9_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T9_[0] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA((*result).kind);
			T9_[1] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA(kind);
			T10_ = (NimStringDesc*)0;
			T10_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_101), T9_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T10_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_102, NIM_FALSE);
		}
		LA7_: ;
		asgnRef((void**) (&(*result).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T12_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
		T12_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T12_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T13_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		result = newSym__IXbidcxhXTQGZY9abN63Cxg(kind, T12_, T13_, (*n).info, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw allowed) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31))) goto LA3_;
		{
			NI T7_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* v;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T7_ == ((NI) 2))) goto LA8_;
			result = newSymG__z0Xq7x7aKOzONyxr8mX73A(kind, (*n)._kind_6.sons->data[((NI) 1)], c);
			v = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((allowed &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0);
				if (!(T12_)) goto LA13_;
				T12_ = ((*v).Sup.id == ((NI) 72));
				LA13_: ;
				if (!T12_) goto LA14_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1)) & 63);
			}
			goto LA10_;
			LA14_: ;
			{
				{
					NimStringDesc* T21_;
					if (!!(((allowed &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0))) goto LA19_;
					T21_ = (NimStringDesc*)0;
					T21_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_104));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_105, NIM_FALSE);
				}
				goto LA17_;
				LA19_: ;
				{
					NimStringDesc* T23_;
					NimStringDesc* T24_;
					T23_ = (NimStringDesc*)0;
					T23_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 0)], 0);
					T24_ = (NimStringDesc*)0;
					T24_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_106), T23_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T24_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_107, NIM_FALSE);
				}
				LA17_: ;
			}
			LA10_: ;
		}
		goto LA5_;
		LA8_: ;
		{
			illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = newSymG__z0Xq7x7aKOzONyxr8mX73A(kind, n, c);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentWithPragma__gSt4lwrAK8GOXOIIBgGsog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw allowed) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA3_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		result = semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2(c, kind, (*n)._kind_6.sons->data[((NI) 0)], allowed);
		switch (kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
		{
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19):
		{
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_108, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
		{
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_109, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
		{
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_109, NIM_FALSE);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
		{
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_110, NIM_FALSE);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		result = semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2(c, kind, n, allowed);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getLineInfo__oiqk14Y4OLEhcR9bJBpfCag_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
{	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 1) < T4_)) goto LA5_;
			result = getLineInfo__oiqk14Y4OLEhcR9bJBpfCag_2((*n)._kind_6.sons->data[((NI) 1)]);
			goto BeforeRet_;
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		{
			NI T10_;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T10_)) goto LA11_;
			result = getLineInfo__oiqk14Y4OLEhcR9bJBpfCag_2((*n)._kind_6.sons->data[((NI) 0)]);
			goto BeforeRet_;
		}
		LA11_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	result = (*n).info;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** usageSym, NIM_BOOL isDecl) {
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!T3_) goto LA4_;
		result = semIdentWithPragma__gSt4lwrAK8GOXOIIBgGsog(c, kind, n, 2);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
	}
	goto LA1_;
	LA4_: ;
	{
		result = semIdentWithPragma__gSt4lwrAK8GOXOIIBgGsog(c, kind, n, 0);
		{
			if (!((*(*result).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA9_;
			(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
		}
		LA9_: ;
	}
	LA1_: ;
	(*result).options = (*(*(*c).graph).config).options;
	info = getLineInfo__oiqk14Y4OLEhcR9bJBpfCag_2(n);
	suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch((*(*c).graph).config, info, result, &(*(*c).graph).usageSym, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGenericConstraints__XPC0ita29a0P9cMGViV9aayYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tySequence__Ef05srmQTDulnBdXR4Ja6Q* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
	T1_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
	asgnRef((void**) (&T1_->data[0]), x);
	result = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12), T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericParamList__00ZJT6x0WT6z8eBqr79cipw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75)))) goto LA3_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				switch ((*a).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
					{
						if (!!((father == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA11_;
						addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(father, (*(*a)._kind_4.sym).typ);
					}
					LA11_: ;
					{
						if (!!((((*(*a)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA15_;
						addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, (*a)._kind_4.sym);
					}
					LA15_: ;
					T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T17_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*a)._kind_4.sym);
					add__P8dDSotTW25BkfbyspojGg(result, T17_);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35):
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					NI T19_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
					NI T20_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					T19_ = (NI)0;
					T19_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					def = (*a)._kind_6.sons->data[(NI)(T19_ - ((NI) 1))];
					T20_ = (NI)0;
					T20_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					constraint = (*a)._kind_6.sons->data[(NI)(T20_ - ((NI) 2))];
					typ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					{
						if (!!(((*constraint).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA23_;
						typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, constraint, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
						{
							NIM_BOOL T27_;
							NI T29_;
							T27_ = (NIM_BOOL)0;
							T27_ = !(((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60)));
							if (T27_) goto LA28_;
							T29_ = (NI)0;
							T29_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
							T27_ = (T29_ == ((NI) 0));
							LA28_: ;
							if (!T27_) goto LA30_;
							{
								if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA34_;
								{
									tySequence__Ef05srmQTDulnBdXR4Ja6Q* T40_;
									if (!((*(*typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA38_;
									T40_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
									T40_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
									asgnRef((void**) (&T40_->data[0]), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c));
									typ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), T40_);
									(*typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
								}
								LA38_: ;
							}
							goto LA32_;
							LA34_: ;
							{
								typ = semGenericConstraints__XPC0ita29a0P9cMGViV9aayYQ(c, typ);
							}
							LA32_: ;
						}
						LA30_: ;
					}
					LA23_: ;
					{
						if (!!(((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA44_;
						def = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, def);
						{
							if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA48_;
							{
								tySequence__Ef05srmQTDulnBdXR4Ja6Q* T54_;
								if (!!(((*(*def).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA52_;
								T54_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
								T54_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
								asgnRef((void**) (&T54_->data[0]), (*def).typ);
								typ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T54_);
							}
							LA52_: ;
						}
						goto LA46_;
						LA48_: ;
						{
							asgnRef((void**) (&(*def).typ), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*def).typ, 256));
							{
								NIM_BOOL T58_;
								T58_ = (NIM_BOOL)0;
								T58_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2((*def).typ);
								if (!!(T58_)) goto LA59_;
								def = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, def, (*def).info);
							}
							LA59_: ;
						}
						LA46_: ;
					}
					LA44_: ;
					{
						if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA63_;
						typ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12), c);
						{
							if (!(father == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA67_;
							(*typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30)) & 63);
						}
						LA67_: ;
					}
					LA63_: ;
					(*typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 25)) & 63);
					{
						NI j;
						NI colontmp__2;
						NI T70_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T70_ = (NI)0;
						T70_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__2 = (NI)(T70_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* finalType;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* paramName;
								tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw covarianceFlag;
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T131_;
								if (!(i_3 < colontmp__2)) goto LA72;
								j = i_3;
								{
									if (!(j == ((NI) 0))) goto LA75_;
									finalType = typ;
								}
								goto LA73_;
								LA75_: ;
								{
									finalType = copyType__4O4aYoscFPo2FRSh4rP9ayg(typ, (*typ).owner, NIM_FALSE);
								}
								LA73_: ;
								paramName = (*a)._kind_6.sons->data[j];
								covarianceFlag = ((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9);
								{
									NI T80_;
									T80_ = (NI)0;
									T80_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(paramName);
									if (!(T80_ == ((NI) 2))) goto LA81_;
									{
										NIM_BOOL T85_;
										T85_ = (NIM_BOOL)0;
										T85_ = NIM_TRUE;
										if (T85_) goto LA86_;
										T85_ = eqStrings((*(*(*paramName)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_111));
										LA86_: ;
										if (!T85_) goto LA87_;
										{
											NIM_BOOL T91_;
											NimStringDesc* T95_;
											NimStringDesc* T96_;
											T91_ = (NIM_BOOL)0;
											T91_ = (father == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
											if (T91_) goto LA92_;
											T91_ = !((((*(*father).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
											LA92_: ;
											if (!T91_) goto LA93_;
											T95_ = (NimStringDesc*)0;
											T95_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*paramName)._kind_6.sons->data[((NI) 0)]);
											T96_ = (NimStringDesc*)0;
											T96_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_112), T95_);
											liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*paramName).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T96_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_113, NIM_FALSE);
										}
										LA93_: ;
									}
									LA87_: ;
									{
										if (!eqStrings((*(*(*paramName)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_111))) goto LA99_;
										covarianceFlag = ((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 37);
									}
									goto LA97_;
									LA99_: ;
									{
										covarianceFlag = ((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35);
									}
									LA97_: ;
									{
										if (!!((father == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA104_;
										(*father).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35)) & 63);
									}
									LA104_: ;
									paramName = (*paramName)._kind_6.sons->data[((NI) 1)];
								}
								LA81_: ;
								{
									NIM_BOOL T108_;
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T112_;
									T108_ = (NIM_BOOL)0;
									T108_ = ((*finalType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
									if (T108_) goto LA109_;
									T108_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0);
									LA109_: ;
									if (!T108_) goto LA110_;
									T112_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
									T112_ = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4), paramName, c);
									s = linkTo__Lxy1G9c1I40y65cWkoPnssA(T112_, finalType);
								}
								goto LA106_;
								LA110_: ;
								{
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T114_;
									T114_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
									T114_ = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), paramName, c);
									s = linkTo__Lxy1G9c1I40y65cWkoPnssA(T114_, finalType);
								}
								LA106_: ;
								{
									if (!!((covarianceFlag == ((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)))) goto LA117_;
									(*(*s).typ).flags |= ((NU64)1)<<((covarianceFlag) & 63);
								}
								LA117_: ;
								{
									if (!!(((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA121_;
									asgnRef((void**) (&(*s).ast), def);
								}
								LA121_: ;
								(*s).position = len__P89cqdlERShb9alU3iC0yj8wast(result);
								{
									if (!!((father == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA125_;
									addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(father, (*s).typ);
								}
								LA125_: ;
								{
									if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA129_;
									addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, s);
								}
								LA129_: ;
								T131_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T131_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s);
								add__P8dDSotTW25BkfbyspojGg(result, T131_);
								i_3 += ((NI) 1);
							} LA72: ;
						}
					}
				}
				break;
				default:
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setGenericParamsMisc__7YxUILpPxooC5qqa89a54dw_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	orig = (*n)._kind_6.sons->data[((NI) 2)];
	result = semGenericParamList__00ZJT6x0WT6z8eBqr79cipw(c, orig, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	{
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T5_;
		if (!((*(*n)._kind_6.sons->data[((NI) 5)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T5_[0] = (*(*c).graph).emptyNode;
		T5_[1] = orig;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 5)]), newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), T5_, 2));
	}
	goto LA1_;
	LA3_: ;
	{
		asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 5)])._kind_6.sons->data[((NI) 1)]), orig);
	}
	LA1_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newProcType__5gg5mq4XYRQKbAkdLMpzGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25), prev, c);
	T1_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)0;
	T1_ = lastOptionEntry__SQasfuhUR9aUpH0EyW9aFezg_2(c);
	(*result).callConv = (*T1_).defaultCC;
	asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), info));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), NIM_TRUE);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), info);
	add__P8dDSotTW25BkfbyspojGg((*result).n, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semParamType__JfIbex3lv6r6Ex7T9a9cADuw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** constraint) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40))) goto LA3_;
		result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		unsureAsgnRef((void**) (&(*constraint)), semNodeKindConstraints__h4580wUcWriTu1bx3JdXfA(n, (*(*c).graph).config, ((NI) 1)));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T10_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27));
		if (!(T7_)) goto LA8_;
		T7_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T10_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T10_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		T6_ = eqStrings((*T10_).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_114));
		LA9_: ;
		if (!T6_) goto LA11_;
		result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		unsureAsgnRef((void**) (&(*constraint)), semNodeKindConstraints__h4580wUcWriTu1bx3JdXfA(n, (*(*c).graph).config, ((NI) 2)));
	}
	goto LA1_;
	LA11_: ;
	{
		result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMagic__aafCJ57RxmXkzBZMJ1lSSQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nPragmas;
{	result = (NIM_BOOL)0;
	nPragmas = (*(*sym).ast)._kind_6.sons->data[((NI) 4)];
	result = hasPragma__oSJ8Ge9caDJrmJG9brFCzlOg(nPragmas, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 74));
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmtSymbol__q2u7Xlf0LOsIed6IkVg52g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, NIM_BOOL fromDotExpr) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0):
	{
		result = n;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
	{
		result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1), NIM_FALSE);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		{
			NIM_BOOL T6_;
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T11_;
			T6_ = (NIM_BOOL)0;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0));
			if (!(T8_)) goto LA9_;
			T8_ = ((393216 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T11_ = (NI)0;
			T11_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
			T7_ = (T11_ == ((NI) 1));
			LA10_: ;
			T6_ = T7_;
			if (!(T6_)) goto LA12_;
			T6_ = !(fromDotExpr);
			LA12_: ;
			if (!T6_) goto LA13_;
			result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, n, s, 8192);
			result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, 0, ctx);
		}
		goto LA4_;
		LA13_: ;
		{
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1), NIM_FALSE);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
	{
		{
			NIM_BOOL T19_;
			NIM_BOOL T20_;
			NIM_BOOL T21_;
			NI T24_;
			T19_ = (NIM_BOOL)0;
			T20_ = (NIM_BOOL)0;
			T21_ = (NIM_BOOL)0;
			T21_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0));
			if (!(T21_)) goto LA22_;
			T21_ = ((393216 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			LA22_: ;
			T20_ = T21_;
			if (!(T20_)) goto LA23_;
			T24_ = (NI)0;
			T24_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
			T20_ = (T24_ == ((NI) 1));
			LA23_: ;
			T19_ = T20_;
			if (!(T19_)) goto LA25_;
			T19_ = !(fromDotExpr);
			LA25_: ;
			if (!T19_) goto LA26_;
			result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, n, n, s, 8192);
			result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, 0, ctx);
		}
		goto LA17_;
		LA26_: ;
		{
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1), NIM_FALSE);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
	{
		{
			NIM_BOOL T32_;
			T32_ = (NIM_BOOL)0;
			T32_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T32_)) goto LA33_;
			T32_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
			LA33_: ;
			if (!T32_) goto LA34_;
			{
				if (!!(((*(*s).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA38_;
				result = (*(*s).typ).n;
			}
			goto LA36_;
			LA38_: ;
			{
				result = n;
			}
			LA36_: ;
		}
		goto LA30_;
		LA34_: ;
		{
			result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
	{
		result = n;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	{
		{
			NIM_BOOL T46_;
			T46_ = (NIM_BOOL)0;
			T46_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T46_)) goto LA47_;
			T46_ = (((*(*s).typ).flags & 100663296) == 0);
			LA47_: ;
			if (!T46_) goto LA48_;
			result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
		}
		goto LA44_;
		LA48_: ;
		{
			result = n;
		}
		LA44_: ;
	}
	break;
	default:
	{
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lookup__aVtCjYVuHV1t3poDWh43wA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
	s = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T1_, n, (*(*c).graph).config);
	{
		if (!(s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA4_;
		s = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).pureEnumFields, ident);
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = !((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			T8_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).ambiguousSymbols), (*s).Sup.id);
			LA9_: ;
			if (!T8_) goto LA10_;
			s = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		}
		LA10_: ;
	}
	LA4_: ;
	{
		if (!(s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA14_;
		{
			NIM_BOOL T18_;
			NIM_BOOL T19_;
			T18_ = (NIM_BOOL)0;
			T19_ = (NIM_BOOL)0;
			T19_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toMixin), (*ident).Sup.id);
			T18_ = !(T19_);
			if (!(T18_)) goto LA20_;
			T18_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 2))&7U)))!=0));
			LA20_: ;
			if (!T18_) goto LA21_;
			errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*n).info, (*ident).s);
		}
		LA21_: ;
	}
	goto LA12_;
	LA14_: ;
	{
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 0))&7U)))!=0);
			if (T26_) goto LA27_;
			T26_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toBind), (*s).Sup.id);
			LA27_: ;
			if (!T26_) goto LA28_;
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
		}
		goto LA24_;
		LA28_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sX60gensym1951_;
			NIM_BOOL T31_;
			NIM_BOOL T33_;
			NIM_BOOL T34_;
			sX60gensym1951_ = s;
			T31_ = (NIM_BOOL)0;
			T31_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toMixin), (*(*sX60gensym1951_).name).Sup.id);
			if (T31_) goto LA32_;
			T33_ = (NIM_BOOL)0;
			T34_ = (NIM_BOOL)0;
			T34_ = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 3))&7U)))!=0);
			if (!(T34_)) goto LA35_;
			T34_ = ((*sX60gensym1951_).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
			LA35_: ;
			T33_ = T34_;
			if (!(T33_)) goto LA36_;
			T33_ = ((OverloadableSyms__yJfP9bpZPSQn9bPO6KCo08fQ &((NU32)1<<((NU)((*sX60gensym1951_).kind)&31U)))!=0);
			LA36_: ;
			T31_ = T33_;
			LA32_: ;
			if (!T31_) goto LA37_;
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2), NIM_FALSE);
		}
		goto LA24_;
		LA37_: ;
		{
			result = semGenericStmtSymbol__q2u7Xlf0LOsIed6IkVg52g(c, n, s, ctx, flags, NIM_FALSE);
		}
		LA24_: ;
	}
	LA12_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDot__9bgrXSJFYUNpBL6r2Dw4dwQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45), (*n).info);
	add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fuzzyLookup__AtVxV9cBv7sgERvmPI9aqfnA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx, NIM_BOOL* isMacro) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ luf;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 2))&7U)))!=0))) goto LA3_;
		luf = 6;
	}
	goto LA1_;
	LA3_: ;
	{
		luf = 4;
	}
	LA1_: ;
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, luf);
	{
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8_;
		result = semGenericStmtSymbol__q2u7Xlf0LOsIed6IkVg52g(c, n, s, ctx, flags, NIM_FALSE);
	}
	goto LA6_;
	LA8_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T11_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 0)], flags, ctx));
		result = n;
		n_2 = (*n)._kind_6.sons->data[((NI) 1)];
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n_2, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		T11_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T11_ = searchInScopes__Jp5sb3DT9aETEb2x58UOk6g(c, ident, 520192);
		s_2 = skipAlias__5qYRPQsu9attXO2xg5lnFVQ(T11_, n_2, (*(*c).graph).config);
		{
			if (!!((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA14_;
			(*isMacro) = ((393216 &((NU32)1<<((NU)((*s_2).kind)&31U)))!=0);
			{
				NIM_BOOL T18_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 0))&7U)))!=0);
				if (T18_) goto LA19_;
				T18_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toBind), (*s_2).Sup.id);
				LA19_: ;
				if (!T18_) goto LA20_;
				T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T22_ = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n_2, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
				result = newDot__9bgrXSJFYUNpBL6r2Dw4dwQ(result, T22_);
			}
			goto LA16_;
			LA20_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sX60gensym1969_;
				NIM_BOOL T24_;
				NIM_BOOL T26_;
				NIM_BOOL T27_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T32_;
				sX60gensym1969_ = s_2;
				T24_ = (NIM_BOOL)0;
				T24_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toMixin), (*(*sX60gensym1969_).name).Sup.id);
				if (T24_) goto LA25_;
				T26_ = (NIM_BOOL)0;
				T27_ = (NIM_BOOL)0;
				T27_ = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 3))&7U)))!=0);
				if (!(T27_)) goto LA28_;
				T27_ = ((*sX60gensym1969_).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
				LA28_: ;
				T26_ = T27_;
				if (!(T26_)) goto LA29_;
				T26_ = ((OverloadableSyms__yJfP9bpZPSQn9bPO6KCo08fQ &((NU32)1<<((NU)((*sX60gensym1969_).kind)&31U)))!=0);
				LA29_: ;
				T24_ = T26_;
				LA25_: ;
				if (!T24_) goto LA30_;
				T32_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T32_ = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n_2, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2), NIM_FALSE);
				result = newDot__9bgrXSJFYUNpBL6r2Dw4dwQ(result, T32_);
			}
			goto LA16_;
			LA30_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* syms;
				syms = semGenericStmtSymbol__q2u7Xlf0LOsIed6IkVg52g(c, n_2, s_2, ctx, flags, NIM_TRUE);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* choice;
					if (!((*syms).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA36_;
					choice = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n_2, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2), NIM_FALSE);
					transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(choice, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 56));
					result = newDot__9bgrXSJFYUNpBL6r2Dw4dwQ(result, choice);
				}
				goto LA34_;
				LA36_: ;
				{
					result = newDot__9bgrXSJFYUNpBL6r2Dw4dwQ(result, syms);
				}
				LA34_: ;
			}
			LA16_: ;
		}
		LA14_: ;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMixinStmt__gk1t9bC9cmwHRhVJXF0sVfqA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* toMixin) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T4_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				T4_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T4_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[i], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				incl__jENnK9c9bPE73pKmo2vYjpqg(toMixin, (*T4_).Sup.id);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBindStmt__9askHuPxNsdv5Fi00VcmrXQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* toBind) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, a, 2);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sc;
					if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
					sc = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
					{
						if (!((*sc).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA10_;
						incl__jENnK9c9bPE73pKmo2vYjpqg(toBind, (*(*sc)._kind_4.sym).Sup.id);
					}
					goto LA8_;
					LA10_: ;
					{
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
							x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							{
								NI i_3;
								NI colontmp__2;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(sc);
								i_4 = ((NI) 0);
								{
									while (1) {
										if (!(i_4 < colontmp__2)) goto LA16;
										i_3 = i_4;
										x = (*sc)._kind_6.sons->data[i_3];
										incl__jENnK9c9bPE73pKmo2vYjpqg(toBind, (*(*x)._kind_4.sym).Sup.id);
										i_4 += ((NI) 1);
									} LA16: ;
								}
							}
						}
					}
					LA8_: ;
				}
				goto LA4_;
				LA6_: ;
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, n, flags, ctx);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSymS__z0Xq7x7aKOzONyxr8mX73A_2)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(kind, T1_, T2_, (*n).info, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getIdentNode__7YxUILpPxooC5qqa89a54dw_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		result = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		result = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = n;
	}
	break;
	default:
	{
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
		result = n;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addTempDecl__XjZLpvNqVUTx1J6TXREPBQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, n);
	s = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T1_, c);
	addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4(c, s);
	{
		if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA4_;
		nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*n).info, s, kind);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmt__aVtCjYVuHV1t3poDWh43wA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags, tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w* ctx) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		result = lookup__aVtCjYVuHV1t3poDWh43wA_2(c, n, flags, ctx);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		NIM_BOOL dummy;
		dummy = (NIM_BOOL)0;
		result = fuzzyLookup__AtVxV9cBv7sgERvmPI9aqfnA(c, n, flags, ctx, (&dummy));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b;
		a = (*n)._kind_4.sym;
		b = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, a);
		{
			if (!!((b == a))) goto LA6_;
			asgnRef((void**) (&(*n)._kind_4.sym), b);
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 55):
	{
		result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 0)], (flags | 1), ctx);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 123):
	{
		result = semMixinStmt__gk1t9bC9cmwHRhVJXF0sVfqA(c, n, (&(*ctx).toMixin));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 122):
	{
		result = semBindStmt__9askHuPxNsdv5Fi00VcmrXQ(c, n, (&(*ctx).toBind));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		NI first;
		NIM_BOOL mixinContext;
		tySet_tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA flags_2;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
		fn = (*n)._kind_6.sons->data[((NI) 0)];
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, fn, 0);
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			NIM_BOOL T17_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T21_;
			NIM_BOOL T22_;
			NimStringDesc* T25_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T17_ = (NIM_BOOL)0;
			T17_ = (s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (!(T17_)) goto LA18_;
			T17_ = ((12 & flags) == 0);
			LA18_: ;
			T16_ = T17_;
			if (!(T16_)) goto LA19_;
			T16_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53));
			LA19_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA20_;
			T21_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T21_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, fn, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			T22_ = (NIM_BOOL)0;
			T22_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toMixin), (*T21_).Sup.id);
			T15_ = !(T22_);
			LA20_: ;
			if (!T15_) goto LA23_;
			T25_ = (NimStringDesc*)0;
			T25_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(fn, 0);
			errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*n).info, T25_);
		}
		LA23_: ;
		first = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 3))&7U)))!=0);
		mixinContext = NIM_FALSE;
		{
			tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA whichChoice;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sc;
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA28_;
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
			mixinContext = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 1) || (*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 2) || (*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 3) || (*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 4) || (*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 140));
			{
				NIM_BOOL T32_;
				T32_ = (NIM_BOOL)0;
				T32_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toBind), (*s).Sup.id);
				if (!T32_) goto LA33_;
				whichChoice = ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0);
			}
			goto LA30_;
			LA33_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sX60gensym1988_;
				NIM_BOOL T36_;
				NIM_BOOL T38_;
				NIM_BOOL T39_;
				sX60gensym1988_ = s;
				T36_ = (NIM_BOOL)0;
				T36_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*ctx).toMixin), (*(*sX60gensym1988_).name).Sup.id);
				if (T36_) goto LA37_;
				T38_ = (NIM_BOOL)0;
				T39_ = (NIM_BOOL)0;
				T39_ = ((flags &((NU8)1<<((NU)(((tyEnum_TSemGenericFlag__awL4DUaf8OhTzyAenbxDoA) 3))&7U)))!=0);
				if (!(T39_)) goto LA40_;
				T39_ = ((*sX60gensym1988_).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
				LA40_: ;
				T38_ = T39_;
				if (!(T38_)) goto LA41_;
				T38_ = ((OverloadableSyms__yJfP9bpZPSQn9bPO6KCo08fQ &((NU32)1<<((NU)((*sX60gensym1988_).kind)&31U)))!=0);
				LA41_: ;
				T36_ = T38_;
				LA37_: ;
				if (!T36_) goto LA42_;
				whichChoice = ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2);
			}
			goto LA30_;
			LA42_: ;
			{
				whichChoice = ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1);
			}
			LA30_: ;
			sc = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, fn, s, whichChoice, NIM_FALSE);
			switch ((*s).kind) {
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
			{
				{
					NIM_BOOL T48_;
					NIM_BOOL T49_;
					NIM_BOOL T51_;
					NI T52_;
					NI T55_;
					T48_ = (NIM_BOOL)0;
					T49_ = (NIM_BOOL)0;
					T49_ = ((393216 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					if (!(T49_)) goto LA50_;
					T51_ = (NIM_BOOL)0;
					T52_ = (NI)0;
					T52_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
					T51_ = (T52_ == ((NI) 1));
					if (T51_) goto LA53_;
					T51_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0);
					LA53_: ;
					T49_ = T51_;
					LA50_: ;
					T48_ = T49_;
					if (!(T48_)) goto LA54_;
					T55_ = (NI)0;
					T55_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(sc);
					T48_ = (T55_ <= ((NI) 1));
					LA54_: ;
					if (!T48_) goto LA56_;
					result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, n, n, s, 8192);
					result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
				}
				goto LA46_;
				LA56_: ;
				{
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), sc);
					result = n;
				}
				LA46_: ;
				mixinContext = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
			{
				{
					NIM_BOOL T62_;
					NIM_BOOL T63_;
					NIM_BOOL T65_;
					NI T66_;
					NI T69_;
					T62_ = (NIM_BOOL)0;
					T63_ = (NIM_BOOL)0;
					T63_ = ((393216 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
					if (!(T63_)) goto LA64_;
					T65_ = (NIM_BOOL)0;
					T66_ = (NI)0;
					T66_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
					T65_ = (T66_ == ((NI) 1));
					if (T65_) goto LA67_;
					T65_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0);
					LA67_: ;
					T63_ = T65_;
					LA64_: ;
					T62_ = T63_;
					if (!(T62_)) goto LA68_;
					T69_ = (NI)0;
					T69_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(sc);
					T62_ = (T69_ <= ((NI) 1));
					LA68_: ;
					if (!T62_) goto LA70_;
					result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, n, s, 8192);
					result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
				}
				goto LA60_;
				LA70_: ;
				{
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), sc);
					result = n;
				}
				LA60_: ;
				mixinContext = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
			{
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
			{
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), sc);
				first = ((NI) 1);
				{
					if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 263))) goto LA77_;
					first = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
				}
				LA77_: ;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
			{
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*fn).info));
				first = ((NI) 1);
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
			{
				{
					NIM_BOOL T83_;
					T83_ = (NIM_BOOL)0;
					T83_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T83_)) goto LA84_;
					T83_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
					LA84_: ;
					if (!T83_) goto LA85_;
					asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*fn).info));
					first = ((NI) 1);
				}
				LA85_: ;
			}
			break;
			default:
			{
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*fn).info));
				first = ((NI) 1);
			}
			break;
			}
		}
		goto LA26_;
		LA28_: ;
		{
			if (!((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA89_;
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), fuzzyLookup__AtVxV9cBv7sgERvmPI9aqfnA(c, fn, flags, ctx, (&mixinContext)));
			first = ((NI) 1);
		}
		goto LA26_;
		LA89_: ;
		LA26_: ;
		{
			if (!mixinContext) goto LA93_;
			flags_2 = (flags | 4);
		}
		goto LA91_;
		LA93_: ;
		{
			flags_2 = flags;
		}
		LA91_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
			i_2 = first;
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA98;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*result)._kind_6.sons->data[i], flags_2, ctx));
					i_2 += ((NI) 1);
				} LA98: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T100_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T101_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T100_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T100_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_114));
		T101_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T101_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T100_, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T101_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA104;
					i_3 = i_4;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i_3]);
					i_4 += ((NI) 1);
				} LA104: ;
			}
		}
		result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T106_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T107_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T106_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T106_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_26));
		T107_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T107_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T106_, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T107_);
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 0);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA110;
					i_5 = i_6;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i_5]);
					i_6 += ((NI) 1);
				} LA110: ;
			}
		}
		result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b_2;
		tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw k;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		a_2 = (*n)._kind_6.sons->data[((NI) 0)];
		b_2 = (*n)._kind_6.sons->data[((NI) 1)];
		k = (*a_2).kind;
		switch (k) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T113_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T114_;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
			T113_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T113_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_118));
			T114_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T114_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T113_, (*n).info);
			add__P8dDSotTW25BkfbyspojGg(result, T114_);
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA117;
						i_7 = i_8;
						add__P8dDSotTW25BkfbyspojGg(result, (*a_2)._kind_6.sons->data[i_7]);
						i_8 += ((NI) 1);
					} LA117: ;
				}
			}
			add__P8dDSotTW25BkfbyspojGg(result, b_2);
			result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T119_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T120_;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
			T119_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T119_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_119));
			T120_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T120_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T119_, (*n).info);
			add__P8dDSotTW25BkfbyspojGg(result, T120_);
			{
				NI i_9;
				NI colontmp__5;
				NI i_10;
				i_9 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
				i_10 = ((NI) 0);
				{
					while (1) {
						if (!(i_10 < colontmp__5)) goto LA123;
						i_9 = i_10;
						add__P8dDSotTW25BkfbyspojGg(result, (*a_2)._kind_6.sons->data[i_9]);
						i_10 += ((NI) 1);
					} LA123: ;
				}
			}
			add__P8dDSotTW25BkfbyspojGg(result, b_2);
			result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, result, flags, ctx);
		}
		break;
		default:
		{
			{
				NI i_11;
				NI colontmp__6;
				NI i_12;
				i_11 = (NI)0;
				colontmp__6 = (NI)0;
				colontmp__6 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_12 = ((NI) 0);
				{
					while (1) {
						if (!(i_12 < colontmp__6)) goto LA127;
						i_11 = i_12;
						asgnRef((void**) (&(*result)._kind_6.sons->data[i_11]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[i_11], flags, ctx));
						i_12 += ((NI) 1);
					} LA127: ;
				}
			}
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	{
		{
			NI i_13;
			NI colontmp__7;
			NI i_14;
			i_13 = (NI)0;
			colontmp__7 = (NI)0;
			colontmp__7 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_14 = ((NI) 0);
			{
				while (1) {
					if (!(i_14 < colontmp__7)) goto LA131;
					i_13 = i_14;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_13]), semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3(c, (*n)._kind_6.sons->data[i_13], flags, ctx));
					i_14 += ((NI) 1);
				} LA131: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			NI i_15;
			NI colontmp__8;
			NI i_16;
			i_15 = (NI)0;
			colontmp__8 = (NI)0;
			colontmp__8 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_16 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					if (!(i_16 < colontmp__8)) goto LA135;
					i_15 = i_16;
					it = (*n)._kind_6.sons->data[i_15];
					{
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 49) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86))) goto LA138_;
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i_15])._kind_6.sons->data[((NI) 0)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*it)._kind_6.sons->data[((NI) 0)], flags, ctx));
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i_15])._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*it)._kind_6.sons->data[((NI) 1)], (flags | 4), ctx));
					}
					goto LA136_;
					LA138_: ;
					{
						asgnRef((void**) (&(*n)._kind_6.sons->data[i_15]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, it, (flags | 4), ctx));
					}
					LA136_: ;
					i_16 += ((NI) 1);
				} LA135: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T142_;
		T142_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T142_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		{
			NI i_17;
			NI colontmp__9;
			NI i_18;
			i_17 = (NI)0;
			colontmp__9 = (NI)0;
			colontmp__9 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_18 = ((NI) 0);
			{
				while (1) {
					if (!(i_18 < colontmp__9)) goto LA145;
					i_17 = i_18;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_17]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[i_17], flags, ctx));
					i_18 += ((NI) 1);
				} LA145: ;
			}
		}
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T147_;
		T147_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T147_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 0)], flags, ctx));
		{
			NI i_19;
			NI colontmp__10;
			NI i_20;
			i_19 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_20 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_3;
					NI T155_;
					NI T156_;
					if (!(i_20 < colontmp__10)) goto LA150;
					i_19 = i_20;
					a_3 = (*n)._kind_6.sons->data[i_19];
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_3, ((NI) 1), (*(*c).graph).config);
					{
						NI j;
						NI colontmp__11;
						NI T152_;
						NI i_21;
						j = (NI)0;
						colontmp__11 = (NI)0;
						T152_ = (NI)0;
						T152_ = len__P89cqdlERShb9alU3iC0yj8wast(a_3);
						colontmp__11 = (NI)(T152_ - ((NI) 1));
						i_21 = ((NI) 0);
						{
							while (1) {
								if (!(i_21 < colontmp__11)) goto LA154;
								j = i_21;
								asgnRef((void**) (&(*a_3)._kind_6.sons->data[j]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_3)._kind_6.sons->data[j], flags, ctx));
								i_21 += ((NI) 1);
							} LA154: ;
						}
					}
					T155_ = (NI)0;
					T155_ = len__P89cqdlERShb9alU3iC0yj8wast(a_3);
					T156_ = (NI)0;
					T156_ = len__P89cqdlERShb9alU3iC0yj8wast(a_3);
					asgnRef((void**) (&(*a_3)._kind_6.sons->data[(NI)(T155_ - ((NI) 1))]), semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3(c, (*a_3)._kind_6.sons->data[(NI)(T156_ - ((NI) 1))], flags, ctx));
					i_20 += ((NI) 1);
				} LA150: ;
			}
		}
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T158_;
		NI T159_;
		NI T160_;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T178_;
		NI T179_;
		NI T180_;
		T158_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T158_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		T159_ = (NI)0;
		T159_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T160_ = (NI)0;
		T160_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T159_ - ((NI) 2))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[(NI)(T160_ - ((NI) 2))], flags, ctx));
		{
			NI i_22;
			NI colontmp__12;
			NI T162_;
			NI i_23;
			i_22 = (NI)0;
			colontmp__12 = (NI)0;
			T162_ = (NI)0;
			T162_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp__12 = (NI)(T162_ - ((NI) 2));
			i_23 = ((NI) 0);
			{
				while (1) {
					if (!(i_23 < colontmp__12)) goto LA164;
					i_22 = i_23;
					{
						if (!((*(*n)._kind_6.sons->data[i_22]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA167_;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s_2;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__13;
							s_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							colontmp__13 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							colontmp__13 = (*n)._kind_6.sons->data[i_22];
							{
								NI i_24;
								NI colontmp__14;
								NI i_25;
								i_24 = (NI)0;
								colontmp__14 = (NI)0;
								colontmp__14 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp__13);
								i_25 = ((NI) 0);
								{
									while (1) {
										if (!(i_25 < colontmp__14)) goto LA172;
										i_24 = i_25;
										s_2 = (*colontmp__13)._kind_6.sons->data[i_24];
										{
											if (!((*s_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA175_;
											addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, s_2, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21));
										}
										LA175_: ;
										i_25 += ((NI) 1);
									} LA172: ;
								}
							}
						}
					}
					goto LA165_;
					LA167_: ;
					{
						addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, (*n)._kind_6.sons->data[i_22], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21));
					}
					LA165_: ;
					i_23 += ((NI) 1);
				} LA164: ;
			}
		}
		T178_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T178_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		T179_ = (NI)0;
		T179_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T180_ = (NI)0;
		T180_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T179_ - ((NI) 1))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[(NI)(T180_ - ((NI) 1))], flags, ctx));
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 129):
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T182_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		T182_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T182_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA185_;
			addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22));
		}
		LA185_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 1)], flags, ctx));
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3(c, (*n)._kind_6.sons->data[((NI) 0)], flags, ctx));
		{
			NI i_26;
			NI colontmp__15;
			NI i_27;
			i_26 = (NI)0;
			colontmp__15 = (NI)0;
			colontmp__15 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_27 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_4;
					tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T191_;
					NI T203_;
					NI T204_;
					if (!(i_27 < colontmp__15)) goto LA190;
					i_26 = i_27;
					a_4 = (*n)._kind_6.sons->data[i_26];
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_4, ((NI) 1), (*(*c).graph).config);
					T191_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
					T191_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
					{
						NI j_2;
						NI colontmp__16;
						NI T193_;
						NI i_28;
						j_2 = (NI)0;
						colontmp__16 = (NI)0;
						T193_ = (NI)0;
						T193_ = len__P89cqdlERShb9alU3iC0yj8wast(a_4);
						colontmp__16 = (NI)(T193_ - ((NI) 1));
						i_28 = ((NI) 0);
						{
							while (1) {
								if (!(i_28 < colontmp__16)) goto LA195;
								j_2 = i_28;
								{
									NIM_BOOL T198_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T201_;
									T198_ = (NIM_BOOL)0;
									T198_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*a_4)._kind_6.sons->data[j_2]);
									if (!T198_) goto LA199_;
									T201_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T201_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*(*a_4)._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 2)]);
									addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T201_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
									asgnRef((void**) (&(*(*a_4)._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*(*a_4)._kind_6.sons->data[j_2])._kind_6.sons->data[((NI) 1)], (flags | 2), ctx));
								}
								goto LA196_;
								LA199_: ;
								{
									asgnRef((void**) (&(*a_4)._kind_6.sons->data[j_2]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_4)._kind_6.sons->data[j_2], (flags | 2), ctx));
								}
								LA196_: ;
								i_28 += ((NI) 1);
							} LA195: ;
						}
					}
					T203_ = (NI)0;
					T203_ = len__P89cqdlERShb9alU3iC0yj8wast(a_4);
					T204_ = (NI)0;
					T204_ = len__P89cqdlERShb9alU3iC0yj8wast(a_4);
					asgnRef((void**) (&(*a_4)._kind_6.sons->data[(NI)(T203_ - ((NI) 1))]), semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3(c, (*a_4)._kind_6.sons->data[(NI)(T204_ - ((NI) 1))], flags, ctx));
					closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
					i_27 += ((NI) 1);
				} LA190: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		{
			NI i_29;
			NI colontmp__17;
			NI i_30;
			i_29 = (NI)0;
			colontmp__17 = (NI)0;
			colontmp__17 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_30 = ((NI) 0);
			{
				while (1) {
					if (!(i_30 < colontmp__17)) goto LA208;
					i_29 = i_30;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_5;
						NI T220_;
						NI T221_;
						NI T222_;
						NI T223_;
						a_5 = (*n)._kind_6.sons->data[i_29];
						{
							if (!((*a_5).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA212_;
							goto LA209;
						}
						LA212_: ;
						{
							NIM_BOOL T216_;
							T216_ = (NIM_BOOL)0;
							T216_ = !(((*a_5).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)));
							if (!(T216_)) goto LA217_;
							T216_ = !(((*a_5).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)));
							LA217_: ;
							if (!T216_) goto LA218_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_5, (*(*c).graph).config);
						}
						LA218_: ;
						checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_5, ((NI) 3), (*(*c).graph).config);
						T220_ = (NI)0;
						T220_ = len__P89cqdlERShb9alU3iC0yj8wast(a_5);
						T221_ = (NI)0;
						T221_ = len__P89cqdlERShb9alU3iC0yj8wast(a_5);
						asgnRef((void**) (&(*a_5)._kind_6.sons->data[(NI)(T220_ - ((NI) 2))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_5)._kind_6.sons->data[(NI)(T221_ - ((NI) 2))], (flags | 2), ctx));
						T222_ = (NI)0;
						T222_ = len__P89cqdlERShb9alU3iC0yj8wast(a_5);
						T223_ = (NI)0;
						T223_ = len__P89cqdlERShb9alU3iC0yj8wast(a_5);
						asgnRef((void**) (&(*a_5)._kind_6.sons->data[(NI)(T222_ - ((NI) 1))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_5)._kind_6.sons->data[(NI)(T223_ - ((NI) 1))], flags, ctx));
						{
							NI j_3;
							NI colontmp__18;
							NI T225_;
							NI i_31;
							j_3 = (NI)0;
							colontmp__18 = (NI)0;
							T225_ = (NI)0;
							T225_ = len__P89cqdlERShb9alU3iC0yj8wast(a_5);
							colontmp__18 = (NI)(T225_ - ((NI) 2));
							i_31 = ((NI) 0);
							{
								while (1) {
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T228_;
									if (!(i_31 < colontmp__18)) goto LA227;
									j_3 = i_31;
									T228_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T228_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*a_5)._kind_6.sons->data[j_3]);
									addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T228_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
									i_31 += ((NI) 1);
								} LA227: ;
							}
						}
					} LA209: ;
					i_30 += ((NI) 1);
				} LA208: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75):
	{
		{
			NI i_32;
			NI colontmp__19;
			NI i_33;
			i_32 = (NI)0;
			colontmp__19 = (NI)0;
			colontmp__19 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_33 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_6;
					NI T237_;
					NI T238_;
					if (!(i_33 < colontmp__19)) goto LA232;
					i_32 = i_33;
					a_6 = (*n)._kind_6.sons->data[i_32];
					{
						if (!!(((*a_6).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)))) goto LA235_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_6, (*(*c).graph).config);
					}
					LA235_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_6, ((NI) 3), (*(*c).graph).config);
					T237_ = (NI)0;
					T237_ = len__P89cqdlERShb9alU3iC0yj8wast(a_6);
					T238_ = (NI)0;
					T238_ = len__P89cqdlERShb9alU3iC0yj8wast(a_6);
					asgnRef((void**) (&(*a_6)._kind_6.sons->data[(NI)(T237_ - ((NI) 2))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_6)._kind_6.sons->data[(NI)(T238_ - ((NI) 2))], (flags | 2), ctx));
					{
						NI j_4;
						NI colontmp__20;
						NI T240_;
						NI i_34;
						j_4 = (NI)0;
						colontmp__20 = (NI)0;
						T240_ = (NI)0;
						T240_ = len__P89cqdlERShb9alU3iC0yj8wast(a_6);
						colontmp__20 = (NI)(T240_ - ((NI) 2));
						i_34 = ((NI) 0);
						{
							while (1) {
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T243_;
								if (!(i_34 < colontmp__20)) goto LA242;
								j_4 = i_34;
								T243_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T243_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*a_6)._kind_6.sons->data[j_4]);
								addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T243_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
								i_34 += ((NI) 1);
							} LA242: ;
						}
					}
					i_33 += ((NI) 1);
				} LA232: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			NI i_35;
			NI colontmp__21;
			NI i_36;
			i_35 = (NI)0;
			colontmp__21 = (NI)0;
			colontmp__21 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_36 = ((NI) 0);
			{
				while (1) {
					if (!(i_36 < colontmp__21)) goto LA247;
					i_35 = i_36;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_7;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T257_;
						a_7 = (*n)._kind_6.sons->data[i_35];
						{
							if (!((*a_7).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA251_;
							goto LA248;
						}
						LA251_: ;
						{
							if (!!(((*a_7).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102)))) goto LA255_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_7, (*(*c).graph).config);
						}
						LA255_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_7, ((NI) 3), (*(*c).graph).config);
						T257_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T257_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*a_7)._kind_6.sons->data[((NI) 0)]);
						addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T257_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
						asgnRef((void**) (&(*a_7)._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_7)._kind_6.sons->data[((NI) 1)], (flags | 2), ctx));
						asgnRef((void**) (&(*a_7)._kind_6.sons->data[((NI) 2)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_7)._kind_6.sons->data[((NI) 2)], flags, ctx));
					} LA248: ;
					i_36 += ((NI) 1);
				} LA247: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	{
		{
			NI i_37;
			NI colontmp__22;
			NI i_38;
			i_37 = (NI)0;
			colontmp__22 = (NI)0;
			colontmp__22 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_38 = ((NI) 0);
			{
				while (1) {
					if (!(i_38 < colontmp__22)) goto LA261;
					i_37 = i_38;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_8;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T271_;
						a_8 = (*n)._kind_6.sons->data[i_37];
						{
							if (!((*a_8).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA265_;
							goto LA262;
						}
						LA265_: ;
						{
							if (!!(((*a_8).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA269_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_8, (*(*c).graph).config);
						}
						LA269_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_8, ((NI) 3), (*(*c).graph).config);
						T271_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T271_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*a_8)._kind_6.sons->data[((NI) 0)]);
						addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T271_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
					} LA262: ;
					i_38 += ((NI) 1);
				} LA261: ;
			}
		}
		{
			NI i_39;
			NI colontmp__23;
			NI i_40;
			i_39 = (NI)0;
			colontmp__23 = (NI)0;
			colontmp__23 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_40 = ((NI) 0);
			{
				while (1) {
					if (!(i_40 < colontmp__23)) goto LA274;
					i_39 = i_40;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_9;
						a_9 = (*n)._kind_6.sons->data[i_39];
						{
							if (!((*a_9).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA278_;
							goto LA275;
						}
						LA278_: ;
						{
							if (!!(((*a_9).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA282_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_9, (*(*c).graph).config);
						}
						LA282_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_9, ((NI) 3), (*(*c).graph).config);
						{
							tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T288_;
							if (!!(((*(*a_9)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA286_;
							T288_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
							T288_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
							asgnRef((void**) (&(*a_9)._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_9)._kind_6.sons->data[((NI) 1)], flags, ctx));
							asgnRef((void**) (&(*a_9)._kind_6.sons->data[((NI) 2)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_9)._kind_6.sons->data[((NI) 2)], (flags | 2), ctx));
							closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
						}
						goto LA284_;
						LA286_: ;
						{
							asgnRef((void**) (&(*a_9)._kind_6.sons->data[((NI) 2)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_9)._kind_6.sons->data[((NI) 2)], (flags | 2), ctx));
						}
						LA284_: ;
					} LA275: ;
					i_40 += ((NI) 1);
				} LA274: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 150):
	{
		{
			NI T293_;
			T293_ = (NI)0;
			T293_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T293_)) goto LA294_;
			{
				if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA298_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 0)], (flags | 2), ctx));
			}
			LA298_: ;
			{
				NI i_41;
				NI colontmp__24;
				NI i_42;
				i_41 = (NI)0;
				colontmp__24 = (NI)0;
				colontmp__24 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_42 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_10;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T306_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T307_;
						if (!(i_42 < colontmp__24)) goto LA302;
						i_41 = i_42;
						a_10 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						switch ((*(*n)._kind_6.sons->data[i_41]).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 151):
						{
							a_10 = (*(*n)._kind_6.sons->data[i_41])._kind_6.sons->data[((NI) 0)];
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
						{
							a_10 = (*n)._kind_6.sons->data[i_41];
						}
						break;
						default:
						{
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
						}
						break;
						}
						T306_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T306_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, a_10);
						T307_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T307_ = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T306_, c);
						addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, T307_);
						i_42 += ((NI) 1);
					} LA302: ;
				}
			}
		}
		LA294_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 134):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 135):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA312_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 0)], (flags | 2), ctx));
		}
		LA312_: ;
		{
			NI i_43;
			NI colontmp__25;
			NI i_44;
			i_43 = (NI)0;
			colontmp__25 = (NI)0;
			colontmp__25 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_44 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_11;
					NI T321_;
					NI T322_;
					NI T323_;
					NI T324_;
					if (!(i_44 < colontmp__25)) goto LA316;
					i_43 = i_44;
					a_11 = (*n)._kind_6.sons->data[i_43];
					{
						if (!!(((*a_11).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)))) goto LA319_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_11, (*(*c).graph).config);
					}
					LA319_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_11, ((NI) 3), (*(*c).graph).config);
					T321_ = (NI)0;
					T321_ = len__P89cqdlERShb9alU3iC0yj8wast(a_11);
					T322_ = (NI)0;
					T322_ = len__P89cqdlERShb9alU3iC0yj8wast(a_11);
					asgnRef((void**) (&(*a_11)._kind_6.sons->data[(NI)(T321_ - ((NI) 2))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_11)._kind_6.sons->data[(NI)(T322_ - ((NI) 2))], (flags | 2), ctx));
					T323_ = (NI)0;
					T323_ = len__P89cqdlERShb9alU3iC0yj8wast(a_11);
					T324_ = (NI)0;
					T324_ = len__P89cqdlERShb9alU3iC0yj8wast(a_11);
					asgnRef((void**) (&(*a_11)._kind_6.sons->data[(NI)(T323_ - ((NI) 1))]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*a_11)._kind_6.sons->data[(NI)(T324_ - ((NI) 1))], flags, ctx));
					{
						NI j_5;
						NI colontmp__26;
						NI T326_;
						NI i_45;
						j_5 = (NI)0;
						colontmp__26 = (NI)0;
						T326_ = (NI)0;
						T326_ = len__P89cqdlERShb9alU3iC0yj8wast(a_11);
						colontmp__26 = (NI)(T326_ - ((NI) 2));
						i_45 = ((NI) 0);
						{
							while (1) {
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T329_;
								if (!(i_45 < colontmp__26)) goto LA328;
								j_5 = i_45;
								T329_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T329_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*a_11)._kind_6.sons->data[j_5]);
								addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T329_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
								i_45 += ((NI) 1);
							} LA328: ;
						}
					}
					i_44 += ((NI) 1);
				} LA316: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T336_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 7), (*(*c).graph).config);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T335_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA333_;
			T335_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T335_ = getIdentNode__7YxUILpPxooC5qqa89a54dw_8(c, (*n)._kind_6.sons->data[((NI) 0)]);
			addTempDecl__XjZLpvNqVUTx1J6TXREPBQ(c, T335_, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
		}
		LA333_: ;
		T336_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T336_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 2)], flags, ctx));
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA339_;
			{
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T345_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T346_;
				if (!!(((*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA343_;
				T345_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T345_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96));
				T346_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T346_ = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T345_, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (*n).info, 0);
				addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4(c, T346_);
			}
			LA343_: ;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 3)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 3)], flags, ctx));
		}
		LA339_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 4)], flags, ctx));
		body = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_3;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA349_;
			s_3 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				NIM_BOOL T353_;
				T353_ = (NIM_BOOL)0;
				T353_ = (((*s_3).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
				if (!(T353_)) goto LA354_;
				T353_ = ((*s_3).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				LA354_: ;
				if (!T353_) goto LA355_;
				body = (*n)._kind_6.sons->data[((NI) 6)];
			}
			goto LA351_;
			LA355_: ;
			{
				body = (*(*s_3).ast)._kind_6.sons->data[((NI) 6)];
			}
			LA351_: ;
		}
		goto LA347_;
		LA349_: ;
		{
			body = (*n)._kind_6.sons->data[((NI) 6)];
		}
		LA347_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), semGenericStmtScope__aVtCjYVuHV1t3poDWh43wA_3(c, body, flags, ctx));
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[((NI) 1)], flags, ctx));
	}
	break;
	default:
	{
		{
			NI i_46;
			NI colontmp__27;
			NI i_47;
			i_46 = (NI)0;
			colontmp__27 = (NI)0;
			colontmp__27 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_47 = ((NI) 0);
			{
				while (1) {
					if (!(i_47 < colontmp__27)) goto LA364;
					i_46 = i_47;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_46]), semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, (*n)._kind_6.sons->data[i_46], flags, ctx));
					i_47 += ((NI) 1);
				} LA364: ;
			}
		}
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semGenericStmt__7YxUILpPxooC5qqa89a54dw_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w ctx;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&ctx), sizeof(tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toMixin));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toBind));
	result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, n, 0, (&ctx));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeClass, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* typId, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, NimStringDesc* paramName) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* finalTypId;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T31_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T32_;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(genericParams == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!!((typId == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)))) goto LA7_;
		finalTypId = typId;
	}
	goto LA5_;
	LA7_: ;
	{
		NimStringDesc* T10_;
		T10_ = (NimStringDesc*)0;
		T10_ = rawNewString((paramName ? paramName->Sup.len : 0) + 5);
appendString(T10_, paramName);
appendString(T10_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_127));
		finalTypId = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T10_);
	}
	LA5_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(genericParams);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA13;
				i = i_2;
				{
					if (!((*(*(*(*genericParams)._kind_6.sons->data[i])._kind_4.sym).name).Sup.id == (*finalTypId).Sup.id)) goto LA16_;
					result = (*(*genericParams)._kind_6.sons->data[i]).typ;
					goto BeforeRet_;
				}
				LA16_: ;
				i_2 += ((NI) 1);
			} LA13: ;
		}
	}
	{
		if (!!(((*typeClass).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA20_;
		owner = (*typeClass).sym;
	}
	goto LA18_;
	LA20_: ;
	{
		owner = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	}
	LA18_: ;
	s = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), finalTypId, owner, info, 0);
	{
		if (!(((*owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 23))&63U)))!=0)) goto LA25_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 23)) & 63);
	}
	LA25_: ;
	{
		if (!(typId == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL))) goto LA29_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33)) & 63);
	}
	LA29_: ;
	T31_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T31_ = linkTo__Lxy1G9c1I40y65cWkoPnssA(s, typeClass);
	(*typeClass).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 26)) & 63);
	(*s).position = len__P89cqdlERShb9alU3iC0yj8wast(genericParams);
	T32_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T32_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s);
	add__P8dDSotTW25BkfbyspojGg(genericParams, T32_);
	result = typeClass;
	addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, s);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, instGenericContainer__sJO8n9aXqgecj24tOSPjmow)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* header, NIM_BOOL allowMetaTypes) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg cl;
	tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ* T5_;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T6_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genericTyp;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NimStringDesc* argX60gensym161_;
		if (!!(((*header).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9)))) goto LA3_;
		argX60gensym161_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_134);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym161_, TM__rF9caJawfOjYTjsgLVUSGFA_134);
	}
	LA3_: ;
	nimZeroMem((void*)(&cl), sizeof(tyObject_TReplTypeVars__gMP9b9b8d4Uze3mE5G9aP9afmg));
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&cl.symMap));
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&cl.localCache));
	T5_ = (tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ*)0;
	T5_ = (tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ*) newObj((&NTI__zSq8dodcWpSdfE0WaiBU9cw_), sizeof(tyObject_LayeredIdTablecolonObjectType___VAXPousy5FCnCEYMcHN9bDQ));
	cl.typeMap = T5_;
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&(*cl.typeMap).topLayer));
	cl.info = info;
	cl.c = c;
	cl.allowMetaTypes = allowMetaTypes;
	T6_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T6_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	genericTyp = base__PfgI9ap7WOnsRfFV4znQ27w(header);
	{
		NI i;
		NI colontmp_;
		NI T8_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T8_ = (NI)0;
		T8_ = len__5mJADrRYkP3r9auuiuDZN9cQast(genericTyp);
		colontmp_ = (NI)(T8_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genParam;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
				if (!(i_2 < colontmp_)) goto LA10;
				i = i_2;
				genParam = (*genericTyp).sons->data[i];
				param = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				{
					if (!((*genParam).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA13_;
					param = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10), (*(*genParam).sym).name, (*genericTyp).sym, (*(*genParam).sym).info, 0);
					asgnRef((void**) (&(*param).ast), (*(*header).sons->data[(NI)(i + ((NI) 1))]).n);
					asgnRef((void**) (&(*param).typ), (*header).sons->data[(NI)(i + ((NI) 1))]);
				}
				goto LA11_;
				LA13_: ;
				{
					param = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), (*(*genParam).sym).name, (*genericTyp).sym, (*(*genParam).sym).info, 0);
					asgnRef((void**) (&(*param).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, (*header).sons->data[(NI)(i + ((NI) 1))]));
				}
				LA11_: ;
				(*param).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, param);
				i_2 += ((NI) 1);
			} LA10: ;
		}
	}
	result = replaceTypeVarsT__cNsAY9aO2v1oTCPqZyHga1w((&cl), header);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, liftParamType__IED6yzEuxOVbtiDk639cvjw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw procKind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* paramType, NimStringDesc* paramName, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL anon) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* paramTypId;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(paramType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !(anon);
		if (!(T7_)) goto LA8_;
		T7_ = !(((*paramType).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA8_: ;
		if (!T7_) goto LA9_;
		paramTypId = (*(*paramType).sym).name;
	}
	goto LA5_;
	LA9_: ;
	{
		paramTypId = ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL);
	}
	LA5_: ;
	switch ((*paramType).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12), c);
		result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, T13_, ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL), info, genericParams, paramName);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T26_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T39_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T40_;
		{
			NIM_BOOL T17_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
			T17_ = (NIM_BOOL)0;
			T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T18_ = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
			T17_ = !(((*T18_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
			if (!(T17_)) goto LA19_;
			T17_ = !(((*paramType).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA19_: ;
			if (!T17_) goto LA20_;
			goto BeforeRet_;
		}
		LA20_: ;
		{
			if (!(((*paramType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0)) goto LA24_;
			goto BeforeRet_;
		}
		LA24_: ;
		T26_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T26_ = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
		lifted = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, T26_, paramName, info, NIM_FALSE);
		{
			if (!!((lifted == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA29_;
			base = lifted;
		}
		goto LA27_;
		LA29_: ;
		{
			base = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
		}
		LA27_: ;
		{
			NIM_BOOL T34_;
			NimStringDesc* T38_;
			T34_ = (NIM_BOOL)0;
			T34_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(base);
			if (!(T34_)) goto LA35_;
			T34_ = (procKind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
			LA35_: ;
			if (!T34_) goto LA36_;
			T38_ = (NimStringDesc*)0;
			T38_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_128), paramName);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T38_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_129, NIM_FALSE);
		}
		LA36_: ;
		T39_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T39_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
		asgnRef((void**) (&T39_->data[0]), base);
		T40_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T40_ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T39_);
		result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, T40_, paramTypId, info, genericParams, paramName);
		{
			if (!!((result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA43_;
			(*result).flags = ((*result).flags | 16777728);
		}
		LA43_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			tySequence__Ef05srmQTDulnBdXR4Ja6Q* T63_;
			if (!!((((*paramType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0))) goto LA48_;
			{
				NIM_BOOL T52_;
				NIM_BOOL T53_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T54_;
				NIM_BOOL T57_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T58_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T60_;
				T52_ = (NIM_BOOL)0;
				T53_ = (NIM_BOOL)0;
				T54_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T54_ = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
				T53_ = ((*T54_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0));
				if (!(T53_)) goto LA55_;
				T53_ = !((paramTypId == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
				LA55_: ;
				T52_ = T53_;
				if (!(T52_)) goto LA56_;
				T57_ = (NIM_BOOL)0;
				T58_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T58_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_130));
				T57_ = ((*paramTypId).Sup.id == (*T58_).Sup.id);
				if (T57_) goto LA59_;
				T60_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T60_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_131));
				T57_ = ((*paramTypId).Sup.id == (*T60_).Sup.id);
				LA59_: ;
				T52_ = T57_;
				LA56_: ;
				if (!T52_) goto LA61_;
				paramTypId = ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL);
			}
			LA61_: ;
			T63_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
			T63_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
			asgnRef((void**) (&T63_->data[0]), base__PfgI9ap7WOnsRfFV4znQ27w(paramType));
			t = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), T63_);
			(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
			result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, t, paramTypId, info, genericParams, paramName);
		}
		LA48_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	{
		{
			NI T67_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T70_;
			T67_ = (NI)0;
			T67_ = len__5mJADrRYkP3r9auuiuDZN9cQast(paramType);
			if (!(T67_ == ((NI) 1))) goto LA68_;
			T70_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T70_ = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
			result = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, T70_, paramName, info, NIM_TRUE);
		}
		LA68_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T72_;
		T72_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T72_ = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
		result = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, T72_, paramName, info, NIM_FALSE);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			NIM_BOOL T76_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T78_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
			tySequence__Ef05srmQTDulnBdXR4Ja6Q* T81_;
			T76_ = (NIM_BOOL)0;
			T76_ = ((*paramType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
			if (!(T76_)) goto LA77_;
			T78_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T78_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(paramType);
			T76_ = ((*T78_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0));
			LA77_: ;
			if (!T76_) goto LA79_;
			T81_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
			T81_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
			asgnRef((void**) (&T81_->data[0]), newTypeS__xb5E2cGIynZweqWlCP8Tig((*paramType).kind, c));
			typ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51), T81_);
			result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, typ, paramTypId, info, genericParams, paramName);
		}
		goto LA74_;
		LA79_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(paramType);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted_2;
						if (!(i_2 < colontmp_)) goto LA85;
						i = i_2;
						{
							NimStringDesc* T90_;
							NimStringDesc* T91_;
							if (!((*paramType).sons->data[i] == paramType)) goto LA88_;
							T90_ = (NimStringDesc*)0;
							T90_ = typeToString__QlvraUan7WbHowhAbvDvdA(paramType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
							T91_ = (NimStringDesc*)0;
							T91_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_132), T90_);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T91_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_133, NIM_FALSE);
						}
						LA88_: ;
						lifted_2 = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, (*paramType).sons->data[i], paramName, info, NIM_FALSE);
						{
							if (!!((lifted_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA94_;
							asgnRef((void**) (&(*paramType).sons->data[i]), lifted_2);
							result = paramType;
						}
						LA94_: ;
						i_2 += ((NI) 1);
					} LA85: ;
				}
			}
		}
		LA74_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T113_;
		result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, paramType, NIM_TRUE);
		{
			NI i_3;
			NI colontmp__2;
			NI T98_;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T98_ = (NI)0;
			T98_ = len__5mJADrRYkP3r9auuiuDZN9cQast(paramType);
			colontmp__2 = (NI)(T98_ - ((NI) 1));
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA100;
					i_3 = i_4;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* staticCopy;
						if (!((*(*paramType).sons->data[i_3]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA103_;
						staticCopy = exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ((*paramType).sons->data[i_3]);
						(*staticCopy).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 27)) & 63);
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, staticCopy, NIM_TRUE);
					}
					goto LA101_;
					LA103_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T106_;
						T106_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T106_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59), c);
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T106_, NIM_TRUE);
					}
					LA101_: ;
					i_4 += ((NI) 1);
				} LA100: ;
			}
		}
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T109_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T112_;
			T109_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T109_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(paramType);
			if (!((*T109_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52))) goto LA110_;
			(*result).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53);
			T112_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T112_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(paramType);
			rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T112_, NIM_TRUE);
			result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, result, paramTypId, info, genericParams, paramName);
			goto BeforeRet_;
		}
		LA110_: ;
		x = instGenericContainer__sJO8n9aXqgecj24tOSPjmow(c, (*(*paramType).sym).info, result, NIM_TRUE);
		T113_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T113_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 2);
		asgnRef((void**) (&T113_->data[0]), paramType);
		asgnRef((void**) (&T113_->data[1]), x);
		result = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54), T113_);
		result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, result, paramTypId, info, genericParams, paramName);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* liftBody;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T134_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T117_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* cp;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T120_;
			T117_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T117_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(paramType);
			if (!((*T117_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52))) goto LA118_;
			T120_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T120_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
			cp = copyType__4O4aYoscFPo2FRSh4rP9ayg(paramType, T120_, NIM_FALSE);
			(*cp).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53);
			result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, cp, paramTypId, info, genericParams, paramName);
			goto BeforeRet_;
		}
		LA118_: ;
		{
			NI i_5;
			NI colontmp__3;
			NI T122_;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			T122_ = (NI)0;
			T122_ = len__5mJADrRYkP3r9auuiuDZN9cQast(paramType);
			colontmp__3 = (NI)(T122_ - ((NI) 1));
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted_3;
					if (!(i_6 < colontmp__3)) goto LA124;
					i_5 = i_6;
					lifted_3 = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, (*paramType).sons->data[i_5], paramName, info, NIM_FALSE);
					{
						if (!!((lifted_3 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA127_;
						asgnRef((void**) (&(*paramType).sons->data[i_5]), lifted_3);
						result = paramType;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T131_;
							NimStringDesc* argX60gensym1121_;
							T131_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T131_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
							if (!!((((*T131_).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21))&63U)))!=0))) goto LA132_;
							argX60gensym1121_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_135);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1121_, TM__rF9caJawfOjYTjsgLVUSGFA_135);
						}
						LA132_: ;
					}
					LA127_: ;
					i_6 += ((NI) 1);
				} LA124: ;
			}
		}
		T134_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T134_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(paramType);
		liftBody = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, T134_, paramName, info, NIM_TRUE);
		{
			if (!!((liftBody == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA137_;
			result = liftBody;
			(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63);
		}
		LA137_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* body;
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__5mJADrRYkP3r9auuiuDZN9cQast(paramType);
			i_8 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted_4;
					if (!(i_8 < colontmp__4)) goto LA142;
					i_7 = i_8;
					lifted_4 = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, (*paramType).sons->data[i_7], paramName, info, NIM_FALSE);
					{
						if (!!((lifted_4 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA145_;
						asgnRef((void**) (&(*paramType).sons->data[i_7]), lifted_4);
					}
					LA145_: ;
					i_8 += ((NI) 1);
				} LA142: ;
			}
		}
		body = base__PfgI9ap7WOnsRfFV4znQ27w(paramType);
		{
			if (!((IL64(1125900980584448) &((NU64)1<<((NU)((*body).kind)&63U)))!=0)) goto LA149_;
			goto BeforeRet_;
		}
		LA149_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T153_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* expanded;
			T153_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T153_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(body);
			if (!((*T153_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52))) goto LA154_;
			expanded = instGenericContainer__sJO8n9aXqgecj24tOSPjmow(c, info, paramType, NIM_TRUE);
			result = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, procKind, genericParams, expanded, paramName, info, NIM_TRUE);
		}
		LA154_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T157_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T158_;
		T157_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T157_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		T158_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T158_ = copyType__4O4aYoscFPo2FRSh4rP9ayg(paramType, T157_, NIM_FALSE);
		result = addImplicitGeneric__PNQVBgqq1K3pEL9atJ4kfOw(c, T158_, paramTypId, info, genericParams, paramName);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*(*paramType).sym).info, (*paramType).sym);
		{
			if (!(((*paramType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0)) goto LA162_;
			(*paramType).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30)) & 63));
			transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw((*paramType).sym);
		}
		LA162_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semProcTypeNode__ZVaxL1YkeVlGuk9csaO0Z2w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, NIM_BOOL isType) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	NI counter;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
	result = newProcType__5gg5mq4XYRQKbAkdLMpzGA(c, (*n).info, prev);
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	counter = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
					NIM_BOOL hasType;
					NI T15_;
					NIM_BOOL hasDefault;
					NI T16_;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)))) goto LA7_;
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
							if (!(T11_)) goto LA12_;
							T11_ = (((*(*a)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0);
							LA12_: ;
							if (!T11_) goto LA13_;
							goto LA4;
						}
						LA13_: ;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA7_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*c).graph).config);
					typ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
					def = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					constraint = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					T15_ = (NI)0;
					T15_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					hasType = !(((*(*a)._kind_6.sons->data[(NI)(T15_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
					T16_ = (NI)0;
					T16_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					hasDefault = !(((*(*a)._kind_6.sons->data[(NI)(T16_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
					{
						NI T21_;
						if (!hasType) goto LA19_;
						T21_ = (NI)0;
						T21_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						typ = semParamType__JfIbex3lv6r6Ex7T9a9cADuw(c, (*a)._kind_6.sons->data[(NI)(T21_ - ((NI) 2))], &constraint);
						{
							NIM_BOOL T24_;
							NIM_BOOL T26_;
							T24_ = (NIM_BOOL)0;
							T24_ = (kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
							if (!(T24_)) goto LA25_;
							T26_ = (NIM_BOOL)0;
							T26_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7));
							if (T26_) goto LA27_;
							T26_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
							LA27_: ;
							T24_ = T26_;
							LA25_: ;
							if (!T24_) goto LA28_;
							{
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T32_;
								NIM_BOOL T33_;
								NI T36_;
								NimStringDesc* T37_;
								T32_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
								T32_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
								T33_ = (NIM_BOOL)0;
								T33_ = isMagic__aafCJ57RxmXkzBZMJ1lSSQ(T32_);
								if (!!(T33_)) goto LA34_;
								T36_ = (NI)0;
								T36_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
								T37_ = (NimStringDesc*)0;
								T37_ = rawNewString(((*(*(*typ).sym).name).s ? (*(*(*typ).sym).name).s->Sup.len : 0) + 57);
appendString(T37_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
appendString(T37_, (*(*(*typ).sym).name).s);
appendString(T37_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_116));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[(NI)(T36_ - ((NI) 2))]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T37_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_117, NIM_FALSE);
							}
							LA34_: ;
						}
						LA28_: ;
					}
					LA19_: ;
					{
						NI T42_;
						if (!hasDefault) goto LA40_;
						T42_ = (NI)0;
						T42_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						def = (*a)._kind_6.sons->data[(NI)(T42_ - ((NI) 1))];
						{
							{
								NIM_BOOL T46_;
								NI T48_;
								T46_ = (NIM_BOOL)0;
								T46_ = !((genericParams == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
								if (!(T46_)) goto LA47_;
								T48_ = (NI)0;
								T48_ = len__P89cqdlERShb9alU3iC0yj8wast(genericParams);
								T46_ = (((NI) 0) < T48_);
								LA47_: ;
								if (!T46_) goto LA49_;
								def = semGenericStmt__7YxUILpPxooC5qqa89a54dw_7(c, def);
								{
									NIM_BOOL T53_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T56_;
									T53_ = (NIM_BOOL)0;
									T53_ = hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ(c, def);
									if (!T53_) goto LA54_;
									T56_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T56_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(def);
									asgnRef((void**) (&(*def).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T56_));
									goto LA43;
								}
								LA54_: ;
							}
							LA49_: ;
							def = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, def, 256);
							{
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T59_;
								NIM_BOOL T60_;
								T59_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
								T59_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
								T60_ = (NIM_BOOL)0;
								T60_ = referencesAnotherParam__cvWGVSvD9adrttq7iqjO7wA(def, T59_);
								if (!T60_) goto LA61_;
								(*def).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19)) & 31);
							}
							LA61_: ;
						} LA43: ;
						{
							if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA65_;
							typ = (*def).typ;
							{
								NIM_BOOL T69_;
								NimStringDesc* T72_;
								NimStringDesc* T73_;
								T69_ = (NIM_BOOL)0;
								T69_ = isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4(typ);
								if (!T69_) goto LA70_;
								T72_ = (NimStringDesc*)0;
								T73_ = (NimStringDesc*)0;
								T73_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*a)._kind_6.sons->data[((NI) 0)]);
								T72_ = rawNewString((T73_ ? T73_->Sup.len : 0) + 37);
appendString(T72_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_120));
appendString(T72_, T73_);
appendString(T72_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T72_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_121, NIM_FALSE);
							}
							LA70_: ;
							{
								tySequence__Ef05srmQTDulnBdXR4Ja6Q* T78_;
								if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA76_;
								T78_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
								T78_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
								asgnRef((void**) (&T78_->data[0]), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c));
								typ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), T78_);
								(*typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
							}
							LA76_: ;
						}
						goto LA63_;
						LA65_: ;
						{
							{
								NIM_BOOL T82_;
								T82_ = (NIM_BOOL)0;
								T82_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(typ);
								if (!!(T82_)) goto LA83_;
								def = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, def, (*def).info);
							}
							goto LA80_;
							LA83_: ;
							{
								if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA86_;
								def = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, def);
								def = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, def, (*def).info);
							}
							goto LA80_;
							LA86_: ;
							LA80_: ;
						}
						LA63_: ;
					}
					LA40_: ;
					{
						NIM_BOOL T90_;
						T90_ = (NIM_BOOL)0;
						T90_ = !(hasType);
						if (!(T90_)) goto LA91_;
						T90_ = !(hasDefault);
						LA91_: ;
						if (!T90_) goto LA92_;
						{
							if (!isType) goto LA96_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_122), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_123, NIM_FALSE);
						}
						LA96_: ;
						{
							if (!((393216 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA100_;
							typ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6), c);
						}
						LA100_: ;
					}
					goto LA88_;
					LA92_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T103_;
						T103_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T103_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(70368744179728));
						if (!((*T103_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA104_;
						goto LA4;
					}
					goto LA88_;
					LA104_: ;
					LA88_: ;
					{
						NI j;
						NI colontmp__2;
						NI T107_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T107_ = (NI)0;
						T107_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__2 = (NI)(T107_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* arg;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T110_;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* finalType;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T150_;
								if (!(i_3 < colontmp__2)) goto LA109;
								j = i_3;
								T110_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								{
									if (!((*(*a)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA113_;
									T110_ = (*(*a)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)];
								}
								goto LA111_;
								LA113_: ;
								{
									T110_ = (*a)._kind_6.sons->data[j];
								}
								LA111_: ;
								arg = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), T110_, c);
								{
									if (!((*(*a)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA118_;
									pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, arg, (*(*a)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_124, NIM_FALSE);
								}
								LA118_: ;
								{
									NIM_BOOL T122_;
									NIM_BOOL T123_;
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
									T122_ = (NIM_BOOL)0;
									T123_ = (NIM_BOOL)0;
									T123_ = !(hasType);
									if (!(T123_)) goto LA124_;
									T123_ = !(hasDefault);
									LA124_: ;
									T122_ = T123_;
									if (!(T122_)) goto LA125_;
									T122_ = !(((393216 &((NU32)1<<((NU)(kind)&31U)))!=0));
									LA125_: ;
									if (!T122_) goto LA126_;
									param = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).signatures, (*arg).name);
									{
										if (!!((param == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA130_;
										typ = (*param).typ;
									}
									goto LA128_;
									LA130_: ;
									{
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_125), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_126, NIM_FALSE);
										typ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
									}
									LA128_: ;
								}
								LA126_: ;
								lifted = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, kind, genericParams, typ, (*(*arg).name).s, (*arg).info, NIM_FALSE);
								{
									if (!!((lifted == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA135_;
									finalType = lifted;
								}
								goto LA133_;
								LA135_: ;
								{
									finalType = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(typ);
								}
								LA133_: ;
								asgnRef((void**) (&(*arg).typ), finalType);
								(*arg).position = counter;
								asgnRef((void**) (&(*arg).constraint), constraint);
								counter += ((NI) 1);
								{
									NIM_BOOL T140_;
									T140_ = (NIM_BOOL)0;
									T140_ = !((def == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
									if (!(T140_)) goto LA141_;
									T140_ = !(((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
									LA141_: ;
									if (!T140_) goto LA142_;
									asgnRef((void**) (&(*arg).ast), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(def));
								}
								LA142_: ;
								{
									NIM_BOOL T146_;
									NimStringDesc* T149_;
									T146_ = (NIM_BOOL)0;
									T146_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&check), (*(*arg).name).Sup.id);
									if (!T146_) goto LA147_;
									T149_ = (NimStringDesc*)0;
									T149_ = rawNewString(((*(*arg).name).s ? (*(*arg).name).s->Sup.len : 0) + 23);
appendString(T149_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_136));
appendString(T149_, (*(*arg).name).s);
appendString(T149_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
									liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T149_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_137, NIM_FALSE);
								}
								LA147_: ;
								T150_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T150_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(arg);
								add__P8dDSotTW25BkfbyspojGg((*result).n, T150_);
								rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, finalType, NIM_TRUE);
								addParamOrResult__pceuJlMM5di29a5a9cxxzXSQ(c, arg, kind);
								{
									if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA153_;
									nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, arg, (*arg).kind);
								}
								LA153_: ;
								{
									if (!((IL64(422212465065984) & (*(*(*c).graph).config).globalOptions) == 0)) goto LA157_;
									asgnRef((void**) (&(*a)._kind_6.sons->data[j]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(arg));
								}
								LA157_: ;
								i_3 += ((NI) 1);
							} LA109: ;
						}
					}
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	r = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA161_;
		r = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	}
	LA161_: ;
	{
		NIM_BOOL T165_;
		NIM_BOOL T166_;
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
		T165_ = (NIM_BOOL)0;
		T166_ = (NIM_BOOL)0;
		T166_ = !((r == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T166_)) goto LA167_;
		T166_ = ((393216 &((NU32)1<<((NU)(kind)&31U)))!=0);
		LA167_: ;
		T165_ = T166_;
		if (!(T165_)) goto LA168_;
		T165_ = ((*r).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7));
		LA168_: ;
		if (!T165_) goto LA169_;
		info = (*(*n)._kind_6.sons->data[((NI) 0)]).info;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_138), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_139, NIM_FALSE);
		r = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	}
	LA169_: ;
	{
		if (!!((r == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA173_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T177_;
			tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw oldFlags;
			T177_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T177_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(r, IL64(70368744179728));
			if (!!(((*T177_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63)))) goto LA178_;
			{
				NIM_BOOL T182_;
				NimStringDesc* T186_;
				NimStringDesc* T187_;
				T182_ = (NIM_BOOL)0;
				T182_ = !(((393216 &((NU32)1<<((NU)(kind)&31U)))!=0));
				if (!(T182_)) goto LA183_;
				T182_ = ((192 &((NU64)1<<((NU)((*r).kind)&63U)))!=0);
				LA183_: ;
				if (!T182_) goto LA184_;
				T186_ = (NimStringDesc*)0;
				T187_ = (NimStringDesc*)0;
				T187_ = typeToString__QlvraUan7WbHowhAbvDvdA(r, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T186_ = rawNewString((T187_ ? T187_->Sup.len : 0) + 53);
appendString(T186_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_140));
appendString(T186_, T187_);
appendString(T186_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_141));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T186_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_142, NIM_FALSE);
			}
			goto LA180_;
			LA184_: ;
			{
				if (!((*r).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59))) goto LA189_;
				r = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6), c);
			}
			goto LA180_;
			LA189_: ;
			{
				if (!((*r).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA192_;
			}
			goto LA180_;
			LA192_: ;
			{
				{
					NIM_BOOL T197_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted_2;
					T197_ = (NIM_BOOL)0;
					T197_ = ((*r).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T197_) goto LA198_;
					T197_ = !((((*(*r).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0));
					LA198_: ;
					if (!T197_) goto LA199_;
					lifted_2 = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, kind, genericParams, r, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96), (*(*n)._kind_6.sons->data[((NI) 0)]).info, NIM_FALSE);
					{
						if (!!((lifted_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA203_;
						r = lifted_2;
						(*r).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 11)) & 63);
					}
					LA203_: ;
				}
				LA199_: ;
				r = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(r);
				{
					if (!(kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA207_;
					(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15)) & 63);
				}
				LA207_: ;
			}
			LA180_: ;
			asgnRef((void**) (&(*result).sons->data[((NI) 0)]), r);
			oldFlags = (*result).flags;
			propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(result, r, NIM_TRUE);
			{
				if (!!((oldFlags == (*result).flags))) goto LA211_;
				{
					if (!!(((oldFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21))&63U)))!=0))) goto LA215_;
					(*result).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63));
				}
				LA215_: ;
			}
			LA211_: ;
			asgnRef((void**) (&(*(*result).n).typ), r);
		}
		LA178_: ;
	}
	LA173_: ;
	{
		NIM_BOOL T219_;
		NI T221_;
		T219_ = (NIM_BOOL)0;
		T219_ = !((genericParams == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T219_)) goto LA220_;
		T221_ = (NI)0;
		T221_ = len__P89cqdlERShb9alU3iC0yj8wast(genericParams);
		T219_ = (((NI) 0) < T221_);
		LA220_: ;
		if (!T219_) goto LA222_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
			n_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_4;
				NI colontmp__3;
				NI i_5;
				i_4 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(genericParams);
				i_5 = ((NI) 0);
				{
					while (1) {
						if (!(i_5 < colontmp__3)) goto LA227;
						i_4 = i_5;
						n_2 = (*genericParams)._kind_6.sons->data[i_4];
						{
							if (!((IL64(8589934593) & (*(*n_2)._kind_4.sym).flags) == 0)) goto LA230_;
							(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
						}
						LA230_: ;
						{
							if (!(((*(*(*n_2)._kind_4.sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0)) goto LA234_;
							transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw((*n_2)._kind_4.sym);
							(*(*(*n_2)._kind_4.sym).typ).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30)) & 63));
						}
						LA234_: ;
						i_5 += ((NI) 1);
					} LA227: ;
				}
			}
		}
	}
	LA222_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semParamList__HJ2sXcKFjirzvqsZjMcpTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	asgnRef((void**) (&(*s).typ), semProcTypeNode__ZVaxL1YkeVlGuk9csaO0Z2w(c, n, genericParams, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), (*s).kind, NIM_FALSE));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newParam__bk0oScE0sXzp15PuTrbg3w_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	x = (*(*(*(*(*c).owner).typ).n)._kind_6.sons->data[(NI)((*s).position + ((NI) 1))])._kind_4.sym;
	result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(x, (*n).info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleSym__bk0oScE0sXzp15PuTrbg3w)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*s).owner == (*c).owner);
			if (!(T7_)) goto LA8_;
			T7_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			LA8_: ;
			if (!T7_) goto LA9_;
			result = newParam__bk0oScE0sXzp15PuTrbg3w_2(c, n, s);
		}
		goto LA5_;
		LA9_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s).Sup.id);
			if (!T12_) goto LA13_;
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
		}
		goto LA5_;
		LA13_: ;
		{
			NIM_BOOL T16_;
			NIM_BOOL T18_;
			NI T19_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T23_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
			if (!(T16_)) goto LA17_;
			T18_ = (NIM_BOOL)0;
			T19_ = (NI)0;
			T19_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
			T18_ = (T19_ == ((NI) 1));
			if (T18_) goto LA20_;
			T18_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0);
			LA20_: ;
			T16_ = T18_;
			LA17_: ;
			if (!T16_) goto LA21_;
			T23_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T23_ = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog((*c).c, n, s, 8192);
			result = semPatternBody__DuioLh4uofptxEKissr2sw(c, T23_);
		}
		goto LA5_;
		LA21_: ;
		{
		}
		LA5_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, expectParam__DuioLh4uofptxEKissr2sw_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*s).owner == (*c).owner);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		LA6_: ;
		if (!T3_) goto LA7_;
		result = newParam__bk0oScE0sXzp15PuTrbg3w_2(c, n, s);
	}
	goto LA1_;
	LA7_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*c).c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_143), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_146, NIM_FALSE);
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPatternBody__DuioLh4uofptxEKissr2sw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		result = handleSym__bk0oScE0sXzp15PuTrbg3w(c, n, s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 122):
	{
		result = semBindStmt__9askHuPxNsdv5Fi00VcmrXQ((*c).c, n, (&(*c).toBind));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
	{
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!((T7_ == ((NI) 2)))) goto LA8_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*c).c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_143), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_144, NIM_FALSE);
		}
		goto LA5_;
		LA8_: ;
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA11_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 0)]));
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), expectParam__DuioLh4uofptxEKissr2sw_2(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA5_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* opr;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30));
			if (!(T14_)) goto LA15_;
			T14_ = ((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
			LA15_: ;
			if (!T14_) goto LA16_;
			opr = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
			{
				if (!eqStrings((*(*opr)._kind_5.ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_42))) goto LA20_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 0)]));
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 1)]), expectParam__DuioLh4uofptxEKissr2sw_2(c, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 1)]));
			}
			goto LA18_;
			LA20_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*c).c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_143), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_147, NIM_FALSE);
			}
			LA18_: ;
		}
		goto LA5_;
		LA16_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*c).c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_143), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_148, NIM_FALSE);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			NIM_BOOL T27_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T30_;
			T27_ = (NIM_BOOL)0;
			T27_ = stupidStmtListExpr__9cP6JNeOKqczaXCI4Zo4SBQ_4(n);
			if (!T27_) goto LA28_;
			T30_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T30_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			result = semPatternBody__DuioLh4uofptxEKissr2sw(c, T30_);
		}
		goto LA25_;
		LA28_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA34;
						i = i_2;
						asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[i]));
						i_2 += ((NI) 1);
					} LA34: ;
				}
			}
		}
		LA25_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		s_2 = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, (*n)._kind_6.sons->data[((NI) 0)], 0);
		{
			if (!!((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA38_;
			{
				NIM_BOOL T42_;
				T42_ = (NIM_BOOL)0;
				T42_ = ((*s_2).owner == (*c).owner);
				if (!(T42_)) goto LA43_;
				T42_ = ((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA43_: ;
				if (!T42_) goto LA44_;
			}
			goto LA40_;
			LA44_: ;
			{
				NIM_BOOL T47_;
				T47_ = (NIM_BOOL)0;
				T47_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s_2).Sup.id);
				if (!T47_) goto LA48_;
			}
			goto LA40_;
			LA48_: ;
			{
				NIM_BOOL T51_;
				NIM_BOOL T53_;
				NI T54_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T58_;
				T51_ = (NIM_BOOL)0;
				T51_ = ((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
				if (!(T51_)) goto LA52_;
				T53_ = (NIM_BOOL)0;
				T54_ = (NI)0;
				T54_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s_2).typ);
				T53_ = (T54_ == ((NI) 1));
				if (T53_) goto LA55_;
				T53_ = (((*s_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9))&63U)))!=0);
				LA55_: ;
				T51_ = T53_;
				LA52_: ;
				if (!T51_) goto LA56_;
				T58_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T58_ = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog((*c).c, n, s_2, 8192);
				result = semPatternBody__DuioLh4uofptxEKissr2sw(c, T58_);
				goto BeforeRet_;
			}
			goto LA40_;
			LA56_: ;
			LA40_: ;
		}
		LA38_: ;
		{
			NIM_BOOL T61_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id;
			T61_ = (NIM_BOOL)0;
			T61_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
			if (!(T61_)) goto LA62_;
			id = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			T61_ = !((id == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
			LA62_: ;
			if (!T61_) goto LA63_;
			{
				NIM_BOOL T67_;
				NI T71_;
				T67_ = (NIM_BOOL)0;
				T67_ = eqStrings((*id).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_149));
				if (T67_) goto LA68_;
				T67_ = eqStrings((*id).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_150));
				LA68_: ;
				if (!T67_) goto LA69_;
				T71_ = (NI)0;
				T71_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 153), (*n).info, T71_);
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(id, (*n).info));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 1)]));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), expectParam__DuioLh4uofptxEKissr2sw_2(c, (*n)._kind_6.sons->data[((NI) 2)]));
				goto BeforeRet_;
			}
			goto LA65_;
			LA69_: ;
			{
				NI T75_;
				if (!eqStrings((*id).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_42))) goto LA73_;
				T75_ = (NI)0;
				T75_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 153), (*n).info, T75_);
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(id, (*n).info));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 1)]));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 2)]));
				goto BeforeRet_;
			}
			goto LA65_;
			LA73_: ;
			LA65_: ;
		}
		LA63_: ;
		{
			NIM_BOOL T78_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id_2;
			T78_ = (NIM_BOOL)0;
			T78_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30));
			if (!(T78_)) goto LA79_;
			id_2 = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			T78_ = !((id_2 == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
			LA79_: ;
			if (!T78_) goto LA80_;
			{
				NI T86_;
				if (!eqStrings((*id_2).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_151))) goto LA84_;
				T86_ = (NI)0;
				T86_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 153), (*n).info, T86_);
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(id_2, (*n).info));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 1)]));
				goto BeforeRet_;
			}
			LA84_: ;
		}
		LA80_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA89;
					i_3 = i_4;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_3]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[i_3]));
					i_4 += ((NI) 1);
				} LA89: ;
			}
		}
	}
	break;
	default:
	{
		switch ((*n).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_3;
			s_3 = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
			{
				if (!!((s_3 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA94_;
				{
					NIM_BOOL T98_;
					T98_ = (NIM_BOOL)0;
					T98_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s_3).Sup.id);
					if (!T98_) goto LA99_;
					result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s_3, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
					goto BeforeRet_;
				}
				goto LA96_;
				LA99_: ;
				{
					result = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ((*s_3).name, (*n).info);
					goto BeforeRet_;
				}
				LA96_: ;
			}
			LA94_: ;
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
		{
			{
				NI T105_;
				T105_ = (NI)0;
				T105_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				if (!(T105_ == ((NI) 1))) goto LA106_;
				result = semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[((NI) 0)]);
				goto BeforeRet_;
			}
			LA106_: ;
		}
		break;
		default:
		{
		}
		break;
		}
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 0);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA111;
					i_5 = i_6;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_5]), semPatternBody__DuioLh4uofptxEKissr2sw(c, (*n)._kind_6.sons->data[i_5]));
					i_6 += ((NI) 1);
				} LA111: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPattern__7YxUILpPxooC5qqa89a54dw_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw ctx;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	nimZeroMem((void*)(&ctx), sizeof(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toBind));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toMixin));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toInject));
	ctx.c = c;
	ctx.owner = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = semPatternBody__DuioLh4uofptxEKissr2sw((&ctx), n);
	result = flattenStmts__qsyX8NJX39ctdwAi4rC8W1g(T2_);
	{
		if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA5_;
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!(T9_ == ((NI) 1))) goto LA10_;
			result = (*result)._kind_6.sons->data[((NI) 0)];
		}
		goto LA7_;
		LA10_: ;
		{
			NI T13_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!(T13_ == ((NI) 0))) goto LA14_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_152), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_153, NIM_FALSE);
		}
		goto LA7_;
		LA14_: ;
		LA7_: ;
	}
	LA5_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addGenericParamListToScope__NRIJDWZtATzMum7OEjYC2g_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75)))) goto LA3_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	LA3_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				{
					if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA10_;
					addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, (*a)._kind_4.sym);
				}
				goto LA8_;
				LA10_: ;
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addParams__XjZLpvNqVUTx1J6TXREPBQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA6_;
					addParamOrResult__pceuJlMM5di29a5a9cxxzXSQ(c, (*(*n)._kind_6.sons->data[i])._kind_4.sym, kind);
				}
				goto LA4_;
				LA6_: ;
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(NIM_BOOL, importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((16640 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, canonType__ZcD0zNCGO9bcEV34hRXFEJA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))) goto LA3_;
		result = (*(*c).graph).sysTypes[(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))- 0];
	}
	goto LA1_;
	LA3_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, prevDestructor__ROJgPFH7qSpxtHsXsMs9bTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prevOp, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* msg;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = typeToString__QlvraUan7WbHowhAbvDvdA(obj, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
	T1_ = rawNewString(((*(*prevOp).name).s ? (*(*prevOp).name).s->Sup.len : 0) + (T2_ ? T2_->Sup.len : 0) + 27);
appendString(T1_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_168));
appendString(T1_, (*(*prevOp).name).s);
appendString(T1_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_169));
appendString(T1_, T2_);
	msg = T1_;
	{
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		if (!!((((*prevOp).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0))) goto LA5_;
		T7_ = (NimStringDesc*)0;
		T8_ = (NimStringDesc*)0;
		T8_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, (*prevOp).info);
		T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 56);
appendString(T7_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_170));
appendString(T7_, T8_);
		msg = resizeString(msg, (T7_ ? T7_->Sup.len : 0) + 0);
appendString(msg, T7_);
	}
	goto LA3_;
	LA5_: ;
	{
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T10_ = (NimStringDesc*)0;
		T11_ = (NimStringDesc*)0;
		T11_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, (*prevOp).info);
		T10_ = rawNewString((T11_ ? T11_->Sup.len : 0) + 33);
appendString(T10_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_171));
appendString(T10_, T11_);
		msg = resizeString(msg, (T10_ ? T10_->Sup.len : 0) + 0);
appendString(msg, T10_);
	}
	LA3_: ;
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), msg, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_172, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, bindTypeHook__tGevY34EeRmY9bzfs7irrbQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NIM_BOOL noError;
	NIM_BOOL cond;
	t = (*s).typ;
	noError = NIM_FALSE;
	{
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NI T7_;
		if (!(op == ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))) goto LA3_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T7_ = (NI)0;
		T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		T6_ = (T7_ == ((NI) 2));
		if (!(T6_)) goto LA8_;
		T6_ = ((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		LA8_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA9_;
		T5_ = ((*(*t).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
		LA9_: ;
		cond = T5_;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T11_;
		NI T12_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NI)0;
		T12_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		T11_ = (((NI) 2) <= T12_);
		if (!(T11_)) goto LA13_;
		T11_ = ((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		LA13_: ;
		cond = T11_;
	}
	LA1_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
		if (!cond) goto LA16_;
		obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 1)], 8388608);
		{
			while (1) {
				(*obj).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
				{
					if (!((3072 &((NU64)1<<((NU)((*obj).kind)&63U)))!=0)) goto LA22_;
					obj = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(obj);
				}
				goto LA20_;
				LA22_: ;
				{
					if (!((*obj).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA25_;
					obj = (*obj).sons->data[((NI) 0)];
				}
				goto LA20_;
				LA25_: ;
				{
					goto LA18;
				}
				LA20_: ;
			}
		} LA18: ;
		{
			if (!((285351936 &((NU64)1<<((NU)((*obj).kind)&63U)))!=0)) goto LA30_;
			obj = canonType__ZcD0zNCGO9bcEV34hRXFEJA(c, obj);
			{
				if (!((*obj).attachedOps[(op)- 0] == s)) goto LA34_;
			}
			goto LA32_;
			LA34_: ;
			{
				NIM_BOOL T37_;
				T37_ = (NIM_BOOL)0;
				T37_ = ((*obj).attachedOps[(op)- 0] == 0);
				if (!(T37_)) goto LA38_;
				T37_ = !((((*obj).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38))&63U)))!=0));
				LA38_: ;
				if (!T37_) goto LA39_;
				asgnRef((void**) (&(*obj).attachedOps[(op)- 0]), s);
			}
			goto LA32_;
			LA39_: ;
			{
				prevDestructor__ROJgPFH7qSpxtHsXsMs9bTg(c, (*obj).attachedOps[(op)- 0], obj, (*n).info);
			}
			LA32_: ;
			noError = NIM_TRUE;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T44_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T45_;
				NimStringDesc* T48_;
				NimStringDesc* T49_;
				T44_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T44_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*obj).owner);
				T45_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T45_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
				if (!!((T44_ == T45_))) goto LA46_;
				T48_ = (NimStringDesc*)0;
				T49_ = (NimStringDesc*)0;
				T49_ = typeToString__QlvraUan7WbHowhAbvDvdA(obj, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T48_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + (T49_ ? T49_->Sup.len : 0) + 79);
appendString(T48_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_173));
appendString(T48_, (*(*s).name).s);
appendString(T48_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_174));
appendString(T48_, T49_);
appendString(T48_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T48_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_175, NIM_FALSE);
			}
			LA46_: ;
		}
		LA30_: ;
	}
	LA16_: ;
	{
		NIM_BOOL T52_;
		NimStringDesc* T56_;
		T52_ = (NIM_BOOL)0;
		T52_ = !(noError);
		if (!(T52_)) goto LA53_;
		T52_ = !((((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0));
		LA53_: ;
		if (!T52_) goto LA54_;
		T56_ = (NimStringDesc*)0;
		T56_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 50);
appendString(T56_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_176));
appendString(T56_, (*(*s).name).s);
appendString(T56_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_177));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T56_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_178, NIM_FALSE);
	}
	LA54_: ;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, semOverride__8H5d8d9cPCfbpMuDrerQMeQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* name;
{	name = nsuNormalize((*(*s).name).s);
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_160))) goto LA1_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_161))) goto LA2_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_162))) goto LA2_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_163))) goto LA3_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_164))) goto LA3_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_165))) goto LA3_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_166))) goto LA4_;
	if (eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_167))) goto LA5_;
	goto LA6_;
	LA1_: ;
	{
		bindTypeHook__tGevY34EeRmY9bzfs7irrbQ(c, s, n, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0));
	}
	goto LA7_;
	LA2_: ;
	{
		{
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			NI T14_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T21_;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T14_ = (NI)0;
			T14_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
			T13_ = (T14_ == ((NI) 2));
			if (!(T13_)) goto LA15_;
			T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T16_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*s).typ).sons->data[((NI) 1)], IL64(36134350135273744));
			T13_ = ((6291456 &((NU64)1<<((NU)((*T16_).kind)&63U)))!=0);
			LA15_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA17_;
			T12_ = sameType__3isNyHKb0U1OCnClmflXSg((*(*s).typ).sons->data[((NI) 1)], (*(*s).typ).sons->data[((NI) 0)], 0);
			LA17_: ;
			if (!T12_) goto LA18_;
			T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T20_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*s).typ).sons->data[((NI) 1)], IL64(36134350135273744));
			T21_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T21_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(T20_);
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T21_, IL64(36134350135273744));
			{
				while (1) {
					{
						if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10))) goto LA26_;
						t = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
					}
					goto LA24_;
					LA26_: ;
					{
						if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA29_;
						t = (*t).sons->data[((NI) 0)];
					}
					goto LA24_;
					LA29_: ;
					{
						goto LA22;
					}
					LA24_: ;
				}
			} LA22: ;
			{
				if (!((285368320 &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA34_;
				{
					if (!((*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0] == 0)) goto LA38_;
					asgnRef((void**) (&(*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))- 0]), s);
				}
				goto LA36_;
				LA38_: ;
				{
					NimStringDesc* T41_;
					NimStringDesc* T42_;
					T41_ = (NimStringDesc*)0;
					T42_ = (NimStringDesc*)0;
					T42_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T41_ = rawNewString((T42_ ? T42_->Sup.len : 0) + 35);
appendString(T41_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_179));
appendString(T41_, T42_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T41_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_180, NIM_FALSE);
				}
				LA36_: ;
			}
			goto LA32_;
			LA34_: ;
			{
				NimStringDesc* T44_;
				NimStringDesc* T45_;
				T44_ = (NimStringDesc*)0;
				T45_ = (NimStringDesc*)0;
				T45_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T44_ = rawNewString((T45_ ? T45_->Sup.len : 0) + 27);
appendString(T44_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_181));
appendString(T44_, T45_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T44_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_182, NIM_FALSE);
			}
			LA32_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T48_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T49_;
				NimStringDesc* T52_;
				NimStringDesc* T53_;
				T48_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T48_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*t).owner);
				T49_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T49_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
				if (!!((T48_ == T49_))) goto LA50_;
				T52_ = (NimStringDesc*)0;
				T53_ = (NimStringDesc*)0;
				T53_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T52_ = rawNewString((name ? name->Sup.len : 0) + (T53_ ? T53_->Sup.len : 0) + 79);
appendString(T52_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_173));
appendString(T52_, name);
appendString(T52_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_174));
appendString(T52_, T53_);
appendString(T52_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T52_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_183, NIM_FALSE);
			}
			LA50_: ;
		}
		goto LA10_;
		LA18_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_184), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_185, NIM_FALSE);
		}
		LA10_: ;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34)) & 63);
	}
	goto LA7_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		{
			if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 7))) goto LA58_;
			goto BeforeRet_;
		}
		LA58_: ;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34)) & 63);
		t_2 = (*s).typ;
		{
			NIM_BOOL T62_;
			NIM_BOOL T63_;
			NI T64_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objB;
			T62_ = (NIM_BOOL)0;
			T63_ = (NIM_BOOL)0;
			T64_ = (NI)0;
			T64_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t_2);
			T63_ = (T64_ == ((NI) 3));
			if (!(T63_)) goto LA65_;
			T63_ = ((*t_2).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			LA65_: ;
			T62_ = T63_;
			if (!(T62_)) goto LA66_;
			T62_ = ((*(*t_2).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
			LA66_: ;
			if (!T62_) goto LA67_;
			obj = (*(*t_2).sons->data[((NI) 1)]).sons->data[((NI) 0)];
			{
				while (1) {
					(*obj).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
					{
						if (!((*obj).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10))) goto LA73_;
						obj = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(obj);
					}
					goto LA71_;
					LA73_: ;
					{
						if (!((*obj).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA76_;
						obj = (*obj).sons->data[((NI) 0)];
					}
					goto LA71_;
					LA76_: ;
					{
						goto LA69;
					}
					LA71_: ;
				}
			} LA69: ;
			objB = (*t_2).sons->data[((NI) 2)];
			{
				while (1) {
					{
						if (!((*objB).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10))) goto LA83_;
						objB = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(objB);
					}
					goto LA81_;
					LA83_: ;
					{
						if (!((2560 &((NU64)1<<((NU)((*objB).kind)&63U)))!=0)) goto LA86_;
						objB = (*objB).sons->data[((NI) 0)];
					}
					goto LA81_;
					LA86_: ;
					{
						goto LA79;
					}
					LA81_: ;
				}
			} LA79: ;
			{
				NIM_BOOL T91_;
				tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg k;
				T91_ = (NIM_BOOL)0;
				T91_ = ((285351936 &((NU64)1<<((NU)((*obj).kind)&63U)))!=0);
				if (!(T91_)) goto LA92_;
				T91_ = sameType__3isNyHKb0U1OCnClmflXSg(obj, objB, 0);
				LA92_: ;
				if (!T91_) goto LA93_;
				obj = canonType__ZcD0zNCGO9bcEV34hRXFEJA(c, obj);
				{
					NIM_BOOL T97_;
					T97_ = (NIM_BOOL)0;
					T97_ = eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_163));
					if (T97_) goto LA98_;
					T97_ = eqStrings(name, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_164));
					LA98_: ;
					if (!T97_) goto LA99_;
					k = ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 1);
				}
				goto LA95_;
				LA99_: ;
				{
					k = ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 2);
				}
				LA95_: ;
				{
					if (!((*obj).attachedOps[(k)- 0] == s)) goto LA104_;
				}
				goto LA102_;
				LA104_: ;
				{
					NIM_BOOL T107_;
					T107_ = (NIM_BOOL)0;
					T107_ = ((*obj).attachedOps[(k)- 0] == 0);
					if (!(T107_)) goto LA108_;
					T107_ = !((((*obj).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38))&63U)))!=0));
					LA108_: ;
					if (!T107_) goto LA109_;
					asgnRef((void**) (&(*obj).attachedOps[(k)- 0]), s);
				}
				goto LA102_;
				LA109_: ;
				{
					prevDestructor__ROJgPFH7qSpxtHsXsMs9bTg(c, (*obj).attachedOps[(k)- 0], obj, (*n).info);
				}
				LA102_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T114_;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T115_;
					NimStringDesc* T118_;
					NimStringDesc* T119_;
					T114_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T114_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*obj).owner);
					T115_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T115_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
					if (!!((T114_ == T115_))) goto LA116_;
					T118_ = (NimStringDesc*)0;
					T119_ = (NimStringDesc*)0;
					T119_ = typeToString__QlvraUan7WbHowhAbvDvdA(obj, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T118_ = rawNewString((name ? name->Sup.len : 0) + (T119_ ? T119_->Sup.len : 0) + 79);
appendString(T118_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_173));
appendString(T118_, name);
appendString(T118_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_174));
appendString(T118_, T119_);
appendString(T118_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T118_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_186, NIM_FALSE);
				}
				LA116_: ;
				goto BeforeRet_;
			}
			LA93_: ;
		}
		LA67_: ;
		{
			NimStringDesc* T124_;
			if (!!((((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0))) goto LA122_;
			T124_ = (NimStringDesc*)0;
			T124_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 56);
appendString(T124_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_176));
appendString(T124_, (*(*s).name).s);
appendString(T124_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_187));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T124_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_188, NIM_FALSE);
		}
		LA122_: ;
	}
	goto LA7_;
	LA4_: ;
	{
		bindTypeHook__tGevY34EeRmY9bzfs7irrbQ(c, s, n, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 3));
	}
	goto LA7_;
	LA5_: ;
	{
		bindTypeHook__tGevY34EeRmY9bzfs7irrbQ(c, s, n, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 4));
	}
	goto LA7_;
	LA6_: ;
	{
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0)) goto LA130_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_189), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_190, NIM_FALSE);
		}
		LA130_: ;
	}
	LA7_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, find__CWgb1wQSxTCKtdHVU5pCYQsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NimStringDesc** i;
		NI i_2;
		i = (NimStringDesc**)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!eqStrings((*i), item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__MghwuKjQqmVLYE8A59cNGHgsystem)(NimStringDesc** a, NI aLen_0, NimStringDesc* item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__CWgb1wQSxTCKtdHVU5pCYQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cursorInProcAux__2z69cmDyuoRHwZ79bXIom4jw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg T3_;
		T3_ = (tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg)0;
		T3_ = inCheckpoint__39cgIJElcz9arpbYiRwV2TVw((*n).info, (*conf).m.trackPos);
		if (!!((T3_ == ((tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg) 0)))) goto LA4_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				{
					NIM_BOOL T11_;
					T11_ = (NIM_BOOL)0;
					T11_ = cursorInProcAux__2z69cmDyuoRHwZ79bXIom4jw_2(conf, (*n)._kind_6.sons->data[i]);
					if (!T11_) goto LA12_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA12_: ;
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cursorInProc__2z69cmDyuoRHwZ79bXIom4jw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*n).info.fileIndex == (*conf).m.trackPos.fileIndex)) goto LA3_;
		result = cursorInProcAux__2z69cmDyuoRHwZ79bXIom4jw_2(conf, n);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasObjParam__J1LR9bIUh18t4XFDmYEYBYw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (NIM_BOOL)0;
	t = (*s).typ;
	{
		NI col;
		NI colontmp_;
		NI i;
		col = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		i = ((NI) 1);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA3;
				col = i;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
					T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[col], IL64(36275087638268176));
					if (!((*T6_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA7_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tt;
		NIM_BOOL foundObj;
		T3_ = (NIM_BOOL)0;
		T3_ = isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA(s);
		if (!T3_) goto LA4_;
		tt = (*s).typ;
		foundObj = NIM_FALSE;
		{
			NI col;
			NI colontmp_;
			NI i;
			col = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(tt);
			i = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
					if (!(i < colontmp_)) goto LA8;
					col = i;
					t = (*tt).sons->data[col];
					{
						NIM_BOOL T11_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
						T11_ = (NIM_BOOL)0;
						T11_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
						if (!(T11_)) goto LA12_;
						T11_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9));
						LA12_: ;
						if (!T11_) goto LA13_;
						x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(246290619305488));
						{
							NIM_BOOL T17_;
							NI T19_;
							NI T20_;
							tyTuple__zwpS6d6iewrdlBSTNFoyVA T23_;
							NI T24_;
							T17_ = (NIM_BOOL)0;
							T17_ = ((*x).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
							if (!(T17_)) goto LA18_;
							T19_ = (NI)0;
							T19_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
							T20_ = (NI)0;
							T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 2)]);
							T17_ = ((NI)(T19_ - ((NI) 1)) == T20_);
							LA18_: ;
							if (!T17_) goto LA21_;
							foundObj = NIM_TRUE;
							nimZeroMem((void*)(&T23_), sizeof(tyTuple__zwpS6d6iewrdlBSTNFoyVA));
							T23_.Field0 = col;
							T23_.Field1 = s;
							asgnRef((void**) (&(*x).methods), (tySequence__MvZmat48bhe9b6x9aUD58D5Q*) incrSeqV3((TGenericSeq*)((*x).methods), (&NTI__MvZmat48bhe9b6x9aUD58D5Q_)));
							T24_ = (*x).methods->Sup.len++;
							(*x).methods->data[T24_].Field0 = T23_.Field0;
							asgnRef((void**) (&(*x).methods->data[T24_].Field1), T23_.Field1);
						}
						LA21_: ;
					}
					LA13_: ;
					i += ((NI) 1);
				} LA8: ;
			}
		}
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_203), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_204, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = hasObjParam__J1LR9bIUh18t4XFDmYEYBYw_2(s);
			if (!T28_) goto LA29_;
			methodDef__NKjYu87vB0uQmGRMfpDEBQ((*c).graph, s, NIM_FALSE);
		}
		goto LA26_;
		LA29_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_205), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_206, NIM_FALSE);
		}
		LA26_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	rawPushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ(c, owner);
	rawHandleSelf__jWGpC0lY8vG9b1MhOYJ9cFiQ_2(c, owner);
}
N_LIB_PRIVATE N_NIMCALL(void, typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg flags) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = typeAllowed__M8lM58Zr3lmYhlOsJv89cVw(typ, kind, c, flags);
	{
		NimStringDesc* err;
		if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		err = (NimStringDesc*)0;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T9_;
			if (!(t == typ)) goto LA7_;
			nimZeroMem((void*)T9_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T9_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T9_[1] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA(kind);
			err = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_207), T9_, 2);
			{
				NIM_BOOL T12_;
				tyArray__nHXaesL0DJZHyVS07ARPRA T16_;
				NimStringDesc* T17_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((1792 &((NU32)1<<((NU)(kind)&31U)))!=0);
				if (!(T12_)) goto LA13_;
				T12_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 5))&7U)))!=0);
				LA13_: ;
				if (!T12_) goto LA14_;
				nimZeroMem((void*)T16_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T16_[0] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA((*(*typ).owner).kind);
				T17_ = (NimStringDesc*)0;
				T17_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_208), T16_, 1);
				err = resizeString(err, (T17_ ? T17_->Sup.len : 0) + 0);
appendString(err, T17_);
			}
			LA14_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			tyArray__24KAM9afIUgUaqBaEBB6r9bg T19_;
			nimZeroMem((void*)T19_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
			T19_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T19_[1] = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T19_[2] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA(kind);
			err = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_209), T19_, 3);
		}
		LA5_: ;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), err, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_210, NIM_FALSE);
	}
	LA3_: ;
}
static N_INLINE(void, paramsTypeCheck__X9cjeXk0ogla5nWLtx0FEkAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q(c, (*(*typ).n).info, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), 0);
}
N_LIB_PRIVATE N_NIMCALL(void, activate__NRIJDWZtATzMum7OEjYC2g_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
}
static N_INLINE(NIM_BOOL, isArrayConstr__crbaOhZgTohCnKAdtWPkSQsem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
	if (!(T1_)) goto LA2_;
	T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
	T1_ = ((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T6_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59));
					if (!(T6_)) goto LA7_;
					T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*it).typ, IL64(36275087632017680));
					T6_ = !(((IL64(281475110928384) &((NU64)1<<((NU)((*T8_).kind)&63U)))!=0));
					LA7_: ;
					if (!T6_) goto LA9_;
					{
						NIM_BOOL T13_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* s;
						T13_ = (NIM_BOOL)0;
						T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T14_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*it)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
						T13_ = ((786464 &((NU64)1<<((NU)((*T14_).kind)&63U)))!=0);
						if (T13_) goto LA15_;
						T13_ = isArrayConstr__crbaOhZgTohCnKAdtWPkSQsem((*it)._kind_6.sons->data[((NI) 1)]);
						LA15_: ;
						if (!T13_) goto LA16_;
						s = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*it).typ, IL64(36275087632017680));
						{
							if (!!(((*s).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6)))) goto LA20_;
							changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, (*it)._kind_6.sons->data[((NI) 1)], s, NIM_TRUE);
						}
						LA20_: ;
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*it)._kind_6.sons->data[((NI) 1)]);
					}
					LA16_: ;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag, isAssignable__ASvZU4uIBad6J9b9cMoLNFvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr) {
	tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag result;
	result = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
	result = isAssignable__H8ClJSBthN45fIRKmjWHMQ((*(*c).p).owner, n, isUnsafeAddr);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderNotLValue__vfKkxNGxagsG9czCdz2IAEQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	result = (NimStringDesc*)0;
	result = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA3_;
		n_2 = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		n_2 = n;
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		NI T10_;
		NimStringDesc* T13_;
		NimStringDesc* T14_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T8_)) goto LA9_;
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		T8_ = (((NI) 1) < T10_);
		LA9_: ;
		if (!T8_) goto LA11_;
		T13_ = (NimStringDesc*)0;
		T14_ = (NimStringDesc*)0;
		T14_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*n_2)._kind_6.sons->data[((NI) 0)]);
		T13_ = rawNewString((T14_ ? T14_->Sup.len : 0) + (result ? result->Sup.len : 0) + 2);
appendString(T13_, T14_);
appendString(T13_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_67));
appendString(T13_, result);
appendString(T13_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
		result = T13_;
	}
	goto LA6_;
	LA11_: ;
	{
		NIM_BOOL T16_;
		NI T18_;
		NimStringDesc* T21_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T22_;
		NimStringDesc* T23_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) || (*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59));
		if (!(T16_)) goto LA17_;
		T18_ = (NI)0;
		T18_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		T16_ = (T18_ == ((NI) 2));
		LA17_: ;
		if (!T16_) goto LA19_;
		T21_ = (NimStringDesc*)0;
		T22_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T22_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36275087632017680));
		T23_ = (NimStringDesc*)0;
		T23_ = typeToString__QlvraUan7WbHowhAbvDvdA(T22_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T21_ = rawNewString((T23_ ? T23_->Sup.len : 0) + (result ? result->Sup.len : 0) + 2);
appendString(T21_, T23_);
appendString(T21_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_67));
appendString(T21_, result);
appendString(T21_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
		result = T21_;
	}
	goto LA6_;
	LA19_: ;
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T5_) goto LA6_;
		T5_ = (((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA6_: ;
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA7_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA7_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
		T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T10_ = makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*n).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64), (*n).info, T10_);
		add__P8dDSotTW25BkfbyspojGg(result, n);
		{
			tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T13_;
			NimStringDesc* T16_;
			NimStringDesc* T17_;
			T13_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
			T13_ = isAssignable__ASvZU4uIBad6J9b9cMoLNFvA(c, n, NIM_FALSE);
			if (!!(((6 &((NU8)1<<((NU)(T13_)&7U)))!=0))) goto LA14_;
			T16_ = (NimStringDesc*)0;
			T16_ = renderNotLValue__vfKkxNGxagsG9czCdz2IAEQ(n);
			T17_ = (NimStringDesc*)0;
			T17_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_215), T16_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T17_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_219, NIM_FALSE);
		}
		LA14_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, analyseIfAddressTaken__7YxUILpPxooC5qqa89a54dw_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NIM_BOOL T4_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
			T4_ = (NIM_BOOL)0;
			T4_ = !(((*(*n)._kind_4.sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T4_)) goto LA5_;
			T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_4.sym).typ, IL64(36134350135273488));
			T4_ = !(((IL64(140737496743936) &((NU64)1<<((NU)((*T6_).kind)&63U)))!=0));
			LA5_: ;
			if (!T4_) goto LA7_;
			(*(*n)._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 17)) & 63);
			result = newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14(c, n);
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_220), TM__rF9caJawfOjYTjsgLVUSGFA_221);
			goto BeforeRet_;
		}
		LA12_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
			T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T16_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).typ, IL64(36134350135273488));
			if (!!(((IL64(140737496743936) &((NU64)1<<((NU)((*T16_).kind)&63U)))!=0))) goto LA17_;
			(*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 17)) & 63);
			result = newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14(c, n);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T22_;
			T22_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T22_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273488));
			if (!!(((IL64(140737496743936) &((NU64)1<<((NU)((*T22_).kind)&63U)))!=0))) goto LA23_;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA27_;
				(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 17)) & 63);
			}
			LA27_: ;
			result = newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14(c, n);
		}
		LA23_: ;
	}
	break;
	default:
	{
		result = newHiddenAddrTaken__7YxUILpPxooC5qqa89a54dw_14(c, n);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(70368744179728));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((TM__rF9caJawfOjYTjsgLVUSGFA_214[(NU)((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic)>>3] &(1U<<((NU)((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic)&7U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					{
						NIM_BOOL T12_;
						NIM_BOOL T13_;
						NI T14_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
						T12_ = (NIM_BOOL)0;
						T13_ = (NIM_BOOL)0;
						T14_ = (NI)0;
						T14_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
						T13_ = (i < T14_);
						if (!(T13_)) goto LA15_;
						T13_ = !(((*t).sons->data[i] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
						LA15_: ;
						T12_ = T13_;
						if (!(T12_)) goto LA16_;
						T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T17_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[i], IL64(36134350135273488));
						T12_ = ((8388608 &((NU64)1<<((NU)((*T17_).kind)&63U)))!=0);
						LA16_: ;
						if (!T12_) goto LA18_;
						it = (*n)._kind_6.sons->data[i];
						{
							tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T22_;
							T22_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
							T22_ = isAssignable__ASvZU4uIBad6J9b9cMoLNFvA(c, it, NIM_FALSE);
							if (!!(((6 &((NU8)1<<((NU)(T22_)&7U)))!=0))) goto LA23_;
							{
								NimStringDesc* T29_;
								NimStringDesc* T30_;
								if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64)))) goto LA27_;
								T29_ = (NimStringDesc*)0;
								T29_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(it);
								T30_ = (NimStringDesc*)0;
								T30_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_215), T29_);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T30_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_216, NIM_FALSE);
							}
							LA27_: ;
						}
						LA23_: ;
					}
					LA18_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
			if (!((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 32) || (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33) || (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 34))) goto LA33_;
			arg = (*n)._kind_6.sons->data[((NI) 1)];
			{
				if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA37_;
				arg = (*arg)._kind_6.sons->data[((NI) 0)];
			}
			LA37_: ;
			{
				NIM_BOOL T41_;
				NIM_BOOL T42_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
				NimStringDesc* T48_;
				NimStringDesc* T49_;
				T41_ = (NIM_BOOL)0;
				T42_ = (NIM_BOOL)0;
				T42_ = ((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T42_)) goto LA43_;
				T42_ = ((*(*arg)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
				LA43_: ;
				T41_ = T42_;
				if (!(T41_)) goto LA44_;
				T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T45_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36134350135273744));
				T41_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*T45_).kind)&63U)))!=0);
				LA44_: ;
				if (!T41_) goto LA46_;
				T48_ = (NimStringDesc*)0;
				T48_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 1)], 4);
				T49_ = (NimStringDesc*)0;
				T49_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_217), T48_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T49_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_218, NIM_FALSE);
			}
			LA46_: ;
		}
		LA33_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_4 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
				if (!(i_4 < colontmp__2)) goto LA52;
				i_3 = i_4;
				{
					if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA55_;
					n_2 = (*n)._kind_6.sons->data[((NI) 0)];
				}
				goto LA53_;
				LA55_: ;
				{
					n_2 = n;
				}
				LA53_: ;
				{
					if (!((*(*n_2)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA60_;
					analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7(c, (*n_2)._kind_6.sons->data[i_3]);
				}
				LA60_: ;
				{
					NIM_BOOL T64_;
					NI T65_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T67_;
					T64_ = (NIM_BOOL)0;
					T65_ = (NI)0;
					T65_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
					T64_ = (i_3 < T65_);
					if (!(T64_)) goto LA66_;
					T67_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T67_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[i_3], IL64(36134350135273488));
					T64_ = ((8388608 &((NU64)1<<((NU)((*T67_).kind)&63U)))!=0);
					LA66_: ;
					if (!T64_) goto LA68_;
					{
						if (!!(((*(*n_2)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64)))) goto LA72_;
						asgnRef((void**) (&(*n_2)._kind_6.sons->data[i_3]), analyseIfAddressTaken__7YxUILpPxooC5qqa89a54dw_13(c, (*n_2)._kind_6.sons->data[i_3]));
					}
					LA72_: ;
				}
				LA68_: ;
				i_4 += ((NI) 1);
			} LA52: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAddrArg__kiPmghV1gaPm718CtGyhQw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isUnsafeAddr) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 0);
	{
		if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		(*(*x)._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 17)) & 63);
	}
	LA3_: ;
	{
		tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T7_;
		T7_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
		T7_ = isAssignable__ASvZU4uIBad6J9b9cMoLNFvA(c, x, isUnsafeAddr);
		if (!!(((6 &((NU8)1<<((NU)(T7_)&7U)))!=0))) goto LA8_;
		{
			if (!isUnsafeAddr) goto LA12_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_222), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_223, NIM_FALSE);
		}
		goto LA10_;
		LA12_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_225), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_226, NIM_FALSE);
		}
		LA10_: ;
	}
	LA8_: ;
	result = x;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeOf__7YxUILpPxooC5qqa89a54dw_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI64 m;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typExpr;
	tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ T11_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	m = IL64(1);
	{
		NI T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* mode;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		mode = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[((NI) 2)]);
		{
			if (!!(((*mode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA8_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_228), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_229, NIM_FALSE);
		}
		goto LA6_;
		LA8_: ;
		{
			m = (*mode)._kind_1.intVal;
		}
		LA6_: ;
	}
	LA4_: ;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132), (*n).info);
	{
		if (!(m == IL64(1))) goto LA14_;
		T11_ = 4;
	}
	goto LA12_;
	LA14_: ;
	{
		T11_ = 0;
	}
	LA12_: ;
	typExpr = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], T11_);
	add__P8dDSotTW25BkfbyspojGg(result, typExpr);
	asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, (*typExpr).typ));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDeref__7YxUILpPxooC5qqa89a54dw_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
	result = n;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(246290613012496));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	{
		asgnRef((void**) (&(*n).typ), lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t));
	}
	break;
	default:
	{
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semStaticType__DMAavRw02YcIRkO3yZ1XeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* childNode, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), prev, c);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, childNode, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	base = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T1_, 272);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, base, NIM_TRUE);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 24)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSymGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericSym__aK9ce4VwkiusXxioJ5dzs5w_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newInst;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__BdjBO3HF6dSjQEzna7SJ1A(c, s, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((NI) -1), (&m));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arg;
				tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ tm;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				formal = (*(*(*(*s).ast)._kind_6.sons->data[((NI) 2)])._kind_6.sons->data[(NI)(i - ((NI) 1))]).typ;
				arg = (*(*n)._kind_6.sons->data[i]).typ;
				{
					NIM_BOOL T6_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*formal).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
					if (!(T6_)) goto LA7_;
					T6_ = !(((*arg).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60)));
					LA7_: ;
					if (!T6_) goto LA8_;
					evaluated = (*c).semTryConstExpr(c, (*n)._kind_6.sons->data[i]);
					{
						if (!!((evaluated == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA12_;
						arg = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), c);
						if ((*arg).sons) { nimGCunrefNoCycle((*arg).sons); (*arg).sons = NIM_NIL; }
						(*arg).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
						asgnRef((void**) (&(*arg).sons->data[0]), (*evaluated).typ);
						asgnRef((void**) (&(*arg).n), evaluated);
					}
					LA12_: ;
				}
				LA8_: ;
				tm = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&m), formal, arg, 0);
				{
					if (!((3 &((NU16)1<<((NU)(tm)&15U)))!=0)) goto LA16_;
					result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					goto BeforeRet_;
				}
				LA16_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	newInst = generateInstance__Bbmaz5QjetnTaor7LYngPg(c, s, m.bindings, (*n).info);
	(*(*newInst).typ).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63));
	info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, s);
	result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(newInst, info);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericInstError__7YxUILpPxooC5qqa89a54dw_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T1_;
	NimStringDesc* T2_;
	NimStringDesc* T3_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	T2_ = (NimStringDesc*)0;
	T2_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
	T3_ = (NimStringDesc*)0;
	T3_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), T2_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, T1_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T3_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_240, NIM_FALSE);
	result = n;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, explicitGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				e = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[i], 0);
				{
					if (!((*e).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA6_;
					asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
				}
				goto LA4_;
				LA6_: ;
				{
					asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, 256));
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	s_2 = s;
	a = (*n)._kind_6.sons->data[((NI) 0)];
	{
		if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA11_;
		{
			NI T15_;
			NI T16_;
			NI expected;
			tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T19_;
			NimStringDesc* T20_;
			NimStringDesc* T21_;
			NI T22_;
			NimStringDesc* T23_;
			NimStringDesc* T24_;
			T15_ = (NI)0;
			T15_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*(*s_2).ast)._kind_6.sons->data[((NI) 2)]);
			T16_ = (NI)0;
			T16_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!((T15_ == (NI)(T16_ - ((NI) 1))))) goto LA17_;
			expected = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*(*s_2).ast)._kind_6.sons->data[((NI) 2)]);
			T19_ = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
			T20_ = (NimStringDesc*)0;
			T21_ = (NimStringDesc*)0;
			T21_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
			T22_ = (NI)0;
			T22_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T23_ = (NimStringDesc*)0;
			T23_ = nimIntToStr((NI)(T22_ - ((NI) 1)));
			T24_ = (NimStringDesc*)0;
			T24_ = nimIntToStr(expected);
			T20_ = rawNewString((T21_ ? T21_->Sup.len : 0) + (T23_ ? T23_->Sup.len : 0) + (T24_ ? T24_->Sup.len : 0) + 52);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_235));
appendString(T20_, T21_);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_236));
appendString(T20_, T23_);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_237));
appendString(T20_, T24_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, T19_, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_238, NIM_FALSE);
			result = n;
			goto BeforeRet_;
		}
		LA17_: ;
		result = explicitGenericSym__aK9ce4VwkiusXxioJ5dzs5w_3(c, n, s_2);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA27_;
			result = explicitGenericInstError__7YxUILpPxooC5qqa89a54dw_17(c, n);
		}
		LA27_: ;
	}
	goto LA9_;
	LA11_: ;
	{
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T32_;
		if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA30_;
		T32_ = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg((*a).kind, T32_);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(a);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate;
					if (!(i_4 < colontmp__2)) goto LA35;
					i_3 = i_4;
					candidate = (*(*a)._kind_6.sons->data[i_3])._kind_4.sym;
					{
						if (!((126976 &((NU32)1<<((NU)((*candidate).kind)&31U)))!=0)) goto LA38_;
						{
							NI T42_;
							NI T43_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
							T42_ = (NI)0;
							T42_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*(*candidate).ast)._kind_6.sons->data[((NI) 2)]);
							T43_ = (NI)0;
							T43_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
							if (!(T42_ == (NI)(T43_ - ((NI) 1)))) goto LA44_;
							x = explicitGenericSym__aK9ce4VwkiusXxioJ5dzs5w_3(c, n, candidate);
							{
								if (!!((x == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA48_;
								add__P8dDSotTW25BkfbyspojGg(result, x);
							}
							LA48_: ;
						}
						LA44_: ;
					}
					LA38_: ;
					i_4 += ((NI) 1);
				} LA35: ;
			}
		}
		{
			NIM_BOOL T52_;
			NI T53_;
			T52_ = (NIM_BOOL)0;
			T53_ = (NI)0;
			T53_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			T52_ = (T53_ == ((NI) 1));
			if (!(T52_)) goto LA54_;
			T52_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56));
			LA54_: ;
			if (!T52_) goto LA55_;
			result = (*result)._kind_6.sons->data[((NI) 0)];
		}
		goto LA50_;
		LA55_: ;
		{
			NI T58_;
			T58_ = (NI)0;
			T58_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!(T58_ == ((NI) 0))) goto LA59_;
			result = explicitGenericInstError__7YxUILpPxooC5qqa89a54dw_17(c, n);
		}
		goto LA50_;
		LA59_: ;
		LA50_: ;
	}
	goto LA9_;
	LA30_: ;
	{
		result = explicitGenericInstError__7YxUILpPxooC5qqa89a54dw_17(c, n);
	}
	LA9_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symFromType__xO2UfktRDKCUWUorFz9cLYA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T5_;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!!(((*t).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		result = (*t).sym;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T5_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_241));
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), T5_, (*t).owner, info, 0);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33)) & 63);
	asgnRef((void**) (&(*result).typ), t);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symNodeFromType__MpkaQE9aiK11PxY8aspzYDw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = symFromType__xO2UfktRDKCUWUorFz9cLYA(c, t, info);
	result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(T1_, info);
	asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, t));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSubscript__vJZwz9bfROKrfrtM50y74CQ_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arr;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 1))) goto LA4_;
		x = semDeref__7YxUILpPxooC5qqa89a54dw_16(c, n);
		{
			if (!(x == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA8_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA8_: ;
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47), (*x).info, (*x).typ);
		add__P8dDSotTW25BkfbyspojGg(result, (*x)._kind_6.sons->data[((NI) 0)]);
		goto BeforeRet_;
	}
	LA4_: ;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 16384));
	arr = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(9253489874044944));
	{
		if (!((*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA12_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
			T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T16_ = base__PfgI9ap7WOnsRfFV4znQ27w(arr);
			if (!((*T16_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA17_;
			result = n;
			asgnRef((void**) (&(*result).typ), semStaticType__DMAavRw02YcIRkO3yZ1XeQ(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			goto BeforeRet_;
		}
		goto LA14_;
		LA17_: ;
		{
			if (!!(((*arr).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA20_;
			result = semSubscript__vJZwz9bfROKrfrtM50y74CQ_9(c, (*arr).n, flags);
			goto BeforeRet_;
		}
		goto LA14_;
		LA20_: ;
		{
			arr = base__PfgI9ap7WOnsRfFV4znQ27w(arr);
		}
		LA14_: ;
	}
	LA12_: ;
	switch ((*arr).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		{
			NI T26_;
			T26_ = (NI)0;
			T26_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!((T26_ == ((NI) 2)))) goto LA27_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA27_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), makeDeref__wWBimsBS4M6UZBvTRDlQTQ((*n)._kind_6.sons->data[((NI) 0)]));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA31;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[i], (flags & 260)));
					i_2 += ((NI) 1);
				} LA31: ;
			}
		}
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* indexType;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
			if (!((*arr).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16))) goto LA34_;
			indexType = (*arr).sons->data[((NI) 0)];
			arg = indexTypesMatch__8llRCFM4VdmgY27XJn2sRA(c, indexType, (*(*n)._kind_6.sons->data[((NI) 1)]).typ, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!((arg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA38_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), arg);
				result = n;
				asgnRef((void**) (&(*result).typ), elemType__PfgI9ap7WOnsRfFV4znQ27w_2(arr));
			}
			LA38_: ;
		}
		goto LA32_;
		LA34_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T41_;
			T41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T41_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136314128));
			if (!((IL64(34151432454144) &((NU64)1<<((NU)((*T41_).kind)&63U)))!=0)) goto LA42_;
			result = n;
			asgnRef((void**) (&(*result).typ), elemType__PfgI9ap7WOnsRfFV4znQ27w_2(arr));
		}
		goto LA32_;
		LA42_: ;
		LA32_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
		result = n;
		T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T45_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, T45_));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			NI T49_;
			T49_ = (NI)0;
			T49_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!((T49_ == ((NI) 2)))) goto LA50_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA50_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), makeDeref__wWBimsBS4M6UZBvTRDlQTQ((*n)._kind_6.sons->data[((NI) 0)]));
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[((NI) 1)]));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T54_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA idx;
			T54_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T54_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(70368745261072));
			if (!((IL64(66571993088) &((NU64)1<<((NU)((*T54_).kind)&63U)))!=0)) goto LA55_;
			idx = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*n)._kind_6.sons->data[((NI) 1)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
			{
				NIM_BOOL T59_;
				NI T61_;
				NI T64_;
				T59_ = (NIM_BOOL)0;
				T59_ = lteq___xL5gyZrjbGMarSdRAXOo9ag(IL64(0), idx);
				if (!(T59_)) goto LA60_;
				T61_ = (NI)0;
				T61_ = len__5mJADrRYkP3r9auuiuDZN9cQast(arr);
				T59_ = lt___nr9cP9b0OL9cabygV9bo19cJgZA_3(idx, ((NI64) (T61_)));
				LA60_: ;
				if (!T59_) goto LA62_;
				T64_ = (NI)0;
				T64_ = toInt__TIX0sFuRf3uBpOBltYp7bw(idx);
				asgnRef((void**) (&(*n).typ), (*arr).sons->data[T64_]);
			}
			goto LA57_;
			LA62_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_233), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_234, NIM_FALSE);
			}
			LA57_: ;
			result = n;
		}
		goto LA52_;
		LA55_: ;
		{
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		LA52_: ;
	}
	break;
	default:
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA70_;
			s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		goto LA68_;
		LA70_: ;
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA73_;
			s = (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		goto LA68_;
		LA73_: ;
		{
			s = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		}
		LA68_: ;
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA78_;
			switch ((*s).kind) {
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
			{
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semSymGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w(c, (*n)._kind_6.sons->data[((NI) 0)], s));
				result = explicitGenericInstantiation__aK9ce4VwkiusXxioJ5dzs5w_2(c, n, s);
				{
					if (!(result == n)) goto LA83_;
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(result));
				}
				goto LA81_;
				LA83_: ;
				{
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), result);
				}
				LA81_: ;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
			{
				{
					if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 15))&31U)))!=0)) goto LA89_;
					result = n;
				}
				goto LA87_;
				LA89_: ;
				{
					transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 27));
					switch ((*s).kind) {
					case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
					{
						result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, n, n, s, flags);
					}
					break;
					case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
					{
						result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, n, s, flags);
					}
					break;
					default:
					{
					}
					break;
					}
				}
				LA87_: ;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T96_;
				T96_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T96_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				result = symNodeFromType__MpkaQE9aiK11PxY8aspzYDw(c, T96_, (*n).info);
			}
			break;
			default:
			{
			}
			break;
			}
		}
		LA78_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, effectProblem__3uc8nf1Yi57kIzOPCNU9caA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, NimStringDesc** result, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		if (!(T3_)) goto LA4_;
		T3_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7))&63U)))!=0);
			if (!(T9_)) goto LA10_;
			T9_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7))&63U)))!=0));
			LA10_: ;
			if (!T9_) goto LA11_;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 103));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_263));
		}
		goto LA7_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0);
			if (!(T14_)) goto LA15_;
			T14_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0));
			LA15_: ;
			if (!T14_) goto LA16_;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 116));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_264));
		}
		goto LA7_;
		LA16_: ;
		{
			tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ T19_;
			T19_ = (tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ)0;
			T19_ = compatibleEffects__jMDzK5tLgCQpWKRW9azac5w(f, a);
			switch (T19_) {
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 0):
			{
			}
			break;
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 1):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 37));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_265));
			}
			break;
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 2):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 110));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_266));
			}
			break;
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 3):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 35));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_267));
			}
			break;
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 4):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 106));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_268));
			}
			break;
			case ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 5):
			{
				unsureAsgnRef((void**) (&(*result)), resizeString((*result), 107));
appendString((*result), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_269));
			}
			break;
			}
		}
		LA7_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, presentFailedCandidates__DzsD9bOR72VurwdjRilOhmA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__0dpGN6F4ocevqUQGsaf41w* errors, tyTuple__ZtAk5YtH0VW1iPowvxePrg* Result) {
	tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer;
	NimStringDesc* proto;
	NIM_BOOL filterOnlyFirst;
	NIM_BOOL maybeWrongSpace;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ* candidatesAll;
	NimStringDesc* candidates;
	NI skipped;
	tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw colontmp__2;
	NimStringDesc* colontmp__3;
	prefer = ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0);
	proto = describeArgs__cCrxh8TxJsIrMINltM1ovw(c, n, ((NI) 1), ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
	{
		tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ* err;
		NI i;
		NI L;
		NI T2_;
		err = (tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ*)0;
		i = ((NI) 0);
		T2_ = (errors ? errors->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				NimStringDesc* errProto;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
				if (!(i < L)) goto LA4;
				err = (&errors->data[i]);
				errProto = ((NimStringDesc*) NIM_NIL);
				n_2 = (*(*(*err).sym).typ).n;
				{
					NI i_2;
					NI colontmp_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
					i_3 = ((NI) 1);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
							if (!(i_3 < colontmp_)) goto LA7;
							i_2 = i_3;
							p = (*n_2)._kind_6.sons->data[i_2];
							{
								NimStringDesc* T12_;
								if (!((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA10_;
								T12_ = (NimStringDesc*)0;
								T12_ = typeToString__QlvraUan7WbHowhAbvDvdA((*(*p)._kind_4.sym).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
								errProto = resizeString(errProto, (T12_ ? T12_->Sup.len : 0) + 0);
appendString(errProto, T12_);
								{
									NI T15_;
									T15_ = (NI)0;
									T15_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
									if (!!((i_2 == (NI)(T15_ - ((NI) 1))))) goto LA16_;
									errProto = resizeString(errProto, 2);
appendString(errProto, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
								}
								LA16_: ;
							}
							LA10_: ;
							i_3 += ((NI) 1);
						} LA7: ;
					}
				}
				{
					if (!eqStrings(errProto, proto)) goto LA20_;
					prefer = ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 3);
					goto LA1;
				}
				LA20_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	} LA1: ;
	filterOnlyFirst = NIM_FALSE;
	{
		if (!!((((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 32))&63U)))!=0))) goto LA24_;
		{
			tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ* err_2;
			NI i_4;
			NI L_2;
			NI T27_;
			err_2 = (tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ*)0;
			i_4 = ((NI) 0);
			T27_ = (errors ? errors->Sup.len : 0);
			L_2 = T27_;
			{
				while (1) {
					if (!(i_4 < L_2)) goto LA29;
					err_2 = (&errors->data[i_4]);
					{
						if (!(((NI) 1) < (*err_2).firstMismatch.arg)) goto LA32_;
						filterOnlyFirst = NIM_TRUE;
						goto LA26;
					}
					LA32_: ;
					i_4 += ((NI) 1);
				} LA29: ;
			}
		} LA26: ;
	}
	LA24_: ;
	maybeWrongSpace = NIM_FALSE;
	candidatesAll = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
	candidates = ((NimStringDesc*) NIM_NIL);
	skipped = ((NI) 0);
	{
		tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ* err_3;
		NI i_5;
		NI L_3;
		NI T35_;
		err_3 = (tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ*)0;
		i_5 = ((NI) 0);
		T35_ = (errors ? errors->Sup.len : 0);
		L_3 = T35_;
		{
			while (1) {
				if (!(i_5 < L_3)) goto LA37;
				err_3 = (&errors->data[i_5]);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nArg;
					NimStringDesc* nameParam;
					NI T128_;
					NimStringDesc* T129_;
					candidates = setLengthStr(candidates, ((NI) 0));
					{
						NIM_BOOL T41_;
						T41_ = (NIM_BOOL)0;
						T41_ = filterOnlyFirst;
						if (!(T41_)) goto LA42_;
						T41_ = ((*err_3).firstMismatch.arg == ((NI) 1));
						LA42_: ;
						if (!T41_) goto LA43_;
						skipped += ((NI) 1);
						goto LA38;
					}
					LA43_: ;
					{
						NIM_BOOL T47_;
						NimStringDesc* T51_;
						T47_ = (NIM_BOOL)0;
						T47_ = ((520192 &((NU32)1<<((NU)((*(*err_3).sym).kind)&31U)))!=0);
						if (!(T47_)) goto LA48_;
						T47_ = !(((*(*err_3).sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
						LA48_: ;
						if (!T47_) goto LA49_;
						T51_ = (NimStringDesc*)0;
						T51_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*(*err_3).sym).ast, 22);
						candidates = resizeString(candidates, (T51_ ? T51_->Sup.len : 0) + 0);
appendString(candidates, T51_);
					}
					goto LA45_;
					LA49_: ;
					{
						NimStringDesc* T53_;
						T53_ = (NimStringDesc*)0;
						T53_ = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, (*err_3).sym, prefer, NIM_TRUE);
						candidates = resizeString(candidates, (T53_ ? T53_->Sup.len : 0) + 0);
appendString(candidates, T53_);
					}
					LA45_: ;
					candidates = resizeString(candidates, 1);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_247));
					{
						NI T56_;
						T56_ = (NI)0;
						T56_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						if (!((*err_3).firstMismatch.arg < T56_)) goto LA57_;
						nArg = (*n)._kind_6.sons->data[(*err_3).firstMismatch.arg];
					}
					goto LA54_;
					LA57_: ;
					{
						nArg = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					}
					LA54_: ;
					{
						if (!!(((*err_3).firstMismatch.formal == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA62_;
						nameParam = (*(*(*err_3).firstMismatch.formal).name).s;
					}
					goto LA60_;
					LA62_: ;
					{
						nameParam = ((NimStringDesc*) NIM_NIL);
					}
					LA60_: ;
					{
						NI T67_;
						NimStringDesc* T70_;
						NimStringDesc* T71_;
						T67_ = (NI)0;
						T67_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						if (!(((NI) 1) < T67_)) goto LA68_;
						T70_ = (NimStringDesc*)0;
						T71_ = (NimStringDesc*)0;
						T71_ = nimIntToStr((*err_3).firstMismatch.arg);
						T70_ = rawNewString((T71_ ? T71_->Sup.len : 0) + 35);
appendString(T70_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_248));
appendString(T70_, T71_);
						candidates = resizeString(candidates, (T70_ ? T70_->Sup.len : 0) + 0);
appendString(candidates, T70_);
						switch ((*err_3).firstMismatch.kind) {
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 2):
						{
							{
								if (!(nArg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA75_;
								candidates = resizeString(candidates, 26);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_249));
							}
							goto LA73_;
							LA75_: ;
							{
								NimStringDesc* T78_;
								NimStringDesc* T79_;
								T78_ = (NimStringDesc*)0;
								T79_ = (NimStringDesc*)0;
								T79_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*nArg)._kind_6.sons->data[((NI) 0)]);
								T78_ = rawNewString((T79_ ? T79_->Sup.len : 0) + 28);
appendString(T78_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_250));
appendString(T78_, T79_);
								candidates = resizeString(candidates, (T78_ ? T78_->Sup.len : 0) + 0);
appendString(candidates, T78_);
							}
							LA73_: ;
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 1):
						{
							NimStringDesc* T81_;
							NimStringDesc* T82_;
							T81_ = (NimStringDesc*)0;
							T82_ = (NimStringDesc*)0;
							T82_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*nArg)._kind_6.sons->data[((NI) 0)]);
							T81_ = rawNewString((T82_ ? T82_->Sup.len : 0) + 33);
appendString(T81_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_251));
appendString(T81_, T82_);
							candidates = resizeString(candidates, (T81_ ? T81_->Sup.len : 0) + 0);
appendString(candidates, T81_);
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 7):
						{
							candidates = resizeString(candidates, 52);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_252));
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 6):
						{
							candidates = resizeString(candidates, 23);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_253));
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 5):
						{
							NimStringDesc* T86_;
							T86_ = (NimStringDesc*)0;
							T86_ = rawNewString((nameParam ? nameParam->Sup.len : 0) + 22);
appendString(T86_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_254));
appendString(T86_, nameParam);
							candidates = resizeString(candidates, (T86_ ? T86_->Sup.len : 0) + 0);
appendString(candidates, T86_);
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 3):
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4):
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* wanted;
							NimStringDesc* T96_;
							NimStringDesc* T97_;
							{
								if (!!(!((nArg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))) goto LA90_;
								failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_255));
							}
							LA90_: ;
							wanted = (*(*err_3).firstMismatch.formal).typ;
							{
								if (!!(!(((*err_3).firstMismatch.formal == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))))) goto LA94_;
								failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_256));
							}
							LA94_: ;
							T96_ = (NimStringDesc*)0;
							T96_ = rawNewString((nameParam ? nameParam->Sup.len : 0) + 23);
appendString(T96_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_257));
appendString(T96_, nameParam);
appendString(T96_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_258));
							candidates = resizeString(candidates, (T96_ ? T96_->Sup.len : 0) + 0);
appendString(candidates, T96_);
							T97_ = (NimStringDesc*)0;
							T97_ = typeToString__QlvraUan7WbHowhAbvDvdA(wanted, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
							candidates = resizeString(candidates, (T97_ ? T97_->Sup.len : 0) + 0);
appendString(candidates, T97_);
							candidates = resizeString(candidates, 19);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_259));
							{
								NimStringDesc* T102_;
								if (!((*err_3).firstMismatch.kind == ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4))) goto LA100_;
								T102_ = (NimStringDesc*)0;
								T102_ = renderNotLValue__vfKkxNGxagsG9czCdz2IAEQ(nArg);
								candidates = resizeString(candidates, (T102_ ? T102_->Sup.len : 0) + 0);
appendString(candidates, T102_);
								candidates = resizeString(candidates, 25);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_260));
							}
							goto LA98_;
							LA100_: ;
							{
								NimStringDesc* T104_;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* got;
								NimStringDesc* T105_;
								T104_ = (NimStringDesc*)0;
								T104_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(nArg, 0);
								candidates = resizeString(candidates, (T104_ ? T104_->Sup.len : 0) + 0);
appendString(candidates, T104_);
								candidates = resizeString(candidates, 14);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_261));
								got = (*nArg).typ;
								T105_ = (NimStringDesc*)0;
								T105_ = typeToString__QlvraUan7WbHowhAbvDvdA(got, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
								candidates = resizeString(candidates, (T105_ ? T105_->Sup.len : 0) + 0);
appendString(candidates, T105_);
								{
									if (!!(!((wanted == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))))) goto LA108_;
									failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_262));
								}
								LA108_: ;
								{
									if (!!((got == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA112_;
									effectProblem__3uc8nf1Yi57kIzOPCNU9caA(wanted, got, (&candidates), c);
								}
								LA112_: ;
							}
							LA98_: ;
						}
						break;
						case ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 0):
						{
						}
						break;
						}
						candidates = resizeString(candidates, 1);
appendString(candidates, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_247));
						{
							NIM_BOOL T117_;
							NIM_BOOL T118_;
							T117_ = (NIM_BOOL)0;
							T118_ = (NIM_BOOL)0;
							T118_ = ((*err_3).firstMismatch.arg == ((NI) 1));
							if (!(T118_)) goto LA119_;
							T118_ = ((*nArg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
							LA119_: ;
							T117_ = T118_;
							if (!(T117_)) goto LA120_;
							T117_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26));
							LA120_: ;
							if (!T117_) goto LA121_;
							maybeWrongSpace = NIM_TRUE;
						}
						LA121_: ;
					}
					LA68_: ;
					{
						NimStringDesc** diag;
						NI i_6;
						NI L_4;
						NI T124_;
						diag = (NimStringDesc**)0;
						i_6 = ((NI) 0);
						T124_ = ((*err_3).diagnostics ? (*err_3).diagnostics->Sup.len : 0);
						L_4 = T124_;
						{
							while (1) {
								NimStringDesc* T127_;
								if (!(i_6 < L_4)) goto LA126;
								diag = (&(*err_3).diagnostics->data[i_6]);
								T127_ = (NimStringDesc*)0;
								T127_ = rawNewString(((*diag) ? (*diag)->Sup.len : 0) + 1);
appendString(T127_, (*diag));
appendString(T127_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_247));
								candidates = resizeString(candidates, (T127_ ? T127_->Sup.len : 0) + 0);
appendString(candidates, T127_);
								i_6 += ((NI) 1);
							} LA126: ;
						}
					}
					candidatesAll = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)(candidatesAll), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
					T128_ = candidatesAll->Sup.len++;
					T129_ = (NimStringDesc*)0;
					T129_ = candidatesAll->data[T128_]; candidatesAll->data[T128_] = copyStringRC1(candidates);
					if (T129_) nimGCunrefNoCycle(T129_);
				} LA38: ;
				i_5 += ((NI) 1);
			} LA37: ;
		}
	}
	sort__QeVk9c1PKgtuLn69cFZt89cSg(candidatesAll->data, (candidatesAll ? candidatesAll->Sup.len : 0), ((tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA) 1));
	candidates = nsuJoinSep(candidatesAll->data, (candidatesAll ? candidatesAll->Sup.len : 0), ((NimStringDesc*) NIM_NIL));
	{
		NimStringDesc* T134_;
		NimStringDesc* T135_;
		if (!(((NI) 0) < skipped)) goto LA132_;
		T134_ = (NimStringDesc*)0;
		T135_ = (NimStringDesc*)0;
		T135_ = nimIntToStr(skipped);
		T134_ = rawNewString((T135_ ? T135_->Sup.len : 0) + 97);
appendString(T134_, T135_);
appendString(T134_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_270));
		candidates = resizeString(candidates, (T134_ ? T134_->Sup.len : 0) + 0);
appendString(candidates, T134_);
	}
	LA132_: ;
	{
		NimStringDesc* T140_;
		NimStringDesc* T141_;
		if (!maybeWrongSpace) goto LA138_;
		T140_ = (NimStringDesc*)0;
		T141_ = (NimStringDesc*)0;
		T141_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 0)], 0);
		T140_ = rawNewString((T141_ ? T141_->Sup.len : 0) + 40);
appendString(T140_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_271));
appendString(T140_, T141_);
appendString(T140_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_272));
		candidates = resizeString(candidates, (T140_ ? T140_->Sup.len : 0) + 0);
appendString(candidates, T140_);
	}
	LA138_: ;
	colontmp__2 = prefer;
	colontmp__3 = copyString(candidates);
	(*Result).Field0 = colontmp__2;
	unsureAsgnRef((void**) (&(*Result).Field1), copyString(colontmp__3));
}
N_LIB_PRIVATE N_NIMCALL(void, notFoundError__3yYIcS0VQPQvrknpxFc7TQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__0dpGN6F4ocevqUQGsaf41w* errors) {
	tyTuple__ZtAk5YtH0VW1iPowvxePrg T12_;
	tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer;
	NimStringDesc* candidates;
	NimStringDesc* result;
	NimStringDesc* T13_;
	NimStringDesc* T19_;
	NimStringDesc* T20_;
{	{
		if (!((*(*(*c).graph).config).m.errorOutputs == 0)) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_29), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_244, NIM_FALSE);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		NimStringDesc* T10_;
		NimStringDesc* T11_;
		T7_ = (errors ? errors->Sup.len : 0);
		if (!(T7_ == ((NI) 0))) goto LA8_;
		T10_ = (NimStringDesc*)0;
		T10_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 0)], 0);
		T11_ = (NimStringDesc*)0;
		T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_245), T10_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_246, NIM_FALSE);
		goto BeforeRet_;
	}
	LA8_: ;
	nimZeroMem((void*)(&T12_), sizeof(tyTuple__ZtAk5YtH0VW1iPowvxePrg));
	presentFailedCandidates__DzsD9bOR72VurwdjRilOhmA(c, n, errors, (&T12_));
	prefer = (tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw)0;
	prefer = T12_.Field0;
	candidates = (NimStringDesc*)0;
	candidates = T12_.Field1;
	result = copyString(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_273));
	T13_ = (NimStringDesc*)0;
	T13_ = describeArgs__cCrxh8TxJsIrMINltM1ovw(c, n, ((NI) 1), prefer);
	result = resizeString(result, (T13_ ? T13_->Sup.len : 0) + 0);
appendString(result, T13_);
	result = addChar(result, 62);
	{
		NimStringDesc* T18_;
		if (!!(((candidates ? candidates->Sup.len : 0) == 0))) goto LA16_;
		T18_ = (NimStringDesc*)0;
		T18_ = rawNewString((candidates ? candidates->Sup.len : 0) + 23);
appendString(T18_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_274));
appendString(T18_, candidates);
		result = resizeString(result, (T18_ ? T18_->Sup.len : 0) + 0);
appendString(result, T18_);
	}
	LA16_: ;
	T19_ = (NimStringDesc*)0;
	T20_ = (NimStringDesc*)0;
	T20_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
	T19_ = rawNewString((result ? result->Sup.len : 0) + (T20_ ? T20_->Sup.len : 0) + 13);
appendString(T19_, result);
appendString(T19_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_275));
appendString(T19_, T20_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_276, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, bracketNotFoundError__NRIJDWZtATzMum7OEjYC2g_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tySequence__0dpGN6F4ocevqUQGsaf41w* errors;
	tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* symx;
	errors = NIM_NIL;
	nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
	headSymbol = (*n)._kind_6.sons->data[((NI) 0)];
	symx = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, headSymbol);
	{
		while (1) {
			if (!!((symx == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ T7_;
				NI T8_;
				if (!((520192 &((NU32)1<<((NU)((*symx).kind)&31U)))!=0)) goto LA5_;
				nimZeroMem((void*)(&T7_), sizeof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ));
				nimZeroMem((void*)(&T7_), sizeof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ));
				T7_.sym = symx;
				nimZeroMem((void*)(&T7_.firstMismatch), sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ));
				T7_.diagnostics = NIM_NIL;
				T7_.enabled = NIM_FALSE;
				errors = (tySequence__0dpGN6F4ocevqUQGsaf41w*) incrSeqV3((TGenericSeq*)(errors), (&NTI__0dpGN6F4ocevqUQGsaf41w_));
				T8_ = errors->Sup.len++;
				asgnRef((void**) (&errors->data[T8_].sym), T7_.sym);
				errors->data[T8_].firstMismatch.kind = T7_.firstMismatch.kind;
				errors->data[T8_].firstMismatch.arg = T7_.firstMismatch.arg;
				asgnRef((void**) (&errors->data[T8_].firstMismatch.formal), T7_.firstMismatch.formal);
				genericSeqAssign((&errors->data[T8_].diagnostics), T7_.diagnostics, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
				errors->data[T8_].enabled = T7_.enabled;
			}
			LA5_: ;
			symx = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
		} LA2: ;
	}
	{
		NI T11_;
		NimStringDesc* T14_;
		NimStringDesc* T15_;
		T11_ = (errors ? errors->Sup.len : 0);
		if (!(T11_ == ((NI) 0))) goto LA12_;
		T14_ = (NimStringDesc*)0;
		T15_ = (NimStringDesc*)0;
		T15_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
		T14_ = rawNewString((T15_ ? T15_->Sup.len : 0) + 19);
appendString(T14_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_242));
appendString(T14_, T15_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_243, NIM_FALSE);
	}
	goto LA9_;
	LA12_: ;
	{
		notFoundError__3yYIcS0VQPQvrknpxFc7TQ(c, n, errors);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrGet__vJZwz9bfROKrfrtM50y74CQ_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = semSubscript__vJZwz9bfROKrfrtM50y74CQ_9(c, result, flags);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T8_;
		if (!(result == 0)) goto LA6_;
		x = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		T8_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T8_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_26));
		asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T8_, (*n).info));
		bracketNotFoundError__NRIJDWZtATzMum7OEjYC2g_8(c, x);
		result = n;
	}
	LA6_: ;
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipAddr__7hiIf9cX1T4l9amfLkdHBowAast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrPut__vJZwz9bfROKrfrtM50y74CQ_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), (*n).info);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = skipAddr__7hiIf9cX1T4l9amfLkdHBowAast((*n)._kind_6.sons->data[((NI) 1)]);
	add__P8dDSotTW25BkfbyspojGg(b, T1_);
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T3_ - ((NI) 1));
		i_2 = ((NI) 2);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				add__P8dDSotTW25BkfbyspojGg(b, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), b);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), lastSon__UPSW0jLTX5qJL51YMUAHgw(n));
	result = semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, result, ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsgnOpr__7YxUILpPxooC5qqa89a54dw_18)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), (*n)._kind_6.sons->data[((NI) 1)]);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), (*n)._kind_6.sons->data[((NI) 2)]);
	result = semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, result, ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semShallowCopy__vJZwz9bfROKrfrtM50y74CQ_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 1)]);
		add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 2)]);
		result = semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, result, ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 0));
	}
	goto LA1_;
	LA4_: ;
	{
		result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIsPartOf__vJZwz9bfROKrfrtM50y74CQ_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyEnum_TAnalysisResult__p9a9bcrXoRmLT4eUuwrDq9b4w r;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	r = isPartOf__1otDDZAmvFsmbqPyFytXFg((*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 2)]);
	T1_ = toInt128__161i7kexvUAISxPtGBRWYw(r);
	result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T1_, n, (*c).graph);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, toNode__pidBpg4XuuDNdF3NVODN6A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), i, t);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getTypeDescNode__PDBS7GU6I7t8evrM8dmPkA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* resType;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	resType = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), sym);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(resType, typ, NIM_TRUE);
	result = toNode__pidBpg4XuuDNdF3NVODN6A(resType, info);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, uninstantiate__9cRlRlKvV58Tq3YoHJJi1Rw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	{
		result = t;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		result = base__PfgI9ap7WOnsRfFV4znQ27w(t);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	{
		result = uninstantiate__9cRlRlKvV58Tq3YoHJJi1Rw_2((*t).sons->data[((NI) 1)]);
	}
	break;
	default:
	{
		result = t;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalTypeTrait__J9a21UTKN4zETETiDQaaUMw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* traitCall, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* operand, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* context) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* trait;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* operand_2;
	NimStringDesc* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	trait = (*traitCall)._kind_6.sons->data[((NI) 0)];
	{
		NimStringDesc* argX60gensym3952_;
		if (!!(((*trait).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		argX60gensym3952_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_278);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3952_, TM__rF9caJawfOjYTjsgLVUSGFA_278);
	}
	LA3_: ;
	operand_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(operand, IL64(70368744177936));
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		NI T10_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*operand_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
		if (T7_) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(traitCall);
		T9_ = (((NI) 2) < T10_);
		if (!(T9_)) goto LA11_;
		T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T12_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*traitCall)._kind_6.sons->data[((NI) 2)]).typ, 256);
		T9_ = ((*T12_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
		LA11_: ;
		T7_ = T9_;
		LA8_: ;
		if (!T7_) goto LA13_;
		result = traitCall;
		goto BeforeRet_;
	}
	LA13_: ;
	s = (*(*(*trait)._kind_4.sym).name).s;
	switch (hashString(s) & 15) {
	case 0: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_284))) goto LA19_;
break;
	case 1: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_286))) goto LA21_;
break;
	case 3: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_42))) goto LA15_;
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_285))) goto LA20_;
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_289))) goto LA24_;
break;
	case 4: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_283))) goto LA19_;
break;
	case 5: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_281))) goto LA17_;
break;
	case 7: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_282))) goto LA18_;
break;
	case 9: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_291))) goto LA26_;
break;
	case 10: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_279))) goto LA15_;
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_290))) goto LA25_;
break;
	case 11: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_288))) goto LA23_;
break;
	case 13: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_287))) goto LA22_;
break;
	case 14: 
if (eqStrings(s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_280))) goto LA16_;
break;
	}
	goto LA27_;
	LA15_: ;
	{
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T30_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
		T30_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T30_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 2);
		asgnRef((void**) (&T30_->data[0]), operand_2);
		asgnRef((void**) (&T30_->data[1]), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*traitCall)._kind_6.sons->data[((NI) 2)]).typ, 256));
		T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T31_ = newTypeWithSons__aSykZlHQuGR9almJ1ehcUew(context, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57), T30_);
		result = toNode__pidBpg4XuuDNdF3NVODN6A(T31_, (*traitCall).info);
		goto BeforeRet_;
	}
	goto LA28_;
	LA16_: ;
	{
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T33_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T34_;
		T33_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T33_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 2);
		asgnRef((void**) (&T33_->data[0]), operand_2);
		asgnRef((void**) (&T33_->data[1]), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*traitCall)._kind_6.sons->data[((NI) 2)]).typ, 256));
		T34_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T34_ = newTypeWithSons__aSykZlHQuGR9almJ1ehcUew(context, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56), T33_);
		result = toNode__pidBpg4XuuDNdF3NVODN6A(T34_, (*traitCall).info);
		goto BeforeRet_;
	}
	goto LA28_;
	LA17_: ;
	{
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T36_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
		T36_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T36_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
		asgnRef((void**) (&T36_->data[0]), operand_2);
		T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T37_ = newTypeWithSons__aSykZlHQuGR9almJ1ehcUew(context, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58), T36_);
		result = toNode__pidBpg4XuuDNdF3NVODN6A(T37_, (*traitCall).info);
		goto BeforeRet_;
	}
	goto LA28_;
	LA18_: ;
	{
		tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer;
		NimStringDesc* T44_;
		prefer = ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 5);
		{
			NI T41_;
			NimStringDesc* preferStr;
			T41_ = (NI)0;
			T41_ = len__P89cqdlERShb9alU3iC0yj8wast(traitCall);
			if (!(((NI) 2) <= T41_)) goto LA42_;
			preferStr = (*(*traitCall)._kind_6.sons->data[((NI) 2)])._kind_3.strVal;
			prefer = parseEnum__ASE7k7bSFM18MJ5iPda8rQ(preferStr);
		}
		LA42_: ;
		T44_ = (NimStringDesc*)0;
		T44_ = typeToString__QlvraUan7WbHowhAbvDvdA(operand_2, prefer);
		result = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), T44_);
		asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*(*traitCall)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
		(*result).info = (*traitCall).info;
	}
	goto LA28_;
	LA19_: ;
	{
		NimStringDesc* T46_;
		T46_ = (NimStringDesc*)0;
		T46_ = typeToString__QlvraUan7WbHowhAbvDvdA(operand_2, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 5));
		result = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), T46_);
		asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*(*traitCall)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
		(*result).info = (*traitCall).info;
	}
	goto LA28_;
	LA20_: ;
	{
		NI T48_;
		T48_ = (NI)0;
		T48_ = len__5mJADrRYkP3r9auuiuDZN9cQast(operand_2);
		result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) ((NI)(T48_ - ((*operand_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25))))));
		asgnRef((void**) (&(*result).typ), newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), context));
		(*result).info = (*traitCall).info;
	}
	goto LA28_;
	LA21_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arg;
		arg = operand_2;
		switch ((*arg).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T51_;
			T51_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T51_ = base__PfgI9ap7WOnsRfFV4znQ27w(arg);
			result = getTypeDescNode__PDBS7GU6I7t8evrM8dmPkA(T51_, (*operand_2).owner, (*traitCall).info);
		}
		break;
		default:
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T53_;
			NimStringDesc* T54_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T55_;
			nimZeroMem((void*)T53_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T53_[0] = toHumanStr__8clA3iQh1Lbc5cnapppbXQ((*arg).kind);
			T53_[1] = typeToString__QlvraUan7WbHowhAbvDvdA(operand_2, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T54_ = (NimStringDesc*)0;
			T54_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_292), T53_, 2);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*traitCall).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T54_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_293, NIM_FALSE);
			T55_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T55_ = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), context);
			result = toNode__pidBpg4XuuDNdF3NVODN6A(T55_, (*traitCall).info);
		}
		break;
		}
	}
	goto LA28_;
	LA22_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T57_;
		T57_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T57_ = uninstantiate__9cRlRlKvV58Tq3YoHJJi1Rw_2(operand_2);
		result = toNode__pidBpg4XuuDNdF3NVODN6A(T57_, (*traitCall).info);
	}
	goto LA28_;
	LA23_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		NIM_BOOL complexObj;
		NIM_BOOL T59_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T61_;
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(operand_2, IL64(36239903259887632));
		T59_ = (NIM_BOOL)0;
		T59_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(t);
		if (T59_) goto LA60_;
		T59_ = !(((IL64(2147483664) & (*t).flags) == 0));
		LA60_: ;
		complexObj = T59_;
		T61_ = toInt128__161i7kexvUAISxPtGBRWYw(!(complexObj));
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T61_, traitCall, (*c).graph);
	}
	goto LA28_;
	LA24_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* operand_3;
		NIM_BOOL cond;
		NIM_BOOL T63_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T65_;
		operand_3 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(operand_2, 2048);
		T63_ = (NIM_BOOL)0;
		T63_ = ((*operand_3).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
		if (!(T63_)) goto LA64_;
		T63_ = !(((*operand_3).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA64_: ;
		cond = T63_;
		T65_ = toInt128__161i7kexvUAISxPtGBRWYw(cond);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T65_, traitCall, (*c).graph);
	}
	goto LA28_;
	LA25_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* operand_4;
		NI T67_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T68_;
		operand_4 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(operand_2, 2048);
		T67_ = (NI)0;
		T67_ = len__5mJADrRYkP3r9auuiuDZN9cQast(operand_4);
		T68_ = toInt128__161i7kexvUAISxPtGBRWYw(T67_);
		result = newIntNodeT__NzFGf0r9bOfRvVQjkvApbgQ(T68_, traitCall, (*c).graph);
	}
	goto LA28_;
	LA26_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arg_2;
		arg_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(operand_2, 2048);
		{
			if (!((*arg_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13))) goto LA72_;
			{
				while (1) {
					if (!((*arg_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13))) goto LA75;
					arg_2 = base__PfgI9ap7WOnsRfFV4znQ27w(arg_2);
					arg_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(arg_2, IL64(70368744179984));
				} LA75: ;
			}
			result = getTypeDescNode__PDBS7GU6I7t8evrM8dmPkA(arg_2, (*operand_2).owner, (*traitCall).info);
		}
		goto LA70_;
		LA72_: ;
		{
			NimStringDesc* T77_;
			NimStringDesc* T78_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T79_;
			T77_ = (NimStringDesc*)0;
			T78_ = (NimStringDesc*)0;
			T78_ = typeToString__QlvraUan7WbHowhAbvDvdA(operand_2, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T77_ = rawNewString((T78_ ? T78_->Sup.len : 0) + 69);
appendString(T77_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_294));
appendString(T77_, T78_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*traitCall).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T77_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_295, NIM_FALSE);
			T79_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T79_ = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), context);
			result = toNode__pidBpg4XuuDNdF3NVODN6A(T79_, (*traitCall).info);
		}
		LA70_: ;
	}
	goto LA28_;
	LA27_: ;
	{
		NimStringDesc* T81_;
		T81_ = (NimStringDesc*)0;
		T81_ = rawNewString((s ? s->Sup.len : 0) + 15);
appendString(T81_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_296));
appendString(T81_, s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*traitCall).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T81_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_297, NIM_FALSE);
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*traitCall).info);
	}
	LA28_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeTraits__7YxUILpPxooC5qqa89a54dw_19)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
	t = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
	{
		NIM_BOOL T3_;
		NimStringDesc* argX60gensym3988_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		argX60gensym3988_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_277);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3988_, TM__rF9caJawfOjYTjsgLVUSGFA_277);
	}
	LA5_: ;
	{
		NI T9_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
		T9_ = (NI)0;
		T9_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		if (!(((NI) 0) < T9_)) goto LA10_;
		T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T12_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		result = evalTypeTrait__J9a21UTKN4zETETiDQaaUMw(c, n, t, T12_);
	}
	goto LA7_;
	LA10_: ;
	{
		result = n;
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__a4cQxFar9atOGMK9b4U0EEVA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (NI)0;
	x = (*c).semConstExpr(c, n);
	switch ((*x).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
	{
		result = ((NI) ((*x)._kind_1.intVal));
	}
	break;
	default:
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_298), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_299, NIM_FALSE);
	}
	break;
	}
	return result;
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semInstantiationInfo__7YxUILpPxooC5qqa89a54dw_20)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI idx;
	NI useFullPaths;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* filename;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* line;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T22_;
	NI T23_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* column;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
	NI T25_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T26_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T28_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T30_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160), (*n).info, (*n).typ);
	idx = expectIntLit__a4cQxFar9atOGMK9b4U0EEVA(c, (*n)._kind_6.sons->data[((NI) 1)]);
	useFullPaths = expectIntLit__a4cQxFar9atOGMK9b4U0EEVA(c, (*n)._kind_6.sons->data[((NI) 2)]);
	info = getInfoContext__TXxF2CG3kwLqptPWf0kC9aQ((*(*c).graph).config, idx);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
	filename = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*n).info, T1_);
	{
		if (!!((useFullPaths == ((NI) 0)))) goto LA4_;
		asgnRef((void**) (&(*filename)._kind_3.strVal), toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*c).graph).config, info.fileIndex));
	}
	goto LA2_;
	LA4_: ;
	{
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = (info.fileIndex < ((NI32) 0));
			if (T9_) goto LA10_;
			T9_ = ((*(*c).graph).config == ((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL));
			LA10_: ;
			if (!T9_) goto LA11_;
			{
				NimStringDesc* T17_;
				if (!(info.fileIndex == ((NI32) -3))) goto LA15_;
				T17_ = (NimStringDesc*)0;
				T17_ = (*filename)._kind_3.strVal; (*filename)._kind_3.strVal = copyStringRC1(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_300));
				if (T17_) nimGCunrefNoCycle(T17_);
			}
			goto LA13_;
			LA15_: ;
			{
				NimStringDesc* T19_;
				T19_ = (NimStringDesc*)0;
				T19_ = (*filename)._kind_3.strVal; (*filename)._kind_3.strVal = copyStringRC1(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_301));
				if (T19_) nimGCunrefNoCycle(T19_);
			}
			LA13_: ;
		}
		goto LA7_;
		LA11_: ;
		{
			NimStringDesc* T21_;
			T21_ = (NimStringDesc*)0;
			T21_ = (*filename)._kind_3.strVal; (*filename)._kind_3.strVal = copyStringRC1((*(*(*c).graph).config).m.fileInfos->data[info.fileIndex].shortName);
			if (T21_) nimGCunrefNoCycle(T21_);
		}
		LA7_: ;
	}
	LA2_: ;
	T22_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T22_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	line = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), (*n).info, T22_);
	T23_ = (NI)0;
	T23_ = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs(info);
	(*line)._kind_1.intVal = ((NI64) (T23_));
	T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T24_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	column = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), (*n).info, T24_);
	T25_ = (NI)0;
	T25_ = toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs(info);
	(*column)._kind_1.intVal = ((NI64) (T25_));
	nimZeroMem((void*)T26_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T26_[0] = (*(*(*n).typ).n)._kind_6.sons->data[((NI) 0)];
	T26_[1] = filename;
	T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T27_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34), T26_, 2);
	add__P8dDSotTW25BkfbyspojGg(result, T27_);
	nimZeroMem((void*)T28_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T28_[0] = (*(*(*n).typ).n)._kind_6.sons->data[((NI) 1)];
	T28_[1] = line;
	T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T29_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34), T28_, 2);
	add__P8dDSotTW25BkfbyspojGg(result, T29_);
	nimZeroMem((void*)T30_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T30_[0] = (*(*(*n).typ).n)._kind_6.sons->data[((NI) 2)];
	T30_[1] = column;
	T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T31_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34), T30_, 2);
	add__P8dDSotTW25BkfbyspojGg(result, T31_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOrd__7YxUILpPxooC5qqa89a54dw_21)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* parType;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	parType = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(parType, NIM_TRUE);
		if (!T3_) goto LA4_;
	}
	goto LA1_;
	LA4_: ;
	{
		NI64 a;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
		NI64 b;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T10_;
		if (!((*parType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19))) goto LA7_;
		T9_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, parType);
		a = toInt64__1szweXXq3RBN50owrYu2Xw(T9_);
		T10_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, parType);
		b = toInt64__1szweXXq3RBN50owrYu2Xw(T10_);
		asgnRef((void**) (&(*result).typ), makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, a, b, (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	}
	goto LA1_;
	LA7_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_303, NIM_FALSE);
		asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOf__7YxUILpPxooC5qqa89a54dw_22)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 0));
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 2)], 256));
		a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087638309136));
		b = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 2)]).typ, IL64(36275087638309136));
		x = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087638308880));
		y = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 2)]).typ, IL64(36275087638308880));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((*x).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			if (T8_) goto LA9_;
			T8_ = !(((*y).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
			LA9_: ;
			if (!T8_) goto LA10_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_304), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_305, NIM_FALSE);
		}
		goto LA6_;
		LA10_: ;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = !(((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)));
			if (T13_) goto LA14_;
			T13_ = !(((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)));
			LA14_: ;
			if (!T13_) goto LA15_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_304), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_306, NIM_FALSE);
		}
		goto LA6_;
		LA15_: ;
		{
			NI diff;
			diff = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(a, b);
			{
				NimStringDesc* T22_;
				if (!(diff <= ((NI) 0))) goto LA20_;
				T22_ = (NimStringDesc*)0;
				T22_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 67), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_307, NIM_FALSE);
				result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(1));
				(*result).info = (*n).info;
				asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
				goto BeforeRet_;
			}
			goto LA18_;
			LA20_: ;
			{
				if (!(diff == ((NI) IL64(9223372036854775807)))) goto LA24_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
					NimStringDesc* T31_;
					NimStringDesc* T32_;
					T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T28_ = commonSuperclass__CFsXKWHnV1O9asJrtw08whA(a, b);
					if (!(T28_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA29_;
					T31_ = (NimStringDesc*)0;
					T31_ = typeToString__QlvraUan7WbHowhAbvDvdA(a, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T32_ = (NimStringDesc*)0;
					T32_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_308), T31_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_309, NIM_FALSE);
				}
				goto LA26_;
				LA29_: ;
				{
					NimStringDesc* T34_;
					T34_ = (NimStringDesc*)0;
					T34_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 68), T34_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_310, NIM_FALSE);
					result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
					(*result).info = (*n).info;
					asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
				}
				LA26_: ;
			}
			goto LA18_;
			LA24_: ;
			LA18_: ;
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_311), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_312, NIM_FALSE);
	}
	LA1_: ;
	asgnRef((void**) (&(*n).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	result = n;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLowHigh__7e8kUc3a9a4gEAcnG7wUcyQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		NimStringDesc* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 2)))) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_313), opToStr__x47hvY2ezR4p9cvQjupSCVQ[(m)- 8]);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_316, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 256));
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(45141549399451920));
		switch ((*typ).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		{
			asgnRef((void**) (&(*n).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		{
			asgnRef((void**) (&(*n).typ), (*typ).sons->data[((NI) 0)]);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
		{
			asgnRef((void**) (&(*n).typ), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, 256));
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
			T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T12_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
			asgnRef((void**) (&(*n).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T12_));
		}
		break;
		default:
		{
			NimStringDesc* T14_;
			T14_ = (NimStringDesc*)0;
			T14_ = rawNewString((opToStr__x47hvY2ezR4p9cvQjupSCVQ[(m)- 8] ? opToStr__x47hvY2ezR4p9cvQjupSCVQ[(m)- 8]->Sup.len : 0) + 22);
appendString(T14_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_317));
appendString(T14_, opToStr__x47hvY2ezR4p9cvQjupSCVQ[(m)- 8]);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_318, NIM_FALSE);
		}
		break;
		}
	}
	LA1_: ;
	result = n;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeProc__Ye2MiAptq3GrXxTQeyXNeA_2ast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((12288 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBindSym__7YxUILpPxooC5qqa89a54dw_23)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sl;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* isMixin;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* id;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T13_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 0)]);
	sl = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[((NI) 1)]);
	{
		if (!!(((*sl).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) || (*sl).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21) || (*sl).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_319), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_320, NIM_FALSE);
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		goto BeforeRet_;
	}
	LA3_: ;
	isMixin = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[((NI) 2)]);
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = !(((*isMixin).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)));
		if (T8_) goto LA9_;
		T8_ = ((*isMixin)._kind_1.intVal < IL64(0));
		LA9_: ;
		T7_ = T8_;
		if (T7_) goto LA10_;
		T7_ = (IL64(2) < (*isMixin)._kind_1.intVal);
		LA10_: ;
		if (!T7_) goto LA11_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 2)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_322, NIM_FALSE);
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		goto BeforeRet_;
	}
	LA11_: ;
	T13_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T13_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, (*sl)._kind_3.strVal);
	id = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T13_, (*n).info);
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, id, 2);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sc;
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
		sc = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, id, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) ((*isMixin)._kind_1.intVal)), NIM_FALSE);
		{
			NIM_BOOL T20_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T22_;
			T20_ = (NIM_BOOL)0;
			T20_ = (((NI) 0) < (*c).inStaticContext);
			if (T20_) goto LA21_;
			T22_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T22_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
			T20_ = isCompileTimeProc__Ye2MiAptq3GrXxTQeyXNeA_2ast(T22_);
			LA21_: ;
			if (!!(T20_)) goto LA23_;
			result = sc;
			goto BeforeRet_;
		}
		LA23_: ;
		add__P8dDSotTW25BkfbyspojGg(result, sc);
	}
	goto LA14_;
	LA16_: ;
	{
		errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*(*n)._kind_6.sons->data[((NI) 1)]).info, (*sl)._kind_3.strVal);
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__IqGNbqKVyQ9b9an5n9bN8QJsQ)(void* p, NI op) {
	tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg* a;
	a = (tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*)p;
	nimGCvisit((void*)(*a).c1, op);
	nimGCvisit((void*)(*a).scope2, op);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, opBindSym__WI1aMJFzyk8ggPo9bdhAVJw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI isMixin, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* id;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* tmpScope;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*info).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_325), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_326, NIM_FALSE);
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (isMixin < ((NI) 0));
		if (T7_) goto LA8_;
		T7_ = (((NI) 2) < isMixin);
		LA8_: ;
		if (!T7_) goto LA9_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*info).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_327, NIM_FALSE);
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		goto BeforeRet_;
	}
	LA9_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA13_;
		id = n;
	}
	goto LA11_;
	LA13_: ;
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T16_;
		T16_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T16_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, (*n)._kind_3.strVal);
		id = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T16_, (*info).info);
	}
	LA11_: ;
	tmpScope = (*c).currentScope;
	asgnRef((void**) (&(*c).currentScope), scope);
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, id, 2);
	{
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA19_;
		result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, id, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) (isMixin)), NIM_FALSE);
	}
	goto LA17_;
	LA19_: ;
	{
		NimStringDesc* T22_;
		T22_ = (NimStringDesc*)0;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA25_;
			T22_ = copyString((*(*n)._kind_5.ident).s);
		}
		goto LA23_;
		LA25_: ;
		{
			T22_ = copyString((*n)._kind_3.strVal);
		}
		LA23_: ;
		errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*info).info, T22_);
	}
	LA17_: ;
	asgnRef((void**) (&(*c).currentScope), tmpScope);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, bindSymWrapper__Yigy4cCtqH652LhibVuvOA)(tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* a, void* ClE_0) {
	tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg* colonenvP_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	NI64 T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T4_;
	colonenvP_ = (tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*) ClE_0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = getNode__DuJnnnM0aSaXeDv118rkUw(a, ((NI) 0));
	T2_ = (NI64)0;
	T2_ = getInt__VJ5Unk9bDoOAoLiZLdhb9b1Q(a, ((NI) 1));
	T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T3_ = getNode__DuJnnnM0aSaXeDv118rkUw(a, ((NI) 2));
	T4_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T4_ = opBindSym__WI1aMJFzyk8ggPo9bdhAVJw((*colonenvP_).c1, (*colonenvP_).scope2, T1_, ((NI) (T2_)), T3_);
	setResult__Adyk89aSgmLp9bDuSV0Va03A(a, T4_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDynamicBindSym__7YxUILpPxooC5qqa89a54dw_24)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg* colonenv_;
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* vm;
	NI idx;
	tyProc__5QC9cKfPJmKuW0XbCTd8ylA T12_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idxNode;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T13_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	colonenv_ = (tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*)0;
	colonenv_ = (tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*) newObj((&NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_), sizeof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg));
	(*colonenv_).Sup.m_type = (&NTI__LF0eKAnygFo4etNDdpTetg_);
	asgnRef((void**) (&(*colonenv_).c1), c);
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (*(*colonenv_).c1).inStaticContext);
		if (T3_) goto LA4_;
		T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T5_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w((*colonenv_).c1);
		T3_ = isCompileTimeProc__Ye2MiAptq3GrXxTQeyXNeA_2ast(T5_);
		LA4_: ;
		if (!!(T3_)) goto LA6_;
		result = semBindSym__7YxUILpPxooC5qqa89a54dw_23((*colonenv_).c1, n);
		goto BeforeRet_;
	}
	LA6_: ;
	{
		if (!((*(*(*colonenv_).c1).graph).vm == 0)) goto LA10_;
		setupGlobalCtx__41qwP9bj6cfy3VehAu9aAFvw((*(*colonenv_).c1).module, (*(*colonenv_).c1).graph);
	}
	LA10_: ;
	vm = (*((tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw**) (&((*(*(*colonenv_).c1).graph).vm))));
	asgnRef((void**) (&(*colonenv_).scope2), (*(*colonenv_).c1).currentScope);
	nimZeroMem((void*)(&T12_), sizeof(tyProc__5QC9cKfPJmKuW0XbCTd8ylA));
	T12_.ClP_0 = bindSymWrapper__Yigy4cCtqH652LhibVuvOA; T12_.ClE_0 = colonenv_;
	idx = registerCallback__KnNoqgKj9bmG2p3f4SLNFqA(vm, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_324), T12_);
	nimZeroMem((void*)(&T13_), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T14_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*(*colonenv_).c1).graph, T13_, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	idxNode = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(((NI64) (idx)), T14_);
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					x = (*n)._kind_6.sons->data[i];
					add__P8dDSotTW25BkfbyspojGg(result, x);
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
	}
	add__P8dDSotTW25BkfbyspojGg(result, n);
	add__P8dDSotTW25BkfbyspojGg(result, idxNode);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, whereToBindTypeHook__ZcD0zNCGO9bcEV34hRXFEJA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = t;
	{
		while (1) {
			{
				if (!((3072 &((NU64)1<<((NU)((*result).kind)&63U)))!=0)) goto LA5_;
				result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
			}
			goto LA3_;
			LA5_: ;
			{
				if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA8_;
				result = (*result).sons->data[((NI) 0)];
			}
			goto LA3_;
			LA8_: ;
			{
				goto LA1;
			}
			LA3_: ;
		}
	} LA1: ;
	{
		if (!((285351936 &((NU64)1<<((NU)((*result).kind)&63U)))!=0)) goto LA13_;
		result = canonType__ZcD0zNCGO9bcEV34hRXFEJA(c, result);
	}
	LA13_: ;
	return result;
}
static N_NIMCALL(void, Marker_tyRef__NaDYkbcAjZXYRP9arR0vzYg)(void* p, NI op) {
	tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg* a;
	a = (tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*)p;
	nimGCvisit((void*)(*a).orig1, op);
}
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transform__jpL3B9a76sXjWDD2lkGF2ew)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* procSym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fresh, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam, void* ClE_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg* colonenvP_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	colonenvP_ = (tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*) ClE_0;
	result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameTypeOrNil__3isNyHKb0U1OCnClmflXSg_2((*n).typ, old, 0);
		if (!T3_) goto LA4_;
		asgnRef((void**) (&(*result).typ), fresh);
	}
	LA4_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA8_;
		{
			if (!((*n)._kind_4.sym == oldParam)) goto LA12_;
			asgnRef((void**) (&(*result)._kind_4.sym), newParam);
		}
		goto LA10_;
		LA12_: ;
		{
			if (!((*(*n)._kind_4.sym).owner == (*colonenvP_).orig1)) goto LA15_;
			asgnRef((void**) (&(*result)._kind_4.sym), copySym__lIu8wX6Beq6dBJgESOFFjg((*n)._kind_4.sym));
			asgnRef((void**) (&(*(*result)._kind_4.sym).owner), procSym);
		}
		goto LA10_;
		LA15_: ;
		LA10_: ;
	}
	LA8_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyProc__ZB008LFGdRYy2vj1OH1xuQ T20_;
				if (!(i_2 < colontmp_)) goto LA19;
				i = i_2;
				nimZeroMem((void*)(&T20_), sizeof(tyProc__ZB008LFGdRYy2vj1OH1xuQ));
				T20_.ClP_0 = transform__jpL3B9a76sXjWDD2lkGF2ew; T20_.ClE_0 = colonenvP_;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), T20_.ClE_0? T20_.ClP_0(procSym, (*n)._kind_6.sons->data[i], old, fresh, oldParam, newParam, T20_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_335)(T20_.ClP_0))(procSym, (*n)._kind_6.sons->data[i], old, fresh, oldParam, newParam));
				i_2 += ((NI) 1);
			} LA19: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, turnFinalizerIntoDestructor__ZI4mbm59aB4PCl4xGhxV09bw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg* colonenv_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origParamType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* newParamType;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldParam;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newParam;
	tyProc__ZB008LFGdRYy2vj1OH1xuQ T2_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	colonenv_ = (tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*)0;
	colonenv_ = (tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*) newObj((&NTI__NaDYkbcAjZXYRP9arR0vzYg_), sizeof(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg));
	(*colonenv_).Sup.m_type = (&NTI__UaUb9bgQbqCS7gyXItZuJNg_);
	asgnRef((void**) (&(*colonenv_).orig1), orig);
	result = copySym__lIu8wX6Beq6dBJgESOFFjg((*colonenv_).orig1);
	(*result).info = info;
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
	asgnRef((void**) (&(*result).owner), (*colonenv_).orig1);
	origParamType = (*(*(*colonenv_).orig1).typ).sons->data[((NI) 1)];
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(origParamType, IL64(36275087638309136));
	newParamType = makeVarType__1XhuXEO6E22P9aDkvWkNrHQ(result, T1_, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
	oldParam = (*(*(*(*(*colonenv_).orig1).typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	newParam = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), (*oldParam).name, result, (*result).info, 0);
	asgnRef((void**) (&(*newParam).typ), newParamType);
	nimZeroMem((void*)(&T2_), sizeof(tyProc__ZB008LFGdRYy2vj1OH1xuQ));
	T2_.ClP_0 = transform__jpL3B9a76sXjWDD2lkGF2ew; T2_.ClE_0 = colonenv_;
	asgnRef((void**) (&(*result).ast), T2_.ClE_0? T2_.ClP_0(result, (*(*colonenv_).orig1).ast, origParamType, newParamType, oldParam, newParam, T2_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_336)(T2_.ClP_0))(result, (*(*colonenv_).orig1).ast, origParamType, newParamType, oldParam, newParam));
	asgnRef((void**) (&(*result).typ), newProcType__9bgJAAoskVeu3l1AHMmz9adg((*result).info, result));
	addParam__MnxL8SpIj0v6dB7M1prhCw((*result).typ, newParam);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, unownedType__ZcD0zNCGO9bcEV34hRXFEJA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* elems;
		NI T2_;
		NIM_BOOL someChange;
		T2_ = (NI)0;
		T2_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		elems = newSeq__g2qIn6210g4boJ9cN37Mg3Q(((NI) (T2_)));
		someChange = NIM_FALSE;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					asgnRef((void**) (&elems->data[i]), unownedType__ZcD0zNCGO9bcEV34hRXFEJA_3(c, (*t).sons->data[i]));
					{
						if (!!((elems->data[i] == (*t).sons->data[i]))) goto LA8_;
						someChange = NIM_TRUE;
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
		{
			if (!someChange) goto LA12_;
			result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), (*t).owner);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** e;
				NI i_3;
				NI L;
				NI T15_;
				e = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i_3 = ((NI) 0);
				T15_ = (elems ? elems->Sup.len : 0);
				L = T15_;
				{
					while (1) {
						if (!(i_3 < L)) goto LA17;
						e = &elems->data[i_3];
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, (*e), NIM_TRUE);
						i_3 += ((NI) 1);
					} LA17: ;
				}
			}
		}
		goto LA10_;
		LA12_: ;
		{
			result = t;
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		result = (*t).sons->data[((NI) 0)];
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b;
		NI T21_;
		T21_ = (NI)0;
		T21_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		b = unownedType__ZcD0zNCGO9bcEV34hRXFEJA_3(c, (*t).sons->data[(NI)(T21_ - ((NI) 1))]);
		{
			NI T24_;
			NI T27_;
			T24_ = (NI)0;
			T24_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			if (!!((b == (*t).sons->data[(NI)(T24_ - ((NI) 1))]))) goto LA25_;
			result = copyType__4O4aYoscFPo2FRSh4rP9ayg(t, (*t).owner, NIM_FALSE);
			T27_ = (NI)0;
			T27_ = len__5mJADrRYkP3r9auuiuDZN9cQast(result);
			asgnRef((void**) (&(*result).sons->data[(NI)(T27_ - ((NI) 1))]), b);
			(*result).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63));
		}
		goto LA22_;
		LA25_: ;
		{
			result = t;
		}
		LA22_: ;
	}
	break;
	default:
	{
		result = t;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semUnown__7YxUILpPxooC5qqa89a54dw_25)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[((NI) 1)]);
	asgnRef((void**) (&(*result).typ), unownedType__ZcD0zNCGO9bcEV34hRXFEJA_3(c, (*result).typ));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semQuantifier__7YxUILpPxooC5qqa89a54dw_26)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* args;
	NI T24_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T26_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg((*n).kind, (*n).info, (*n).typ);
	add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 0)]);
	args = (*n)._kind_6.sons->data[((NI) 1)];
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(args);
		colontmp_ = (NI)(T3_ - ((NI) 2));
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				NIM_BOOL valid;
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				it = (*args)._kind_6.sons->data[i];
				valid = NIM_FALSE;
				{
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* op;
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29))) goto LA8_;
					op = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*it)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* domain;
						tyArray__T6RKPw8xfAeNaoei9aZGzXg T18_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
						if (!((*op).Sup.id == ((NI) 31))) goto LA12_;
						v = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21), (*it)._kind_6.sons->data[((NI) 1)], c);
						{
							if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA16_;
							nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*v).info, v, (*v).kind);
						}
						LA16_: ;
						domain = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*it)._kind_6.sons->data[((NI) 2)], 2);
						asgnRef((void**) (&(*v).typ), (*domain).typ);
						valid = NIM_TRUE;
						addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, v);
						nimZeroMem((void*)T18_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
						T18_[0] = (*it)._kind_6.sons->data[((NI) 0)];
						T18_[1] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
						T18_[2] = domain;
						T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T19_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29), T18_, 3);
						add__P8dDSotTW25BkfbyspojGg(result, T19_);
					}
					LA12_: ;
				}
				LA8_: ;
				{
					if (!!(valid)) goto LA22_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_337), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_338, NIM_FALSE);
				}
				LA22_: ;
				res += ((NI) 1);
			} LA5: ;
		}
	}
	T24_ = (NI)0;
	T24_ = len__P89cqdlERShb9alU3iC0yj8wast(args);
	T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T25_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*args)._kind_6.sons->data[(NI)(T24_ - ((NI) 1))], 0);
	T26_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T26_ = forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T25_);
	add__P8dDSotTW25BkfbyspojGg(result, T26_);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOld__7YxUILpPxooC5qqa89a54dw_27)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]);
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		if (T7_) goto LA8_;
		T7_ = !(((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3)));
		LA8_: ;
		if (!T7_) goto LA9_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_339), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_340, NIM_FALSE);
	}
	goto LA5_;
	LA9_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
		NimStringDesc* T15_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T16_;
		T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T12_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		if (!!(((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).owner == T12_))) goto LA13_;
		T15_ = (NimStringDesc*)0;
		T16_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T16_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		T15_ = rawNewString(((*(*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).name).s ? (*(*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).name).s->Sup.len : 0) + ((*(*T16_).name).s ? (*(*T16_).name).s->Sup.len : 0) + 20);
appendString(T15_, (*(*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).name).s);
appendString(T15_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_341));
appendString(T15_, (*(*T16_).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_342, NIM_FALSE);
	}
	goto LA5_;
	LA13_: ;
	LA5_: ;
	result = n;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, magicsAfterOverloadResolution__vJZwz9bfROKrfrtM50y74CQ_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 16):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		result = n;
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semAddrArg__kiPmghV1gaPm718CtGyhQw(c, (*n)._kind_6.sons->data[((NI) 1)], eqStrings((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_227))));
		asgnRef((void**) (&(*result).typ), makePtrType__PDWeh9cjpi22xXdNggYvsWA(c, (*(*result)._kind_6.sons->data[((NI) 1)]).typ));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18):
	{
		result = semTypeOf__7YxUILpPxooC5qqa89a54dw_15(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 10):
	{
		tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym4120_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym4120_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym4120_;
		NI64 sizeX60gensym4120_;
		configX60gensym4120_ = (*(*c).graph).config;
		nodeX60gensym4120_ = n;
		typX60gensym4120_ = (*(*nodeX60gensym4120_)._kind_6.sons->data[((NI) 1)]).typ;
		computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym4120_, typX60gensym4120_);
		sizeX60gensym4120_ = (*typX60gensym4120_).size;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resX60gensym4120_;
			if (!(IL64(0) <= sizeX60gensym4120_)) goto LA6_;
			resX60gensym4120_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), sizeX60gensym4120_);
			(*resX60gensym4120_).info = (*nodeX60gensym4120_).info;
			asgnRef((void**) (&(*resX60gensym4120_).typ), (*nodeX60gensym4120_).typ);
			result = resX60gensym4120_;
		}
		goto LA4_;
		LA6_: ;
		{
			result = n;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 11):
	{
		tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym4124_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym4124_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym4124_;
		NI16 alignX60gensym4124_;
		configX60gensym4124_ = (*(*c).graph).config;
		nodeX60gensym4124_ = n;
		typX60gensym4124_ = (*(*nodeX60gensym4124_)._kind_6.sons->data[((NI) 1)]).typ;
		computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym4124_, typX60gensym4124_);
		alignX60gensym4124_ = (*typX60gensym4124_).align;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resX60gensym4124_;
			if (!(((NI16) 0) <= alignX60gensym4124_)) goto LA12_;
			resX60gensym4124_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (alignX60gensym4124_)));
			(*resX60gensym4124_).info = (*nodeX60gensym4124_).info;
			asgnRef((void**) (&(*resX60gensym4124_).typ), (*nodeX60gensym4124_).typ);
			result = resX60gensym4124_;
		}
		goto LA10_;
		LA12_: ;
		{
			result = n;
		}
		LA10_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 12):
	{
		tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym4128_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym4128_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dotExprX60gensym4128_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* valueX60gensym4128_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* memberX60gensym4128_;
		NI offsetX60gensym4128_;
		configX60gensym4128_ = (*(*c).graph).config;
		nodeX60gensym4128_ = n;
		dotExprX60gensym4128_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			{
				if (!((*(*nodeX60gensym4128_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA19_;
				dotExprX60gensym4128_ = (*nodeX60gensym4128_)._kind_6.sons->data[((NI) 1)];
			}
			goto LA17_;
			LA19_: ;
			{
				if (!((*(*nodeX60gensym4128_)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46))) goto LA22_;
				dotExprX60gensym4128_ = (*(*nodeX60gensym4128_)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
			}
			goto LA17_;
			LA22_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew(configX60gensym4128_, (*nodeX60gensym4128_).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_230), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_231, NIM_FALSE);
			}
			LA17_: ;
		}
		valueX60gensym4128_ = (*dotExprX60gensym4128_)._kind_6.sons->data[((NI) 0)];
		memberX60gensym4128_ = (*dotExprX60gensym4128_)._kind_6.sons->data[((NI) 1)];
		computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym4128_, (*valueX60gensym4128_).typ);
		offsetX60gensym4128_ = (*(*memberX60gensym4128_)._kind_4.sym).offset;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tmpX60gensym4128_;
			if (!(((NI) 0) <= offsetX60gensym4128_)) goto LA27_;
			tmpX60gensym4128_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (offsetX60gensym4128_)));
			(*tmpX60gensym4128_).info = (*nodeX60gensym4128_).info;
			asgnRef((void**) (&(*tmpX60gensym4128_).typ), (*nodeX60gensym4128_).typ);
			result = tmpX60gensym4128_;
		}
		goto LA25_;
		LA27_: ;
		{
			result = n;
		}
		LA25_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5):
	{
		result = semArrGet__vJZwz9bfROKrfrtM50y74CQ_8(c, n, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 6):
	{
		result = semArrPut__vJZwz9bfROKrfrtM50y74CQ_10(c, n, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 7):
	{
		{
			if (!eqStrings((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_163))) goto LA35_;
			result = semAsgnOpr__7YxUILpPxooC5qqa89a54dw_18(c, n);
		}
		goto LA33_;
		LA35_: ;
		{
			result = semShallowCopy__vJZwz9bfROKrfrtM50y74CQ_11(c, n, flags);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 139):
	{
		result = semIsPartOf__vJZwz9bfROKrfrtM50y74CQ_12(c, n, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 13):
	{
		result = semTypeTraits__7YxUILpPxooC5qqa89a54dw_19(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 140):
	{
		NimStringDesc* T41_;
		T41_ = (NimStringDesc*)0;
		T41_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 1)], 4);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T41_, n, (*c).graph);
		asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 256):
	{
		result = semInstantiationInfo__7YxUILpPxooC5qqa89a54dw_20(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 31):
	{
		result = semOrd__7YxUILpPxooC5qqa89a54dw_21(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 15):
	{
		result = semOf__7YxUILpPxooC5qqa89a54dw_22(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 8):
	{
		result = semLowHigh__7e8kUc3a9a4gEAcnG7wUcyQ(c, n, (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 21):
	{
		result = semShallowCopy__vJZwz9bfROKrfrtM50y74CQ_11(c, n, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 246):
	{
		{
			if (!!((((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 6))&15U)))!=0))) goto LA50_;
			result = semBindSym__7YxUILpPxooC5qqa89a54dw_23(c, n);
		}
		goto LA48_;
		LA50_: ;
		{
			result = semDynamicBindSym__7YxUILpPxooC5qqa89a54dw_24(c, n);
		}
		LA48_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 199):
	{
		result = n;
		asgnRef((void**) (&(*result).typ), (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 127):
	{
		result = n;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 19):
	{
		tyProc__RcJNn9bSvWdJgUmA1O6sbHA plugin;
		plugin = getPlugin__CPe4POy5nrj1aG8wD32ycw((*c).cache, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		{
			NimStringDesc* T60_;
			if (!(plugin == 0)) goto LA58_;
			T60_ = (NimStringDesc*)0;
			T60_ = rawNewString(((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s ? (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s->Sup.len : 0) + 19);
appendString(T60_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_328));
appendString(T60_, (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T60_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_329, NIM_FALSE);
			result = n;
		}
		goto LA56_;
		LA58_: ;
		{
			result = plugin(c, n);
		}
		LA56_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33):
	{
		{
			NIM_BOOL T65_;
			NI T66_;
			NI T68_;
			T65_ = (NIM_BOOL)0;
			T66_ = (NI)0;
			T66_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T65_ = ((*(*n)._kind_6.sons->data[(NI)(T66_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T65_)) goto LA67_;
			T68_ = (NI)0;
			T68_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T65_ = !(((12288 &((NU32)1<<((NU)((*(*(*n)._kind_6.sons->data[(NI)(T68_ - ((NI) 1))])._kind_4.sym).kind)&31U)))!=0));
			LA67_: ;
			if (!T65_) goto LA69_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_330), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_331, NIM_FALSE);
		}
		goto LA63_;
		LA69_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nfin;
			NI T74_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fin;
			if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0)) goto LA72_;
			T74_ = (NI)0;
			T74_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			nfin = skipConvCastAndClosure__esBhdYyFV8ZlnsxfarHAfQ((*n)._kind_6.sons->data[(NI)(T74_ - ((NI) 1))]);
			switch ((*nfin).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
			{
				fin = (*nfin)._kind_4.sym;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
			{
				fin = (*(*nfin)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			}
			break;
			default:
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_330), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_332, NIM_FALSE);
				fin = NIM_NIL;
			}
			break;
			}
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T86_;
				if (!!((fin == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA80_;
				{
					if (!!(((12288 &((NU32)1<<((NU)((*fin).kind)&31U)))!=0))) goto LA84_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_330), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_333, NIM_FALSE);
				}
				LA84_: ;
				T86_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T86_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*fin).typ).sons->data[((NI) 1)], IL64(36134350139468048));
				t = whereToBindTypeHook__ZcD0zNCGO9bcEV34hRXFEJA_2(c, T86_);
				{
					NIM_BOOL T89_;
					NIM_BOOL T90_;
					T89_ = (NIM_BOOL)0;
					T90_ = (NIM_BOOL)0;
					T90_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T90_)) goto LA91_;
					T90_ = !(((*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					LA91_: ;
					T89_ = T90_;
					if (!(T89_)) goto LA92_;
					T89_ = ((*(*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]).owner == fin);
					LA92_: ;
					if (!T89_) goto LA93_;
				}
				goto LA87_;
				LA93_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T96_;
					T96_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T96_ = turnFinalizerIntoDestructor__ZI4mbm59aB4PCl4xGhxV09bw(c, fin, (*n).info);
					bindTypeHook__tGevY34EeRmY9bzfs7irrbQ(c, T96_, n, ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0));
				}
				LA87_: ;
			}
			LA80_: ;
		}
		goto LA63_;
		LA72_: ;
		LA63_: ;
		result = n;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 150):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		result = n;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
		{
			if (!!(((*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA100_;
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*t_2).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0]));
		}
		LA100_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 152):
	{
		result = semUnown__7YxUILpPxooC5qqa89a54dw_25(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 113):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 114):
	{
		result = semQuantifier__7YxUILpPxooC5qqa89a54dw_26(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 115):
	{
		result = semOld__7YxUILpPxooC5qqa89a54dw_27(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 138):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* seqType;
		result = n;
		seqType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*result)._kind_6.sons->data[((NI) 1)]).typ, IL64(9112752385689616));
		{
			NIM_BOOL T108_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T110_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T113_;
			NimStringDesc* T114_;
			T108_ = (NIM_BOOL)0;
			T108_ = ((*seqType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
			if (!(T108_)) goto LA109_;
			T110_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T110_ = base__PfgI9ap7WOnsRfFV4znQ27w(seqType);
			T108_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ(T110_);
			LA109_: ;
			if (!T108_) goto LA111_;
			T113_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T113_ = base__PfgI9ap7WOnsRfFV4znQ27w(seqType);
			T114_ = (NimStringDesc*)0;
			T114_ = typeToString__QlvraUan7WbHowhAbvDvdA(T113_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 32), T114_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_343, NIM_FALSE);
		}
		LA111_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 151):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* constructed;
		result = n;
		{
			NimStringDesc* argX60gensym4190_;
			if (!!(((*(*(*result)._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA118_;
			argX60gensym4190_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_344);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4190_, TM__rF9caJawfOjYTjsgLVUSGFA_344);
		}
		LA118_: ;
		constructed = base__PfgI9ap7WOnsRfFV4znQ27w((*(*result)._kind_6.sons->data[((NI) 1)]).typ);
		{
			NIM_BOOL T122_;
			NimStringDesc* T125_;
			T122_ = (NIM_BOOL)0;
			T122_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ(constructed);
			if (!T122_) goto LA123_;
			T125_ = (NimStringDesc*)0;
			T125_ = typeToString__QlvraUan7WbHowhAbvDvdA(constructed, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 33), T125_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_345, NIM_FALSE);
		}
		LA123_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 153):
	{
		{
			NIM_BOOL T129_;
			NimStringDesc* T132_;
			NimStringDesc* T133_;
			T129_ = (NIM_BOOL)0;
			T129_ = checkIsolate__ZXNCKm9cN9beZ9cx11s9c1Qypw((*n)._kind_6.sons->data[((NI) 1)]);
			if (!!(T129_)) goto LA130_;
			T132_ = (NimStringDesc*)0;
			T133_ = (NimStringDesc*)0;
			T133_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*n)._kind_6.sons->data[((NI) 1)]);
			T132_ = rawNewString((T133_ ? T133_->Sup.len : 0) + 31);
appendString(T132_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_346));
appendString(T132_, T133_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T132_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_347, NIM_FALSE);
		}
		LA130_: ;
		result = n;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T137_;
			T137_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T137_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350135273744));
			if (!((IL64(34084860461056) &((NU64)1<<((NU)((*T137_).kind)&63U)))!=0)) goto LA138_;
			(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic = ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66);
		}
		LA138_: ;
		result = n;
	}
	break;
	default:
	{
		result = n;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCycle__OiccTa3ruRNl9anoSqZh2Sg_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0)) & 31);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = (((*(*n)._kind_6.sons->data[i]).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0))&31U)))!=0);
					if (T6_) goto LA7_;
					T6_ = hasCycle__OiccTa3ruRNl9anoSqZh2Sg_3((*n)._kind_6.sons->data[i]);
					LA7_: ;
					if (!T6_) goto LA8_;
					result = NIM_TRUE;
					goto LA1;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	} LA1: ;
	(*n).flags &= ~(((NU32)1) << ((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 0)) & 31));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* eOrig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((448 &((NU64)1<<((NU)((*(*eOrig).typ).kind)&63U)))!=0)) goto LA3_;
		result = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, evaluated, 0);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* expectedType;
		result = evaluated;
		expectedType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*eOrig).typ, IL64(1152921504606846976));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = hasCycle__OiccTa3ruRNl9anoSqZh2Sg_3(result);
			if (!T8_) goto LA9_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*eOrig).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_351), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_352, NIM_FALSE);
			result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, eOrig);
		}
		goto LA6_;
		LA9_: ;
		{
			annotateType__zBoL79cc9cORdBkTIEpbntbg(result, expectedType, (*(*c).graph).config);
		}
		LA6_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalAtCompileTime__7YxUILpPxooC5qqa89a54dw_28)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	callee = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T9_)) goto LA10_;
		T9_ = (((*(*n).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 33))&63U)))!=0);
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		NIM_BOOL T15_;
		NIM_BOOL T16_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
		NIM_BOOL allConst;
		T15_ = (NIM_BOOL)0;
		T16_ = (NIM_BOOL)0;
		T16_ = !(((*callee).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
		if (!(T16_)) goto LA17_;
		T16_ = ((TM__rF9caJawfOjYTjsgLVUSGFA_348[(NU)((*callee).magic)>>3] &(1U<<((NU)((*callee).magic)&7U)))!=0);
		LA17_: ;
		T15_ = T16_;
		if (!(T15_)) goto LA18_;
		T15_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA18_: ;
		if (!T15_) goto LA19_;
		call = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, (*n).typ);
		add__P8dDSotTW25BkfbyspojGg(call, (*n)._kind_6.sons->data[((NI) 0)]);
		allConst = NIM_TRUE;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					if (!(i_2 < colontmp_)) goto LA23;
					i = i_2;
					a = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, (*n)._kind_6.sons->data[i], (*c).graph);
					{
						if (!(a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA26_;
						allConst = NIM_FALSE;
						a = (*n)._kind_6.sons->data[i];
						{
							if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58))) goto LA30_;
							a = (*a)._kind_6.sons->data[((NI) 1)];
						}
						LA30_: ;
					}
					LA26_: ;
					add__P8dDSotTW25BkfbyspojGg(call, a);
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
		{
			if (!allConst) goto LA34_;
			result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, call, (*c).graph);
			{
				if (!(result == 0)) goto LA38_;
				result = n;
			}
			goto LA36_;
			LA38_: ;
			{
				goto BeforeRet_;
			}
			LA36_: ;
		}
		LA34_: ;
	}
	LA19_: ;
	{
		{
			NI T44_;
			tySequence__Ef05srmQTDulnBdXR4Ja6Q* T58_;
			T44_ = (NI)0;
			T44_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 1) < T44_)) goto LA45_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_4 = ((NI) 1);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA49;
						i_3 = i_4;
						{
							NIM_BOOL T52_;
							NIM_BOOL T53_;
							T52_ = (NIM_BOOL)0;
							T53_ = (NIM_BOOL)0;
							T53_ = ((*(*n)._kind_6.sons->data[i_3]).typ == 0);
							if (T53_) goto LA54_;
							T53_ = !(((*(*(*n)._kind_6.sons->data[i_3]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60)));
							LA54_: ;
							T52_ = T53_;
							if (T52_) goto LA55_;
							T52_ = !((((*(*(*n)._kind_6.sons->data[i_3]).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0));
							LA55_: ;
							if (!T52_) goto LA56_;
							goto LA41;
						}
						LA56_: ;
						i_4 += ((NI) 1);
					} LA49: ;
				}
			}
			T58_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
			T58_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
			asgnRef((void**) (&T58_->data[0]), (*n).typ);
			asgnRef((void**) (&(*n).typ), newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T58_));
			(*(*n).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
		}
		LA45_: ;
	} LA41: ;
	{
		NIM_BOOL T61_;
		NIM_BOOL T63_;
		NIM_BOOL T64_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call_2;
		T61_ = (NIM_BOOL)0;
		T61_ = ((*callee).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
		if (T61_) goto LA62_;
		T63_ = (NIM_BOOL)0;
		T64_ = (NIM_BOOL)0;
		T64_ = !(((134221824 & (*callee).flags) == 0));
		if (!(T64_)) goto LA65_;
		T64_ = ((80 & (*callee).flags) == 0);
		LA65_: ;
		T63_ = T64_;
		if (!(T63_)) goto LA66_;
		T63_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA66_: ;
		T61_ = T63_;
		LA62_: ;
		if (!T61_) goto LA67_;
		{
			NIM_BOOL T71_;
			NIM_BOOL T72_;
			T71_ = (NIM_BOOL)0;
			T72_ = (NIM_BOOL)0;
			T72_ = !(((*callee).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10)));
			if (!(T72_)) goto LA73_;
			T72_ = !((((*callee).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0));
			LA73_: ;
			T71_ = T72_;
			if (!(T71_)) goto LA74_;
			T71_ = !((((*(*(*c).graph).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 22))&31U)))!=0));
			LA74_: ;
			if (!T71_) goto LA75_;
			goto BeforeRet_;
		}
		LA75_: ;
		{
			if (!!(((TM__rF9caJawfOjYTjsgLVUSGFA_348[(NU)((*callee).magic)>>3] &(1U<<((NU)((*callee).magic)&7U)))!=0))) goto LA79_;
			goto BeforeRet_;
		}
		LA79_: ;
		{
			NIM_BOOL T83_;
			T83_ = (NIM_BOOL)0;
			T83_ = !(((78848 &((NU32)1<<((NU)((*callee).kind)&31U)))!=0));
			if (T83_) goto LA84_;
			T83_ = isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA(callee);
			LA84_: ;
			if (!T83_) goto LA85_;
			goto BeforeRet_;
		}
		LA85_: ;
		{
			NIM_BOOL T89_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T91_;
			T89_ = (NIM_BOOL)0;
			T89_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T89_)) goto LA90_;
			T91_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T91_ = typeAllowed__M8lM58Zr3lmYhlOsJv89cVw((*n).typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10), c, 0);
			T89_ = !((T91_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA90_: ;
			if (!T89_) goto LA92_;
			goto BeforeRet_;
		}
		LA92_: ;
		call_2 = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, (*n).typ);
		add__P8dDSotTW25BkfbyspojGg(call_2, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
					if (!(i_6 < colontmp__3)) goto LA96;
					i_5 = i_6;
					a_2 = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, (*n)._kind_6.sons->data[i_5], (*c).graph);
					{
						if (!(a_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA99_;
						result = n;
						goto BeforeRet_;
					}
					LA99_: ;
					add__P8dDSotTW25BkfbyspojGg(call_2, a_2);
					i_6 += ((NI) 1);
				} LA96: ;
			}
		}
		{
			NIM_BOOL T103_;
			T103_ = (NIM_BOOL)0;
			T103_ = ((*c).inStaticContext == ((NI) 0));
			if (T103_) goto LA104_;
			T103_ = (((*callee).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 12))&63U)))!=0);
			LA104_: ;
			if (!T103_) goto LA105_;
			{
				if (!(((*callee).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA109_;
				result = evalStaticExpr__ajRaPV9aInq6ZNnUYn0DaVw((*c).module, (*c).graph, call_2, (*(*c).p).owner);
				{
					NimStringDesc* T115_;
					NimStringDesc* T116_;
					if (!(result == 0)) goto LA113_;
					T115_ = (NimStringDesc*)0;
					T115_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(call_2, 0);
					T116_ = (NimStringDesc*)0;
					T116_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_349), T115_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T116_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_350, NIM_FALSE);
				}
				goto LA111_;
				LA113_: ;
				{
					result = fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA(c, result, n);
				}
				LA111_: ;
			}
			goto LA107_;
			LA109_: ;
			{
				result = evalConstExpr__P8uF2QSxl7YdNpBnl0Ybqg((*c).module, (*c).graph, call_2);
				{
					if (!(result == 0)) goto LA121_;
					result = n;
				}
				goto LA119_;
				LA121_: ;
				{
					result = fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA(c, result, n);
				}
				LA119_: ;
			}
			LA107_: ;
		}
		goto LA101_;
		LA105_: ;
		{
			result = n;
		}
		LA101_: ;
	}
	LA67_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, afterCallActions__Qn3T9bt6Cg4I7XaYRMg219aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	callee = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	switch ((*callee).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
	{
		result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, result, orig, callee, flags);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, result, callee, flags);
	}
	break;
	default:
	{
		semFinishOperands__wb6KhAx6bZ5NV37kY4bXJw_3(c, result);
		activate__NRIJDWZtATzMum7OEjYC2g_5(c, result);
		fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6(c, result);
		analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7(c, result);
		{
			if (!!(((*callee).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)))) goto LA6_;
			result = magicsAfterOverloadResolution__vJZwz9bfROKrfrtM50y74CQ_7(c, result, flags);
		}
		LA6_: ;
	}
	break;
	}
	{
		if (!((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL))) goto LA10_;
		result = evalAtCompileTime__7YxUILpPxooC5qqa89a54dw_28(c, result);
	}
	LA10_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nOrig = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
	result = semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA(c, n, nOrig, flags);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		result = afterCallActions__Qn3T9bt6Cg4I7XaYRMg219aw(c, result, nOrig, flags);
	}
	goto LA1_;
	LA3_: ;
	{
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalPattern__bbosmif5uBCIMfZ0A73vOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* rule;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* argX60gensym74_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA4_: ;
		if (!!(T3_)) goto LA5_;
		argX60gensym74_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_213);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym74_, TM__rF9caJawfOjYTjsgLVUSGFA_213);
	}
	LA5_: ;
	rule = (NimStringDesc*)0;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2((*(*c).graph).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 70));
		if (!T9_) goto LA10_;
		rule = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
	}
	LA10_: ;
	s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
	{
		result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, n, orig, s, 0);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, n, s, 65536);
	}
	break;
	default:
	{
		result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, 0);
	}
	break;
	}
	{
		NIM_BOOL T17_;
		NimStringDesc* T20_;
		NimStringDesc* T21_;
		T17_ = (NIM_BOOL)0;
		T17_ = hasHint__zh6OC34d9cPUHXjZ4qVA9bkw_2((*(*c).graph).config, ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) 70));
		if (!T17_) goto LA18_;
		T20_ = (NimStringDesc*)0;
		T21_ = (NimStringDesc*)0;
		T21_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
		T20_ = rawNewString((rule ? rule->Sup.len : 0) + (T21_ ? T21_->Sup.len : 0) + 7);
appendString(T20_, rule);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_353));
appendString(T20_, T21_);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*orig).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 70), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_354, NIM_FALSE);
	}
	LA18_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, applyPatterns__7YxUILpPxooC5qqa89a54dw_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).patterns ? (*c).patterns->Sup.len : 0);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		res = colontmp_;
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* pattern;
				if (!(((NI) 0) <= res)) goto LA4;
				i = res;
				pattern = (*c).patterns->data[i];
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
					if (!!((pattern == 0))) goto LA7_;
					x = applyRule__ZQ863YHaqTVgTAf1B1grTA(c, pattern, result);
					{
						if (!!((x == 0))) goto LA11_;
						(*(*(*c).graph).config).evalTemplateCounter += ((NI) 1);
						{
							if (!(((NI) 1000) < (*(*(*c).graph).config).evalTemplateCounter)) goto LA15_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_13), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_211, NIM_FALSE);
						}
						LA15_: ;
						asgnRef((void**) (&(*c).patterns->data[i]), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
						{
							if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA19_;
							asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 1)]), evalPattern__bbosmif5uBCIMfZ0A73vOQ(c, (*x)._kind_6.sons->data[((NI) 1)], result));
							result = flattenStmts__qsyX8NJX39ctdwAi4rC8W1g(x);
						}
						goto LA17_;
						LA19_: ;
						{
							result = evalPattern__bbosmif5uBCIMfZ0A73vOQ(c, x, result);
						}
						LA17_: ;
						(*(*(*c).graph).config).evalTemplateCounter -= ((NI) 1);
						asgnRef((void**) (&(*c).patterns->data[i]), pattern);
					}
					LA11_: ;
				}
				LA7_: ;
				res -= ((NI) 1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hlo__7YxUILpPxooC5qqa89a54dw_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*c).hloLoopDetector += ((NI) 1);
	{
		if (!(((NI) 300) < (*c).hloLoopDetector)) goto LA3_;
		result = n;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = n;
	}
	break;
	default:
	{
		{
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36));
			if (!(T10_)) goto LA11_;
			T10_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA11_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA12_;
			T9_ = ((2056 & (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags) == 2056);
			LA12_: ;
			if (!T9_) goto LA13_;
			result = n;
			goto BeforeRet_;
		}
		LA13_: ;
		result = applyPatterns__7YxUILpPxooC5qqa89a54dw_12(c, n);
		{
			if (!(result == n)) goto LA17_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* h;
						if (!(i_2 < colontmp_)) goto LA21;
						i = i_2;
						a = (*result)._kind_6.sons->data[i];
						h = hlo__7YxUILpPxooC5qqa89a54dw_11(c, a);
						{
							if (!!((h == a))) goto LA24_;
							asgnRef((void**) (&(*result)._kind_6.sons->data[i]), h);
						}
						LA24_: ;
						i_2 += ((NI) 1);
					} LA21: ;
				}
			}
		}
		goto LA15_;
		LA17_: ;
		{
			{
				NIM_BOOL T29_;
				T29_ = (NIM_BOOL)0;
				T29_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
				if (!(T29_)) goto LA30_;
				T29_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*result).typ);
				LA30_: ;
				if (!T29_) goto LA31_;
			}
			goto LA27_;
			LA31_: ;
			{
				result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*n).typ, result, (*n).info);
			}
			LA27_: ;
			result = commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg((*c).graph, (*c).module, result);
			result = hlo__7YxUILpPxooC5qqa89a54dw_11(c, result);
			result = commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg((*c).graph, (*c).module, result);
		}
		LA15_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hloBody__7YxUILpPxooC5qqa89a54dw_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = ((*c).patterns ? (*c).patterns->Sup.len : 0);
		T3_ = (T4_ == ((NI) 0));
		if (T3_) goto LA5_;
		T3_ = !((((*(*(*c).graph).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 23))&31U)))!=0));
		LA5_: ;
		if (!T3_) goto LA6_;
		result = n;
		goto BeforeRet_;
	}
	LA6_: ;
	(*c).hloLoopDetector = ((NI) 0);
	result = hlo__7YxUILpPxooC5qqa89a54dw_11(c, n);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	asgnRef((void**) (&(*c).p), (*(*c).p).next);
}
N_LIB_PRIVATE N_NIMCALL(void, fixupInstantiatedSymbols__PSSiITp8zAUcZ8z1k5AMLA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).generics ? (*c).generics->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldPrc;
					tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T9_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
					if (!((*(*c).generics->data[i].genericSym).Sup.id == (*s).Sup.id)) goto LA7_;
					oldPrc = (*(*c).generics->data[i].inst).sym;
					pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3(c, oldPrc);
					pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, oldPrc);
					pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*oldPrc).info, ((NimStringDesc*) NIM_NIL));
					T9_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
					T9_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
					n = (*oldPrc).ast;
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*s).ast)._kind_6.sons->data[((NI) 6)]));
					instantiateBody__6k2yIpmfdYEOM5RXDFvgYQ(c, n, (*(*oldPrc).typ).n, oldPrc, s);
					closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
					popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
					popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
					popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchForBorrowProc__4pWHBKQGe6fnkUK3uFl6xQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* startScope, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	NIM_BOOL hasDistinct;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	call = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*fn).info);
	hasDistinct = NIM_FALSE;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ((*fn).name, (*fn).info);
	add__P8dDSotTW25BkfbyspojGg(call, T1_);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*fn).typ).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* param;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				param = (*(*(*fn).typ).n)._kind_6.sons->data[i];
				t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*param).typ, IL64(36275087632009232));
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13));
					if (T7_) goto LA8_;
					T7_ = ((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13));
					LA8_: ;
					if (!T7_) goto LA9_;
					hasDistinct = NIM_TRUE;
				}
				LA9_: ;
				x = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T15_;
					if (!((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23))) goto LA13_;
					x = newTypeS__xb5E2cGIynZweqWlCP8Tig((*(*param).typ).kind, c);
					T15_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T15_ = baseOfDistinct__PfgI9ap7WOnsRfFV4znQ27w_4(t);
					addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(x, T15_);
				}
				goto LA11_;
				LA13_: ;
				{
					x = baseOfDistinct__PfgI9ap7WOnsRfFV4znQ27w_4(t);
				}
				LA11_: ;
				T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T17_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*fn).info, x);
				add__P8dDSotTW25BkfbyspojGg(call, T17_);
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resolved;
		if (!hasDistinct) goto LA20_;
		{
			if (!((12288 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0)) goto LA24_;
			filter = 12288;
		}
		goto LA22_;
		LA24_: ;
		{
			filter = 0;
			filter |=((NU32)(1)<<(((*fn).kind)%(sizeof(NU32)*8)));
		}
		LA22_: ;
		resolved = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, call, call, filter, 0);
		{
			if (!!((resolved == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA29_;
			result = (*(*resolved)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				NIM_BOOL T33_;
				T33_ = (NIM_BOOL)0;
				T33_ = compareTypes__oyXq5u7iL4RjsT9bovvTE9cg((*(*result).typ).sons->data[((NI) 0)], (*(*fn).typ).sons->data[((NI) 0)], ((tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg) 1), 0);
				if (!!(T33_)) goto LA34_;
				result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
			}
			goto LA31_;
			LA34_: ;
			{
				if (!((*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 6) || (*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5))) goto LA37_;
				result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
			}
			goto LA31_;
			LA37_: ;
			LA31_: ;
		}
		LA29_: ;
	}
	LA20_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semBorrow__OGQY86R2SObbzHiM7l0Jxg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b;
	b = searchForBorrowProc__4pWHBKQGe6fnkUK3uFl6xQ(c, (*(*c).currentScope).parent, s);
	{
		if (!!((b == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(b));
		(*s).magic = (*b).magic;
	}
	goto LA1_;
	LA3_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_359), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_360, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sideEffectsCheck__PSSiITp8zAUcZ8z1k5AMLA_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcAux__HtuGXsziiAueY6wARBVVAA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg phase) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	NIM_BOOL typeIsDetermined;
	NIM_BOOL isAnon;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* oldScope;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T16_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
	tyTuple__jdFwpivBCgGar3GHRE8kKQ T51_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* proto;
	NIM_BOOL comesFromShadowScope;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semProcAnnotation__Uz9bZ6N7ZeTxuwI9b9cYeOeYw(c, n, validPragmas);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = n;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 7), (*(*c).graph).config);
	s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	typeIsDetermined = NIM_FALSE;
	isAnon = NIM_FALSE;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA7_;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA11_;
			T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T13_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
			s = newSym__IXbidcxhXTQGZY9abN63Cxg(kind, (*(*c).cache).idAnon, T13_, (*n).info, 0);
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
			isAnon = NIM_TRUE;
		}
		goto LA9_;
		LA11_: ;
		{
			s = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, (*n)._kind_6.sons->data[((NI) 0)], kind);
		}
		LA9_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s));
		asgnRef((void**) (&(*s).ast), n);
	}
	goto LA5_;
	LA7_: ;
	{
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		asgnRef((void**) (&(*s).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
		typeIsDetermined = ((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		asgnRef((void**) (&(*s).ast), n);
	}
	LA5_: ;
	(*s).options = (*(*(*c).graph).config).options;
	oldScope = (*c).currentScope;
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
	T16_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T16_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	gp = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA19_;
		gp = setGenericParamsMisc__7YxUILpPxooC5qqa89a54dw_6(c, n);
	}
	goto LA17_;
	LA19_: ;
	{
		gp = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75), (*n).info);
	}
	LA17_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA24_;
		semParamList__HJ2sXcKFjirzvqsZjMcpTg(c, (*n)._kind_6.sons->data[((NI) 3)], gp, s);
		{
			NI T28_;
			T28_ = (NI)0;
			T28_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
			if (!(((NI) 0) < T28_)) goto LA29_;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA33_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), gp);
			}
			LA33_: ;
		}
		LA29_: ;
	}
	goto LA22_;
	LA24_: ;
	{
		asgnRef((void**) (&(*s).typ), newProcType__5gg5mq4XYRQKbAkdLMpzGA(c, (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	}
	LA22_: ;
	{
		if (!(((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 33))&63U)))!=0)) goto LA38_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27)) & 63);
	}
	LA38_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA42_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semPattern__7YxUILpPxooC5qqa89a54dw_9(c, (*n)._kind_6.sons->data[((NI) 1)]));
	}
	LA42_: ;
	{
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA46_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15)) & 63);
	}
	goto LA44_;
	LA46_: ;
	{
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13))) goto LA49_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 12)) & 63);
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1)) & 63);
	}
	goto LA44_;
	LA49_: ;
	LA44_: ;
	nimZeroMem((void*)(&T51_), sizeof(tyTuple__jdFwpivBCgGar3GHRE8kKQ));
	{
		if (!isAnon) goto LA54_;
		T51_.Field0 = TM__rF9caJawfOjYTjsgLVUSGFA_154.Field0;
		T51_.Field1 = TM__rF9caJawfOjYTjsgLVUSGFA_154.Field1;
	}
	goto LA52_;
	LA54_: ;
	{
		searchForProc__onRsQxI12p1JaTFcIxF6cA(c, oldScope, s, (&T51_));
	}
	LA52_: ;
	proto = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	proto = T51_.Field0;
	comesFromShadowScope = (NIM_BOOL)0;
	comesFromShadowScope = T51_.Field1;
	{
		NIM_BOOL T59_;
		T59_ = (NIM_BOOL)0;
		T59_ = (proto == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (!(T59_)) goto LA60_;
		T59_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0);
		LA60_: ;
		if (!T59_) goto LA61_;
		proto = s;
	}
	LA61_: ;
	{
		if (!(proto == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA65_;
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA69_;
			{
				if (!!(((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA73_;
				{
					if (!isAnon) goto LA77_;
					(*(*s).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
				}
				goto LA75_;
				LA77_: ;
				{
					(*(*s).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5);
				}
				LA75_: ;
			}
			LA73_: ;
		}
		goto LA67_;
		LA69_: ;
		{
			tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* T81_;
			T81_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*)0;
			T81_ = lastOptionEntry__SQasfuhUR9aUpH0EyW9aFezg_2(c);
			(*(*s).typ).callConv = (*T81_).defaultCC;
		}
		LA67_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0)) goto LA84_;
			{
				if (!((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA88_;
				asgnRef((void**) (&(*s).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
			}
			LA88_: ;
		}
		goto LA82_;
		LA84_: ;
		{
			if (!((520256 &((NU32)1<<((NU)(kind)&31U)))!=0)) goto LA91_;
			{
				if (!!(typeIsDetermined)) goto LA95_;
				addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg(c, oldScope, s);
			}
			LA95_: ;
		}
		goto LA82_;
		LA91_: ;
		{
			{
				if (!!(typeIsDetermined)) goto LA100_;
				addInterfaceDeclAt__HcojHyPBYsbchSQtmBqThg_2(c, oldScope, s);
			}
			LA100_: ;
		}
		LA82_: ;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA104_;
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 4)], validPragmas, NIM_FALSE);
		}
		goto LA102_;
		LA104_: ;
		{
			implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw(c, s, n, validPragmas);
		}
		LA102_: ;
		{
			if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA109_;
			nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*s).info, s, (*s).kind);
		}
		LA109_: ;
	}
	goto LA63_;
	LA65_: ;
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T139_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA114_;
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 4)], validPragmas, NIM_FALSE);
			{
				NIM_BOOL T118_;
				NimStringDesc* T122_;
				NimStringDesc* T123_;
				NimStringDesc* T124_;
				T118_ = (NIM_BOOL)0;
				T118_ = !(((*(*proto).typ).callConv == (*(*s).typ).callConv));
				if (T118_) goto LA119_;
				T118_ = ((((*(*proto).typ).flags & ~ (*(*s).typ).flags)==0)&&((*(*proto).typ).flags != (*(*s).typ).flags));
				LA119_: ;
				if (!T118_) goto LA120_;
				T122_ = (NimStringDesc*)0;
				T123_ = (NimStringDesc*)0;
				T123_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, (*proto).info);
				T122_ = rawNewString(((*(*proto).name).s ? (*(*proto).name).s->Sup.len : 0) + (T123_ ? T123_->Sup.len : 0) + 8);
appendString(T122_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
appendString(T122_, (*(*proto).name).s);
appendString(T122_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_156));
appendString(T122_, T123_);
				T124_ = (NimStringDesc*)0;
				T124_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_155), T122_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 4)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T124_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_157, NIM_FALSE);
			}
			LA120_: ;
		}
		LA114_: ;
		{
			if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA127_;
			nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*s).info, s, (*s).kind);
		}
		LA127_: ;
		{
			NIM_BOOL T131_;
			T131_ = (NIM_BOOL)0;
			T131_ = !((((*proto).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0));
			if (!(T131_)) goto LA132_;
			T131_ = ((*proto).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
			LA132_: ;
			if (!T131_) goto LA133_;
			wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*n).info, (*(*proto).name).s, (*proto).info);
		}
		LA133_: ;
		{
			if (!!(comesFromShadowScope)) goto LA137_;
			(*proto).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
			(*proto).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5)) & 63);
		}
		LA137_: ;
		suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch((*(*c).graph).config, (*s).info, proto, &(*(*c).graph).usageSym, NIM_TRUE);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
		T139_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T139_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		{
			if (!!(((*(*(*proto).ast)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA142_;
			addGenericParamListToScope__NRIJDWZtATzMum7OEjYC2g_4(c, (*(*proto).ast)._kind_6.sons->data[((NI) 2)]);
		}
		LA142_: ;
		addParams__XjZLpvNqVUTx1J6TXREPBQ_2(c, (*(*proto).typ).n, (*proto).kind);
		(*proto).info = (*s).info;
		(*proto).options = (*s).options;
		s = proto;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), (*(*proto).ast)._kind_6.sons->data[((NI) 2)]);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 3)]), (*(*proto).ast)._kind_6.sons->data[((NI) 3)]);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), (*(*proto).ast)._kind_6.sons->data[((NI) 4)]);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA146_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_158), TM__rF9caJawfOjYTjsgLVUSGFA_159);
		}
		LA146_: ;
		asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym), proto);
		{
			NIM_BOOL T150_;
			NimStringDesc* T154_;
			T150_ = (NIM_BOOL)0;
			T150_ = importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions((*(*c).graph).config);
			if (!(T150_)) goto LA151_;
			T150_ = (((NI) 0) < ((*(*proto).ast).comment ? (*(*proto).ast).comment->Sup.len : 0));
			LA151_: ;
			if (!T150_) goto LA152_;
			T154_ = (NimStringDesc*)0;
			T154_ = (*n).comment; (*n).comment = copyStringRC1((*(*proto).ast).comment);
			if (T154_) nimGCunrefNoCycle(T154_);
		}
		LA152_: ;
		asgnRef((void**) (&(*proto).ast), n);
		popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
		pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
	}
	LA63_: ;
	{
		NIM_BOOL T157_;
		T157_ = (NIM_BOOL)0;
		T157_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34))&63U)))!=0);
		if (T157_) goto LA158_;
		T157_ = ((NU8)((*(*s).name).s->data[((NI) 0)]) == (NU8)(61));
		LA158_: ;
		if (!T157_) goto LA159_;
		semOverride__8H5d8d9cPCfbpMuDrerQMeQ_2(c, s, n);
	}
	LA159_: ;
	{
		if (!(((NU8)((*(*s).name).s->data[((NI) 0)])) == ((NU8)(46)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) == ((NU8)(40)))) goto LA163_;
		{
			NIM_BOOL T167_;
			NimStringDesc* T171_;
			T167_ = (NIM_BOOL)0;
			T167_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem(TM__rF9caJawfOjYTjsgLVUSGFA_191, 3, (*(*s).name).s);
			if (!(T167_)) goto LA168_;
			T167_ = ((18 & (*c).features) == 0);
			LA168_: ;
			if (!T167_) goto LA169_;
			T171_ = (NimStringDesc*)0;
			T171_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 80);
appendString(T171_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_195));
appendString(T171_, (*(*s).name).s);
appendString(T171_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_196));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T171_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_197, NIM_FALSE);
		}
		goto LA165_;
		LA169_: ;
		{
			NIM_BOOL T173_;
			NimStringDesc* T177_;
			T173_ = (NIM_BOOL)0;
			T173_ = eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_198));
			if (!(T173_)) goto LA174_;
			T173_ = !((((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 2))&15U)))!=0));
			LA174_: ;
			if (!T173_) goto LA175_;
			T177_ = (NimStringDesc*)0;
			T177_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 80);
appendString(T177_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_195));
appendString(T177_, (*(*s).name).s);
appendString(T177_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_199));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T177_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_200, NIM_FALSE);
		}
		goto LA165_;
		LA175_: ;
		LA165_: ;
	}
	LA163_: ;
	{
		NIM_BOOL T180_;
		NIM_BOOL usePseudoGenerics;
		T180_ = (NIM_BOOL)0;
		T180_ = !(((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		if (!(T180_)) goto LA181_;
		T180_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24))&63U)))!=0));
		LA181_: ;
		if (!T180_) goto LA182_;
		{
			NimStringDesc* T188_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30))&63U)))!=0)) goto LA186_;
			T188_ = (NimStringDesc*)0;
			T188_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_201), (*(*s).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 6)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T188_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_202, NIM_FALSE);
		}
		LA186_: ;
		usePseudoGenerics = ((393216 &((NU32)1<<((NU)(kind)&31U)))!=0);
		{
			NIM_BOOL T191_;
			NIM_BOOL T192_;
			NIM_BOOL T195_;
			T191_ = (NIM_BOOL)0;
			T192_ = (NIM_BOOL)0;
			T192_ = !(usePseudoGenerics);
			if (!(T192_)) goto LA193_;
			T192_ = ((6 &((NU16)1<<((NU)((*(*(*c).graph).config).ideCmd)&15U)))!=0);
			LA193_: ;
			T191_ = T192_;
			if (!(T191_)) goto LA194_;
			T195_ = (NIM_BOOL)0;
			T195_ = cursorInProc__2z69cmDyuoRHwZ79bXIom4jw((*(*c).graph).config, (*n)._kind_6.sons->data[((NI) 6)]);
			T191_ = !(T195_);
			LA194_: ;
			if (!T191_) goto LA196_;
			{
				if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14))) goto LA200_;
				semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3(c, s, n);
			}
			LA200_: ;
		}
		goto LA189_;
		LA196_: ;
		{
			pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3(c, s);
			{
				NIM_BOOL T205_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T215_;
				T205_ = (NIM_BOOL)0;
				T205_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
				if (T205_) goto LA206_;
				T205_ = usePseudoGenerics;
				LA206_: ;
				if (!T205_) goto LA207_;
				{
					NIM_BOOL T211_;
					T211_ = (NIM_BOOL)0;
					T211_ = !(usePseudoGenerics);
					if (!(T211_)) goto LA212_;
					T211_ = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
					LA212_: ;
					if (!T211_) goto LA213_;
					paramsTypeCheck__X9cjeXk0ogla5nWLtx0FEkAsem(c, (*s).typ);
				}
				LA213_: ;
				maybeAddResult__8H5d8d9cPCfbpMuDrerQMeQ(c, s, n);
				T215_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T215_ = semProcBody__7YxUILpPxooC5qqa89a54dw_5(c, (*n)._kind_6.sons->data[((NI) 6)]);
				asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 6)]), hloBody__7YxUILpPxooC5qqa89a54dw_10(c, T215_));
				trackProc__P9bJkIGwY9beKGfhhcBedbpg(c, s, (*(*s).ast)._kind_6.sons->data[((NI) 6)]);
				{
					if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14))) goto LA218_;
					semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3(c, s, n);
				}
				LA218_: ;
			}
			goto LA203_;
			LA207_: ;
			{
				tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T231_;
				{
					NIM_BOOL T223_;
					NIM_BOOL T224_;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T229_;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T230_;
					T223_ = (NIM_BOOL)0;
					T224_ = (NIM_BOOL)0;
					T224_ = !(((*(*s).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T224_)) goto LA225_;
					T224_ = !((kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)));
					LA225_: ;
					T223_ = T224_;
					if (T223_) goto LA226_;
					T223_ = (kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
					LA226_: ;
					if (!T223_) goto LA227_;
					T229_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
					T229_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96));
					T230_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T230_ = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T229_, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (*n).info, 0);
					addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, T230_);
				}
				LA227_: ;
				T231_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
				T231_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), semGenericStmt__7YxUILpPxooC5qqa89a54dw_7(c, (*n)._kind_6.sons->data[((NI) 6)]));
				closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
				{
					if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA234_;
					fixupInstantiatedSymbols__PSSiITp8zAUcZ8z1k5AMLA_2(c, s);
				}
				LA234_: ;
				{
					if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14))) goto LA238_;
					semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3(c, s, n);
				}
				LA238_: ;
			}
			LA203_: ;
			{
				if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0)) goto LA242_;
			}
			LA242_: ;
			popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
		}
		LA189_: ;
	}
	goto LA178_;
	LA182_: ;
	{
		{
			NIM_BOOL T247_;
			NIM_BOOL T248_;
			T247_ = (NIM_BOOL)0;
			T248_ = (NIM_BOOL)0;
			T248_ = ((12288 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			if (!(T248_)) goto LA249_;
			T248_ = !(((*(*s).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA249_: ;
			T247_ = T248_;
			if (!(T247_)) goto LA250_;
			T247_ = ((*(*(*s).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
			LA250_: ;
			if (!T247_) goto LA251_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*n)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_355), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_356, NIM_FALSE);
		}
		LA251_: ;
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14))) goto LA255_;
			semMethodPrototype__8H5d8d9cPCfbpMuDrerQMeQ_3(c, s, n);
		}
		LA255_: ;
		{
			NimStringDesc* T261_;
			if (!!((proto == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA259_;
			T261_ = (NimStringDesc*)0;
			T261_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*proto).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T261_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_358, NIM_FALSE);
		}
		LA259_: ;
		{
			NIM_BOOL T264_;
			T264_ = (NIM_BOOL)0;
			T264_ = ((1090519104 & (*s).flags) == 0);
			if (!(T264_)) goto LA265_;
			T264_ = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
			LA265_: ;
			if (!T264_) goto LA266_;
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63);
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5)) & 63);
		}
		goto LA262_;
		LA266_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30))&63U)))!=0)) goto LA269_;
			semBorrow__OGQY86R2SObbzHiM7l0Jxg(c, n, s);
		}
		goto LA262_;
		LA269_: ;
		LA262_: ;
	}
	LA178_: ;
	sideEffectsCheck__PSSiITp8zAUcZ8z1k5AMLA_3(c, s);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	{
		NI T275_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA273_;
		asgnRef((void**) (&(*c).patterns), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).patterns), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
		T275_ = (*c).patterns->Sup.len++;
		asgnRef((void**) (&(*c).patterns->data[T275_]), s);
	}
	LA273_: ;
	{
		if (!isAnon) goto LA278_;
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 51));
		asgnRef((void**) (&(*result).typ), (*s).typ);
		{
			if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA282_;
			asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
		}
		LA282_: ;
	}
	LA278_: ;
	{
		NIM_BOOL T286_;
		NIM_BOOL T287_;
		T286_ = (NIM_BOOL)0;
		T287_ = (NIM_BOOL)0;
		T287_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!(T287_)) goto LA288_;
		T287_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)));
		LA288_: ;
		T286_ = T287_;
		if (!(T286_)) goto LA289_;
		T286_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA289_: ;
		if (!T286_) goto LA290_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_361), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_362, NIM_FALSE);
	}
	LA290_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, determineType__PSSiITp8zAUcZ8z1k5AMLA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
{	{
		if (!!(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T5_ = semProcAux__HtuGXsziiAueY6wARBVVAA(c, (*s).ast, (*s).kind, TM__rF9caJawfOjYTjsgLVUSGFA_363, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 1));
	(void)(T5_);
	}BeforeRet_: ;
}
static N_NIMCALL(void, Marker_tySequence__P9bWebqKHkrGHwy9aZW9bw0TA)(void* p, NI op) {
	tySequence__P9bWebqKHkrGHwy9aZW9bw0TA* a;
	NI T1_;
	a = (tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*, initCandidateSymbols__6M9chcVQEVQseAfXvR9bENIw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initialBinding, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* best, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* alt, tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ* o, NIM_BOOL diagnostics) {
	tySequence__P9bWebqKHkrGHwy9aZW9bw0TA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* symx;
	result = (tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*)0;
	result = NIM_NIL;
	symx = initOverloadIter__yTTeeqtnENsm0xyCro9a61w(o, c, headSymbol);
	{
		while (1) {
			if (!!((symx == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q T7_;
				NI T8_;
				if (!((filter &((NU32)1<<((NU)((*symx).kind)&31U)))!=0)) goto LA5_;
				nimZeroMem((void*)(&T7_), sizeof(tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q));
				T7_.Field0 = symx;
				T7_.Field1 = lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw((&(*o)));
				result = (tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*) incrSeqV3((TGenericSeq*)(result), (&NTI__P9bWebqKHkrGHwy9aZW9bw0TA_));
				T8_ = result->Sup.len++;
				asgnRef((void**) (&result->data[T8_].Field0), T7_.Field0);
				result->data[T8_].Field1 = T7_.Field1;
			}
			LA5_: ;
			symx = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2(o, c, headSymbol);
		} LA2: ;
	}
	{
		NI T11_;
		T11_ = (result ? result->Sup.len : 0);
		if (!(((NI) 0) < T11_)) goto LA12_;
		initCandidate__KpVjtqarjr9c7ddovPDNqvA(c, best, result->data[((NI) 0)].Field0, initialBinding, result->data[((NI) 0)].Field1, diagnostics);
		initCandidate__KpVjtqarjr9c7ddovPDNqvA(c, alt, result->data[((NI) 0)].Field0, initialBinding, result->data[((NI) 0)].Field1, diagnostics);
		(*best).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
	}
	LA12_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initialBinding, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* best, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* alt, tySequence__0dpGN6F4ocevqUQGsaf41w** errors, NIM_BOOL diagnosticsFlag, NIM_BOOL errorsEnabled) {
	tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	NI scope;
	NI counterInitial;
	tySequence__P9bWebqKHkrGHwy9aZW9bw0TA* syms;
	NIM_BOOL noSyms;
	NI nextSymIndex;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA z;
	nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
	sym = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, headSymbol);
	scope = lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw((&o));
	counterInitial = (*(*c).currentScope).symbols.counter;
	syms = (tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*)0;
	noSyms = NIM_TRUE;
	nextSymIndex = ((NI) 0);
	{
		while (1) {
			if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			{
				if (!((filter &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA5_;
				initCandidate__KpVjtqarjr9c7ddovPDNqvA(c, best, sym, initialBinding, scope, diagnosticsFlag);
				initCandidate__KpVjtqarjr9c7ddovPDNqvA(c, alt, sym, initialBinding, scope, diagnosticsFlag);
				(*best).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
				goto LA1;
			}
			goto LA3_;
			LA5_: ;
			{
				sym = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
				scope = lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw((&o));
			}
			LA3_: ;
		} LA2: ;
	} LA1: ;
	nimZeroMem((void*)(&z), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	{
		while (1) {
			if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9;
			{
				{
					if (!!(((filter &((NU32)1<<((NU)((*sym).kind)&31U)))!=0))) goto LA13_;
					sym = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
					scope = lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw((&o));
					goto LA10;
				}
				LA13_: ;
				determineType__PSSiITp8zAUcZ8z1k5AMLA(c, sym);
				initCandidate__KpVjtqarjr9c7ddovPDNqvA(c, (&z), sym, initialBinding, scope, diagnosticsFlag);
				{
					NIM_BOOL T17_;
					NI T19_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*(*c).currentScope).symbols.counter == counterInitial);
					if (T17_) goto LA18_;
					T19_ = (syms ? syms->Sup.len : 0);
					T17_ = !((T19_ == ((NI) 0)));
					LA18_: ;
					if (!T17_) goto LA20_;
					matches__BxEsf1Gt7Hq3usrwPERzyA_2(c, n, orig, (&z));
					{
						if (!(z.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1))) goto LA24_;
						{
							if (!((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA28_;
							z.exactMatches += ((NI) 200);
						}
						LA28_: ;
						switch ((*best).state) {
						case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0):
						case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2):
						{
							genericAssign((void*)(&(*best)), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
						}
						break;
						case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1):
						{
							NI cmp;
							cmp = cmpCandidates__K2h4nBXAyIEnS4gvLx162g((&(*best)), (&z));
							{
								if (!(cmp < ((NI) 0))) goto LA34_;
								genericAssign((void*)(&(*best)), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
							}
							goto LA32_;
							LA34_: ;
							{
								if (!(cmp == ((NI) 0))) goto LA37_;
								genericAssign((void*)(&(*alt)), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
							}
							goto LA32_;
							LA37_: ;
							LA32_: ;
						}
						break;
						}
					}
					goto LA22_;
					LA24_: ;
					{
						NIM_BOOL T40_;
						tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ T44_;
						NI T45_;
						T40_ = (NIM_BOOL)0;
						T40_ = errorsEnabled;
						if (T40_) goto LA41_;
						T40_ = z.diagnosticsEnabled;
						LA41_: ;
						if (!T40_) goto LA42_;
						nimZeroMem((void*)(&T44_), sizeof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ));
						nimZeroMem((void*)(&T44_), sizeof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ));
						T44_.sym = sym;
						T44_.firstMismatch.kind = z.firstMismatch.kind;
						T44_.firstMismatch.arg = z.firstMismatch.arg;
						T44_.firstMismatch.formal = z.firstMismatch.formal;
						genericSeqAssign((&T44_.diagnostics), z.diagnostics, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
						unsureAsgnRef((void**) (&(*errors)), (tySequence__0dpGN6F4ocevqUQGsaf41w*) incrSeqV3((TGenericSeq*)((*errors)), (&NTI__0dpGN6F4ocevqUQGsaf41w_)));
						T45_ = (*errors)->Sup.len++;
						asgnRef((void**) (&(*errors)->data[T45_].sym), T44_.sym);
						(*errors)->data[T45_].firstMismatch.kind = T44_.firstMismatch.kind;
						(*errors)->data[T45_].firstMismatch.arg = T44_.firstMismatch.arg;
						asgnRef((void**) (&(*errors)->data[T45_].firstMismatch.formal), T44_.firstMismatch.formal);
						genericSeqAssign((&(*errors)->data[T45_].diagnostics), T44_.diagnostics, (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_));
						(*errors)->data[T45_].enabled = T44_.enabled;
					}
					goto LA22_;
					LA42_: ;
					LA22_: ;
				}
				goto LA15_;
				LA20_: ;
				{
					syms = initCandidateSymbols__6M9chcVQEVQseAfXvR9bENIw(c, headSymbol, initialBinding, filter, best, alt, (&o), diagnosticsFlag);
					noSyms = NIM_FALSE;
				}
				LA15_: ;
				{
					if (!noSyms) goto LA49_;
					sym = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
					scope = lastOverloadScope__8ksyNJM57vm1Sx3GOp09acw((&o));
				}
				goto LA47_;
				LA49_: ;
				{
					NI T52_;
					T52_ = (syms ? syms->Sup.len : 0);
					if (!(nextSymIndex < T52_)) goto LA53_;
					sym = syms->data[nextSymIndex].Field0;
					scope = syms->data[nextSymIndex].Field1;
					nextSymIndex += ((NI) 1);
				}
				goto LA47_;
				LA53_: ;
				{
					goto LA8;
				}
				LA47_: ;
			} LA10: ;
		} LA9: ;
	} LA8: ;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getMsgDiagnostic__9a9cj3QUHlIK9ah21FZrVSRgw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f) {
	NimStringDesc* result;
	NimStringDesc* ident;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T10_;
	result = (NimStringDesc*)0;
	{
		if (!(((NI) 0) < (*c).compilesContextId)) goto LA3_;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
		sym = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, f);
		{
			while (1) {
				tyArray__Re75IspeoxXy2oCZHwcRrA T8_;
				NimStringDesc* T9_;
				if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7;
				nimZeroMem((void*)T8_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T8_[0] = getSymRepr__q0Idm3DQlYmoqr1FN0Wn2g((*(*c).graph).config, sym);
				T8_[1] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA((*sym).kind);
				T9_ = (NimStringDesc*)0;
				T9_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_366), T8_, 2);
				result = resizeString(result, (T9_ ? T9_->Sup.len : 0) + 0);
appendString(result, T9_);
				sym = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, f);
			} LA7: ;
		}
	}
	LA1_: ;
	T10_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T10_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, f, n);
	ident = (*T10_).s;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym_2;
		NimStringDesc* typeHint;
		NimStringDesc* T22_;
		NimStringDesc* T23_;
		if (!((2560 & (*n).flags) == 512)) goto LA13_;
		sym_2 = (*(*(*n)._kind_6.sons->data[((NI) 1)]).typ).sym;
		typeHint = ((NimStringDesc*) NIM_NIL);
		{
			if (!(sym_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA17_;
		}
		goto LA15_;
		LA17_: ;
		{
			NimStringDesc* T20_;
			NimStringDesc* T21_;
			T20_ = (NimStringDesc*)0;
			T21_ = (NimStringDesc*)0;
			T21_ = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, sym_2, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
			T20_ = rawNewString((T21_ ? T21_->Sup.len : 0) + 10);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_367));
appendString(T20_, T21_);
			typeHint = T20_;
		}
		LA15_: ;
		T22_ = (NimStringDesc*)0;
		T23_ = (NimStringDesc*)0;
		T23_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_368), ident);
		T22_ = rawNewString((T23_ ? T23_->Sup.len : 0) + (typeHint ? typeHint->Sup.len : 0) + (result ? result->Sup.len : 0) + 1);
appendString(T22_, T23_);
appendString(T22_, typeHint);
appendString(T22_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_369));
appendString(T22_, result);
		result = T22_;
	}
	goto LA11_;
	LA13_: ;
	{
		{
			if (!((result ? result->Sup.len : 0) == ((NI) 0))) goto LA27_;
			result = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_370), ident);
		}
		goto LA25_;
		LA27_: ;
		{
			tyArray__Re75IspeoxXy2oCZHwcRrA T30_;
			nimZeroMem((void*)T30_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
			T30_[0] = copyString(ident);
			T30_[1] = copyString(result);
			result = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_371), T30_, 2);
		}
		LA25_: ;
	}
	LA11_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameMethodDispatcher__J29brquhJ05YcB0AjRLYFEg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = NIM_FALSE;
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* aa;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* bb;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*a).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
		if (!(T3_)) goto LA4_;
		T3_ = ((*b).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
		LA4_: ;
		if (!T3_) goto LA5_;
		aa = lastSon__UPSW0jLTX5qJL51YMUAHgw((*a).ast);
		bb = lastSon__UPSW0jLTX5qJL51YMUAHgw((*b).ast);
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*aa).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T9_)) goto LA10_;
			T9_ = ((*bb).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA10_: ;
			if (!T9_) goto LA11_;
			{
				if (!((*aa)._kind_4.sym == (*bb)._kind_4.sym)) goto LA15_;
				result = NIM_TRUE;
			}
			LA15_: ;
		}
		goto LA7_;
		LA11_: ;
		{
		}
		LA7_: ;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, resolveOverloads__deoiEhU508ju9btmg2AXeFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tySequence__0dpGN6F4ocevqUQGsaf41w** errors, NIM_BOOL errorsEnabled, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initialBinding;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA alt;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f;
	tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg overloadsState;
{	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initialBinding = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&alt), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	f = (*n)._kind_6.sons->data[((NI) 0)];
	{
		if (!((*f).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42))) goto LA3_;
		semOpAux__NRIJDWZtATzMum7OEjYC2g_3(c, f);
		initialBinding = f;
		f = (*f)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		initialBinding = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA1_: ;
	pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg(c, f, n, orig, initialBinding, filter, Result, (&alt), errors, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), errorsEnabled);
	overloadsState = (*Result).state;
	{
		if (!!((overloadsState == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA8_;
		{
			NIM_BOOL T12_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hiddenArg;
			T12_ = (NIM_BOOL)0;
			T12_ = !(((*c).p == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)));
			if (!(T12_)) goto LA13_;
			T12_ = !(((*(*c).p).selfSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA13_: ;
			if (!T12_) goto LA14_;
			hiddenArg = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*c).p).selfSym);
			asgnRef((void**) (&(*hiddenArg).typ), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			insert__k2dh9aOATKmq7LxvapyA7CA((&(*n)._kind_6.sons), hiddenArg, ((NI) 1));
			insert__k2dh9aOATKmq7LxvapyA7CA((&(*orig)._kind_6.sons), hiddenArg, ((NI) 1));
			pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg(c, f, n, orig, initialBinding, filter, Result, (&alt), errors, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), errorsEnabled);
			{
				if (!!(((*Result).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA18_;
				delete__TgBXLpGAm0rF5SZ3bkKUbg((&(*n)._kind_6.sons), ((NI) 1));
				delete__TgBXLpGAm0rF5SZ3bkKUbg((&(*orig)._kind_6.sons), ((NI) 1));
				(*n).flags &= ~(((NU32)1) << ((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 12)) & 31));
			}
			goto LA16_;
			LA18_: ;
			{
				goto BeforeRet_;
			}
			LA16_: ;
		}
		LA14_: ;
		{
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T32_;
			tyArray__T6RKPw8xfAeNaoei9aZGzXg T33_;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T34_;
			tyArray__T6RKPw8xfAeNaoei9aZGzXg T35_;
			if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 9))&31U)))!=0)) goto LA23_;
			{
				NIM_BOOL T27_;
				NI T29_;
				NimStringDesc* argX60gensym311_;
				T27_ = (NIM_BOOL)0;
				T27_ = ((*f).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
				if (!(T27_)) goto LA28_;
				T29_ = (NI)0;
				T29_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				T27_ = (((NI) 2) <= T29_);
				LA28_: ;
				if (!!(T27_)) goto LA30_;
				argX60gensym311_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_365);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym311_, TM__rF9caJawfOjYTjsgLVUSGFA_365);
			}
			LA30_: ;
			T32_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), ((NI) 1));
			nimZeroMem((void*)T33_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
			T33_[0] = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			T33_[1] = (*n)._kind_6.sons->data[((NI) 1)];
			T33_[2] = f;
			X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*n)._kind_6.sons), T32_, T33_, 3);
			T34_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), ((NI) 1));
			nimZeroMem((void*)T35_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
			T35_[0] = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			T35_[1] = (*orig)._kind_6.sons->data[((NI) 1)];
			T35_[2] = f;
			X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*orig)._kind_6.sons), T34_, T35_, 3);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* opX60gensym316_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T40_;
				if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 11))&31U)))!=0)) goto LA38_;
				T40_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T40_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_193));
				opX60gensym316_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T40_, (*n).info);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), opX60gensym316_);
				asgnRef((void**) (&(*orig)._kind_6.sons->data[((NI) 0)]), opX60gensym316_);
				pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg(c, opX60gensym316_, n, orig, initialBinding, filter, Result, (&alt), errors, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), errorsEnabled);
			}
			LA38_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* opX60gensym322_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T45_;
				if (!((5 &((NU8)1<<((NU)((*Result).state)&7U)))!=0)) goto LA43_;
				T45_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T45_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_192));
				opX60gensym322_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T45_, (*n).info);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), opX60gensym322_);
				asgnRef((void**) (&(*orig)._kind_6.sons->data[((NI) 0)]), opX60gensym322_);
				pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg(c, opX60gensym322_, n, orig, initialBinding, filter, Result, (&alt), errors, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), errorsEnabled);
			}
			LA43_: ;
		}
		goto LA21_;
		LA23_: ;
		{
			NIM_BOOL T47_;
			NIM_BOOL T48_;
			NI T51_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* calleeName;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T54_;
			NimStringDesc* T55_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T56_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callOp;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T57_;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T58_;
			tyArray__T6RKPw8xfAeNaoei9aZGzXg T59_;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T60_;
			tyArray__T6RKPw8xfAeNaoei9aZGzXg T61_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NIM_BOOL)0;
			T48_ = (((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 10))&31U)))!=0);
			if (!(T48_)) goto LA49_;
			T48_ = ((*f).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
			LA49_: ;
			T47_ = T48_;
			if (!(T47_)) goto LA50_;
			T51_ = (NI)0;
			T51_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T47_ = (T51_ == ((NI) 3));
			LA50_: ;
			if (!T47_) goto LA52_;
			T54_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 0), ((NI) 2));
			T55_ = (NimStringDesc*)0;
			T55_ = X5BX5D___ogYTOKbgqbjPfyC123US1gsystem((*(*f)._kind_5.ident).s, T54_);
			T56_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T56_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T55_);
			calleeName = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T56_, (*n).info);
			T57_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T57_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_194));
			callOp = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T57_, (*n).info);
			T58_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), ((NI) 1));
			nimZeroMem((void*)T59_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
			T59_[0] = callOp;
			T59_[1] = (*n)._kind_6.sons->data[((NI) 1)];
			T59_[2] = calleeName;
			X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*n)._kind_6.sons), T58_, T59_, 3);
			T60_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), ((NI) 1));
			nimZeroMem((void*)T61_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
			T61_[0] = callOp;
			T61_[1] = (*orig)._kind_6.sons->data[((NI) 1)];
			T61_[2] = calleeName;
			X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*orig)._kind_6.sons), T60_, T61_, 3);
			pickBestCandidate__IETBO4nA4t9bpyaJXqQ9aSTg(c, callOp, n, orig, initialBinding, filter, Result, (&alt), errors, ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), errorsEnabled);
		}
		goto LA21_;
		LA52_: ;
		LA21_: ;
		{
			NIM_BOOL T64_;
			T64_ = (NIM_BOOL)0;
			T64_ = (overloadsState == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0));
			if (!(T64_)) goto LA65_;
			T64_ = ((*Result).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0));
			LA65_: ;
			if (!T64_) goto LA66_;
			{
				NimStringDesc* T72_;
				if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 18))&31U)))!=0))) goto LA70_;
				T72_ = (NimStringDesc*)0;
				T72_ = getMsgDiagnostic__9a9cj3QUHlIK9ah21FZrVSRgw(c, flags, n, f);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T72_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_372, NIM_FALSE);
			}
			LA70_: ;
			goto BeforeRet_;
		}
		goto LA62_;
		LA66_: ;
		{
			if (!!(((*Result).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA74_;
			{
				NimStringDesc* T80_;
				NimStringDesc* T81_;
				if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 12))&31U)))!=0)) goto LA78_;
				T80_ = (NimStringDesc*)0;
				T80_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
				T81_ = (NimStringDesc*)0;
				T81_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_245), T80_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T81_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_373, NIM_FALSE);
			}
			goto LA76_;
			LA78_: ;
			{
				{
					if (!!(((1536 & (*n).flags) == 0))) goto LA85_;
					delete__TgBXLpGAm0rF5SZ3bkKUbg((&(*n)._kind_6.sons), ((NI) 2));
					asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), f);
				}
				LA85_: ;
			}
			LA76_: ;
			goto BeforeRet_;
		}
		goto LA62_;
		LA74_: ;
		LA62_: ;
	}
	LA8_: ;
	{
		NIM_BOOL T89_;
		NIM_BOOL T90_;
		NI T92_;
		NIM_BOOL T94_;
		T89_ = (NIM_BOOL)0;
		T90_ = (NIM_BOOL)0;
		T90_ = (alt.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1));
		if (!(T90_)) goto LA91_;
		T92_ = (NI)0;
		T92_ = cmpCandidates__K2h4nBXAyIEnS4gvLx162g(Result, (&alt));
		T90_ = (T92_ == ((NI) 0));
		LA91_: ;
		T89_ = T90_;
		if (!(T89_)) goto LA93_;
		T94_ = (NIM_BOOL)0;
		T94_ = sameMethodDispatcher__J29brquhJ05YcB0AjRLYFEg((*Result).calleeSym, alt.calleeSym);
		T89_ = !(T94_);
		LA93_: ;
		if (!T89_) goto LA95_;
		{
			NimStringDesc* argX60gensym346_;
			if (!!(((*Result).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA99_;
			argX60gensym346_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_374);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym346_, TM__rF9caJawfOjYTjsgLVUSGFA_374);
		}
		LA99_: ;
		{
			if (!((*(*(*c).graph).config).m.errorOutputs == 0)) goto LA103_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_375), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_376, NIM_FALSE);
		}
		goto LA101_;
		LA103_: ;
		{
			NimStringDesc* args;
			tyArray__24KAM9afIUgUaqBaEBB6r9bg T116_;
			NimStringDesc* T117_;
			if (!((*(*(*c).graph).config).errorCounter == ((NI) 0))) goto LA106_;
			args = copyString(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_67));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						NimStringDesc* T115_;
						if (!(i_2 < colontmp_)) goto LA110;
						i = i_2;
						{
							if (!(((NI) 1) < i)) goto LA113_;
							args = resizeString(args, 2);
appendString(args, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
						}
						LA113_: ;
						T115_ = (NimStringDesc*)0;
						T115_ = typeToString__QlvraUan7WbHowhAbvDvdA((*(*n)._kind_6.sons->data[i]).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
						args = resizeString(args, (T115_ ? T115_->Sup.len : 0) + 0);
appendString(args, T115_);
						i_2 += ((NI) 1);
					} LA110: ;
				}
			}
			args = resizeString(args, 1);
appendString(args, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_69));
			nimZeroMem((void*)T116_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
			T116_[0] = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, (*Result).calleeSym, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
			T116_[1] = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, alt.calleeSym, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
			T116_[2] = copyString(args);
			T117_ = (NimStringDesc*)0;
			T117_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_377), T116_, 3);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T117_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_378, NIM_FALSE);
		}
		goto LA101_;
		LA106_: ;
		LA101_: ;
	}
	LA95_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, instGenericConvertersSons__DyVfh0xLvP9cQgsc36rPgEA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x) {
	{
		if (!(*x).genericConverter) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					instGenericConvertersArg__OiEXsRRJbWjgfYLWIAKYYQ(c, (*n)._kind_6.sons->data[i], x);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, updateDefaultParams__eSEQYRkB13fhZ9c33IzktDQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* calleeParams;
	calleeParams = (*(*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).typ).n;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					if (!(((*(*call)._kind_6.sons->data[i]).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 18))&31U)))!=0)) goto LA6_;
					def = (*(*(*calleeParams)._kind_6.sons->data[i])._kind_4.sym).ast;
					{
						if (!(((*def).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19))&31U)))!=0)) goto LA10_;
						(*call).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19)) & 31);
					}
					LA10_: ;
					asgnRef((void**) (&(*call)._kind_6.sons->data[i]), def);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semResolvedCall__tI9alV34Tv2MGPKAeQ6xsmw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* finalCallee;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T90_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	finalCallee = (*x).calleeSym;
	info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, finalCallee);
	{
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T5_;
		if (!!(((*x).fauxMatch == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)))) goto LA3_;
		result = (*x).call;
		T5_ = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag((*result)._kind_6.sons->data[((NI) 0)]);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(finalCallee, T5_));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2((*result).typ);
			if (T8_) goto LA9_;
			T8_ = ((*x).fauxMatch == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61));
			LA9_: ;
			if (!T8_) goto LA10_;
			asgnRef((void**) (&(*result).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig((*x).fauxMatch, c));
			{
				if (!((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50))) goto LA14_;
				(*(*result).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
			}
			LA14_: ;
		}
		LA10_: ;
		goto BeforeRet_;
	}
	LA3_: ;
	gp = (*(*finalCallee).ast)._kind_6.sons->data[((NI) 2)];
	{
		if (!!(((*gp).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA18_;
		{
			if (!!(((393216 &((NU32)1<<((NU)((*(*x).calleeSym).kind)&31U)))!=0))) goto LA22_;
			{
				if (!((*(*x).calleeSym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5) || (*(*x).calleeSym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 6))) goto LA26_;
				finalCallee = (*x).calleeSym;
			}
			goto LA24_;
			LA26_: ;
			{
				finalCallee = generateInstance__Bbmaz5QjetnTaor7LYngPg(c, (*x).calleeSym, (*x).bindings, (*n).info);
			}
			LA24_: ;
		}
		goto LA20_;
		LA22_: ;
		{
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
				s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				{
					NimStringDesc* argX60gensym124_;
					if (!!(((*gp).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75)))) goto LA33_;
					argX60gensym124_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_75);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym124_, TM__rF9caJawfOjYTjsgLVUSGFA_75);
				}
				LA33_: ;
				{
					NI i;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					i = (NI)0;
					a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					{
						NI i_2;
						NI colontmp_;
						NI i_3;
						i_2 = (NI)0;
						colontmp_ = (NI)0;
						colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(gp);
						i_3 = ((NI) 0);
						{
							while (1) {
								if (!(i_3 < colontmp_)) goto LA38;
								i_2 = i_3;
								i = i_2;
								a = (*gp)._kind_6.sons->data[i_2];
								{
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* q;
									tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind;
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T53_;
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
									tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T54_;
									RootObj* T55_;
									{
										NimStringDesc* argX60gensym127_;
										if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA42_;
										argX60gensym127_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_76);
										internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym127_, TM__rF9caJawfOjYTjsgLVUSGFA_76);
									}
									LA42_: ;
									q = (*a)._kind_4.sym;
									{
										if (!!(((IL64(2267562412381049088) &((NU64)1<<((NU)((*(*q).typ).kind)&63U)))!=0))) goto LA46_;
										goto LA39;
									}
									LA46_: ;
									{
										if (!((*(*q).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA50_;
										symKind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10);
									}
									goto LA48_;
									LA50_: ;
									{
										symKind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7);
									}
									LA48_: ;
									T53_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
									T53_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
									s_2 = newSym__IXbidcxhXTQGZY9abN63Cxg(symKind, (*q).name, T53_, (*q).info, 0);
									(*s_2).flags = ((*s_2).flags | 5);
									T54_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
									T54_ = &(*q).typ->Sup;
									T55_ = (RootObj*)0;
									T55_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*x).bindings, T54_);
									t = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T55_));
									{
										if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA58_;
										{
											if (!(((*(*q).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 11))&63U)))!=0)) goto LA62_;
											t = (*q).typ;
										}
										goto LA60_;
										LA62_: ;
										{
											NimStringDesc* T65_;
											T65_ = (NimStringDesc*)0;
											T65_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), (*(*s_2).name).s);
											liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T65_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_78, NIM_FALSE);
											t = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
										}
										LA60_: ;
									}
									goto LA56_;
									LA58_: ;
									{
										NimStringDesc* T69_;
										if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA67_;
										T69_ = (NimStringDesc*)0;
										T69_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), (*(*q).name).s);
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T69_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_79, NIM_FALSE);
										t = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
									}
									goto LA56_;
									LA67_: ;
									{
										if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA71_;
										t = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, (*x).bindings, (*a).info, t);
									}
									goto LA56_;
									LA71_: ;
									LA56_: ;
									asgnRef((void**) (&(*s_2).typ), t);
									{
										if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA75_;
										asgnRef((void**) (&(*s_2).ast), (*t).n);
									}
									LA75_: ;
									s = s_2;
									switch ((*s).kind) {
									case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
									{
										{
											if (!!(((*s).ast == 0))) goto LA80_;
											add__P8dDSotTW25BkfbyspojGg((*x).call, (*s).ast);
										}
										goto LA78_;
										LA80_: ;
										{
											add__P8dDSotTW25BkfbyspojGg((*x).call, (*(*c).graph).emptyNode);
										}
										LA78_: ;
									}
									break;
									case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T84_;
										T84_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T84_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
										add__P8dDSotTW25BkfbyspojGg((*x).call, T84_);
									}
									break;
									default:
									{
										{
											NimStringDesc* argX60gensym401_;
											if (!NIM_TRUE) goto LA88_;
											argX60gensym401_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_381);
											internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym401_, TM__rF9caJawfOjYTjsgLVUSGFA_381);
										}
										LA88_: ;
									}
									break;
									}
								} LA39: ;
								i_3 += ((NI) 1);
							} LA38: ;
						}
					}
				}
			}
		}
		LA20_: ;
	}
	LA18_: ;
	result = (*x).call;
	instGenericConvertersSons__DyVfh0xLvP9cQgsc36rPgEA(c, result, x);
	T90_ = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag((*result)._kind_6.sons->data[((NI) 0)]);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(finalCallee, T90_));
	asgnRef((void**) (&(*result).typ), (*(*finalCallee).typ).sons->data[((NI) 0)]);
	updateDefaultParams__eSEQYRkB13fhZ9c33IzktDQ(result);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, canDeref__crbaOhZgTohCnKAdtWPkSQ_2sem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NIM_BOOL T4_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NI)0;
	T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T1_ = (((NI) 2) <= T2_);
	if (!(T1_)) goto LA3_;
	t = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
	T4_ = (NIM_BOOL)0;
	T4_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	if (!(T4_)) goto LA5_;
	T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(70368744179728));
	T4_ = ((6291456 &((NU64)1<<((NU)((*T6_).kind)&63U)))!=0);
	LA5_: ;
	T1_ = T4_;
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryDeref__wWBimsBS4M6UZBvTRDlQTQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65), (*n).info);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350135273744));
	asgnRef((void**) (&(*result).typ), (*T1_).sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tySequence__0dpGN6F4ocevqUQGsaf41w* errors;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA r;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	errors = NIM_NIL;
	nimZeroMem((void*)(&r), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	resolveOverloads__deoiEhU508ju9btmg2AXeFw(c, n, nOrig, filter, flags, (&errors), ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), (&r));
	{
		if (!(r.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1))) goto LA3_;
		{
			NI T7_;
			tyTuple__ZtAk5YtH0VW1iPowvxePrg T10_;
			tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw _;
			NimStringDesc* candidates;
			NimStringDesc* T11_;
			NimStringDesc* T12_;
			T7_ = (errors ? errors->Sup.len : 0);
			if (!(((NI) 0) < T7_)) goto LA8_;
			nimZeroMem((void*)(&T10_), sizeof(tyTuple__ZtAk5YtH0VW1iPowvxePrg));
			presentFailedCandidates__DzsD9bOR72VurwdjRilOhmA(c, n, errors, (&T10_));
			_ = (tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw)0;
			_ = T10_.Field0;
			candidates = (NimStringDesc*)0;
			candidates = T10_.Field1;
			T11_ = (NimStringDesc*)0;
			T12_ = (NimStringDesc*)0;
			T12_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
			T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + (candidates ? candidates->Sup.len : 0) + 29);
appendString(T11_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_379));
appendString(T11_, T12_);
appendString(T11_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_247));
appendString(T11_, candidates);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 81), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_380, NIM_FALSE);
		}
		LA8_: ;
		result = semResolvedCall__tI9alV34Tv2MGPKAeQ6xsmw(c, (&r), n, flags);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T14_;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA r_2;
		T14_ = (NIM_BOOL)0;
		T14_ = (((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 0))&15U)))!=0);
		if (!(T14_)) goto LA15_;
		T14_ = canDeref__crbaOhZgTohCnKAdtWPkSQ_2sem(n);
		LA15_: ;
		if (!T14_) goto LA16_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), tryDeref__wWBimsBS4M6UZBvTRDlQTQ_2((*n)._kind_6.sons->data[((NI) 1)]));
		nimZeroMem((void*)(&r_2), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		resolveOverloads__deoiEhU508ju9btmg2AXeFw(c, n, nOrig, filter, flags, (&errors), ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0), (&r_2));
		{
			if (!(r_2.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1))) goto LA20_;
			result = semResolvedCall__tI9alV34Tv2MGPKAeQ6xsmw(c, (&r_2), n, flags);
		}
		goto LA18_;
		LA20_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
				if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0))) goto LA25_;
				T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T27_ = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, n, nOrig, filter, (flags | 512));
				(void)(T27_);
			}
			goto LA23_;
			LA25_: ;
			{
				if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 18))&31U)))!=0))) goto LA29_;
				notFoundError__3yYIcS0VQPQvrknpxFc7TQ(c, n, errors);
			}
			goto LA23_;
			LA29_: ;
			LA23_: ;
		}
		LA18_: ;
	}
	goto LA1_;
	LA16_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
			if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0))) goto LA34_;
			T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T36_ = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, n, nOrig, filter, (flags | 512));
			(void)(T36_);
		}
		goto LA32_;
		LA34_: ;
		{
			if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 18))&31U)))!=0))) goto LA38_;
			notFoundError__3yYIcS0VQPQvrknpxFc7TQ(c, n, errors);
		}
		goto LA32_;
		LA38_: ;
		LA32_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((flags & 6) == 0))) goto LA3_;
		result = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, n, nOrig, 520192, flags);
	}
	goto LA1_;
	LA3_: ;
	{
		result = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, n, nOrig, 487424, flags);
	}
	LA1_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee;
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA8_;
		{
			if (!!(((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA12_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_382), TM__rF9caJawfOjYTjsgLVUSGFA_383);
			goto BeforeRet_;
		}
		LA12_: ;
		callee = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		switch ((*callee).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
		{
		}
		break;
		default:
		{
			{
				NIM_BOOL T18_;
				NimStringDesc* T22_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T23_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*callee).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
				if (!(T18_)) goto LA19_;
				T18_ = ((*callee).Sup.id == (*(*(*c).p).owner).Sup.id);
				LA19_: ;
				if (!T18_) goto LA20_;
				T22_ = (NimStringDesc*)0;
				T22_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_384), (*(*callee).name).s);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_385, NIM_FALSE);
				T23_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T23_ = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T23_));
			}
			LA20_: ;
		}
		break;
		}
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, propertyWriteAccess__LlYuhVuv4UT9crSsgDzV0sQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* setterId;
	NimStringDesc* T1_;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* aOrig;
	tyArray__T6RKPw8xfAeNaoei9aZGzXg T3_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig;
	tyArray__T6RKPw8xfAeNaoei9aZGzXg T4_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	id = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*a)._kind_6.sons->data[((NI) 1)], a);
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString(((*id).s ? (*id).s->Sup.len : 0) + 1);
appendString(T1_, (*id).s);
appendChar(T1_, 61);
	T2_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T2_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T1_);
	setterId = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T2_, (*n).info);
	aOrig = (*nOrig)._kind_6.sons->data[((NI) 0)];
	nimZeroMem((void*)T3_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
	T3_[0] = setterId;
	T3_[1] = (*a)._kind_6.sons->data[((NI) 0)];
	T3_[2] = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 0);
	result = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T3_, 3);
	(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 10)) & 31);
	nimZeroMem((void*)T4_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
	T4_[0] = setterId;
	T4_[1] = (*aOrig)._kind_6.sons->data[((NI) 0)];
	T4_[2] = (*nOrig)._kind_6.sons->data[((NI) 1)];
	orig = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T4_, 3);
	result = semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA(c, result, orig, 0);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA7_;
		result = afterCallActions__Qn3T9bt6Cg4I7XaYRMg219aw(c, result, nOrig, 0);
	}
	LA7_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, dotTransformation__7YxUILpPxooC5qqa89a54dw_29)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem((*n)._kind_6.sons->data[((NI) 1)]);
		if (!T3_) goto LA4_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 25), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 1)]);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, T6_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
		i = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], n);
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 25), (*n).info);
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 9)) & 31);
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(i, (*(*n)._kind_6.sons->data[((NI) 1)]).info);
		add__P8dDSotTW25BkfbyspojGg(result, T8_);
		T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T9_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, T9_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(ident, (*n).info);
	add__P8dDSotTW25BkfbyspojGg(result, T1_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
		s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					s = (*n)._kind_6.sons->data[i];
					add__P8dDSotTW25BkfbyspojGg(result, s);
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getRoot__WJ80zbTOky5IFknpruSGag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL followDeref) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
			{
				{
					if (!followDeref) goto LA6_;
					result = (*result)._kind_6.sons->data[((NI) 0)];
				}
				goto LA4_;
				LA6_: ;
				{
					goto LA1;
				}
				LA4_: ;
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
			{
				result = (*result)._kind_6.sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
			{
				result = (*result)._kind_6.sons->data[((NI) 1)];
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	return result;
}
static N_INLINE(NIM_BOOL, scopedLifetime__Ht8IGDD0esJjGANh4G2DZwsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T4_;
	result = (NIM_BOOL)0;
	n = getRoot__WJ80zbTOky5IFknpruSGag(ri, NIM_FALSE);
	T1_ = (NIM_BOOL)0;
	T1_ = ((*ri).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) && (*ri).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32) || (*ri).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T4_ = (NIM_BOOL)0;
	T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T4_)) goto LA5_;
	T4_ = ((*(*n)._kind_4.sym).owner == (*(*c).p).owner);
	LA5_: ;
	T3_ = T4_;
	if (!(T3_)) goto LA6_;
	T3_ = !(((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11)));
	LA6_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, escapes__cZ8gUfmyb9cMvgwP1Q5K9bbAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	n = getRoot__WJ80zbTOky5IFknpruSGag(le, NIM_TRUE);
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, borrowCheck__J1O6ZLf1JD7YcSRxfw8Usg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*ri).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T6_)) goto LA7_;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*ri).typ, IL64(36099165763184912));
		T6_ = ((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45));
		LA7_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA9_;
		T5_ = !(((*le).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA9_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA10_;
		T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*le).typ, IL64(36099165763184912));
		T4_ = !(((*T11_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
		LA10_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA12_;
		T3_ = scopedLifetime__Ht8IGDD0esJjGANh4G2DZwsem(c, ri);
		LA12_: ;
		if (!T3_) goto LA13_;
		{
			NIM_BOOL T17_;
			NimStringDesc* T21_;
			NimStringDesc* T22_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*le).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T17_)) goto LA18_;
			T17_ = ((*(*le)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			LA18_: ;
			if (!T17_) goto LA19_;
			T21_ = (NimStringDesc*)0;
			T22_ = (NimStringDesc*)0;
			T22_ = typeToString__QlvraUan7WbHowhAbvDvdA((*le).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T21_ = rawNewString((T22_ ? T22_->Sup.len : 0) + 86);
appendString(T21_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_391));
appendString(T21_, T22_);
appendString(T21_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_392));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_393, NIM_FALSE);
		}
		goto LA15_;
		LA19_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = escapes__cZ8gUfmyb9cMvgwP1Q5K9bbAsem(c, le);
			if (!T24_) goto LA25_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_394), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_395, NIM_FALSE);
		}
		goto LA15_;
		LA25_: ;
		LA15_: ;
	}
	LA13_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, goodLineInfo__eFiXGzEcaqcZ648kwvI9a9ag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q));
	{
		NIM_BOOL T3_;
		NI T5_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(arg);
		T3_ = (((NI) 0) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = (NI)0;
		T8_ = len__P89cqdlERShb9alU3iC0yj8wast(arg);
		result = goodLineInfo__eFiXGzEcaqcZ648kwvI9a9ag((*arg)._kind_6.sons->data[(NI)(T8_ - ((NI) 1))]);
	}
	goto LA1_;
	LA6_: ;
	{
		result = (*arg).info;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL isLent) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* root;
	tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag valid;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	root = exprRoot__XD7qSmhHQJchscUPfXW57g(n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((root == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*root).owner == (*(*c).p).owner);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			tyArray__24KAM9afIUgUaqBaEBB6r9bg T13_;
			NimStringDesc* T14_;
			T9_ = (NIM_BOOL)0;
			T9_ = ((800 &((NU32)1<<((NU)((*root).kind)&31U)))!=0);
			if (!(T9_)) goto LA10_;
			T9_ = !((((*root).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
			LA10_: ;
			if (!T9_) goto LA11_;
			nimZeroMem((void*)T13_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
			T13_[0] = copyString((*(*root).name).s);
			T13_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
			T13_[2] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_397));
			T14_ = (NimStringDesc*)0;
			T14_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_396), T13_, 3);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T14_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_398, NIM_FALSE);
		}
		goto LA7_;
		LA11_: ;
		{
			NIM_BOOL T16_;
			tyArray__24KAM9afIUgUaqBaEBB6r9bg T20_;
			NimStringDesc* T21_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*root).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			if (!(T16_)) goto LA17_;
			T16_ = !(((*root).position == ((NI) 0)));
			LA17_: ;
			if (!T16_) goto LA18_;
			nimZeroMem((void*)T20_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
			T20_[0] = copyString((*(*root).name).s);
			T20_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
			T20_[2] = createDocLink__pWiLD3R2s41obcTDlPhj9cA(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_397));
			T21_ = (NimStringDesc*)0;
			T21_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_399), T20_, 3);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_400, NIM_FALSE);
		}
		goto LA7_;
		LA18_: ;
		LA7_: ;
	}
	LA5_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	{
		result = n;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	{
		result = (*n)._kind_6.sons->data[((NI) 0)];
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		{
			NI T27_;
			T27_ = (NI)0;
			T27_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T27_ == ((NI) 1))) goto LA28_;
			result = (*n)._kind_6.sons->data[((NI) 0)];
			goto BeforeRet_;
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
	}
	break;
	default:
	{
	}
	break;
	}
	valid = isAssignable__ASvZU4uIBad6J9b9cMoLNFvA(c, n, isLent);
	{
		if (!!((valid == ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 1)))) goto LA34_;
		{
			NimStringDesc* T40_;
			NimStringDesc* T41_;
			if (!(valid == ((tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag) 2))) goto LA38_;
			T40_ = (NimStringDesc*)0;
			T40_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
			T41_ = (NimStringDesc*)0;
			T41_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_217), T40_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T41_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_401, NIM_FALSE);
		}
		goto LA36_;
		LA38_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_222), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_402, NIM_FALSE);
		}
		LA36_: ;
	}
	LA34_: ;
	T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T43_ = makePtrType__PDWeh9cjpi22xXdNggYvsWA(c, (*n).typ);
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64), (*n).info, T43_);
	add__P8dDSotTW25BkfbyspojGg(result, n);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, asgnToResultVar__h9b9cHg6rgpKzNHniS8pqoyAsem)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		if (!((*le).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA3_;
		x = (*le)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			tyEnum_ViewTypeKind__3S4FAWaxPP9ahVaUnMsznog T11_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*(*x).typ).kind)&63U)))!=0);
			if (T9_) goto LA10_;
			T11_ = (tyEnum_ViewTypeKind__3S4FAWaxPP9ahVaUnMsznog)0;
			T11_ = classifyViewType__mrAxDuBowGCWq5wvtjg9bxA((*x).typ);
			T9_ = !((T11_ == ((tyEnum_ViewTypeKind__3S4FAWaxPP9ahVaUnMsznog) 0)));
			LA10_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA12_;
			T8_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA12_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA13_;
			T7_ = ((*(*x)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
			LA13_: ;
			if (!T7_) goto LA14_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), x);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ(c, ri, ((*(*x).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))));
			(*(*x).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
		}
		LA14_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsgn__mkzYzG9avRzHz5NmIFyZdRg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ mode) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* le;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	a = (*n)._kind_6.sons->data[((NI) 0)];
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig;
		nOrig = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		a = builtinFieldAccess__vJZwz9bfROKrfrtM50y74CQ_5(c, a, 1);
		{
			if (!(a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA4_;
			a = propertyWriteAccess__LlYuhVuv4UT9crSsgDzV0sQ(c, n, nOrig, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA8_;
				result = a;
				goto BeforeRet_;
			}
			LA8_: ;
			a = dotTransformation__7YxUILpPxooC5qqa89a54dw_29(c, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 25))) goto LA12_;
				transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(a, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 27));
				a = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, a, 1);
			}
			LA12_: ;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		a = semSubscript__vJZwz9bfROKrfrtM50y74CQ_9(c, a, 1);
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T19_;
			if (!(a == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA17_;
			T19_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T19_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_119));
			result = buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w((*n)._kind_6.sons->data[((NI) 0)], T19_);
			add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!(mode == ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 1))) goto LA22_;
				bracketNotFoundError__NRIJDWZtATzMum7OEjYC2g_8(c, result);
				result = n;
				goto BeforeRet_;
			}
			goto LA20_;
			LA22_: ;
			{
				result = semExprNoType__7YxUILpPxooC5qqa89a54dw_2(c, result);
				goto BeforeRet_;
			}
			LA20_: ;
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T26_;
		T26_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T26_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_118));
		result = buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w((*n)._kind_6.sons->data[((NI) 0)], T26_);
		add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 1)]);
		result = semExprNoType__7YxUILpPxooC5qqa89a54dw_2(c, result);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		{
			NI T30_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T33_;
			T30_ = (NI)0;
			T30_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
			if (!(((NI) 2) <= T30_)) goto LA31_;
			T33_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T33_ = lowerTupleUnpackingForAsgn__8A4G64HByteFanrMUexmNw_3((*c).graph, n, (*(*c).p).owner);
			result = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, T33_, 0);
			goto BeforeRet_;
		}
		goto LA28_;
		LA31_: ;
		{
			a = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, a, 1);
		}
		LA28_: ;
	}
	break;
	default:
	{
		a = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, a, 1);
	}
	break;
	}
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), a);
	le = (*a).typ;
	{
		if (!(le == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA38_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_386), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_387, NIM_FALSE);
	}
	goto LA36_;
	LA38_: ;
	{
		NIM_BOOL T41_;
		NIM_BOOL T42_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
		tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag T45_;
		NIM_BOOL T47_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T48_;
		NimStringDesc* T52_;
		NimStringDesc* T53_;
		T41_ = (NIM_BOOL)0;
		T42_ = (NIM_BOOL)0;
		T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T43_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(le, IL64(70368744179728));
		T42_ = !(((8388608 &((NU64)1<<((NU)((*T43_).kind)&63U)))!=0));
		if (!(T42_)) goto LA44_;
		T45_ = (tyEnum_TAssignableResult__JFgO3TudAWntzWI8Fmx4Ag)0;
		T45_ = isAssignable__ASvZU4uIBad6J9b9cMoLNFvA(c, a, NIM_FALSE);
		T42_ = ((17 &((NU8)1<<((NU)(T45_)&7U)))!=0);
		LA44_: ;
		T41_ = T42_;
		if (T41_) goto LA46_;
		T47_ = (NIM_BOOL)0;
		T48_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T48_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(le, IL64(36275087632017680));
		T47_ = ((IL64(281475110928384) &((NU64)1<<((NU)((*T48_).kind)&63U)))!=0);
		if (!(T47_)) goto LA49_;
		T47_ = !((((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 13))&15U)))!=0));
		LA49_: ;
		T41_ = T47_;
		LA46_: ;
		if (!T41_) goto LA50_;
		T52_ = (NimStringDesc*)0;
		T52_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(a, 4);
		T53_ = (NimStringDesc*)0;
		T53_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_388), T52_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T53_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_389, NIM_FALSE);
	}
	goto LA36_;
	LA50_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs;
		NIM_BOOL lhsIsResult;
		NIM_BOOL T55_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs;
		tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ T57_;
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T91_;
		lhs = (*n)._kind_6.sons->data[((NI) 0)];
		T55_ = (NIM_BOOL)0;
		T55_ = ((*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T55_)) goto LA56_;
		T55_ = ((*(*lhs)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
		LA56_: ;
		lhsIsResult = T55_;
		{
			if (!lhsIsResult) goto LA60_;
			T57_ = 1024;
		}
		goto LA58_;
		LA60_: ;
		{
			T57_ = 0;
		}
		LA58_: ;
		rhs = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], T57_);
		{
			if (!lhsIsResult) goto LA65_;
			asgnRef((void**) (&(*n).typ), (*c).enforceVoidContext);
			{
				NIM_BOOL T69_;
				NIM_BOOL T71_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rhsTyp;
				T69_ = (NIM_BOOL)0;
				T69_ = !(((*(*(*c).p).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
				if (!(T69_)) goto LA70_;
				T71_ = (NIM_BOOL)0;
				T71_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw((*(*lhs)._kind_4.sym).typ);
				if (!(T71_)) goto LA72_;
				T71_ = !(((*(*(*lhs)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
				LA72_: ;
				T69_ = T71_;
				LA70_: ;
				if (!T69_) goto LA73_;
				rhsTyp = (*rhs).typ;
				{
					NIM_BOOL T77_;
					T77_ = (NIM_BOOL)0;
					T77_ = ((IL64(13510798882111488) &((NU64)1<<((NU)((*rhsTyp).kind)&63U)))!=0);
					if (!(T77_)) goto LA78_;
					T77_ = (((*rhsTyp).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
					LA78_: ;
					if (!T77_) goto LA79_;
					rhsTyp = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(rhsTyp);
				}
				LA79_: ;
				{
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T83_;
					T83_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
					T83_ = cmpTypes__6LyhcPFOyQXLaZFXoqJM1w(c, (*lhs).typ, rhsTyp);
					if (!((1280 &((NU16)1<<((NU)(T83_)&15U)))!=0)) goto LA84_;
					{
						NimStringDesc* argX60gensym4577_;
						if (!!(!(((*(*c).p).resultSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))))) goto LA88_;
						argX60gensym4577_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_390);
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4577_, TM__rF9caJawfOjYTjsgLVUSGFA_390);
					}
					LA88_: ;
					typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q(c, (*n).info, rhsTyp, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11), 0);
					asgnRef((void**) (&(*lhs).typ), rhsTyp);
					asgnRef((void**) (&(*(*(*c).p).resultSym).typ), rhsTyp);
					asgnRef((void**) (&(*(*(*(*c).p).owner).typ).sons->data[((NI) 0)]), rhsTyp);
				}
				goto LA81_;
				LA84_: ;
				{
					typeMismatch__1xxyFIws27lai2cG4n31Ow((*(*c).graph).config, (*n).info, (*lhs).typ, rhsTyp);
				}
				LA81_: ;
			}
			LA73_: ;
		}
		LA65_: ;
		borrowCheck__J1O6ZLf1JD7YcSRxfw8Usg(c, n, lhs, rhs);
		T91_ = goodLineInfo__eFiXGzEcaqcZ648kwvI9a9ag((*n)._kind_6.sons->data[((NI) 1)]);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, le, rhs, T91_));
		fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6(c, n);
		asgnToResultVar__h9b9cHg6rgpKzNHniS8pqoyAsem(c, n, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)]);
	}
	LA36_: ;
	result = n;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProcBody__7YxUILpPxooC5qqa89a54dw_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, 0);
	{
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*(*c).p).resultSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*result).typ);
		T4_ = !(T6_);
		LA5_: ;
		if (!T4_) goto LA7_;
		{
			if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA11_;
			asgnRef((void**) (&(*result).typ), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		}
		goto LA9_;
		LA11_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
			if (!(T14_)) goto LA15_;
			T14_ = ((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
			LA15_: ;
			if (!T14_) goto LA16_;
			fixNilType__NRIJDWZtATzMum7OEjYC2g_2(c, result);
		}
		goto LA9_;
		LA16_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
			a = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info, ((NI) 2));
			asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*c).p).resultSym));
			asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 1)]), result);
			result = semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, a, ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 0));
		}
		LA9_: ;
	}
	goto LA2_;
	LA7_: ;
	{
		discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, result, 0);
	}
	LA2_: ;
	{
		NIM_BOOL T22_;
		NIM_BOOL T23_;
		T22_ = (NIM_BOOL)0;
		T23_ = (NIM_BOOL)0;
		T23_ = !(((393216 &((NU32)1<<((NU)((*(*(*c).p).owner).kind)&31U)))!=0));
		if (!(T23_)) goto LA24_;
		T23_ = !(((*(*c).p).resultSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA24_: ;
		T22_ = T23_;
		if (!(T22_)) goto LA25_;
		T22_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw((*(*(*c).p).resultSym).typ);
		LA25_: ;
		if (!T22_) goto LA26_;
		{
			NIM_BOOL T30_;
			T30_ = (NIM_BOOL)0;
			T30_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*result).typ);
			if (!T30_) goto LA31_;
			asgnRef((void**) (&(*(*(*c).p).resultSym).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
			asgnRef((void**) (&(*(*(*(*c).p).owner).typ).sons->data[((NI) 0)]), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		}
		goto LA28_;
		LA31_: ;
		{
			NimStringDesc* T34_;
			T34_ = (NimStringDesc*)0;
			T34_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_403), (*(*(*(*c).p).owner).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*c).p).resultSym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T34_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_404, NIM_FALSE);
		}
		LA28_: ;
	}
	LA26_: ;
	{
		NIM_BOOL T37_;
		NIM_BOOL T38_;
		NimStringDesc* T43_;
		T37_ = (NIM_BOOL)0;
		T38_ = (NIM_BOOL)0;
		T38_ = isInlineIterator__EhCVbB6PynSh7XFAFVMiJAast((*(*(*c).p).owner).typ);
		if (!(T38_)) goto LA39_;
		T38_ = !(((*(*(*(*c).p).owner).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA39_: ;
		T37_ = T38_;
		if (!(T37_)) goto LA40_;
		T37_ = ((*(*(*(*(*c).p).owner).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
		LA40_: ;
		if (!T37_) goto LA41_;
		T43_ = (NimStringDesc*)0;
		T43_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_403), (*(*(*(*c).p).owner).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*c).p).owner).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T43_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_405, NIM_FALSE);
	}
	LA41_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, instantiateBody__6k2yIpmfdYEOM5RXDFvgYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* orig) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procParams;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMap;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		procParams = (*(*result).typ).n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(procParams);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, (*(*procParams)._kind_6.sons->data[i])._kind_4.sym);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
		maybeAddResult__8H5d8d9cPCfbpMuDrerQMeQ(c, result, (*result).ast);
		(*c).inGenericInst += ((NI) 1);
		b = (*n)._kind_6.sons->data[((NI) 6)];
		nimZeroMem((void*)(&symMap), sizeof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q));
		initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&symMap));
		{
			if (!!((params == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA10_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(params);
				i_4 = ((NI) 1);
				{
					while (1) {
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
						if (!(i_4 < colontmp__2)) goto LA14;
						i_3 = i_4;
						param = (*(*params)._kind_6.sons->data[i_3])._kind_4.sym;
						{
							tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T19_;
							RootObj* T20_;
							if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0)) goto LA17_;
							T19_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
							T19_ = &(*(*params)._kind_6.sons->data[i_3])._kind_4.sym->Sup;
							T20_ = (RootObj*)0;
							T20_ = &(*(*(*(*result).typ).n)._kind_6.sons->data[(NI)((*param).position + ((NI) 1))])._kind_4.sym->Sup.Sup;
							idTablePut__anELyz7VLsjbCIoxLpxbfQ((&symMap), T19_, T20_);
						}
						LA17_: ;
						i_4 += ((NI) 1);
					} LA14: ;
				}
			}
		}
		LA10_: ;
		freshGenSyms__sniSZ3lXmsiJXk4n7qLgPw(b, result, orig, (&symMap));
		b = semProcBody__7YxUILpPxooC5qqa89a54dw_5(c, b);
		asgnRef((void**) (&(*(*result).ast)._kind_6.sons->data[((NI) 6)]), hloBody__7YxUILpPxooC5qqa89a54dw_10(c, b));
		trackProc__P9bJkIGwY9beKGfhhcBedbpg(c, result, (*(*result).ast)._kind_6.sons->data[((NI) 6)]);
		(*result).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
		(*c).inGenericInst -= ((NI) 1);
	}
	LA3_: ;
}
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI L;
	NI T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, finishMethod__PSSiITp8zAUcZ8z1k5AMLA_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasObjParam__J1LR9bIUh18t4XFDmYEYBYw_2(s);
		if (!T3_) goto LA4_;
		methodDef__NKjYu87vB0uQmGRMfpDEBQ((*c).graph, s, NIM_FALSE);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, generateInstance__Bbmaz5QjetnTaor7LYngPg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T9_;
	NI T10_;
	tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* oldMatchedConcept;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* oldScope;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T14_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
	tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* entry;
	NI i;
	NI T19_;
	NI T20_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* oldPrc;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T99_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NimStringDesc* argX60gensym204_;
		if (!!(!(((393216 &((NU32)1<<((NU)((*fn).kind)&31U)))!=0)))) goto LA3_;
		argX60gensym204_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_70);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym204_, TM__rF9caJawfOjYTjsgLVUSGFA_70);
	}
	LA3_: ;
	{
		if (!(((NI) 50) < (*c).instCounter)) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_72), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_73, NIM_FALSE);
	}
	LA7_: ;
	(*c).instCounter += ((NI) 1);
	n = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*fn).ast);
	T9_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T9_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(fn);
	asgnRef((void**) (&(*c).friendModules), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).friendModules), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T10_ = (*c).friendModules->Sup.len++;
	asgnRef((void**) (&(*c).friendModules->data[T10_]), T9_);
	oldMatchedConcept = (*c).matchedConcept;
	(*c).matchedConcept = ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL);
	oldScope = (*c).currentScope;
	{
		while (1) {
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
			if (!!(T13_)) goto LA12;
			asgnRef((void**) (&(*c).currentScope), (*(*c).currentScope).parent);
		} LA12: ;
	}
	result = copySym__lIu8wX6Beq6dBJgESOFFjg(fn);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
	asgnRef((void**) (&(*result).owner), fn);
	asgnRef((void**) (&(*result).ast), n);
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, result);
	T14_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T14_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	gp = (*n)._kind_6.sons->data[((NI) 2)];
	{
		NimStringDesc* argX60gensym213_;
		if (!!(!(((*gp).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))))) goto LA17_;
		argX60gensym213_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_74);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym213_, TM__rF9caJawfOjYTjsgLVUSGFA_74);
	}
	LA17_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result));
	pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, info, (*(*fn).name).s);
	entry = new__BiEKflRN9azaxRNwAA9br7uA();
	asgnRef((void**) (&(*entry).sym), result);
	i = ((NI) 0);
	T19_ = (NI)0;
	T19_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*fn).typ);
	T20_ = (NI)0;
	T20_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
	if ((*entry).concreteTypes) { nimGCunrefNoCycle((*entry).concreteTypes); (*entry).concreteTypes = NIM_NIL; }
	(*entry).concreteTypes = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), ((NI) ((NI)((NI)(T19_ + T20_) - ((NI) 1)))));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		{
			NimStringDesc* argX60gensym124_;
			if (!!(((*gp).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75)))) goto LA24_;
			argX60gensym124_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_75);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym124_, TM__rF9caJawfOjYTjsgLVUSGFA_75);
		}
		LA24_: ;
		{
			NI i_2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
			i_2 = (NI)0;
			a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp_;
				NI i_4;
				i_3 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(gp);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp_)) goto LA29;
						i_3 = i_4;
						i_2 = i_3;
						a = (*gp)._kind_6.sons->data[i_3];
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* q;
							tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T44_;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
							tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T45_;
							RootObj* T46_;
							{
								NimStringDesc* argX60gensym127_;
								if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA33_;
								argX60gensym127_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_76);
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym127_, TM__rF9caJawfOjYTjsgLVUSGFA_76);
							}
							LA33_: ;
							q = (*a)._kind_4.sym;
							{
								if (!!(((IL64(2267562412381049088) &((NU64)1<<((NU)((*(*q).typ).kind)&63U)))!=0))) goto LA37_;
								goto LA30;
							}
							LA37_: ;
							{
								if (!((*(*q).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA41_;
								symKind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10);
							}
							goto LA39_;
							LA41_: ;
							{
								symKind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7);
							}
							LA39_: ;
							T44_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T44_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
							s_2 = newSym__IXbidcxhXTQGZY9abN63Cxg(symKind, (*q).name, T44_, (*q).info, 0);
							(*s_2).flags = ((*s_2).flags | 5);
							T45_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
							T45_ = &(*q).typ->Sup;
							T46_ = (RootObj*)0;
							T46_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw(pt, T45_);
							t = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T46_));
							{
								if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA49_;
								{
									if (!(((*(*q).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 11))&63U)))!=0)) goto LA53_;
									t = (*q).typ;
								}
								goto LA51_;
								LA53_: ;
								{
									NimStringDesc* T56_;
									T56_ = (NimStringDesc*)0;
									T56_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), (*(*s_2).name).s);
									liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T56_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_78, NIM_FALSE);
									t = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
								}
								LA51_: ;
							}
							goto LA47_;
							LA49_: ;
							{
								NimStringDesc* T60_;
								if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA58_;
								T60_ = (NimStringDesc*)0;
								T60_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), (*(*q).name).s);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T60_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_79, NIM_FALSE);
								t = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
							}
							goto LA47_;
							LA58_: ;
							{
								if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA62_;
								t = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, pt, (*a).info, t);
							}
							goto LA47_;
							LA62_: ;
							LA47_: ;
							asgnRef((void**) (&(*s_2).typ), t);
							{
								if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA66_;
								asgnRef((void**) (&(*s_2).ast), (*t).n);
							}
							LA66_: ;
							s = s_2;
							addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, s);
							asgnRef((void**) (&(*entry).concreteTypes->data[i]), (*s).typ);
							i += ((NI) 1);
						} LA30: ;
						i_4 += ((NI) 1);
					} LA29: ;
				}
			}
		}
	}
	rawPushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ(c, result);
	instantiateProcType__1PhCjyNxyOAJRoRgfsrJDQ(c, pt, result, info);
	{
		NI j;
		NI colontmp__2;
		NI i_5;
		j = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast((*result).typ);
		i_5 = ((NI) 1);
		{
			while (1) {
				if (!(i_5 < colontmp__2)) goto LA70;
				j = i_5;
				asgnRef((void**) (&(*entry).concreteTypes->data[i]), (*(*result).typ).sons->data[j]);
				i += ((NI) 1);
				i_5 += ((NI) 1);
			} LA70: ;
		}
	}
	{
		if (!(((*(*result).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 33))&63U)))!=0)) goto LA73_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27)) & 63);
	}
	LA73_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), (*(*c).graph).emptyNode);
	oldPrc = genericCacheGet__yrVWUjVCLM4qNMOOOoQryQ(fn, (*entry), (*c).compilesContextId);
	{
		NI T79_;
		tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ T80_;
		NI T81_;
		if (!(oldPrc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA77_;
		rawHandleSelf__jWGpC0lY8vG9b1MhOYJ9cFiQ_2(c, result);
		(*entry).compilesId = (*c).compilesContextId;
		asgnRef((void**) (&(*fn)._kind_2.procInstCache), (tySequence__DXS6mEo7PVUFJkirsQ9bNQA*) incrSeqV3((TGenericSeq*)((*fn)._kind_2.procInstCache), (&NTI__DXS6mEo7PVUFJkirsQ9bNQA_)));
		T79_ = (*fn)._kind_2.procInstCache->Sup.len++;
		asgnRef((void**) (&(*fn)._kind_2.procInstCache->data[T79_]), entry);
		nimZeroMem((void*)(&T80_), sizeof(tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ));
		makeInstPair__OBM04JqIpDFmR9bhgy9ckD3w(fn, entry, (&T80_));
		asgnRef((void**) (&(*c).generics), (tySequence__jWKvSdankQPoT5bw9cBU9aiw*) incrSeqV3((TGenericSeq*)((*c).generics), (&NTI__jWKvSdankQPoT5bw9cBU9aiw_)));
		T81_ = (*c).generics->Sup.len++;
		asgnRef((void**) (&(*c).generics->data[T81_].genericSym), T80_.genericSym);
		asgnRef((void**) (&(*c).generics->data[T81_].inst), T80_.inst);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA84_;
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 4)], TM__rF9caJawfOjYTjsgLVUSGFA_92, NIM_FALSE);
		}
		LA84_: ;
		{
			if (!((*n)._kind_6.sons->data[((NI) 6)] == 0)) goto LA88_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*fn).ast)._kind_6.sons->data[((NI) 6)]));
		}
		LA88_: ;
		{
			if (!((*c).inGenericContext == ((NI) 0))) goto LA92_;
			instantiateBody__6k2yIpmfdYEOM5RXDFvgYQ(c, n, (*(*fn).typ).n, result, fn);
		}
		LA92_: ;
		sideEffectsCheck__PSSiITp8zAUcZ8z1k5AMLA_3(c, result);
		{
			if (!!(((*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126) || (*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18)))) goto LA96_;
			paramsTypeCheck__X9cjeXk0ogla5nWLtx0FEkAsem(c, (*result).typ);
		}
		LA96_: ;
	}
	goto LA75_;
	LA77_: ;
	{
		result = oldPrc;
	}
	LA75_: ;
	popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
	popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	asgnRef((void**) (&(*c).currentScope), oldScope);
	T99_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T99_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).friendModules));
	(void)(T99_);
	(*c).instCounter -= ((NI) 1);
	(*c).matchedConcept = oldMatchedConcept;
	{
		if (!((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14))) goto LA102_;
		finishMethod__PSSiITp8zAUcZ8z1k5AMLA_4(c, result);
	}
	LA102_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, instGenericConvertersArg__OiEXsRRJbWjgfYLWIAKYYQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* x) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
	{
		if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA3_;
		a_2 = (*a)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		a_2 = a;
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*a_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T8_)) goto LA9_;
		T8_ = ((*(*a_2)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA9_: ;
		if (!T8_) goto LA10_;
		s = (*(*a_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T14_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* finalCallee;
			T14_ = (NIM_BOOL)0;
			T14_ = !(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T14_)) goto LA15_;
			T14_ = !(((*(*(*s).ast)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
			LA15_: ;
			if (!T14_) goto LA16_;
			finalCallee = generateInstance__Bbmaz5QjetnTaor7LYngPg(c, s, (*x).bindings, (*a_2).info);
			asgnRef((void**) (&(*(*a_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym), finalCallee);
			asgnRef((void**) (&(*(*a_2)._kind_6.sons->data[((NI) 0)]).typ), (*finalCallee).typ);
		}
		LA16_: ;
	}
	LA10_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, indexTypesMatch__8llRCFM4VdmgY27XJn2sRA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, f, (&m));
	result = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA((&m), f, a, arg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = m.genericConverter;
		if (!(T3_)) goto LA4_;
		T3_ = !((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		instGenericConvertersArg__OiEXsRRJbWjgfYLWIAKYYQ(c, result, (&m));
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitNode__3gQ9buvlr7tPLmWwfmGV7fw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((*arg).typ == 0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T6_ = (NimStringDesc*)0;
		T6_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(arg, 4);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 24);
appendString(T5_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_65));
appendString(T5_, T6_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*arg).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_66, NIM_FALSE);
		result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
		asgnRef((void**) (&(*result).typ), formal);
	}
	goto LA1_;
	LA3_: ;
	{
		result = indexTypesMatch__8llRCFM4VdmgY27XJn2sRA(c, formal, (*arg).typ, arg);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA10_;
			typeMismatch__1xxyFIws27lai2cG4n31Ow((*(*c).graph).config, info, formal, (*arg).typ);
			result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
			asgnRef((void**) (&(*result).typ), formal);
		}
		goto LA8_;
		LA10_: ;
		{
			result = fitNodePostMatch__t9cW9ai7WILQBcTRPAW4swfA(c, formal, result);
		}
		LA8_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, forceBool__7YxUILpPxooC5qqa89a54dw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
	result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, T1_, n, (*n).info);
	{
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA4_;
		result = n;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstBoolExpr__7YxUILpPxooC5qqa89a54dw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, n);
	result = forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T1_);
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_406, NIM_FALSE);
	}
	LA4_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callee;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA3_;
		callee = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			NIM_BOOL T12_;
			NIM_BOOL T15_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*callee).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
			if (!(T9_)) goto LA10_;
			T9_ = ((*(*callee)._kind_5.ident).Sup.id == ((NI) 71));
			LA10_: ;
			T8_ = T9_;
			if (T8_) goto LA11_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*callee).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T12_)) goto LA13_;
			T12_ = ((*(*(*callee)._kind_4.sym).name).Sup.id == ((NI) 71));
			LA13_: ;
			T8_ = T12_;
			LA11_: ;
			T7_ = T8_;
			if (T7_) goto LA14_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((*callee).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*callee).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57));
			if (!(T15_)) goto LA16_;
			T15_ = ((*(*(*(*callee)._kind_6.sons->data[((NI) 1)])._kind_4.sym).name).Sup.id == ((NI) 71));
			LA16_: ;
			T7_ = T15_;
			LA14_: ;
			if (!T7_) goto LA17_;
			result = NIM_TRUE;
		}
		LA17_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBranchRange__j3LbHf9bqKk6Mw4S3FFgkVQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ac;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* bc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* at;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* bt;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(t, ((NI) 1), (*(*c).graph).config);
	ac = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, a);
	bc = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, b);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, ac, (*ac).info);
	at = skipConvTakeType__BH9abOhPX8pH0DnEWlRxmlw_4(T1_);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, bc, (*bc).info);
	bt = skipConvTakeType__BH9abOhPX8pH0DnEWlRxmlw_4(T2_);
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), (*a).info);
	add__P8dDSotTW25BkfbyspojGg(result, at);
	add__P8dDSotTW25BkfbyspojGg(result, bt);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = emptyRange__tlIBRycg3YyKwtO2aPbGGg_2(ac, bc);
		if (!T5_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*b).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_27), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_416, NIM_FALSE);
	}
	goto LA3_;
	LA6_: ;
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T10_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T11_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
		T9_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(bc, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		T10_ = plus___Sp7OcCEIFoBYolB6PB1fAg((*covered), T9_);
		T11_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(T10_, IL64(1));
		T12_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(ac, Max__zlJMNfqX7LwCYj0PF6ncWQ);
		(*covered) = minus___Sp7OcCEIFoBYolB6PB1fAg_2(T11_, T12_);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCaseBranchRange__0knXB2kLqr5zutyOXWu8Rg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(b, ((NI) 3), (*(*c).graph).config);
	result = semBranchRange__j3LbHf9bqKk6Mw4S3FFgkVQ(c, t, (*b)._kind_6.sons->data[((NI) 1)], (*b)._kind_6.sons->data[((NI) 2)], covered);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCaseBranchSetElem__0knXB2kLqr5zutyOXWu8Rg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees(b);
		if (!T3_) goto LA4_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(b, ((NI) 3), (*(*c).graph).config);
		result = semBranchRange__j3LbHf9bqKk6Mw4S3FFgkVQ(c, t, (*b)._kind_6.sons->data[((NI) 1)], (*b)._kind_6.sons->data[((NI) 2)], covered);
	}
	goto LA1_;
	LA4_: ;
	{
		if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA7_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(b, ((NI) 2), (*(*c).graph).config);
		result = semBranchRange__j3LbHf9bqKk6Mw4S3FFgkVQ(c, t, (*b)._kind_6.sons->data[((NI) 0)], (*b)._kind_6.sons->data[((NI) 1)], covered);
	}
	goto LA1_;
	LA7_: ;
	{
		result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, b, (*b).info);
		inc__Glh2geFlMs9aE78UZ1JZGAA(covered, ((NU32) 1));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkForOverlap__72gDnaHzi4O4sp9av09bP7vw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, NI currentEx, NI branchIndex) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ex;
	ex = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*(*t)._kind_6.sons->data[branchIndex])._kind_6.sons->data[currentEx]);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= branchIndex)) goto LA3;
				i = res;
				{
					NI j;
					NI colontmp_;
					NI T5_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T5_ = (NI)0;
					T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*t)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T5_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA7;
							j = i_2;
							{
								NIM_BOOL T10_;
								T10_ = (NIM_BOOL)0;
								T10_ = (i == branchIndex);
								if (!(T10_)) goto LA11_;
								T10_ = (j == currentEx);
								LA11_: ;
								if (!T10_) goto LA12_;
								goto LA4;
							}
							LA12_: ;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
								NIM_BOOL T17_;
								T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T16_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*(*t)._kind_6.sons->data[i])._kind_6.sons->data[j]);
								T17_ = (NIM_BOOL)0;
								T17_ = overlap__tlIBRycg3YyKwtO2aPbGGg(T16_, ex);
								if (!T17_) goto LA18_;
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*ex).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_417), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_418, NIM_FALSE);
							}
							LA18_: ;
							i_2 += ((NI) 1);
						} LA7: ;
					}
				} LA4: ;
				res += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, semCaseBranch__v9aNPEhC9bTKfOzSbulyV4jw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch, NI branchIndex, tyObject_Int128__9a9axPfb75jdWY25AamJewkA* covered) {
	NI lastIndex;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
	lastIndex = (NI)(T1_ - ((NI) 2));
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
				if (!(res <= lastIndex)) goto LA4;
				i = res;
				b = (*branch)._kind_6.sons->data[i];
				{
					if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA7_;
					asgnRef((void**) (&(*branch)._kind_6.sons->data[i]), b);
				}
				goto LA5_;
				LA7_: ;
				{
					NIM_BOOL T10_;
					T10_ = (NIM_BOOL)0;
					T10_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees(b);
					if (!T10_) goto LA11_;
					asgnRef((void**) (&(*branch)._kind_6.sons->data[i]), semCaseBranchRange__0knXB2kLqr5zutyOXWu8Rg(c, t, b, covered));
				}
				goto LA5_;
				LA11_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
					r = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, b);
					{
						NIM_BOOL T16_;
						NIM_BOOL T17_;
						NI T19_;
						NI T21_;
						T16_ = (NIM_BOOL)0;
						T17_ = (NIM_BOOL)0;
						T17_ = ((*r).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*r).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
						if (!(T17_)) goto LA18_;
						T19_ = (NI)0;
						T19_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
						T17_ = (T19_ == ((NI) 0));
						LA18_: ;
						T16_ = T17_;
						if (!(T16_)) goto LA20_;
						T21_ = (NI)0;
						T21_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
						T16_ = (T21_ == ((NI) 2));
						LA20_: ;
						if (!T16_) goto LA22_;
						delSon__oU9bKATaboy8iUhv0r9bMBPw(branch, ((NI) 0));
						goto BeforeRet_;
					}
					goto LA14_;
					LA22_: ;
					{
						NIM_BOOL T25_;
						NI T27_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tmp;
						T25_ = (NIM_BOOL)0;
						T25_ = !(((*r).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*r).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)));
						if (T25_) goto LA26_;
						T27_ = (NI)0;
						T27_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
						T25_ = (T27_ == ((NI) 0));
						LA26_: ;
						if (!T25_) goto LA28_;
						checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(t, ((NI) 1), (*(*c).graph).config);
						tmp = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*(*t)._kind_6.sons->data[((NI) 0)]).typ, r, (*r).info);
						{
							if (!((*tmp).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA32_;
							tmp = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, tmp);
						}
						LA32_: ;
						asgnRef((void**) (&(*branch)._kind_6.sons->data[i]), skipConv__BH9abOhPX8pH0DnEWlRxmlw(tmp));
						inc__Glh2geFlMs9aE78UZ1JZGAA(covered, ((NU32) 1));
					}
					goto LA14_;
					LA28_: ;
					{
						{
							if (!((*r).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39))) goto LA37_;
							r = deduplicate__npqksG7nXsyGRBfJK1db1g((*(*c).graph).config, r);
						}
						LA37_: ;
						asgnRef((void**) (&(*branch)._kind_6.sons->data[i]), semCaseBranchSetElem__0knXB2kLqr5zutyOXWu8Rg_2(c, t, (*r)._kind_6.sons->data[((NI) 0)], covered));
						{
							NI j;
							NI colontmp_;
							NI i_2;
							j = (NI)0;
							colontmp_ = (NI)0;
							colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
							i_2 = ((NI) 1);
							{
								while (1) {
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
									NI T44_;
									NI T45_;
									if (!(i_2 < colontmp_)) goto LA41;
									j = i_2;
									T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T42_ = semCaseBranchSetElem__0knXB2kLqr5zutyOXWu8Rg_2(c, t, (*r)._kind_6.sons->data[j], covered);
									add__P8dDSotTW25BkfbyspojGg(branch, T42_);
									T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T44_ = (NI)0;
									T44_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
									T45_ = (NI)0;
									T45_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
									T43_ = (*branch)._kind_6.sons->data[(NI)(T44_ - ((NI) 2))];
									asgnRef((void**) (&(*branch)._kind_6.sons->data[(NI)(T44_ - ((NI) 2))]), (*branch)._kind_6.sons->data[(NI)(T45_ - ((NI) 1))]);
									asgnRef((void**) (&(*branch)._kind_6.sons->data[(NI)(T45_ - ((NI) 1))]), T43_);
									i_2 += ((NI) 1);
								} LA41: ;
							}
						}
					}
					LA14_: ;
				}
				LA5_: ;
				checkForOverlap__72gDnaHzi4O4sp9av09bP7vw(c, t, i, branchIndex);
				res += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI i_3;
		NI colontmp__2;
		NI colontmp__3;
		NI T47_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__2 = (NI)(lastIndex + ((NI) 1));
		T47_ = (NI)0;
		T47_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
		colontmp__3 = (NI)(T47_ - ((NI) 1));
		i_4 = colontmp__2;
		{
			while (1) {
				if (!(i_4 < colontmp__3)) goto LA49;
				i_3 = i_4;
				checkForOverlap__72gDnaHzi4O4sp9av09bP7vw(c, t, i_3, branchIndex);
				i_4 += ((NI) 1);
			} LA49: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toCover__VyVU6SDhkTqKxSsQUZSePg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2;
	nimZeroMem((void*)(&result), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
	t2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350144710672));
	{
		NIM_BOOL T3_;
		NI T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
		if (!(T3_)) goto LA4_;
		T3_ = enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3(t2);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast((*t2).n);
		result = toInt128__161i7kexvUAISxPtGBRWYw(T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36275087632017424));
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T13_;
			if (!((IL64(17626545782784) &((NU64)1<<((NU)((*t_2).kind)&63U)))!=0)) goto LA11_;
			T13_ = toInt128__161i7kexvUAISxPtGBRWYw(((NI) 1));
			result = shl__al6Zjboz2CA0pIDMg9a9cJFw(T13_, ((NI) 64));
		}
		goto LA9_;
		LA11_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T17_;
			if (!((IL64(1101659111424) &((NU64)1<<((NU)((*t_2).kind)&63U)))!=0)) goto LA15_;
			T17_ = toInt128__161i7kexvUAISxPtGBRWYw(((NI) 1));
			result = shl__al6Zjboz2CA0pIDMg9a9cJFw(T17_, (NI)((*(*(*c).graph).config).target.intSize * ((NI) 8)));
		}
		goto LA9_;
		LA15_: ;
		{
			result = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, t_2);
		}
		LA9_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__litHeZeW9bpJugmXT0ufvwgintsets)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s) {
	NI result;
	result = (NI)0;
	{
		if (!((*s).elems < ((NI) 34))) goto LA3_;
		result = (*s).elems;
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((NI) 0);
		{
			NI _;
			_ = (NI)0;
			{
				if (!((*s).elems <= ((NI) 34))) goto LA9_;
				{
					NI i;
					NI i_2;
					i = (NI)0;
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < (*s).elems)) goto LA13;
							i = i_2;
							_ = (*s).a[(i)- 0];
							result += ((NI) 1);
							i_2 += ((NI) 1);
						} LA13: ;
					}
				}
			}
			goto LA7_;
			LA9_: ;
			{
				tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* r;
				r = (*s).head;
				{
					while (1) {
						NI i_3;
						if (!!((r == ((tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ*) NIM_NIL)))) goto LA16;
						i_3 = ((NI) 0);
						{
							while (1) {
								NU w;
								NI j;
								if (!(i_3 <= ((NI) 7))) goto LA18;
								w = (*r).bits[(i_3)- 0];
								j = ((NI) 0);
								{
									while (1) {
										if (!!((w == ((NU) 0)))) goto LA20;
										{
											NI T25_;
											if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA23_;
											T25_ = (NI)0;
											T25_ = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((NI)((NU64)(i_3) << (NU64)(((NI) 6))), j);
											_ = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T25_);
											result += ((NI) 1);
										}
										LA23_: ;
										j += ((NI) 1);
										w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
									} LA20: ;
								}
								i_3 += ((NI) 1);
							} LA18: ;
						}
						r = (*r).next;
					} LA16: ;
				}
			}
			LA7_: ;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderAsType__jONWMAXSsSmnBgUvyxg7Hw)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* vals, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NimStringDesc* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NI enumSymOffset;
	NI i;
	result = (NimStringDesc*)0;
	result = copyString(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_421));
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350136322320));
	enumSymOffset = ((NI) 0);
	i = ((NI) 0);
	{
		NI val;
		val = (NI)0;
		{
			if (!((*vals).elems <= ((NI) 34))) goto LA4_;
			{
				NI i_2;
				NI i_3;
				i_2 = (NI)0;
				i_3 = ((NI) 0);
				{
					while (1) {
						if (!(i_3 < (*vals).elems)) goto LA8;
						i_2 = i_3;
						val = (*vals).a[(i_2)- 0];
						{
							if (!(((NI) 1) < (result ? result->Sup.len : 0))) goto LA11_;
							result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
						}
						LA11_: ;
						switch ((*t_2).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
						{
							{
								while (1) {
									if (!((*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).position < val)) goto LA15;
									enumSymOffset += ((NI) 1);
								} LA15: ;
							}
							result = resizeString(result, ((*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s ? (*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s->Sup.len : 0) + 0);
appendString(result, (*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s);
						}
						break;
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
						{
							addQuoted__Jx9cyf9byen4PwchGOyl5LUg((&result), ((NIM_CHAR) (val)));
						}
						break;
						default:
						{
							{
								NI T22_;
								NimStringDesc* T23_;
								NimStringDesc* T24_;
								if (!(i == ((NI) 64))) goto LA20_;
								T22_ = (NI)0;
								T22_ = len__litHeZeW9bpJugmXT0ufvwgintsets(vals);
								T23_ = (NimStringDesc*)0;
								T23_ = nimIntToStr((NI)(T22_ - i));
								T24_ = (NimStringDesc*)0;
								T24_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_422), T23_);
								result = resizeString(result, (T24_ ? T24_->Sup.len : 0) + 0);
appendString(result, T24_);
								goto LA1;
							}
							goto LA18_;
							LA20_: ;
							{
								NimStringDesc* T26_;
								T26_ = (NimStringDesc*)0;
								T26_ = nimIntToStr(val);
								result = resizeString(result, (T26_ ? T26_->Sup.len : 0) + 0);
appendString(result, T26_);
							}
							LA18_: ;
						}
						break;
						}
						i += ((NI) 1);
						i_3 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* r;
			r = (*vals).head;
			{
				while (1) {
					NI i_4;
					if (!!((r == ((tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ*) NIM_NIL)))) goto LA29;
					i_4 = ((NI) 0);
					{
						while (1) {
							NU w;
							NI j;
							if (!(i_4 <= ((NI) 7))) goto LA31;
							w = (*r).bits[(i_4)- 0];
							j = ((NI) 0);
							{
								while (1) {
									if (!!((w == ((NU) 0)))) goto LA33;
									{
										NI T38_;
										if (!!(((NU)(w & ((NU) 1)) == ((NU) 0)))) goto LA36_;
										T38_ = (NI)0;
										T38_ = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((NI)((NU64)(i_4) << (NU64)(((NI) 6))), j);
										val = (NI)((NI)((NU64)((*r).key) << (NU64)(((NI) 9))) | T38_);
										{
											if (!(((NI) 1) < (result ? result->Sup.len : 0))) goto LA41_;
											result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
										}
										LA41_: ;
										switch ((*t_2).kind) {
										case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
										case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
										{
											{
												while (1) {
													if (!((*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).position < val)) goto LA45;
													enumSymOffset += ((NI) 1);
												} LA45: ;
											}
											result = resizeString(result, ((*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s ? (*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s->Sup.len : 0) + 0);
appendString(result, (*(*(*(*(*t_2).n)._kind_6.sons->data[enumSymOffset])._kind_4.sym).name).s);
										}
										break;
										case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
										{
											addQuoted__Jx9cyf9byen4PwchGOyl5LUg((&result), ((NIM_CHAR) (val)));
										}
										break;
										default:
										{
											{
												NI T52_;
												NimStringDesc* T53_;
												NimStringDesc* T54_;
												if (!(i == ((NI) 64))) goto LA50_;
												T52_ = (NI)0;
												T52_ = len__litHeZeW9bpJugmXT0ufvwgintsets(vals);
												T53_ = (NimStringDesc*)0;
												T53_ = nimIntToStr((NI)(T52_ - i));
												T54_ = (NimStringDesc*)0;
												T54_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_422), T53_);
												result = resizeString(result, (T54_ ? T54_->Sup.len : 0) + 0);
appendString(result, T54_);
												goto LA1;
											}
											goto LA48_;
											LA50_: ;
											{
												NimStringDesc* T56_;
												T56_ = (NimStringDesc*)0;
												T56_ = nimIntToStr(val);
												result = resizeString(result, (T56_ ? T56_->Sup.len : 0) + 0);
appendString(result, T56_);
											}
											LA48_: ;
										}
										break;
										}
										i += ((NI) 1);
									}
									LA36_: ;
									j += ((NI) 1);
									w = (NU)((NU64)(w) >> (NU64)(((NI) 1)));
								} LA33: ;
							}
							i_4 += ((NI) 1);
						} LA31: ;
					}
					r = (*r).next;
				} LA29: ;
			}
		}
		LA2_: ;
	} LA1: ;
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_423));
	return result;
}
static N_INLINE(void, minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s1, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s2, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	difference__jhF9cCHu5ggiDdc87e1wx3g(s1, s2, (&T1_));
	genericShallowAssign((void*)Result, (void*)(&T1_), (&NTI__PQrmFm4BXFkFSVOUl1ojSg_));
}
N_LIB_PRIVATE N_NIMCALL(void, getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result) {
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q(Result);
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
		T3_ = (NIM_BOOL)0;
		T3_ = enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3(t);
		if (!T3_) goto LA4_;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350136322320));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** field;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T7_;
			field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*(*t_2).n)._kind_6.sons;
			i = ((NI) 0);
			T7_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T7_;
			{
				while (1) {
					if (!(i < L)) goto LA9;
					field = &colontmp_->data[i];
					incl__jENnK9c9bPE73pKmo2vYjpqg(Result, (*(*(*field))._kind_4.sym).position);
					i += ((NI) 1);
				} LA9: ;
			}
		}
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NI64 i_2;
			NI64 colontmp__2;
			NI64 colontmp__3;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T13_;
			NI64 res;
			i_2 = (NI64)0;
			colontmp__2 = (NI64)0;
			colontmp__3 = (NI64)0;
			T12_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, t);
			colontmp__2 = toInt64__1szweXXq3RBN50owrYu2Xw(T12_);
			T13_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, t);
			colontmp__3 = toInt64__1szweXXq3RBN50owrYu2Xw(T13_);
			res = colontmp__2;
			{
				while (1) {
					if (!(res <= colontmp__3)) goto LA15;
					i_2 = res;
					incl__jENnK9c9bPE73pKmo2vYjpqg(Result, ((NI) (i_2)));
					res += ((NI) 1);
				} LA15: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, formatMissingEnums__zUJc3JNayUkQ8i11jOQJeQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg coveredCases;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T23_;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T24_;
	result = (NimStringDesc*)0;
	nimZeroMem((void*)(&coveredCases), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&coveredCases));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NI val;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__2;
					val = (NI)0;
					colontmp__2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					colontmp__2 = (*n)._kind_6.sons->data[i];
					{
						if (!((*colontmp__2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA7_;
						{
							NI i_3;
							NI colontmp__3;
							NI T10_;
							NI i_4;
							i_3 = (NI)0;
							colontmp__3 = (NI)0;
							T10_ = (NI)0;
							T10_ = len__P89cqdlERShb9alU3iC0yj8wast(colontmp__2);
							colontmp__3 = (NI)(T10_ - ((NI) 1));
							i_4 = ((NI) 0);
							{
								while (1) {
									if (!(i_4 < colontmp__3)) goto LA12;
									i_3 = i_4;
									{
										if (!((*(*colontmp__2)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) || (*(*colontmp__2)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5))) goto LA15_;
										val = ((NI) ((*(*colontmp__2)._kind_6.sons->data[i_3])._kind_1.intVal));
										incl__jENnK9c9bPE73pKmo2vYjpqg((&coveredCases), val);
									}
									goto LA13_;
									LA15_: ;
									{
										if (!((*(*colontmp__2)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA18_;
										{
											NI64 i_5;
											NI64 colontmp__4;
											NI64 colontmp__5;
											NI64 res;
											i_5 = (NI64)0;
											colontmp__4 = (NI64)0;
											colontmp__5 = (NI64)0;
											colontmp__4 = (*(*(*colontmp__2)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 0)])._kind_1.intVal;
											colontmp__5 = (*(*(*colontmp__2)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 1)])._kind_1.intVal;
											res = colontmp__4;
											{
												while (1) {
													if (!(res <= colontmp__5)) goto LA22;
													i_5 = res;
													val = ((NI) (i_5));
													incl__jENnK9c9bPE73pKmo2vYjpqg((&coveredCases), val);
													res += ((NI) 1);
												} LA22: ;
											}
										}
									}
									goto LA13_;
									LA18_: ;
									LA13_: ;
									i_4 += ((NI) 1);
								} LA12: ;
							}
						}
					}
					LA7_: ;
				}
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	nimZeroMem((void*)(&T23_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ(c, (*(*n)._kind_6.sons->data[((NI) 0)]).typ, (&T23_));
	nimZeroMem((void*)(&T24_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets((&T23_), (&coveredCases), (&T24_));
	result = renderAsType__jONWMAXSsSmnBgUvyxg7Hw((&T24_), (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semRecordCase__b2sT4Mx5xMcD0WzRKPqmPA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA covered;
	NIM_BOOL chckCovered;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
{	a = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
	semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, (*n)._kind_6.sons->data[((NI) 0)], check, pos, a, rectype, NIM_TRUE);
	{
		if (!!(((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_407), TM__rF9caJawfOjYTjsgLVUSGFA_408);
		goto BeforeRet_;
	}
	LA3_: ;
	(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20)) & 63);
	covered = toInt128__161i7kexvUAISxPtGBRWYw(((NI) 0));
	chckCovered = NIM_FALSE;
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*a)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087632017424));
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		chckCovered = NIM_TRUE;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50):
	{
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
			T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T10_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[((NI) 0)], IL64(36134350135273744));
			if (!((IL64(16559246426118) &((NU64)1<<((NU)((*T10_).kind)&63U)))!=0)) goto LA11_;
			chckCovered = NIM_TRUE;
		}
		LA11_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30):
	{
		errorUndeclaredIdentifier__2jJM9bqw5w9caMyqez0JSuZw(c, (*(*n)._kind_6.sons->data[((NI) 0)]).info, (*(*(*typ).sym).name).s);
	}
	break;
	default:
	{
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(typ, NIM_FALSE);
			if (!!(T17_)) goto LA18_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_409), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_410, NIM_FALSE);
		}
		LA18_: ;
	}
	break;
	}
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T22_;
		NIM_BOOL T23_;
		NimStringDesc* T26_;
		T22_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, typ);
		T23_ = (NIM_BOOL)0;
		T23_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T22_, IL64(0));
		if (!!(T23_)) goto LA24_;
		T26_ = (NimStringDesc*)0;
		T26_ = rawNewString(((*(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s ? (*(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s->Sup.len : 0) + 32);
appendString(T26_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_411));
appendString(T26_, (*(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
appendString(T26_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_412));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_413, NIM_FALSE);
	}
	goto LA20_;
	LA24_: ;
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T28_;
		NIM_BOOL T29_;
		NimStringDesc* T32_;
		T28_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, typ);
		T29_ = (NIM_BOOL)0;
		T29_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(32767), T28_);
		if (!T29_) goto LA30_;
		T32_ = (NimStringDesc*)0;
		T32_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_414), (*(*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_415, NIM_FALSE);
	}
	goto LA20_;
	LA30_: ;
	LA20_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
				NI T46_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T47_;
				if (!(i_2 < colontmp_)) goto LA35;
				i = i_2;
				b = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[i]);
				add__P8dDSotTW25BkfbyspojGg(a, b);
				switch ((*(*n)._kind_6.sons->data[i]).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
				{
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(b, ((NI) 2), (*(*c).graph).config);
					semCaseBranch__v9aNPEhC9bTKfOzSbulyV4jw(c, a, b, i, (&covered));
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
				{
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(b, ((NI) 1), (*(*c).graph).config);
					{
						NIM_BOOL T40_;
						tyObject_Int128__9a9axPfb75jdWY25AamJewkA T42_;
						T40_ = (NIM_BOOL)0;
						T40_ = chckCovered;
						if (!(T40_)) goto LA41_;
						T42_ = toCover__VyVU6SDhkTqKxSsQUZSePg(c, (*(*a)._kind_6.sons->data[((NI) 0)]).typ);
						T40_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(covered, T42_);
						LA41_: ;
						if (!T40_) goto LA43_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*b).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 37), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_419, NIM_FALSE);
					}
					LA43_: ;
					chckCovered = NIM_FALSE;
				}
				break;
				default:
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
				}
				break;
				}
				T46_ = (NI)0;
				T46_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
				delSon__oU9bKATaboy8iUhv0r9bMBPw(b, (NI)(T46_ - ((NI) 1)));
				T47_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T47_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i]);
				semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, T47_, check, pos, b, rectype, NIM_TRUE);
				i_2 += ((NI) 1);
			} LA35: ;
		}
	}
	{
		NIM_BOOL T50_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T52_;
		NIM_BOOL T53_;
		T50_ = (NIM_BOOL)0;
		T50_ = chckCovered;
		if (!(T50_)) goto LA51_;
		T52_ = toCover__VyVU6SDhkTqKxSsQUZSePg(c, (*(*a)._kind_6.sons->data[((NI) 0)]).typ);
		T53_ = (NIM_BOOL)0;
		T53_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(covered, T52_);
		T50_ = !(T53_);
		LA51_: ;
		if (!T50_) goto LA54_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T58_;
			NimStringDesc* T61_;
			NimStringDesc* T62_;
			T58_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T58_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*a)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350136322320));
			if (!((*T58_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14))) goto LA59_;
			T61_ = (NimStringDesc*)0;
			T61_ = formatMissingEnums__zUJc3JNayUkQ8i11jOQJeQ(c, a);
			T62_ = (NimStringDesc*)0;
			T62_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_420), T61_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T62_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_424, NIM_FALSE);
		}
		goto LA56_;
		LA59_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_425), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_426, NIM_FALSE);
		}
		LA56_: ;
	}
	LA54_: ;
	add__P8dDSotTW25BkfbyspojGg(father, a);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* check, NI* pos, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rectype, NIM_BOOL hasCaseFields) {
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 140):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
		branch = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					NI idx;
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						if (!(it == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA11_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
					}
					LA11_: ;
					idx = ((NI) 1);
					switch ((*it).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
					{
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(it, ((NI) 2), (*(*c).graph).config);
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
							if (!((*c).inGenericContext == ((NI) 0))) goto LA16_;
							e = semConstBoolExpr__7YxUILpPxooC5qqa89a54dw_3(c, (*it)._kind_6.sons->data[((NI) 0)]);
							{
								if (!!(((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA20_;
							}
							goto LA18_;
							LA20_: ;
							{
								NIM_BOOL T23_;
								T23_ = (NIM_BOOL)0;
								T23_ = !(((*e)._kind_1.intVal == IL64(0)));
								if (!(T23_)) goto LA24_;
								T23_ = (branch == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
								LA24_: ;
								if (!T23_) goto LA25_;
								branch = (*it)._kind_6.sons->data[((NI) 1)];
							}
							goto LA18_;
							LA25_: ;
							LA18_: ;
						}
						goto LA14_;
						LA16_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
							T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T28_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*it)._kind_6.sons->data[((NI) 0)], 0);
							asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 0)]), forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T28_));
						}
						LA14_: ;
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(it, ((NI) 1), (*(*c).graph).config);
						{
							if (!(branch == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA32_;
							branch = (*it)._kind_6.sons->data[((NI) 0)];
						}
						LA32_: ;
						idx = ((NI) 0);
					}
					break;
					default:
					{
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
					}
					break;
					}
					{
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg newCheck;
						NI newPos;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newf;
						if (!(((NI) 0) < (*c).inGenericContext)) goto LA37_;
						nimZeroMem((void*)(&newCheck), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						assign__9aeoXSYLtfdHDeDWcO9bHVbg((&newCheck), (&(*check)));
						newPos = (*pos);
						newf = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info);
						semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, (*it)._kind_6.sons->data[idx], (&newCheck), (&newPos), newf, rectype, hasCaseFields);
						{
							NI T41_;
							T41_ = (NI)0;
							T41_ = len__P89cqdlERShb9alU3iC0yj8wast(newf);
							if (!(T41_ == ((NI) 1))) goto LA42_;
							asgnRef((void**) (&(*it)._kind_6.sons->data[idx]), (*newf)._kind_6.sons->data[((NI) 0)]);
						}
						goto LA39_;
						LA42_: ;
						{
							asgnRef((void**) (&(*it)._kind_6.sons->data[idx]), newf);
						}
						LA39_: ;
					}
					LA37_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
		{
			if (!(((NI) 0) < (*c).inGenericContext)) goto LA47_;
			add__P8dDSotTW25BkfbyspojGg(father, n);
		}
		goto LA45_;
		LA47_: ;
		{
			if (!!((branch == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA50_;
			semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, branch, check, pos, father, rectype, hasCaseFields);
		}
		goto LA45_;
		LA50_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T55_;
			if (!((*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88) || (*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA53_;
			T55_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T55_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info);
			add__P8dDSotTW25BkfbyspojGg(father, T55_);
		}
		goto LA45_;
		LA53_: ;
		LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		semRecordCase__b2sT4Mx5xMcD0WzRKPqmPA(c, n, check, pos, father, rectype);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T62_;
			if (!!(((*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138)))) goto LA60_;
			T62_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T62_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info);
			add__P8dDSotTW25BkfbyspojGg(father, T62_);
		}
		LA60_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		{
			if (!((*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138))) goto LA66_;
			a = father;
		}
		goto LA64_;
		LA66_: ;
		{
			a = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
		}
		LA64_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA71;
					i_3 = i_4;
					semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, (*n)._kind_6.sons->data[i_3], check, pos, a, rectype, hasCaseFields);
					i_4 += ((NI) 1);
				} LA71: ;
			}
		}
		{
			if (!!((a == father))) goto LA74_;
			add__P8dDSotTW25BkfbyspojGg(father, a);
		}
		LA74_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fieldOwner;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 3), (*(*c).graph).config);
		a_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NIM_BOOL T79_;
			NI T81_;
			T79_ = (NIM_BOOL)0;
			T79_ = !(((*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138)));
			if (!(T79_)) goto LA80_;
			T81_ = (NI)0;
			T81_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T79_ = (((NI) 4) <= T81_);
			LA80_: ;
			if (!T79_) goto LA82_;
			a_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info);
		}
		goto LA77_;
		LA82_: ;
		{
			a_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		}
		LA77_: ;
		{
			NI T87_;
			NI T90_;
			T87_ = (NI)0;
			T87_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!!(((*(*n)._kind_6.sons->data[(NI)(T87_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA88_;
			T90_ = (NI)0;
			T90_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[(NI)(T90_ - ((NI) 1))]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_427), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_428, NIM_FALSE);
		}
		LA88_: ;
		typ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		{
			NI T93_;
			T93_ = (NI)0;
			T93_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!((*(*n)._kind_6.sons->data[(NI)(T93_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA94_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_429, NIM_FALSE);
			typ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		}
		goto LA91_;
		LA94_: ;
		{
			NI T97_;
			T97_ = (NI)0;
			T97_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[(NI)(T97_ - ((NI) 2))], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(rectype, typ, NIM_TRUE);
		}
		LA91_: ;
		{
			if (!(((NI) 0) < (*c).inGenericContext)) goto LA100_;
			fieldOwner = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		}
		goto LA98_;
		LA100_: ;
		{
			fieldOwner = (*rectype).sym;
		}
		LA98_: ;
		{
			NI i_5;
			NI colontmp__3;
			NI T104_;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			T104_ = (NI)0;
			T104_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp__3 = (NI)(T104_ - ((NI) 2));
			i_6 = ((NI) 0);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
					tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
					if (!(i_6 < colontmp__3)) goto LA106;
					i_5 = i_6;
					f = semIdentWithPragma__gSt4lwrAK8GOXOIIBgGsog(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), (*n)._kind_6.sons->data[i_5], 2);
					{
						if (!((*(*n)._kind_6.sons->data[i_5]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31))) goto LA109_;
						info = (*(*(*n)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)]).info;
					}
					goto LA107_;
					LA109_: ;
					{
						info = (*(*n)._kind_6.sons->data[i_5]).info;
					}
					LA107_: ;
					suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch((*(*c).graph).config, info, f, &(*(*c).graph).usageSym, NIM_TRUE);
					asgnRef((void**) (&(*f).typ), typ);
					(*f).position = (*pos);
					(*f).options = (*(*(*c).graph).config).options;
					{
						NIM_BOOL T114_;
						NIM_BOOL T115_;
						NIM_BOOL T116_;
						T114_ = (NIM_BOOL)0;
						T115_ = (NIM_BOOL)0;
						T116_ = (NIM_BOOL)0;
						T116_ = !((fieldOwner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T116_)) goto LA117_;
						T116_ = !(((192 & (*fieldOwner).flags) == 0));
						LA117_: ;
						T115_ = T116_;
						if (!(T115_)) goto LA118_;
						T115_ = !(hasCaseFields);
						LA118_: ;
						T114_ = T115_;
						if (!(T114_)) goto LA119_;
						T114_ = ((*f).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
						LA119_: ;
						if (!T114_) goto LA120_;
						asgnRef((void**) (&(*f).loc.r), rope__yShmEg9cffWxI7s5XzEKBow((*(*f).name).s));
						(*f).flags = ((*f).flags | (192 & (*fieldOwner).flags));
					}
					LA120_: ;
					(*pos) += ((NI) 1);
					{
						NIM_BOOL T124_;
						NimStringDesc* T127_;
						T124_ = (NIM_BOOL)0;
						T124_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(check, (*(*f).name).Sup.id);
						if (!T124_) goto LA125_;
						T127_ = (NimStringDesc*)0;
						T127_ = rawNewString(((*(*f).name).s ? (*(*f).name).s->Sup.len : 0) + 23);
appendString(T127_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_136));
appendString(T127_, (*(*f).name).s);
appendString(T127_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T127_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_430, NIM_FALSE);
					}
					LA125_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T132_;
						if (!((*a_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA130_;
						T132_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T132_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f);
						add__P8dDSotTW25BkfbyspojGg(father, T132_);
					}
					goto LA128_;
					LA130_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T134_;
						T134_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T134_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f);
						add__P8dDSotTW25BkfbyspojGg(a_2, T134_);
					}
					LA128_: ;
					{
						if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA137_;
						nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*f).info, f, (*f).kind);
					}
					LA137_: ;
					i_6 += ((NI) 1);
				} LA106: ;
			}
		}
		{
			if (!!(((*a_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA141_;
			add__P8dDSotTW25BkfbyspojGg(father, a_2);
		}
		LA141_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NIM_BOOL T146_;
			NimStringDesc* T149_;
			T146_ = (NIM_BOOL)0;
			T146_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(check, (*(*(*n)._kind_4.sym).name).Sup.id);
			if (!T146_) goto LA147_;
			T149_ = (NimStringDesc*)0;
			T149_ = rawNewString(((*(*(*n)._kind_4.sym).name).s ? (*(*(*n)._kind_4.sym).name).s->Sup.len : 0) + 23);
appendString(T149_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_136));
appendString(T149_, (*(*(*n)._kind_4.sym).name).s);
appendString(T149_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T149_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_431, NIM_FALSE);
		}
		LA147_: ;
		add__P8dDSotTW25BkfbyspojGg(father, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	{
		{
			if (!((*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88) || (*father).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA153_;
			add__P8dDSotTW25BkfbyspojGg(father, n);
		}
		LA153_: ;
	}
	break;
	default:
	{
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initConstrContext__RYPHxM9aTf8uWaAnZ0rNc2A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* Result) {
	unsureAsgnRef((void**)&(*Result).typ, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).initExpr, NIM_NIL);
	(*Result).needsFullInit = 0;
	unsureAsgnRef((void**)&(*Result).missingFields, NIM_NIL);
	unsureAsgnRef((void**) (&(*Result).typ), t);
	unsureAsgnRef((void**) (&(*Result).initExpr), initExpr);
	(*Result).needsFullInit = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 19))&63U)))!=0);
}
N_LIB_PRIVATE N_NIMCALL(void, mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw)(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ* existing, tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ newStatus) {
	switch (newStatus) {
	case ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 4):
	{
		(*existing) = newStatus;
	}
	break;
	case ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2):
	{
		{
			if (!((11 &((NU8)1<<((NU)((*existing))&7U)))!=0)) goto LA5_;
			(*existing) = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3):
	{
		{
			if (!((*existing) == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 0))) goto LA10_;
			(*existing) = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3);
		}
		goto LA8_;
		LA10_: ;
		{
			if (!((*existing) == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 1))) goto LA13_;
			(*existing) = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2);
		}
		goto LA8_;
		LA13_: ;
		LA8_: ;
	}
	break;
	case ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 1):
	{
		{
			if (!((*existing) == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 0))) goto LA18_;
			(*existing) = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 1);
		}
		goto LA16_;
		LA18_: ;
		{
			if (!((*existing) == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3))) goto LA21_;
			(*existing) = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2);
		}
		goto LA16_;
		LA21_: ;
		LA16_: ;
	}
	break;
	case ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 0):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, invalidObjConstr__NRIJDWZtATzMum7OEjYC2g_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((NU8)((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s->data[((NI) 0)]) == (NU8)(58));
		LA6_: ;
		if (!T3_) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_436), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_437, NIM_FALSE);
	}
	goto LA1_;
	LA7_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_438), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_439, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI fieldId;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	fieldId = (*(*field).name).Sup.id;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(initExpr);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* assignment;
					assignment = (*initExpr)._kind_6.sons->data[i];
					{
						if (!!(((*assignment).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA7_;
						invalidObjConstr__NRIJDWZtATzMum7OEjYC2g_9(c, assignment);
						goto LA4;
					}
					LA7_: ;
					{
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T11_;
						T11_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
						T11_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*assignment)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						if (!(fieldId == (*T11_).Sup.id)) goto LA12_;
						result = assignment;
						goto BeforeRet_;
					}
					LA12_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsRecList, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = ((NimStringDesc*) NIM_NIL);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
		field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			if (!((*fieldsRecList).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA4_;
			field = fieldsRecList;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
				NimStringDesc* T15_;
				T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T8_ = locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg(c, (*field)._kind_4.sym, initExpr);
				if (!!((T8_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA9_;
				{
					if (!!(((result ? result->Sup.len : 0) == ((NI) 0)))) goto LA13_;
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
				}
				LA13_: ;
				T15_ = (NimStringDesc*)0;
				T15_ = rawNewString(((*(*(*field)._kind_4.sym).name).s ? (*(*(*field)._kind_4.sym).name).s->Sup.len : 0) + 2);
appendString(T15_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
appendString(T15_, (*(*(*field)._kind_4.sym).name).s);
appendString(T15_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
				result = resizeString(result, (T15_ ? T15_->Sup.len : 0) + 0);
appendString(result, T15_);
			}
			LA9_: ;
		}
		goto LA2_;
		LA4_: ;
		{
			{
				if (!!(((*fieldsRecList).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138)))) goto LA19_;
				failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_440));
			}
			LA19_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field_2;
				field_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(fieldsRecList);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA24;
							i = i_2;
							field_2 = (*fieldsRecList)._kind_6.sons->data[i];
							{
								{
									if (!!(((*field_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA28_;
									goto LA25;
								}
								LA28_: ;
								field = field_2;
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T32_;
									NimStringDesc* T39_;
									T32_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T32_ = locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg(c, (*field)._kind_4.sym, initExpr);
									if (!!((T32_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA33_;
									{
										if (!!(((result ? result->Sup.len : 0) == ((NI) 0)))) goto LA37_;
										result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
									}
									LA37_: ;
									T39_ = (NimStringDesc*)0;
									T39_ = rawNewString(((*(*(*field)._kind_4.sym).name).s ? (*(*(*field)._kind_4.sym).name).s->Sup.len : 0) + 2);
appendString(T39_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
appendString(T39_, (*(*(*field)._kind_4.sym).name).s);
appendString(T39_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
									result = resizeString(result, (T39_ ? T39_->Sup.len : 0) + 0);
appendString(result, T39_);
								}
								LA33_: ;
							} LA25: ;
							i_2 += ((NI) 1);
						} LA24: ;
					}
				}
			}
		}
		LA2_: ;
	}
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryConstExpr__7YxUILpPxooC5qqa89a54dw_30)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
	NI oldErrorCount;
	NI oldErrorMax;
	tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA oldErrorOutputs;
	TSafePoint TM__rF9caJawfOjYTjsgLVUSGFA_445;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	e = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 0);
	{
		if (!(e == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, e, (*c).graph);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	oldErrorCount = (*(*(*c).graph).config).errorCounter;
	oldErrorMax = (*(*(*c).graph).config).errorMax;
	oldErrorOutputs = (*(*(*c).graph).config).m.errorOutputs;
	(*(*(*c).graph).config).m.errorOutputs = 0;
	(*(*(*c).graph).config).errorMax = ((NI) IL64(9223372036854775807));
	pushSafePoint(&TM__rF9caJawfOjYTjsgLVUSGFA_445);
	TM__rF9caJawfOjYTjsgLVUSGFA_445.status = _setjmp(TM__rF9caJawfOjYTjsgLVUSGFA_445.context);
	if (TM__rF9caJawfOjYTjsgLVUSGFA_445.status == 0) {
	result = evalConstExpr__P8uF2QSxl7YdNpBnl0Ybqg((*c).module, (*c).graph, e);
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T11_) goto LA12_;
		T11_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		LA12_: ;
		if (!T11_) goto LA13_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	goto LA9_;
	LA13_: ;
	{
		result = fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA(c, result, e);
	}
	LA9_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__IxbcvonC7TQkv166Uvdu1g_))) {
			TM__rF9caJawfOjYTjsgLVUSGFA_445.status = 0;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			popCurrentException();
		}
	}
	if (TM__rF9caJawfOjYTjsgLVUSGFA_445.status != 0) reraiseException();
	(*(*(*c).graph).config).errorCounter = oldErrorCount;
	(*(*(*c).graph).config).errorMax = oldErrorMax;
	(*(*(*c).graph).config).m.errorOutputs = oldErrorOutputs;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprFlagDispatched__vJZwz9bfROKrfrtM50y74CQ_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 3))&31U)))!=0)) goto LA3_;
		{
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 5))&31U)))!=0)) goto LA7_;
			result = tryConstExpr__7YxUILpPxooC5qqa89a54dw_30(c, n);
			goto BeforeRet_;
		}
		goto LA5_;
		LA7_: ;
		{
			result = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, n);
			goto BeforeRet_;
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		result = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, flags);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated;
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 4))&31U)))!=0)) goto LA13_;
			evaluated = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, result, (*c).graph);
			{
				if (!!((evaluated == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA17_;
				result = evaluated;
				goto BeforeRet_;
			}
			LA17_: ;
			evaluated = evalAtCompileTime__7YxUILpPxooC5qqa89a54dw_28(c, result);
			{
				if (!!((evaluated == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA21_;
				result = evaluated;
				goto BeforeRet_;
			}
			LA21_: ;
		}
		LA13_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstrField__dYxITD6gRULNORUNQ6Cc9cg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initExpr) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* assignment;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	assignment = locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg(c, field, initExpr);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* initValue;
		if (!!((assignment == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		{
			if (!(((*assignment).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7))&31U)))!=0)) goto LA7_;
			result = (*assignment)._kind_6.sons->data[((NI) 1)];
			goto BeforeRet_;
		}
		LA7_: ;
		{
			NIM_BOOL T11_;
			tyArray__nHXaesL0DJZHyVS07ARPRA T14_;
			NimStringDesc* T15_;
			T11_ = (NIM_BOOL)0;
			T11_ = fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch(c, field);
			if (!!(T11_)) goto LA12_;
			nimZeroMem((void*)T14_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
			T14_[0] = copyString((*(*field).name).s);
			T15_ = (NimStringDesc*)0;
			T15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_443), T14_, 1);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*initExpr).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_444, NIM_FALSE);
			goto BeforeRet_;
		}
		LA12_: ;
		initValue = semExprFlagDispatched__vJZwz9bfROKrfrtM50y74CQ_13(c, (*assignment)._kind_6.sons->data[((NI) 1)], flags);
		{
			if (!!((initValue == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA18_;
			initValue = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*field).typ, initValue, (*assignment).info);
		}
		LA18_: ;
		asgnRef((void**) (&(*assignment)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(field));
		asgnRef((void**) (&(*assignment)._kind_6.sons->data[((NI) 1)]), initValue);
		(*assignment).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7)) & 31);
		result = initValue;
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, findUsefulCaseContext__0hNT3646PPGbJcsdagLbHg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* discrimator, tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw* Result) {
{	unsureAsgnRef((void**)&(*Result).Field0, NIM_NIL);
	(*Result).Field1 = 0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*(*c).p).caseContext ? (*(*c).p).caseContext->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = colontmp_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseNode;
				NI index;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* skipped;
				if (!(((NI) 0) <= res)) goto LA4;
				i = res;
				caseNode = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				caseNode = (*(*c).p).caseContext->data[i].Field0;
				index = (NI)0;
				index = (*(*c).p).caseContext->data[i].Field1;
				skipped = skipHidden__BH9abOhPX8pH0DnEWlRxmlw_3((*caseNode)._kind_6.sons->data[((NI) 0)]);
				{
					NIM_BOOL T7_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__2;
					NI colontmp__3;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*skipped).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
					if (!(T7_)) goto LA8_;
					T7_ = ((*skipped)._kind_4.sym == (*discrimator)._kind_4.sym);
					LA8_: ;
					if (!T7_) goto LA9_;
					colontmp__2 = caseNode;
					colontmp__3 = index;
					unsureAsgnRef((void**) (&(*Result).Field0), colontmp__2);
					(*Result).Field1 = colontmp__3;
					goto BeforeRet_;
				}
				LA9_: ;
				res -= ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, branchVals__XK56AwQllxmCRE7fuCvRCQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseNode, NI caseIdx, NIM_BOOL isStmtBranch, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result) {
	{
		if (!((*(*caseNode)._kind_6.sons->data[caseIdx]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA3_;
		initIntSet__n8oDZMn19bEdodSnrBQB9a1Q(Result);
		{
			NI val;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp_;
			val = (NI)0;
			colontmp_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			colontmp_ = (*caseNode)._kind_6.sons->data[caseIdx];
			{
				if (!((*colontmp_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA8_;
				{
					NI i;
					NI colontmp__2;
					NI T11_;
					NI i_2;
					i = (NI)0;
					colontmp__2 = (NI)0;
					T11_ = (NI)0;
					T11_ = len__P89cqdlERShb9alU3iC0yj8wast(colontmp_);
					colontmp__2 = (NI)(T11_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp__2)) goto LA13;
							i = i_2;
							{
								if (!((*(*colontmp_)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) || (*(*colontmp_)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5))) goto LA16_;
								val = ((NI) ((*(*colontmp_)._kind_6.sons->data[i])._kind_1.intVal));
								incl__jENnK9c9bPE73pKmo2vYjpqg(Result, val);
							}
							goto LA14_;
							LA16_: ;
							{
								if (!((*(*colontmp_)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA19_;
								{
									NI64 i_3;
									NI64 colontmp__3;
									NI64 colontmp__4;
									NI64 res;
									i_3 = (NI64)0;
									colontmp__3 = (NI64)0;
									colontmp__4 = (NI64)0;
									colontmp__3 = (*(*(*colontmp_)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)])._kind_1.intVal;
									colontmp__4 = (*(*(*colontmp_)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)])._kind_1.intVal;
									res = colontmp__3;
									{
										while (1) {
											if (!(res <= colontmp__4)) goto LA23;
											i_3 = res;
											val = ((NI) (i_3));
											incl__jENnK9c9bPE73pKmo2vYjpqg(Result, val);
											res += ((NI) 1);
										} LA23: ;
									}
								}
							}
							goto LA14_;
							LA19_: ;
							LA14_: ;
							i_2 += ((NI) 1);
						} LA13: ;
					}
				}
			}
			LA8_: ;
		}
	}
	goto LA1_;
	LA3_: ;
	{
		getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ(c, (*(*caseNode)._kind_6.sons->data[((NI) 0)]).typ, Result);
		{
			NI i_4;
			NI colontmp__5;
			NI T26_;
			NI i_5;
			i_4 = (NI)0;
			colontmp__5 = (NI)0;
			T26_ = (NI)0;
			T26_ = len__P89cqdlERShb9alU3iC0yj8wast(caseNode);
			colontmp__5 = (NI)(T26_ - ((NI) 1));
			i_5 = ((NI) 1);
			{
				while (1) {
					if (!(i_5 < colontmp__5)) goto LA28;
					i_4 = i_5;
					{
						NI val_2;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__6;
						val_2 = (NI)0;
						colontmp__6 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						colontmp__6 = (*caseNode)._kind_6.sons->data[i_4];
						{
							if (!((*colontmp__6).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85))) goto LA32_;
							{
								NI i_6;
								NI colontmp__7;
								NI T35_;
								NI i_7;
								i_6 = (NI)0;
								colontmp__7 = (NI)0;
								T35_ = (NI)0;
								T35_ = len__P89cqdlERShb9alU3iC0yj8wast(colontmp__6);
								colontmp__7 = (NI)(T35_ - ((NI) 1));
								i_7 = ((NI) 0);
								{
									while (1) {
										if (!(i_7 < colontmp__7)) goto LA37;
										i_6 = i_7;
										{
											if (!((*(*colontmp__6)._kind_6.sons->data[i_6]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) || (*(*colontmp__6)._kind_6.sons->data[i_6]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5))) goto LA40_;
											val_2 = ((NI) ((*(*colontmp__6)._kind_6.sons->data[i_6])._kind_1.intVal));
											excl__jENnK9c9bPE73pKmo2vYjpqg_2(Result, val_2);
										}
										goto LA38_;
										LA40_: ;
										{
											if (!((*(*colontmp__6)._kind_6.sons->data[i_6]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA43_;
											{
												NI64 i_8;
												NI64 colontmp__8;
												NI64 colontmp__9;
												NI64 res_2;
												i_8 = (NI64)0;
												colontmp__8 = (NI64)0;
												colontmp__9 = (NI64)0;
												colontmp__8 = (*(*(*colontmp__6)._kind_6.sons->data[i_6])._kind_6.sons->data[((NI) 0)])._kind_1.intVal;
												colontmp__9 = (*(*(*colontmp__6)._kind_6.sons->data[i_6])._kind_6.sons->data[((NI) 1)])._kind_1.intVal;
												res_2 = colontmp__8;
												{
													while (1) {
														if (!(res_2 <= colontmp__9)) goto LA47;
														i_8 = res_2;
														val_2 = ((NI) (i_8));
														excl__jENnK9c9bPE73pKmo2vYjpqg_2(Result, val_2);
														res_2 += ((NI) 1);
													} LA47: ;
												}
											}
										}
										goto LA38_;
										LA43_: ;
										LA38_: ;
										i_7 += ((NI) 1);
									} LA37: ;
								}
							}
						}
						LA32_: ;
					}
					i_5 += ((NI) 1);
				} LA28: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, caseBranchMatchesExpr__2m1qzNtSRcrBCjT714EGTA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matched) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!((*(*branch)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA7_;
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = overlap__tlIBRycg3YyKwtO2aPbGGg((*branch)._kind_6.sons->data[i], matched);
						if (!T11_) goto LA12_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA12_: ;
				}
				goto LA5_;
				LA7_: ;
				{
					NIM_BOOL T15_;
					T15_ = (NIM_BOOL)0;
					T15_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*branch)._kind_6.sons->data[i], matched, NIM_FALSE);
					if (!T15_) goto LA16_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				goto LA5_;
				LA16_: ;
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, collectMissingFields__R8ignHxUaQZzB8x7tzNkEg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsRecList, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
		r = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			if (!((*fieldsRecList).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA4_;
			r = fieldsRecList;
			{
				NIM_BOOL T8_;
				NIM_BOOL T9_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* assignment;
				T8_ = (NIM_BOOL)0;
				T9_ = (NIM_BOOL)0;
				T9_ = (*constrCtx).needsFullInit;
				if (T9_) goto LA10_;
				T9_ = (((*(*r)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 21))&63U)))!=0);
				LA10_: ;
				T8_ = T9_;
				if (T8_) goto LA11_;
				T8_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ((*(*r)._kind_4.sym).typ);
				LA11_: ;
				if (!T8_) goto LA12_;
				assignment = locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg(c, (*r)._kind_4.sym, (*constrCtx).initExpr);
				{
					NI T18_;
					if (!(assignment == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA16_;
					unsureAsgnRef((void**) (&(*constrCtx).missingFields), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*constrCtx).missingFields), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
					T18_ = (*constrCtx).missingFields->Sup.len++;
					asgnRef((void**) (&(*constrCtx).missingFields->data[T18_]), (*r)._kind_4.sym);
				}
				LA16_: ;
			}
			LA12_: ;
		}
		goto LA2_;
		LA4_: ;
		{
			{
				if (!!(((*fieldsRecList).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138)))) goto LA22_;
				failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_440));
			}
			LA22_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
				field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(fieldsRecList);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA27;
							i = i_2;
							field = (*fieldsRecList)._kind_6.sons->data[i];
							{
								{
									if (!!(((*field).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA31_;
									goto LA28;
								}
								LA31_: ;
								r = field;
								{
									NIM_BOOL T35_;
									NIM_BOOL T36_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* assignment_2;
									T35_ = (NIM_BOOL)0;
									T36_ = (NIM_BOOL)0;
									T36_ = (*constrCtx).needsFullInit;
									if (T36_) goto LA37_;
									T36_ = (((*(*r)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 21))&63U)))!=0);
									LA37_: ;
									T35_ = T36_;
									if (T35_) goto LA38_;
									T35_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ((*(*r)._kind_4.sym).typ);
									LA38_: ;
									if (!T35_) goto LA39_;
									assignment_2 = locateFieldInInitExpr__3B9cY0H3QtrZxUpHxV7SvKg(c, (*r)._kind_4.sym, (*constrCtx).initExpr);
									{
										NI T45_;
										if (!(assignment_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA43_;
										unsureAsgnRef((void**) (&(*constrCtx).missingFields), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*constrCtx).missingFields), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
										T45_ = (*constrCtx).missingFields->Sup.len++;
										asgnRef((void**) (&(*constrCtx).missingFields->data[T45_]), (*r)._kind_4.sym);
									}
									LA43_: ;
								}
								LA39_: ;
							} LA28: ;
							i_2 += ((NI) 1);
						} LA27: ;
					}
				}
			}
		}
		LA2_: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, pickCaseBranch__XwTdxP6ATUC1LHA9bBiTnDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matched) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL endsWithElse;
	NI T1_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(caseExpr);
	endsWithElse = ((*(*caseExpr)._kind_6.sons->data[(NI)(T1_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(caseExpr);
		colontmp_ = (NI)(T3_ - ((NI) (endsWithElse)));
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = caseBranchMatchesExpr__2m1qzNtSRcrBCjT714EGTA((*caseExpr)._kind_6.sons->data[i], matched);
					if (!T8_) goto LA9_;
					result = (*caseExpr)._kind_6.sons->data[i];
					goto BeforeRet_;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	{
		NI T15_;
		if (!endsWithElse) goto LA13_;
		T15_ = (NI)0;
		T15_ = len__P89cqdlERShb9alU3iC0yj8wast(caseExpr);
		result = (*caseExpr)._kind_6.sons->data[(NI)(T15_ - ((NI) 1))];
		goto BeforeRet_;
	}
	LA13_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ, semConstructFields__uWuMnWjhYSs5k358Hz7X7w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ result;
	result = (tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ)0;
	result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 0);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
			field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ status;
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						field = (*n)._kind_6.sons->data[i];
						status = semConstructFields__uWuMnWjhYSs5k358Hz7X7w(c, field, constrCtx, flags);
						mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw((&result), status);
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* discriminator;
		NI selectedBranch;
		discriminator = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NimStringDesc* argX60gensym4992_;
			if (!!(((*discriminator).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA9_;
			argX60gensym4992_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_434);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4992_, TM__rF9caJawfOjYTjsgLVUSGFA_434);
		}
		LA9_: ;
		selectedBranch = ((NI) -1);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* innerRecords;
					NI T14_;
					tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ status_2;
					if (!(i_4 < colontmp__2)) goto LA13;
					i_3 = i_4;
					T14_ = (NI)0;
					T14_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i_3]);
					innerRecords = (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[(NI)(T14_ - ((NI) 1))];
					status_2 = semConstructFields__uWuMnWjhYSs5k358Hz7X7w(c, innerRecords, constrCtx, flags);
					{
						if (!!(((9 &((NU8)1<<((NU)(status_2)&7U)))!=0))) goto LA17_;
						mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw((&result), status_2);
						{
							NimStringDesc* prevFields;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchX60gensym5000_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5000_;
							NI T23_;
							NimStringDesc* currentFields;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchX60gensym5005_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5005_;
							NI T24_;
							tyArray__Re75IspeoxXy2oCZHwcRrA T25_;
							NimStringDesc* T26_;
							if (!!((selectedBranch == ((NI) -1)))) goto LA21_;
							branchX60gensym5000_ = (*n)._kind_6.sons->data[selectedBranch];
							T23_ = (NI)0;
							T23_ = len__P89cqdlERShb9alU3iC0yj8wast(branchX60gensym5000_);
							fieldsX60gensym5000_ = (*branchX60gensym5000_)._kind_6.sons->data[(NI)(T23_ - ((NI) 1))];
							prevFields = fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw(c, fieldsX60gensym5000_, (*constrCtx).initExpr);
							branchX60gensym5005_ = (*n)._kind_6.sons->data[i_3];
							T24_ = (NI)0;
							T24_ = len__P89cqdlERShb9alU3iC0yj8wast(branchX60gensym5005_);
							fieldsX60gensym5005_ = (*branchX60gensym5005_)._kind_6.sons->data[(NI)(T24_ - ((NI) 1))];
							currentFields = fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw(c, fieldsX60gensym5005_, (*constrCtx).initExpr);
							nimZeroMem((void*)T25_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							T25_[0] = copyString(prevFields);
							T25_[1] = copyString(currentFields);
							T26_ = (NimStringDesc*)0;
							T26_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_441), T25_, 2);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*constrCtx).initExpr).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_442, NIM_FALSE);
							result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 4);
						}
						goto LA19_;
						LA21_: ;
						{
							selectedBranch = i_3;
						}
						LA19_: ;
					}
					LA17_: ;
					i_4 += ((NI) 1);
				} LA13: ;
			}
		}
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchNode;
			tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags_2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* discriminatorVal;
			if (!!((selectedBranch == ((NI) -1)))) goto LA30_;
			branchNode = (*n)._kind_6.sons->data[selectedBranch];
			flags_2 = ((flags & 1024) | 48);
			discriminatorVal = semConstrField__dYxITD6gRULNORUNQ6Cc9cg(c, flags_2, (*discriminator)._kind_4.sym, (*constrCtx).initExpr);
			{
				if (!!((discriminatorVal == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA34_;
				discriminatorVal = skipHidden__BH9abOhPX8pH0DnEWlRxmlw_3(discriminatorVal);
				{
					NIM_BOOL T38_;
					NIM_BOOL T40_;
					NIM_BOOL T41_;
					NIM_BOOL T42_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T44_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T46_;
					T38_ = (NIM_BOOL)0;
					T38_ = !(((*discriminatorVal).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*discriminatorVal).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)));
					if (!(T38_)) goto LA39_;
					T40_ = (NIM_BOOL)0;
					T41_ = (NIM_BOOL)0;
					T42_ = (NIM_BOOL)0;
					T42_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA((*discriminatorVal).typ, NIM_TRUE);
					T41_ = !(T42_);
					if (T41_) goto LA43_;
					T44_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, (*discriminatorVal).typ);
					T41_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(65536), T44_);
					LA43_: ;
					T40_ = T41_;
					if (T40_) goto LA45_;
					T46_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
					T40_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(65536), T46_);
					LA45_: ;
					T38_ = T40_;
					LA39_: ;
					if (!T38_) goto LA47_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_446), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_447, NIM_FALSE);
				}
				LA47_: ;
			}
			LA34_: ;
			{
				NimStringDesc* fieldsX60gensym5025_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchX60gensym5026_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5026_;
				NI T53_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T54_;
				NimStringDesc* T55_;
				if (!(discriminatorVal == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA51_;
				branchX60gensym5026_ = (*n)._kind_6.sons->data[selectedBranch];
				T53_ = (NI)0;
				T53_ = len__P89cqdlERShb9alU3iC0yj8wast(branchX60gensym5026_);
				fieldsX60gensym5026_ = (*branchX60gensym5026_)._kind_6.sons->data[(NI)(T53_ - ((NI) 1))];
				fieldsX60gensym5025_ = fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw(c, fieldsX60gensym5026_, (*constrCtx).initExpr);
				nimZeroMem((void*)T54_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T54_[0] = copyString(fieldsX60gensym5025_);
				T54_[1] = copyString((*(*(*discriminator)._kind_4.sym).name).s);
				T55_ = (NimStringDesc*)0;
				T55_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_448), T54_, 2);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*constrCtx).initExpr).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T55_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_449, NIM_FALSE);
				mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw((&result), ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3));
			}
			goto LA49_;
			LA51_: ;
			{
				tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw T59_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ctorCase;
				NI ctorIdx;
				if (!((*discriminatorVal).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA57_;
				nimZeroMem((void*)(&T59_), sizeof(tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw));
				findUsefulCaseContext__0hNT3646PPGbJcsdagLbHg(c, discriminatorVal, (&T59_));
				ctorCase = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				ctorCase = T59_.Field0;
				ctorIdx = (NI)0;
				ctorIdx = T59_.Field1;
				{
					if (!(ctorCase == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA62_;
					{
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg rangeVals;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg recBranchVals;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg diff;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T68_;
						if (!((*(*discriminatorVal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20))) goto LA66_;
						nimZeroMem((void*)(&rangeVals), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ(c, (*discriminatorVal).typ, (&rangeVals));
						nimZeroMem((void*)(&recBranchVals), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						branchVals__XK56AwQllxmCRE7fuCvRCQ(c, n, selectedBranch, NIM_FALSE, (&recBranchVals));
						nimZeroMem((void*)(&diff), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						nimZeroMem((void*)(&T68_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets((&rangeVals), (&recBranchVals), (&T68_));
						nimCopyMem((void*)(&diff), (NIM_CONST void*)(&T68_), sizeof(diff));
						{
							NI T71_;
							tyArray__Re75IspeoxXy2oCZHwcRrA T74_;
							NimStringDesc* T75_;
							T71_ = (NI)0;
							T71_ = len__litHeZeW9bpJugmXT0ufvwgintsets((&diff));
							if (!!((T71_ == ((NI) 0)))) goto LA72_;
							nimZeroMem((void*)T74_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							T74_[0] = nimIntToStr(selectedBranch);
							T74_[1] = renderAsType__jONWMAXSsSmnBgUvyxg7Hw((&diff), (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
							T75_ = (NimStringDesc*)0;
							T75_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_450), T74_, 2);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T75_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_451, NIM_FALSE);
						}
						LA72_: ;
					}
					goto LA64_;
					LA66_: ;
					{
						NimStringDesc* fieldsX60gensym5040_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchX60gensym5041_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5041_;
						NI T77_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T78_;
						NimStringDesc* T79_;
						branchX60gensym5041_ = (*n)._kind_6.sons->data[selectedBranch];
						T77_ = (NI)0;
						T77_ = len__P89cqdlERShb9alU3iC0yj8wast(branchX60gensym5041_);
						fieldsX60gensym5041_ = (*branchX60gensym5041_)._kind_6.sons->data[(NI)(T77_ - ((NI) 1))];
						fieldsX60gensym5040_ = fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw(c, fieldsX60gensym5041_, (*constrCtx).initExpr);
						nimZeroMem((void*)T78_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T78_[0] = copyString(fieldsX60gensym5040_);
						T78_[1] = copyString((*(*(*discriminator)._kind_4.sym).name).s);
						T79_ = (NimStringDesc*)0;
						T79_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_448), T78_, 2);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*constrCtx).initExpr).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T79_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_449, NIM_FALSE);
						mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw((&result), ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3));
					}
					LA64_: ;
				}
				goto LA60_;
				LA62_: ;
				{
					NIM_BOOL T81_;
					T81_ = (NIM_BOOL)0;
					T81_ = !(((520 &((NU32)1<<((NU)((*(*discriminatorVal)._kind_4.sym).kind)&31U)))!=0));
					if (T81_) goto LA82_;
					T81_ = ((8388608 &((NU64)1<<((NU)((*(*(*discriminatorVal)._kind_4.sym).typ).kind)&63U)))!=0);
					LA82_: ;
					if (!T81_) goto LA83_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_452), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_453, NIM_FALSE);
				}
				goto LA60_;
				LA83_: ;
				{
					if (!((*(*ctorCase)._kind_6.sons->data[ctorIdx]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86))) goto LA86_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_454), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_455, NIM_FALSE);
				}
				goto LA60_;
				LA86_: ;
				{
					tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ctorBranchVals;
					tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg recBranchVals_2;
					tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg branchValsDiff;
					nimZeroMem((void*)(&ctorBranchVals), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
					branchVals__XK56AwQllxmCRE7fuCvRCQ(c, ctorCase, ctorIdx, NIM_TRUE, (&ctorBranchVals));
					nimZeroMem((void*)(&recBranchVals_2), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
					branchVals__XK56AwQllxmCRE7fuCvRCQ(c, n, selectedBranch, NIM_FALSE, (&recBranchVals_2));
					nimZeroMem((void*)(&branchValsDiff), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
					minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets((&ctorBranchVals), (&recBranchVals_2), (&branchValsDiff));
					{
						NI T91_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T94_;
						NimStringDesc* T95_;
						T91_ = (NI)0;
						T91_ = len__litHeZeW9bpJugmXT0ufvwgintsets((&branchValsDiff));
						if (!!((T91_ == ((NI) 0)))) goto LA92_;
						nimZeroMem((void*)T94_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T94_[0] = nimIntToStr(selectedBranch);
						T94_[1] = renderAsType__jONWMAXSsSmnBgUvyxg7Hw((&branchValsDiff), (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
						T95_ = (NimStringDesc*)0;
						T95_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_450), T94_, 2);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T95_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_456, NIM_FALSE);
					}
					LA92_: ;
				}
				LA60_: ;
			}
			goto LA49_;
			LA57_: ;
			{
				NI failedBranch;
				failedBranch = ((NI) -1);
				{
					if (!!(((*branchNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88)))) goto LA99_;
					{
						NIM_BOOL T103_;
						T103_ = (NIM_BOOL)0;
						T103_ = caseBranchMatchesExpr__2m1qzNtSRcrBCjT714EGTA(branchNode, discriminatorVal);
						if (!!(T103_)) goto LA104_;
						failedBranch = selectedBranch;
					}
					LA104_: ;
				}
				goto LA97_;
				LA99_: ;
				{
					{
						NI i_5;
						NI colontmp__3;
						NI T108_;
						NI i_6;
						i_5 = (NI)0;
						colontmp__3 = (NI)0;
						T108_ = (NI)0;
						T108_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						colontmp__3 = (NI)(T108_ - ((NI) 1));
						i_6 = ((NI) 1);
						{
							while (1) {
								if (!(i_6 < colontmp__3)) goto LA110;
								i_5 = i_6;
								{
									NIM_BOOL T113_;
									T113_ = (NIM_BOOL)0;
									T113_ = caseBranchMatchesExpr__2m1qzNtSRcrBCjT714EGTA((*n)._kind_6.sons->data[i_5], discriminatorVal);
									if (!T113_) goto LA114_;
									failedBranch = i_5;
									goto LA107;
								}
								LA114_: ;
								i_6 += ((NI) 1);
							} LA110: ;
						}
					} LA107: ;
				}
				LA97_: ;
				{
					if (!!((failedBranch == ((NI) -1)))) goto LA118_;
					{
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg rangeVals_2;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg recBranchVals_3;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg diff_2;
						tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T124_;
						if (!((*(*discriminatorVal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20))) goto LA122_;
						nimZeroMem((void*)(&rangeVals_2), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						getIntSetOfType__uLhVC3evuQrv7q9aBGOuzeQ(c, (*discriminatorVal).typ, (&rangeVals_2));
						nimZeroMem((void*)(&recBranchVals_3), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						branchVals__XK56AwQllxmCRE7fuCvRCQ(c, n, selectedBranch, NIM_FALSE, (&recBranchVals_3));
						nimZeroMem((void*)(&diff_2), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						nimZeroMem((void*)(&T124_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
						minus___LSsT9adsoi9bg6Vh4SNYfeQQintsets((&rangeVals_2), (&recBranchVals_3), (&T124_));
						nimCopyMem((void*)(&diff_2), (NIM_CONST void*)(&T124_), sizeof(diff_2));
						{
							NI T127_;
							tyArray__Re75IspeoxXy2oCZHwcRrA T130_;
							NimStringDesc* T131_;
							T127_ = (NI)0;
							T127_ = len__litHeZeW9bpJugmXT0ufvwgintsets((&diff_2));
							if (!!((T127_ == ((NI) 0)))) goto LA128_;
							nimZeroMem((void*)T130_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							T130_[0] = nimIntToStr(selectedBranch);
							T130_[1] = renderAsType__jONWMAXSsSmnBgUvyxg7Hw((&diff_2), (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
							T131_ = (NimStringDesc*)0;
							T131_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_450), T130_, 2);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*discriminatorVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T131_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_457, NIM_FALSE);
						}
						LA128_: ;
					}
					goto LA120_;
					LA122_: ;
					{
						NimStringDesc* fieldsX60gensym5073_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branchX60gensym5074_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5074_;
						NI T133_;
						tyArray__24KAM9afIUgUaqBaEBB6r9bg T134_;
						NimStringDesc* T135_;
						branchX60gensym5074_ = (*n)._kind_6.sons->data[failedBranch];
						T133_ = (NI)0;
						T133_ = len__P89cqdlERShb9alU3iC0yj8wast(branchX60gensym5074_);
						fieldsX60gensym5074_ = (*branchX60gensym5074_)._kind_6.sons->data[(NI)(T133_ - ((NI) 1))];
						fieldsX60gensym5073_ = fieldsPresentInInitExpr__fAlP9cVEHopuX8Pfr9b5rx9cw(c, fieldsX60gensym5074_, (*constrCtx).initExpr);
						nimZeroMem((void*)T134_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
						T134_[0] = copyString((*(*(*discriminator)._kind_4.sym).name).s);
						T134_[1] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(discriminatorVal, 0);
						T134_[2] = copyString(fieldsX60gensym5073_);
						T135_ = (NimStringDesc*)0;
						T135_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_458), T134_, 3);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*constrCtx).initExpr).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T135_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_459, NIM_FALSE);
					}
					LA120_: ;
				}
				LA118_: ;
			}
			LA49_: ;
			{
				if (!(result == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2))) goto LA138_;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5082_;
					NI T144_;
					if (!!((branchNode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA142_;
					T144_ = (NI)0;
					T144_ = len__P89cqdlERShb9alU3iC0yj8wast(branchNode);
					fieldsX60gensym5082_ = (*branchNode)._kind_6.sons->data[(NI)(T144_ - ((NI) 1))];
					collectMissingFields__R8ignHxUaQZzB8x7tzNkEg(c, fieldsX60gensym5082_, constrCtx);
				}
				LA142_: ;
			}
			LA138_: ;
		}
		goto LA28_;
		LA30_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* discriminatorVal_2;
			result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3);
			discriminatorVal_2 = semConstrField__dYxITD6gRULNORUNQ6Cc9cg(c, (flags | 16), (*discriminator)._kind_4.sym, (*constrCtx).initExpr);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* defaultValue;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matchedBranch;
				if (!(discriminatorVal_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA148_;
				defaultValue = newIntLit__TuFlkTIoJNHT6fCcycYtSw((*c).graph, (*(*constrCtx).initExpr).info, IL64(0));
				matchedBranch = pickCaseBranch__XwTdxP6ATUC1LHA9bBiTnDA(n, defaultValue);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5087_;
					NI T154_;
					if (!!((matchedBranch == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA152_;
					T154_ = (NI)0;
					T154_ = len__P89cqdlERShb9alU3iC0yj8wast(matchedBranch);
					fieldsX60gensym5087_ = (*matchedBranch)._kind_6.sons->data[(NI)(T154_ - ((NI) 1))];
					collectMissingFields__R8ignHxUaQZzB8x7tzNkEg(c, fieldsX60gensym5087_, constrCtx);
				}
				LA152_: ;
			}
			goto LA146_;
			LA148_: ;
			{
				result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 2);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* matchedBranch_2;
					if (!((*discriminatorVal_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA158_;
					matchedBranch_2 = pickCaseBranch__XwTdxP6ATUC1LHA9bBiTnDA(n, discriminatorVal_2);
					{
						if (!!((matchedBranch_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA162_;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5093_;
							NI T168_;
							if (!!((matchedBranch_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA166_;
							T168_ = (NI)0;
							T168_ = len__P89cqdlERShb9alU3iC0yj8wast(matchedBranch_2);
							fieldsX60gensym5093_ = (*matchedBranch_2)._kind_6.sons->data[(NI)(T168_ - ((NI) 1))];
							collectMissingFields__R8ignHxUaQZzB8x7tzNkEg(c, fieldsX60gensym5093_, constrCtx);
						}
						LA166_: ;
					}
					LA162_: ;
				}
				goto LA156_;
				LA158_: ;
				{
					{
						NI i_7;
						NI colontmp__4;
						NI i_8;
						i_7 = (NI)0;
						colontmp__4 = (NI)0;
						colontmp__4 = len__P89cqdlERShb9alU3iC0yj8wast(n);
						i_8 = ((NI) 1);
						{
							while (1) {
								if (!(i_8 < colontmp__4)) goto LA172;
								i_7 = i_8;
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldsX60gensym5099_;
									NI T177_;
									if (!!(((*n)._kind_6.sons->data[i_7] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA175_;
									T177_ = (NI)0;
									T177_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i_7]);
									fieldsX60gensym5099_ = (*(*n)._kind_6.sons->data[i_7])._kind_6.sons->data[(NI)(T177_ - ((NI) 1))];
									collectMissingFields__R8ignHxUaQZzB8x7tzNkEg(c, fieldsX60gensym5099_, constrCtx);
								}
								LA175_: ;
								i_8 += ((NI) 1);
							} LA172: ;
						}
					}
				}
				LA156_: ;
			}
			LA146_: ;
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_2;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
		field_2 = (*n)._kind_4.sym;
		e = semConstrField__dYxITD6gRULNORUNQ6Cc9cg(c, flags, field_2, (*constrCtx).initExpr);
		{
			if (!!((e == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA181_;
			result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 1);
		}
		goto LA179_;
		LA181_: ;
		{
			result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 3);
		}
		LA179_: ;
	}
	break;
	default:
	{
		{
			NimStringDesc* argX60gensym5106_;
			if (!NIM_TRUE) goto LA187_;
			argX60gensym5106_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_460);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym5106_, TM__rF9caJawfOjYTjsgLVUSGFA_460);
		}
		LA187_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ, semConstructTypeAux__sAwB0gQrQ1keYlqxdq08bQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw* constrCtx, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ)0;
	result = ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 0);
	t = (*constrCtx).typ;
	{
		while (1) {
			tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ status;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
			NIM_BOOL T15_;
			status = semConstructFields__uWuMnWjhYSs5k358Hz7X7w(c, (*t).n, constrCtx, flags);
			mergeInitStatus__P9cKs45sta9alE9cK9aOiS7Rhw((&result), status);
			{
				if (!((13 &((NU8)1<<((NU)(status)&7U)))!=0)) goto LA5_;
				collectMissingFields__R8ignHxUaQZzB8x7tzNkEg(c, (*t).n, constrCtx);
			}
			LA5_: ;
			base = (*t).sons->data[((NI) 0)];
			{
				if (!(base == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA9_;
				goto LA1;
			}
			LA9_: ;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(base, IL64(36275087638268176));
			{
				if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)))) goto LA13_;
				goto BeforeRet_;
			}
			LA13_: ;
			T15_ = (NIM_BOOL)0;
			T15_ = (*constrCtx).needsFullInit;
			if (T15_) goto LA16_;
			T15_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 19))&63U)))!=0);
			LA16_: ;
			(*constrCtx).needsFullInit = T15_;
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, computeRequiresInit__p5rbEi9c5JmURA4qGF6bxhg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw constrCtx;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ initResult;
	NI T2_;
	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&constrCtx), sizeof(tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw));
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
	initConstrContext__RYPHxM9aTf8uWaAnZ0rNc2A(t, T1_, (&constrCtx));
	initResult = semConstructTypeAux__sAwB0gQrQ1keYlqxdq08bQ(c, (&constrCtx), 0);
	T2_ = (constrCtx.missingFields ? constrCtx.missingFields->Sup.len : 0);
	result = (((NI) 0) < T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semObjectNode__T23bTYnaXqU9cKlZ7Ag9bdBg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, NIM_BOOL isInheritable) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	NI pos;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* realBase;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		goto BeforeRet_;
	}
	LA4_: ;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	pos = ((NI) 0);
	base = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	realBase = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 3), (*(*c).graph).config);
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA8_;
		realBase = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		base = skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2(realBase, IL64(36275087638268176));
		{
			if (!(base == 0)) goto LA12_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_51), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_52, NIM_FALSE);
		}
		goto LA10_;
		LA12_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concreteBase;
			concreteBase = skipGenericInvocation__un0CMx5e9axSJU0IN3TyTiwsem(base);
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((135680 &((NU64)1<<((NU)((*concreteBase).kind)&63U)))!=0);
				if (!(T17_)) goto LA18_;
				T17_ = !((((*concreteBase).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0));
				LA18_: ;
				if (!T17_) goto LA19_;
				{
					if (!((*concreteBase).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA23_;
					{
						NIM_BOOL T27_;
						NIM_BOOL T28_;
						T27_ = (NIM_BOOL)0;
						T28_ = (NIM_BOOL)0;
						T28_ = !(((*concreteBase).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T28_)) goto LA29_;
						T28_ = ((*(*concreteBase).sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 264));
						LA29_: ;
						T27_ = T28_;
						if (!(T27_)) goto LA30_;
						T27_ = !((((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0));
						LA30_: ;
						if (!T27_) goto LA31_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 30), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_53, NIM_FALSE);
					}
					LA31_: ;
					addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg(c, (&check), (&pos), concreteBase);
				}
				LA23_: ;
			}
			goto LA15_;
			LA19_: ;
			{
				{
					NimStringDesc* T38_;
					NimStringDesc* T39_;
					if (!!(((*concreteBase).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50)))) goto LA36_;
					T38_ = (NimStringDesc*)0;
					T39_ = (NimStringDesc*)0;
					T39_ = typeToString__QlvraUan7WbHowhAbvDvdA(realBase, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T38_ = rawNewString((T39_ ? T39_->Sup.len : 0) + 120);
appendString(T38_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_60));
appendString(T38_, T39_);
appendString(T38_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_61));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T38_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_62, NIM_FALSE);
				}
				LA36_: ;
				base = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
				realBase = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
			}
			LA15_: ;
		}
		LA10_: ;
	}
	LA8_: ;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133)))) goto LA42_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_63), TM__rF9caJawfOjYTjsgLVUSGFA_64);
	}
	LA42_: ;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17), prev, c);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, realBase, NIM_TRUE);
	{
		NIM_BOOL T46_;
		T46_ = (NIM_BOOL)0;
		T46_ = (realBase == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (!(T46_)) goto LA47_;
		T46_ = isInheritable;
		LA47_: ;
		if (!T46_) goto LA48_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3)) & 63);
	}
	LA48_: ;
	{
		if (!((*result).n == 0)) goto LA52_;
		asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info));
	}
	goto LA50_;
	LA52_: ;
	{
		addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg(c, (&check), (&pos), result);
	}
	LA50_: ;
	semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, (*n)._kind_6.sons->data[((NI) 2)], (&check), (&pos), (*result).n, result, NIM_FALSE);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T59_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA57_;
		T59_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T59_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_432));
		T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T60_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T59_, (*n).info);
		s = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), T60_, c);
		asgnRef((void**) (&(*s).typ), result);
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 0)], TM__rF9caJawfOjYTjsgLVUSGFA_433, NIM_FALSE);
	}
	LA57_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = (base == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (!(T63_)) goto LA64_;
		T63_ = !((((*result).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3))&63U)))!=0));
		LA64_: ;
		if (!T63_) goto LA65_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2)) & 63);
	}
	LA65_: ;
	{
		NIM_BOOL T69_;
		T69_ = (NIM_BOOL)0;
		T69_ = ((*c).inGenericContext == ((NI) 0));
		if (!(T69_)) goto LA70_;
		T69_ = computeRequiresInit__p5rbEi9c5JmURA4qGF6bxhg(c, result);
		LA70_: ;
		if (!T69_) goto LA71_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
	}
	LA71_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semAnyRef__WkfdPzqjIHjpNCHcK8ViDg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ < ((NI) 1))) goto LA4_;
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, kind);
	}
	goto LA1_;
	LA4_: ;
	{
		NI isCall;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		NIM_BOOL isNilable;
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag wrapperKind;
		isCall = ((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA9_;
			n_2 = (*n)._kind_6.sons->data[((NI) 0)];
		}
		goto LA7_;
		LA9_: ;
		{
			n_2 = n;
		}
		LA7_: ;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n_2, ((NI) 1), (*(*c).graph).config);
		body = lastSon__UPSW0jLTX5qJL51YMUAHgw(n_2);
		{
			NIM_BOOL T14_;
			NIM_BOOL T15_;
			T14_ = (NIM_BOOL)0;
			T15_ = (NIM_BOOL)0;
			T15_ = !((prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T15_)) goto LA16_;
			T15_ = ((*body).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133));
			LA16_: ;
			T14_ = T15_;
			if (!(T14_)) goto LA17_;
			T14_ = (((*prev).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3))&63U)))!=0);
			LA17_: ;
			if (!T14_) goto LA18_;
			t = semObjectNode__T23bTYnaXqU9cKlZ7Ag9bdBg(c, body, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), NIM_TRUE);
		}
		goto LA12_;
		LA18_: ;
		{
			t = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, body, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		}
		LA12_: ;
		{
			NIM_BOOL T23_;
			T23_ = (NIM_BOOL)0;
			T23_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			if (!(T23_)) goto LA24_;
			T23_ = !((((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0));
			LA24_: ;
			if (!T23_) goto LA25_;
			t = base__PfgI9ap7WOnsRfFV4znQ27w(t);
		}
		LA25_: ;
		{
			NimStringDesc* T31_;
			NimStringDesc* T32_;
			if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA29_;
			T31_ = (NimStringDesc*)0;
			T31_ = toHumanStr__8clA3iQh1Lbc5cnapppbXQ(kind);
			T32_ = (NimStringDesc*)0;
			T32_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_461), T31_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_462, NIM_FALSE);
		}
		LA29_: ;
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(kind, prev, c);
		isNilable = NIM_FALSE;
		wrapperKind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0);
		{
			NI i;
			NI colontmp_;
			NI T34_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T34_ = (NI)0;
			T34_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
			colontmp_ = (NI)(T34_ - ((NI) 1));
			i_2 = isCall;
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ni;
					if (!(i_2 < colontmp_)) goto LA36;
					i = i_2;
					ni = (*n_2)._kind_6.sons->data[i];
					{
						if (!((*ni).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA39_;
						isNilable = NIM_TRUE;
					}
					goto LA37_;
					LA39_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* region;
						region = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, ni, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
						{
							if (!((IL64(105553116266496) &((NU64)1<<((NU)((*region).kind)&63U)))!=0)) goto LA44_;
							wrapperKind = (*region).kind;
						}
						goto LA42_;
						LA44_: ;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T47_;
							T47_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T47_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(region, IL64(70368744179728));
							if (!!(((IL64(1125899906973696) &((NU64)1<<((NU)((*T47_).kind)&63U)))!=0))) goto LA48_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n_2)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_463), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_464, NIM_FALSE);
							addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, region);
						}
						goto LA42_;
						LA48_: ;
						{
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_465), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_466, NIM_FALSE);
							addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, region);
						}
						LA42_: ;
					}
					LA37_: ;
					i_2 += ((NI) 1);
				} LA36: ;
			}
		}
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, t);
		{
			if (!(((*result).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 16))&63U)))!=0)) goto LA53_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T57_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
				T57_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T57_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
				if (!((*T57_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA58_;
				T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T60_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
				(*T60_).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 16)) & 63);
			}
			LA58_: ;
		}
		LA53_: ;
		switch (wrapperKind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
		{
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
				if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA64_;
				t_2 = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45), c);
				(*t_2).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63);
				rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2(t_2, result);
				result = t_2;
			}
			LA64_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_3;
			t_3 = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46), c);
			rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2(t_3, result);
			result = t_3;
		}
		break;
		default:
		{
		}
		break;
		}
		{
			NIM_BOOL T70_;
			T70_ = (NIM_BOOL)0;
			T70_ = ((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22));
			if (!(T70_)) goto LA71_;
			T70_ = ((48 &((NU16)1<<((NU)((*(*(*c).graph).config).selectedGC)&15U)))!=0);
			LA71_: ;
			if (!T70_) goto LA72_;
			(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
		}
		LA72_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeof2__O8zf75mcUwo9cfPQUQRaEug_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	NI64 m;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t;
	tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ T12_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	m = IL64(1);
	{
		NI T4_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* mode;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T4_ == ((NI) 3))) goto LA5_;
		mode = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[((NI) 2)]);
		{
			if (!!(((*mode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA9_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_228), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_468, NIM_FALSE);
		}
		goto LA7_;
		LA9_: ;
		{
			m = (*mode)._kind_1.intVal;
		}
		LA7_: ;
	}
	LA5_: ;
	{
		if (!(m == IL64(1))) goto LA15_;
		T12_ = 4;
	}
	goto LA13_;
	LA15_: ;
	{
		T12_ = 0;
	}
	LA13_: ;
	t = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], T12_);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	fixupTypeOf__3zDDdB9b7Qt20FH75Al61MA(c, prev, t);
	result = (*t).typ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, commonType__hfwrZ5ThSx8sbABQFEwdHg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* y) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(x == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = x;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!(y == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA7_;
		result = y;
		goto BeforeRet_;
	}
	LA7_: ;
	a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(x, IL64(70368744179728));
	b = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(y, IL64(70368744179728));
	result = x;
	{
		if (!((96 &((NU64)1<<((NU)((*a).kind)&63U)))!=0)) goto LA11_;
		result = y;
	}
	goto LA9_;
	LA11_: ;
	{
		if (!((96 &((NU64)1<<((NU)((*b).kind)&63U)))!=0)) goto LA14_;
		result = x;
	}
	goto LA9_;
	LA14_: ;
	{
		if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7))) goto LA17_;
		result = a;
	}
	goto LA9_;
	LA17_: ;
	{
		if (!((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7))) goto LA20_;
		result = b;
	}
	goto LA9_;
	LA20_: ;
	{
		if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA23_;
		{
			NI T27_;
			T27_ = (NI)0;
			T27_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
			if (!(T27_ == ((NI) 0))) goto LA28_;
			result = a;
		}
		goto LA25_;
		LA28_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
			result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), (*a).owner);
			T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T31_ = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), (*a).owner);
			rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T31_, NIM_TRUE);
		}
		LA25_: ;
	}
	goto LA9_;
	LA23_: ;
	{
		NIM_BOOL T33_;
		NI idx;
		T33_ = (NIM_BOOL)0;
		T33_ = ((17367040 &((NU64)1<<((NU)((*b).kind)&63U)))!=0);
		if (!(T33_)) goto LA34_;
		T33_ = ((*a).kind == (*b).kind);
		LA34_: ;
		if (!T33_) goto LA35_;
		idx = ((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16));
		{
			if (!((*(*a).sons->data[idx]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3))) goto LA39_;
			result = y;
			goto BeforeRet_;
		}
		LA39_: ;
	}
	goto LA9_;
	LA35_: ;
	{
		NIM_BOOL T42_;
		NIM_BOOL T43_;
		NI T46_;
		NI T47_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* nt;
		T42_ = (NIM_BOOL)0;
		T43_ = (NIM_BOOL)0;
		T43_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
		if (!(T43_)) goto LA44_;
		T43_ = ((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
		LA44_: ;
		T42_ = T43_;
		if (!(T42_)) goto LA45_;
		T46_ = (NI)0;
		T46_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
		T47_ = (NI)0;
		T47_ = len__5mJADrRYkP3r9auuiuDZN9cQast(b);
		T42_ = (T46_ == T47_);
		LA45_: ;
		if (!T42_) goto LA48_;
		nt = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
			i_2 = ((NI) 0);
			{
				while (1) {
					NIM_BOOL aEmpty;
					NIM_BOOL bEmpty;
					if (!(i_2 < colontmp_)) goto LA52;
					i = i_2;
					aEmpty = isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4((*a).sons->data[i]);
					bEmpty = isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4((*b).sons->data[i]);
					{
						if (!!((aEmpty == bEmpty))) goto LA55_;
						{
							if (!(nt == 0)) goto LA59_;
							nt = copyType__4O4aYoscFPo2FRSh4rP9ayg(a, (*a).owner, NIM_FALSE);
						}
						LA59_: ;
						{
							if (!aEmpty) goto LA63_;
							asgnRef((void**) (&(*nt).sons->data[i]), (*b).sons->data[i]);
						}
						goto LA61_;
						LA63_: ;
						{
							asgnRef((void**) (&(*nt).sons->data[i]), (*a).sons->data[i]);
						}
						LA61_: ;
					}
					LA55_: ;
					i_2 += ((NI) 1);
				} LA52: ;
			}
		}
		{
			if (!!((nt == 0))) goto LA68_;
			result = nt;
		}
		LA68_: ;
	}
	goto LA9_;
	LA48_: ;
	{
		NIM_BOOL T71_;
		T71_ = (NIM_BOOL)0;
		T71_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20));
		if (!(T71_)) goto LA72_;
		T71_ = ((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20));
		LA72_: ;
		if (!T71_) goto LA73_;
		{
			NIM_BOOL T77_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T80_;
			T77_ = (NIM_BOOL)0;
			T77_ = sameType__3isNyHKb0U1OCnClmflXSg(a, b, 0);
			if (!!(T77_)) goto LA78_;
			T80_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T80_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, 1048576);
			result = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T80_);
		}
		LA78_: ;
	}
	goto LA9_;
	LA73_: ;
	{
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k;
		k = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T90_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T91_;
			if (!((6291456 &((NU64)1<<((NU)((*a).kind)&63U)))!=0)) goto LA84_;
			k = (*a).kind;
			{
				if (!!(((*b).kind == (*a).kind))) goto LA88_;
				result = x;
				goto BeforeRet_;
			}
			LA88_: ;
			T90_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T90_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
			a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T90_, 2048);
			T91_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T91_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(b);
			b = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T91_, 2048);
		}
		LA84_: ;
		{
			NIM_BOOL T94_;
			T94_ = (NIM_BOOL)0;
			T94_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			if (!(T94_)) goto LA95_;
			T94_ = ((*b).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			LA95_: ;
			if (!T94_) goto LA96_;
			result = commonSuperclass__CFsXKWHnV1O9asJrtw08whA(a, b);
			{
				NIM_BOOL T100_;
				T100_ = (NIM_BOOL)0;
				T100_ = (result == 0);
				if (T100_) goto LA101_;
				T100_ = (result == a);
				LA101_: ;
				if (!T100_) goto LA102_;
				result = x;
				goto BeforeRet_;
			}
			LA102_: ;
			{
				if (!(result == b)) goto LA106_;
				result = y;
				goto BeforeRet_;
			}
			LA106_: ;
			{
				NIM_BOOL T110_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
				T110_ = (NIM_BOOL)0;
				T110_ = !((k == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
				if (!(T110_)) goto LA111_;
				T110_ = !(((*x).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11)));
				LA111_: ;
				if (!T110_) goto LA112_;
				r = result;
				result = newType__SNqpa06pdVCLFFBR28119aQ(k, (*r).owner);
				addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, r);
			}
			LA112_: ;
		}
		LA96_: ;
	}
	LA9_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semWhen__5C4HPXQuhxlMYIzPbe36lg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL semCheck) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL whenNimvm;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	whenNimvm = NIM_FALSE;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T1_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T1_).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6);
	typ = T1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exprNode;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T5_ = (T6_ == ((NI) 2));
		if (!(T5_)) goto LA7_;
		T5_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86));
		LA7_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA8_;
		T4_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88));
		LA8_: ;
		if (!T4_) goto LA9_;
		exprNode = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T15_;
			if (!((*exprNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA13_;
			T15_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T15_ = lookUp__CLMmoDuBHkJLvNsKvljGNw_2(c, exprNode);
			whenNimvm = ((*T15_).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 259));
		}
		goto LA11_;
		LA13_: ;
		{
			if (!((*exprNode).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA17_;
			whenNimvm = ((*(*exprNode)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 259));
		}
		goto LA11_;
		LA17_: ;
		LA11_: ;
		{
			if (!whenNimvm) goto LA21_;
			(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 8)) & 31);
		}
		LA21_: ;
	}
	LA9_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA25;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				switch ((*it).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 49):
				{
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(it, ((NI) 2), (*(*c).graph).config);
					{
						if (!whenNimvm) goto LA29_;
						{
							if (!semCheck) goto LA33_;
							asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 1)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*it)._kind_6.sons->data[((NI) 1)], 0));
							typ = commonType__hfwrZ5ThSx8sbABQFEwdHg(typ, (*(*it)._kind_6.sons->data[((NI) 1)]).typ);
						}
						LA33_: ;
						result = n;
					}
					goto LA27_;
					LA29_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
						T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T36_ = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*it)._kind_6.sons->data[((NI) 0)]);
						e = forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T36_);
						{
							if (!!(((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA39_;
						}
						goto LA37_;
						LA39_: ;
						{
							NIM_BOOL T42_;
							T42_ = (NIM_BOOL)0;
							T42_ = !(((*e)._kind_1.intVal == IL64(0)));
							if (!(T42_)) goto LA43_;
							T42_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
							LA43_: ;
							if (!T42_) goto LA44_;
							{
								if (!semCheck) goto LA48_;
								result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*it)._kind_6.sons->data[((NI) 1)], 0);
							}
							goto LA46_;
							LA48_: ;
							{
								result = (*it)._kind_6.sons->data[((NI) 1)];
							}
							LA46_: ;
						}
						goto LA37_;
						LA44_: ;
						LA37_: ;
					}
					LA27_: ;
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 50):
				{
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(it, ((NI) 1), (*(*c).graph).config);
					{
						NIM_BOOL T54_;
						T54_ = (NIM_BOOL)0;
						T54_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						if (T54_) goto LA55_;
						T54_ = whenNimvm;
						LA55_: ;
						if (!T54_) goto LA56_;
						{
							if (!semCheck) goto LA60_;
							asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 0)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*it)._kind_6.sons->data[((NI) 0)], 0));
							typ = commonType__hfwrZ5ThSx8sbABQFEwdHg(typ, (*(*it)._kind_6.sons->data[((NI) 0)]).typ);
						}
						LA60_: ;
						{
							if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA64_;
							result = (*it)._kind_6.sons->data[((NI) 0)];
						}
						LA64_: ;
					}
					LA56_: ;
				}
				break;
				default:
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA25: ;
		}
	}
	{
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA69_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
	}
	LA69_: ;
	{
		if (!whenNimvm) goto LA73_;
		asgnRef((void**) (&(*result).typ), typ);
	}
	LA73_: ;
	idSynchronizationPoint__o9blMKDNUEgfiqOxiffy8Tw(((NI) 200));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, semTypeIdent__AO57Q9bSpsZiuv7kwwoM7yw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		result = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, (*n)._kind_4.sym);
	}
	goto LA1_;
	LA3_: ;
	{
		result = pickSym__SVsbCvrhrWQIRF0pM3cw5Q(c, n, 152, 0);
		{
			if (!(result == 0)) goto LA8_;
			result = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, 3);
		}
		LA8_: ;
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA12_;
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, result);
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				if (!(T16_)) goto LA17_;
				T16_ = ((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
				LA17_: ;
				if (!T16_) goto LA18_;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* bound;
					if (!(((NI) 0) < (*c).inGenericInst)) goto LA22_;
					bound = (*(*(*result).typ).sons->data[((NI) 0)]).sym;
					{
						if (!!((bound == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA26_;
						result = bound;
						goto BeforeRet_;
					}
					LA26_: ;
					goto BeforeRet_;
				}
				LA22_: ;
				{
					if (!((*(*result).typ).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA30_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_470, NIM_FALSE);
					result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
					goto BeforeRet_;
				}
				LA30_: ;
				result = copySym__lIu8wX6Beq6dBJgESOFFjg((*(*result).typ).sym);
				asgnRef((void**) (&(*result).typ), exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ((*result).typ));
				(*(*result).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
			}
			LA18_: ;
			{
				if (!((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4))) goto LA34_;
				{
					NIM_BOOL T38_;
					NIM_BOOL T39_;
					NI T41_;
					T38_ = (NIM_BOOL)0;
					T39_ = (NIM_BOOL)0;
					T39_ = ((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
					if (!(T39_)) goto LA40_;
					T41_ = (NI)0;
					T41_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*result).typ);
					T39_ = (T41_ == ((NI) 0));
					LA40_: ;
					T38_ = T39_;
					if (!(T38_)) goto LA42_;
					T38_ = (((*(*result).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0);
					LA42_: ;
					if (!T38_) goto LA43_;
					transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw(result);
					(*(*result).typ).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30)) & 63));
					goto BeforeRet_;
				}
				goto LA36_;
				LA43_: ;
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_471, NIM_FALSE);
					result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
					goto BeforeRet_;
				}
				LA36_: ;
			}
			LA34_: ;
			{
				NIM_BOOL T48_;
				tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ ov;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* amb;
				T48_ = (NIM_BOOL)0;
				T48_ = !(((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)));
				if (!(T48_)) goto LA49_;
				T48_ = !(((*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 24) || (*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 17) || (*result).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18)));
				LA49_: ;
				if (!T48_) goto LA50_;
				nimZeroMem((void*)(&ov), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
				amb = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&ov), c, n);
				{
					while (1) {
						NIM_BOOL T54_;
						T54_ = (NIM_BOOL)0;
						T54_ = !((amb == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T54_)) goto LA55_;
						T54_ = !(((*amb).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)));
						LA55_: ;
						if (!T54_) goto LA53;
						amb = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&ov), c, n);
					} LA53: ;
				}
				{
					if (!!((amb == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA58_;
					result = amb;
				}
				goto LA56_;
				LA58_: ;
				{
					{
						if (!!(((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0)))) goto LA63_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_472, NIM_FALSE);
					}
					LA63_: ;
					result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
					goto BeforeRet_;
				}
				LA56_: ;
			}
			LA50_: ;
			{
				tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q oldInfo;
				if (!!(((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)))) goto LA67_;
				oldInfo = (*n).info;
				reset__2DpKIamrWIkCdM4vNi0Xcw(n);
				transitionNoneToSym__ZdMf7vswMpd0Pc5oB9aS4og(n);
				asgnRef((void**) (&(*n)._kind_4.sym), result);
				(*n).info = oldInfo;
				asgnRef((void**) (&(*n).typ), (*result).typ);
			}
			LA67_: ;
		}
		goto LA10_;
		LA12_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_473), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_474, NIM_FALSE);
			result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
		}
		LA10_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symFromExpectedTypeNode__AO57Q9bSpsZiuv7kwwoM7yw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4))) goto LA3_;
		result = symFromType__xO2UfktRDKCUWUorFz9cLYA(c, (*n).typ, (*n).info);
	}
	goto LA1_;
	LA3_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_475, NIM_FALSE);
		result = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semArrayIndex__aJQEuszymrhDdKaEXWG3Vg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees(n);
		if (!T3_) goto LA4_;
		result = semRangeAux__O8zf75mcUwo9cfPQUQRaEug_4(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
		e = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 256);
		{
			if (!((*(*e).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61))) goto LA9_;
			result = makeRangeWithStaticExpr__D2YW7F23KYvdV39aTScM3IQ_2(c, (*(*e).typ).n);
		}
		goto LA7_;
		LA9_: ;
		{
			if (!((*e).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) && (*e).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15))) goto LA12_;
			{
				NimStringDesc* T18_;
				NimStringDesc* T19_;
				if (!((*e)._kind_1.intVal < IL64(0))) goto LA16_;
				T18_ = (NimStringDesc*)0;
				T19_ = (NimStringDesc*)0;
				T19_ = nimInt64ToStr((*e)._kind_1.intVal);
				T18_ = rawNewString((T19_ ? T19_->Sup.len : 0) + 40);
appendString(T18_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_476));
appendString(T18_, T19_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T18_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_477, NIM_FALSE);
			}
			LA16_: ;
			result = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), (NI64)((*e)._kind_1.intVal - IL64(1)), (*n).info, (*e).typ);
		}
		goto LA7_;
		LA12_: ;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T21_)) goto LA22_;
			T21_ = ((*(*e).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
			LA22_: ;
			if (!T21_) goto LA23_;
			{
				if (!!(((*(*e)._kind_4.sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA27_;
				result = semArrayIndex__aJQEuszymrhDdKaEXWG3Vg(c, (*(*e)._kind_4.sym).ast);
				goto BeforeRet_;
			}
			LA27_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
				NIM_BOOL T32_;
				tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
				T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T31_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*e).typ);
				T32_ = (NIM_BOOL)0;
				T32_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(T31_, NIM_FALSE);
				if (!!(T32_)) goto LA33_;
				{
					NI T37_;
					T37_ = (NI)0;
					T37_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
					if (!(((NI) 1) < T37_)) goto LA38_;
					info = (*(*n)._kind_6.sons->data[((NI) 1)]).info;
				}
				goto LA35_;
				LA38_: ;
				{
					info = (*n).info;
				}
				LA35_: ;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_478, NIM_FALSE);
			}
			LA33_: ;
			result = makeRangeWithStaticExpr__D2YW7F23KYvdV39aTScM3IQ_2(c, e);
			{
				if (!(((NI) 0) < (*c).inGenericContext)) goto LA43_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
			}
			LA43_: ;
		}
		goto LA7_;
		LA23_: ;
		{
			NIM_BOOL T46_;
			T46_ = (NIM_BOOL)0;
			T46_ = ((*e).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) && (*e).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
			if (!(T46_)) goto LA47_;
			T46_ = hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ(c, e);
			LA47_: ;
			if (!T46_) goto LA48_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T52_;
				NIM_BOOL T53_;
				T52_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T52_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, IL64(1152991873351026704));
				T53_ = (NIM_BOOL)0;
				T53_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(T52_, NIM_FALSE);
				if (!!(T53_)) goto LA54_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_479, NIM_FALSE);
			}
			LA54_: ;
			result = makeRangeWithStaticExpr__D2YW7F23KYvdV39aTScM3IQ_2(c, e);
		}
		goto LA7_;
		LA48_: ;
		{
			if (!((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA57_;
			result = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*e).typ, 256);
		}
		goto LA7_;
		LA57_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			x = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, e);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T64_;
				if (!((*x).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) && (*x).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15))) goto LA62_;
				T64_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T64_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*x).typ, 256);
				result = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), (NI64)((*x)._kind_1.intVal - IL64(1)), (*n).info, T64_);
			}
			goto LA60_;
			LA62_: ;
			{
				result = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*x).typ, 256);
			}
			LA60_: ;
		}
		LA7_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semArray__O8zf75mcUwo9cfPQUQRaEug_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	base = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* indx;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* indxB;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 3))) goto LA4_;
		indx = semArrayIndex__aJQEuszymrhDdKaEXWG3Vg(c, (*n)._kind_6.sons->data[((NI) 1)]);
		indxB = indx;
		{
			if (!((IL64(70368744179728) &((NU64)1<<((NU)((*indxB).kind)&63U)))!=0)) goto LA8_;
			indxB = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(indxB);
		}
		LA8_: ;
		{
			if (!!(((IL64(3458764513820545024) &((NU64)1<<((NU)((*indxB).kind)&63U)))!=0))) goto LA12_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
				T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T16_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(indxB, 1048576);
				if (!((IL64(18691697672192) &((NU64)1<<((NU)((*T16_).kind)&63U)))!=0)) goto LA17_;
			}
			goto LA14_;
			LA17_: ;
			{
				NIM_BOOL T20_;
				T20_ = (NIM_BOOL)0;
				T20_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(indxB, NIM_FALSE);
				if (!!(T20_)) goto LA21_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_480, NIM_FALSE);
			}
			goto LA14_;
			LA21_: ;
			{
				NIM_BOOL T24_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T27_;
				NimStringDesc* T28_;
				NimStringDesc* T29_;
				T24_ = (NIM_BOOL)0;
				T24_ = enumHasHoles__YPjOkGV9axAnGR3UfLeWZ1g_3(indxB);
				if (!T24_) goto LA25_;
				T27_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T27_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(indxB, 1048576);
				T28_ = (NimStringDesc*)0;
				T28_ = typeToString__QlvraUan7WbHowhAbvDvdA(T27_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T29_ = (NimStringDesc*)0;
				T29_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_33), T28_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T29_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_481, NIM_FALSE);
			}
			goto LA14_;
			LA25_: ;
			LA14_: ;
		}
		LA12_: ;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 2)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), prev, c);
		rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2(result, indx);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
	}
	goto LA1_;
	LA4_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_482), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_483, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semContainerArg__tX9cFHLAurfZYsTsUVxevYw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* kindStr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result) {
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 2))) goto LA4_;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		{
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			if (!((*base).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63))) goto LA8_;
			T10_ = (NimStringDesc*)0;
			T10_ = typeToString__QlvraUan7WbHowhAbvDvdA(base, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T11_ = (NimStringDesc*)0;
			T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_484), T10_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_485, NIM_FALSE);
		}
		LA8_: ;
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T13_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
		T13_ = (NimStringDesc*)0;
		T13_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_486), kindStr);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_487, NIM_FALSE);
		T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T14_ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T14_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semContainer__9c9cJm09bVJhp6JDeDwpDcllw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NimStringDesc* kindStr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(kind, prev, c);
	semContainerArg__tX9cFHLAurfZYsTsUVxevYw(c, n, kindStr, result);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semRange__O8zf75mcUwo9cfPQUQRaEug_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 2))) goto LA4_;
		{
			NIM_BOOL T8_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
			T8_ = (NIM_BOOL)0;
			T8_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees((*n)._kind_6.sons->data[((NI) 1)]);
			if (!T8_) goto LA9_;
			result = semRangeAux__O8zf75mcUwo9cfPQUQRaEug_4(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
			n_2 = (*result).n;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*(*n_2)._kind_6.sons->data[((NI) 0)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
				if (!(T13_)) goto LA14_;
				T13_ = (IL64(0) < (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_1.intVal);
				LA14_: ;
				if (!T13_) goto LA15_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
			}
			goto LA11_;
			LA15_: ;
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*(*n_2)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*(*n_2)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
				if (!(T18_)) goto LA19_;
				T18_ = ((*(*n_2)._kind_6.sons->data[((NI) 1)])._kind_1.intVal < IL64(0));
				LA19_: ;
				if (!T18_) goto LA20_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
			}
			goto LA11_;
			LA20_: ;
			{
				NIM_BOOL T23_;
				T23_ = (NIM_BOOL)0;
				T23_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*(*n_2)._kind_6.sons->data[((NI) 0)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
				if (!(T23_)) goto LA24_;
				T23_ = (0.0 < (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_2.floatVal);
				LA24_: ;
				if (!T23_) goto LA25_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
			}
			goto LA11_;
			LA25_: ;
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = ((*(*n_2)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) && (*(*n_2)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
				if (!(T28_)) goto LA29_;
				T28_ = ((*(*n_2)._kind_6.sons->data[((NI) 1)])._kind_2.floatVal < 0.0);
				LA29_: ;
				if (!T28_) goto LA30_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
			}
			goto LA11_;
			LA30_: ;
			LA11_: ;
		}
		goto LA6_;
		LA9_: ;
		{
			{
				NIM_BOOL T35_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T37_;
				T35_ = (NIM_BOOL)0;
				T35_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
				if (!(T35_)) goto LA36_;
				T37_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T37_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				T35_ = eqStrings((*T37_).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_490));
				LA36_: ;
				if (!T35_) goto LA38_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_491), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_492, NIM_FALSE);
			}
			goto LA33_;
			LA38_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_493), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_494, NIM_FALSE);
			}
			LA33_: ;
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T42_;
		T42_ = (NimStringDesc*)0;
		T42_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_486), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_495));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T42_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_496, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semSet__O8zf75mcUwo9cfPQUQRaEug_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19), prev, c);
	{
		NIM_BOOL T3_;
		NI T4_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T4_ == ((NI) 2));
		if (!(T3_)) goto LA5_;
		T3_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		LA5_: ;
		if (!T3_) goto LA6_;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
		{
			if (!((IL64(70368744179728) &((NU64)1<<((NU)((*base).kind)&63U)))!=0)) goto LA10_;
			base = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(base);
		}
		LA10_: ;
		{
			if (!!(((4608 &((NU64)1<<((NU)((*base).kind)&63U)))!=0))) goto LA14_;
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(base, NIM_TRUE);
				if (!!(T18_)) goto LA19_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_497, NIM_FALSE);
			}
			goto LA16_;
			LA19_: ;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T22_;
				NIM_BOOL T23_;
				T22_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, base);
				T23_ = (NIM_BOOL)0;
				T23_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(65536), T22_);
				if (!T23_) goto LA24_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_498), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_499, NIM_FALSE);
			}
			goto LA16_;
			LA24_: ;
			LA16_: ;
		}
		LA14_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		NimStringDesc* T27_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
		T27_ = (NimStringDesc*)0;
		T27_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_486), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_500));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T27_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_501, NIM_FALSE);
		T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T28_ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T28_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semOrdinal__O8zf75mcUwo9cfPQUQRaEug_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15), prev, c);
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 2))) goto LA4_;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		{
			if (!!(((*base).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)))) goto LA8_;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(base, NIM_FALSE);
				if (!!(T12_)) goto LA13_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_502, NIM_FALSE);
			}
			LA13_: ;
		}
		LA8_: ;
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T16_;
		T16_ = (NimStringDesc*)0;
		T16_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_486), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_503));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_504, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semVarargs__O8zf75mcUwo9cfPQUQRaEug_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48), prev, c);
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T4_ == ((NI) 2));
		if (T3_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T6_ == ((NI) 3));
		LA5_: ;
		if (!T3_) goto LA7_;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
		{
			NI T11_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T14_;
			T11_ = (NI)0;
			T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T11_ == ((NI) 3))) goto LA12_;
			T14_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T14_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 2)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			asgnRef((void**) (&(*result).n), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T14_, (*(*n)._kind_6.sons->data[((NI) 2)]).info));
		}
		LA12_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		NimStringDesc* T16_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		T16_ = (NimStringDesc*)0;
		T16_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_486), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_506));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_507, NIM_FALSE);
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T17_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTuple__O8zf75mcUwo9cfPQUQRaEug_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	NI counter;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	typ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), prev, c);
	asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info));
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	counter = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI colontmp__2;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp__2 = (NI)0;
		colontmp_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = colontmp_;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				if (!(i_2 < colontmp__2)) goto LA3;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				{
					if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)))) goto LA6_;
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
				}
				LA6_: ;
				checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*c).graph).config);
				{
					NI T10_;
					NI T13_;
					T10_ = (NI)0;
					T10_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					if (!!(((*(*a)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA11_;
					T13_ = (NI)0;
					T13_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[(NI)(T13_ - ((NI) 2))], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				}
				goto LA8_;
				LA11_: ;
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_510, NIM_FALSE);
					typ = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
				}
				LA8_: ;
				{
					NI T17_;
					NI T20_;
					T17_ = (NI)0;
					T17_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					if (!!(((*(*a)._kind_6.sons->data[(NI)(T17_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA18_;
					T20_ = (NI)0;
					T20_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[(NI)(T20_ - ((NI) 1))]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_427), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_511, NIM_FALSE);
				}
				LA18_: ;
				{
					NI j;
					NI colontmp__3;
					NI T22_;
					NI i_3;
					j = (NI)0;
					colontmp__3 = (NI)0;
					T22_ = (NI)0;
					T22_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					colontmp__3 = (NI)(T22_ - ((NI) 2));
					i_3 = ((NI) 0);
					{
						while (1) {
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
							if (!(i_3 < colontmp__3)) goto LA24;
							j = i_3;
							field = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), (*a)._kind_6.sons->data[j], c);
							asgnRef((void**) (&(*field).typ), typ);
							(*field).position = counter;
							counter += ((NI) 1);
							{
								NIM_BOOL T27_;
								NimStringDesc* T30_;
								T27_ = (NIM_BOOL)0;
								T27_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&check), (*(*field).name).Sup.id);
								if (!T27_) goto LA28_;
								T30_ = (NimStringDesc*)0;
								T30_ = rawNewString(((*(*field).name).s ? (*(*field).name).s->Sup.len : 0) + 23);
appendString(T30_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_136));
appendString(T30_, (*(*field).name).s);
appendString(T30_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T30_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_512, NIM_FALSE);
							}
							goto LA25_;
							LA28_: ;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T32_;
								T32_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T32_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(field);
								add__P8dDSotTW25BkfbyspojGg((*result).n, T32_);
								addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, typ);
							}
							LA25_: ;
							{
								if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA35_;
								nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, field, (*field).kind);
							}
							LA35_: ;
							i_3 += ((NI) 1);
						} LA24: ;
					}
				}
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI T39_;
		T39_ = (NI)0;
		T39_ = len__P89cqdlERShb9alU3iC0yj8wast((*result).n);
		if (!(T39_ == ((NI) 0))) goto LA40_;
		asgnRef((void**) (&(*result).n), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	LA40_: ;
	{
		NIM_BOOL T44_;
		NimStringDesc* T47_;
		NimStringDesc* T48_;
		T44_ = (NIM_BOOL)0;
		T44_ = isTupleRecursive__YPjOkGV9axAnGR3UfLeWZ1g_12(result);
		if (!T44_) goto LA45_;
		T47_ = (NimStringDesc*)0;
		T47_ = typeToString__QlvraUan7WbHowhAbvDvdA(result, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T48_ = (NimStringDesc*)0;
		T48_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_132), T47_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T48_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_513, NIM_FALSE);
	}
	LA45_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGenericParamInInvocation__aJQEuszymrhDdKaEXWG3Vg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	asgnRef((void**) (&(*n).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, result));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semObjectTypeForInheritedGenericInst__ZPW6MqdUk6rECHJvUIgrnA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	NI pos;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* realBase;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newf;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	pos = ((NI) 0);
	realBase = (*t).sons->data[((NI) 0)];
	base = skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2(realBase, IL64(36275087638268176));
	{
		NimStringDesc* T5_;
		if (!(base == 0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_132), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_526));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_527, NIM_FALSE);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concreteBase;
		concreteBase = skipGenericInvocation__un0CMx5e9axSJU0IN3TyTiwsem(base);
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*concreteBase).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			if (!(T9_)) goto LA10_;
			T9_ = !((((*concreteBase).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0));
			LA10_: ;
			if (!T9_) goto LA11_;
			addInheritedFields__PxMjdK03AEVfD5NRj9bgcDg(c, (&check), (&pos), concreteBase);
		}
		goto LA7_;
		LA11_: ;
		{
			{
				if (!!(((*concreteBase).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50)))) goto LA16_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_528), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_529, NIM_FALSE);
			}
			LA16_: ;
		}
		LA7_: ;
	}
	LA1_: ;
	newf = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info);
	semRecordNodeAux__xnbsksR9alpM9axWraQlPoDQ(c, (*t).n, (&check), (&pos), newf, t, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semGeneric__nGXSqtv2avLRNyfQXJjLWw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tx;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		tyArray__Re75IspeoxXy2oCZHwcRrA T5_;
		NimStringDesc* T6_;
		if (!((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T5_[0] = copyString((*(*s).name).s);
		T5_[1] = toHumanStr__QHyA5kxlk0TZf3p6IbMdtA((*s).kind);
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_514), T5_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_515, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
		goto BeforeRet_;
	}
	LA3_: ;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s).typ, 16);
	{
		NIM_BOOL T9_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54));
		if (!(T9_)) goto LA10_;
		T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T11_ = base__PfgI9ap7WOnsRfFV4znQ27w(t);
		T9_ = ((*T11_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10));
		LA10_: ;
		if (!T9_) goto LA12_;
		t = base__PfgI9ap7WOnsRfFV4znQ27w(t);
	}
	LA12_: ;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9), prev, c);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, t);
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30))) goto LA16_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elem;
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					elem = semGenericParamInInvocation__aJQEuszymrhDdKaEXWG3Vg_2(c, (*n)._kind_6.sons->data[i]);
					{
						if (!(elem == 0)) goto LA23_;
						{
							NimStringDesc* argX60gensym1262_;
							if (!NIM_TRUE) goto LA27_;
							argX60gensym1262_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_516);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1262_, TM__rF9caJawfOjYTjsgLVUSGFA_516);
						}
						LA27_: ;
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, elem, NIM_TRUE);
					}
					goto LA21_;
					LA23_: ;
					{
						addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, elem);
					}
					LA21_: ;
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
		goto BeforeRet_;
	}
	goto LA14_;
	LA16_: ;
	{
		NimStringDesc* T33_;
		if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10)))) goto LA31_;
		T33_ = (NimStringDesc*)0;
		T33_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_517), (*(*s).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T33_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_518, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
		goto BeforeRet_;
	}
	goto LA14_;
	LA31_: ;
	{
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
		NIM_BOOL isConcrete;
		nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, t, (&m));
		m.isNoCall = NIM_TRUE;
		T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T35_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		matches__BxEsf1Gt7Hq3usrwPERzyA_2(c, n, T35_, (&m));
		{
			NimStringDesc* err;
			NimStringDesc* T40_;
			NimStringDesc* T41_;
			NimStringDesc* T42_;
			NimStringDesc* T43_;
			if (!!((m.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA38_;
			T40_ = (NimStringDesc*)0;
			T41_ = (NimStringDesc*)0;
			T41_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T42_ = (NimStringDesc*)0;
			T42_ = describeArgs__cCrxh8TxJsIrMINltM1ovw(c, n, ((NI) 1), ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T43_ = (NimStringDesc*)0;
			T43_ = describeArgs__cCrxh8TxJsIrMINltM1ovw(c, (*t).n, ((NI) 0), ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T40_ = rawNewString((T41_ ? T41_->Sup.len : 0) + (T42_ ? T42_->Sup.len : 0) + (T43_ ? T43_->Sup.len : 0) + 44);
appendString(T40_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_519));
appendString(T40_, T41_);
appendString(T40_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_520));
appendString(T40_, T42_);
appendString(T40_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_521));
appendString(T40_, T43_);
appendString(T40_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_522));
			err = T40_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), err, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_523, NIM_FALSE);
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
			goto BeforeRet_;
		}
		LA38_: ;
		isConcrete = NIM_TRUE;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(m.call);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					if (!(i_4 < colontmp__2)) goto LA46;
					i_3 = i_4;
					typ = (*(*m.call)._kind_6.sons->data[i_3]).typ;
					{
						NIM_BOOL T49_;
						NIM_BOOL T50_;
						NIM_BOOL T51_;
						T49_ = (NIM_BOOL)0;
						T50_ = (NIM_BOOL)0;
						T51_ = (NIM_BOOL)0;
						T51_ = ((*(*m.call)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T51_)) goto LA52_;
						T51_ = ((*(*(*m.call)._kind_6.sons->data[i_3])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
						LA52_: ;
						T50_ = T51_;
						if (!(T50_)) goto LA53_;
						T50_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
						LA53_: ;
						T49_ = T50_;
						if (!(T49_)) goto LA54_;
						T49_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(typ);
						LA54_: ;
						if (!T49_) goto LA55_;
						isConcrete = NIM_FALSE;
						{
							if (!(typ == 0)) goto LA59_;
							{
								NimStringDesc* argX60gensym1277_;
								if (!NIM_TRUE) goto LA63_;
								argX60gensym1277_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_516);
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1277_, TM__rF9caJawfOjYTjsgLVUSGFA_516);
							}
							LA63_: ;
							rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, typ, NIM_TRUE);
						}
						goto LA57_;
						LA59_: ;
						{
							addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, typ);
						}
						LA57_: ;
					}
					goto LA47_;
					LA55_: ;
					{
						typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, 256);
						{
							NIM_BOOL T69_;
							T69_ = (NIM_BOOL)0;
							T69_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(typ);
							if (!T69_) goto LA70_;
							isConcrete = NIM_FALSE;
						}
						LA70_: ;
						{
							if (!(typ == 0)) goto LA74_;
							{
								NimStringDesc* argX60gensym1281_;
								if (!NIM_TRUE) goto LA78_;
								argX60gensym1281_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_516);
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1281_, TM__rF9caJawfOjYTjsgLVUSGFA_516);
							}
							LA78_: ;
							rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, typ, NIM_TRUE);
						}
						goto LA72_;
						LA74_: ;
						{
							addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, typ);
						}
						LA72_: ;
					}
					LA47_: ;
					i_4 += ((NI) 1);
				} LA46: ;
			}
		}
		{
			if (!isConcrete) goto LA83_;
			{
				NIM_BOOL T87_;
				NimStringDesc* T91_;
				T87_ = (NIM_BOOL)0;
				T87_ = ((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				if (!(T87_)) goto LA88_;
				T87_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54)));
				LA88_: ;
				if (!T87_) goto LA89_;
				T91_ = (NimStringDesc*)0;
				T91_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_77), (*(*s).name).s);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T91_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_524, NIM_FALSE);
				result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
			}
			goto LA85_;
			LA89_: ;
			{
				result = instGenericContainer__sJO8n9aXqgecj24tOSPjmow(c, (*n).info, result, NIM_FALSE);
			}
			LA85_: ;
		}
		LA83_: ;
	}
	LA14_: ;
	tx = skipTypes__Jb9ck8uy9aKqJSHdNSzDJAJQ(result, IL64(36275087638309136), ((NI) 50));
	{
		NIM_BOOL T95_;
		NimStringDesc* T99_;
		NimStringDesc* T100_;
		T95_ = (NIM_BOOL)0;
		T95_ = (tx == 0);
		if (T95_) goto LA96_;
		T95_ = isTupleRecursive__YPjOkGV9axAnGR3UfLeWZ1g_12(tx);
		LA96_: ;
		if (!T95_) goto LA97_;
		T99_ = (NimStringDesc*)0;
		T99_ = typeToString__QlvraUan7WbHowhAbvDvdA((*result).sons->data[((NI) 0)], ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T100_ = (NimStringDesc*)0;
		T100_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_132), T99_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T100_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_525, NIM_FALSE);
		result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		goto BeforeRet_;
	}
	LA97_: ;
	{
		NIM_BOOL T103_;
		NI position;
		T103_ = (NIM_BOOL)0;
		T103_ = !((tx == result));
		if (!(T103_)) goto LA104_;
		T103_ = ((*tx).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		LA104_: ;
		if (!T103_) goto LA105_;
		{
			if (!!(((*tx).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA109_;
			semObjectTypeForInheritedGenericInst__ZPW6MqdUk6rECHJvUIgrnA(c, n, tx);
		}
		LA109_: ;
		position = ((NI) 0);
		recomputeFieldPositions__XUkgGL16NQZcptTJ0lg7nQ(tx, (*tx).n, (&position));
	}
	LA105_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConceptBody__7YxUILpPxooC5qqa89a54dw_31)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w ctx;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&ctx), sizeof(tyObject_GenericCtx__ldEK1fsP9cZbQbUrs7bxs0w));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toMixin));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toBind));
	result = semGenericStmt__aVtCjYVuHV1t3poDWh43wA(c, n, 8, (&ctx));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeClass__O8zf75mcUwo9cfPQUQRaEug_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* inherited;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* candidateTypeSlot;
	tySequence__Ef05srmQTDulnBdXR4Ja6Q* T1_;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T10_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	pragmas = (*n)._kind_6.sons->data[((NI) 1)];
	inherited = (*n)._kind_6.sons->data[((NI) 2)];
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52), prev, c);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
	owner = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	T1_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
	T1_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
	asgnRef((void**) (&T1_->data[0]), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	candidateTypeSlot = newTypeWithSons__aSykZlHQuGR9almJ1ehcUew(owner, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4), T1_);
	if ((*result).sons) { nimGCunrefNoCycle((*result).sons); (*result).sons = NIM_NIL; }
	(*result).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
	asgnRef((void**) (&(*result).sons->data[0]), candidateTypeSlot);
	asgnRef((void**) (&(*result).n), n);
	{
		if (!!(((*inherited).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA4_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n_2;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T7_;
			n_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*inherited)._kind_6.sons;
			i = ((NI) 0);
			T7_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T7_;
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					if (!(i < L)) goto LA9;
					n_2 = &colontmp_->data[i];
					typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n_2), ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					add__9a8CdZqChTyqzq5bpSL3TzA(result, typ);
					i += ((NI) 1);
				} LA9: ;
			}
		}
	}
	LA4_: ;
	T10_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T10_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* param;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__2;
		param = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp__2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		colontmp__2 = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NI i_2;
			NI colontmp__3;
			NI i_3;
			i_2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp__2);
			i_3 = ((NI) 0);
			{
				while (1) {
					if (!(i_3 < colontmp__3)) goto LA14;
					i_2 = i_3;
					param = (*colontmp__2)._kind_6.sons->data[i_2];
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dummyName;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dummyType;
						tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag modifier;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dummyParam;
						tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw T39_;
						dummyName = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						dummyType = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						switch ((*param).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 143):
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 141):
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 142):
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 137):
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8);
						}
						break;
						default:
						{
							modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0);
						}
						break;
						}
						{
							if (!!((modifier == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)))) goto LA24_;
							dummyName = (*param)._kind_6.sons->data[((NI) 0)];
							dummyType = makeTypeWithModifier__YyNjY7O2UpEApULCS9ctQYQ(c, modifier, candidateTypeSlot);
							{
								if (!(modifier == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA28_;
								(*dummyType).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 28)) & 63);
								(*dummyType).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
							}
							LA28_: ;
						}
						goto LA22_;
						LA24_: ;
						{
							dummyName = param;
							dummyType = candidateTypeSlot;
						}
						LA22_: ;
						{
							if (!((*dummyName).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA33_;
							goto LA15;
						}
						LA33_: ;
						{
							NimStringDesc* argX60gensym1311_;
							if (!!(((*dummyName).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA37_;
							argX60gensym1311_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_540);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1311_, TM__rF9caJawfOjYTjsgLVUSGFA_540);
						}
						LA37_: ;
						T39_ = (tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw)0;
						{
							if (!(modifier == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA42_;
							T39_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7);
						}
						goto LA40_;
						LA42_: ;
						{
							T39_ = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8);
						}
						LA40_: ;
						dummyParam = newSym__IXbidcxhXTQGZY9abN63Cxg(T39_, (*dummyName)._kind_5.ident, owner, (*param).info, 0);
						asgnRef((void**) (&(*dummyParam).typ), dummyType);
						(*dummyParam).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
						addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, dummyParam);
					} LA15: ;
					i_3 += ((NI) 1);
				} LA14: ;
			}
		}
	}
	asgnRef((void**) (&(*(*result).n)._kind_6.sons->data[((NI) 3)]), semConceptBody__7YxUILpPxooC5qqa89a54dw_31(c, (*n)._kind_6.sons->data[((NI) 3)]));
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semVarOutType__kPfUv0X9aI6AfGcdSb9aYz9cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 1))) goto LA4_;
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(kind, prev, c);
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		base = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T6_, 256);
		{
			if (!((*base).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23))) goto LA9_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_508), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_541, NIM_FALSE);
			base = (*base).sons->data[((NI) 0)];
		}
		LA9_: ;
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
	}
	goto LA1_;
	LA4_: ;
	{
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, kind);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semDistinct__O8zf75mcUwo9cfPQUQRaEug_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13));
		goto BeforeRet_;
	}
	LA4_: ;
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13), prev, c);
	T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T6_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T6_);
	{
		NI T9_;
		T9_ = (NI)0;
		T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 1) < T9_)) goto LA10_;
		asgnRef((void**) (&(*result).n), (*n)._kind_6.sons->data[((NI) 1)]);
	}
	LA10_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, applyTypeSectionPragmas__n3MU2Z4B9cngRayLYQCel5A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* operand) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
		p = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(pragmas);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					p = (*pragmas)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						NI T9_;
						T7_ = (NIM_BOOL)0;
						T7_ = ((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T7_)) goto LA8_;
						T9_ = (NI)0;
						T9_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
						T7_ = (((NI) 1) <= T9_);
						LA8_: ;
						if (!T7_) goto LA10_;
						key = (*p)._kind_6.sons->data[((NI) 0)];
					}
					goto LA5_;
					LA10_: ;
					{
						key = p;
					}
					LA5_: ;
					{
						NIM_BOOL T15_;
						tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T17_;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
						if (T15_) goto LA16_;
						T17_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
						T17_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(p);
						T15_ = !((T17_ == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 0)));
						LA16_: ;
						if (!T15_) goto LA18_;
					}
					goto LA13_;
					LA18_: ;
					{
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
						ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, key, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T23_;
							T23_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T23_ = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).userPragmas, ident);
							if (!!((T23_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA24_;
						}
						goto LA21_;
						LA24_: ;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
							sym = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
							{
								NIM_BOOL T29_;
								T29_ = (NIM_BOOL)0;
								T29_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
								if (!(T29_)) goto LA30_;
								T29_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0);
								LA30_: ;
								if (!T29_) goto LA31_;
							}
							goto LA27_;
							LA31_: ;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
								x = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*key).info);
								add__P8dDSotTW25BkfbyspojGg(x, key);
								{
									NIM_BOOL T36_;
									NI T38_;
									T36_ = (NIM_BOOL)0;
									T36_ = ((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
									if (!(T36_)) goto LA37_;
									T38_ = (NI)0;
									T38_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
									T36_ = (((NI) 1) < T38_);
									LA37_: ;
									if (!T36_) goto LA39_;
									{
										NI i_3;
										NI colontmp__2;
										NI i_4;
										i_3 = (NI)0;
										colontmp__2 = (NI)0;
										colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(p);
										i_4 = ((NI) 1);
										{
											while (1) {
												if (!(i_4 < colontmp__2)) goto LA43;
												i_3 = i_4;
												add__P8dDSotTW25BkfbyspojGg(x, (*p)._kind_6.sons->data[i_3]);
												i_4 += ((NI) 1);
											} LA43: ;
										}
									}
								}
								LA39_: ;
								T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T44_ = copyTreeWithoutNode__aN5jlv83QmlsI1PY356I2w(operand, p);
								add__P8dDSotTW25BkfbyspojGg(x, T44_);
								r = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg(c, x, x, 393216, 262144);
								{
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
									if (!!((r == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA47_;
									{
										if (!!(((*(*r)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA51_;
										failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_542));
									}
									LA51_: ;
									m = (*(*r)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
									switch ((*m).kind) {
									case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
									{
										result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, r, r, m, 8192);
										goto BeforeRet_;
									}
									break;
									case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
									{
										result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, r, m, 8192);
										goto BeforeRet_;
									}
									break;
									default:
									{
										{
											if (!NIM_TRUE) goto LA58_;
											failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_543));
										}
										LA58_: ;
									}
									break;
									}
								}
								LA47_: ;
							}
							LA27_: ;
						}
						LA21_: ;
					}
					LA13_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semProcTypeWithScope__HVX0MCOg4yL8PRkNzdiEmQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T12_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T13_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* macroEval;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 1)]);
		T3_ = (((NI) 0) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		macroEval = applyTypeSectionPragmas__n3MU2Z4B9cngRayLYQCel5A(c, (*n)._kind_6.sons->data[((NI) 1)], n);
		{
			if (!!((macroEval == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA10_;
			result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, macroEval, prev);
			goto BeforeRet_;
		}
		LA10_: ;
	}
	LA6_: ;
	T12_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T12_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = semProcTypeNode__ZVaxL1YkeVlGuk9csaO0Z2w(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), prev, kind, NIM_TRUE);
	(*result).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
	T13_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T13_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_432));
	T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T14_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T13_, (*n).info);
	s = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(kind, T14_, c);
	asgnRef((void**) (&(*s).typ), result);
	{
		NIM_BOOL T17_;
		NI T19_;
		T17_ = (NIM_BOOL)0;
		T17_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		if (!(T17_)) goto LA18_;
		T19_ = (NI)0;
		T19_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 1)]);
		T17_ = (((NI) 0) < T19_);
		LA18_: ;
		if (!T17_) goto LA20_;
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_544, NIM_FALSE);
		setEffectsForProcType__anXKpeIcfo8QOiHQxzurxw((*c).graph, result, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA15_;
	LA20_: ;
	{
		NIM_BOOL T23_;
		NI T24_;
		tyArray__voNMFnIDThVNu9afe2zfZWA T28_;
		T23_ = (NIM_BOOL)0;
		T24_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
		T23_ = (((NI) 0) < T24_);
		if (!(T23_)) goto LA25_;
		T23_ = !((((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 47))&63U)))!=0));
		LA25_: ;
		if (!T23_) goto LA26_;
		nimZeroMem((void*)T28_, sizeof(tyArray__voNMFnIDThVNu9afe2zfZWA));
		T28_[0] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		T28_[1] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		T28_[2] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		T28_[3] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		T28_[4] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		asgnRef((void**) (&(*s).ast), newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79), T28_, 5));
		implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw(c, s, n, TM__rF9caJawfOjYTjsgLVUSGFA_545);
		setEffectsForProcType__anXKpeIcfo8QOiHQxzurxw((*c).graph, result, (*(*s).ast)._kind_6.sons->data[((NI) 4)]);
	}
	goto LA15_;
	LA26_: ;
	LA15_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semEnum__O8zf75mcUwo9cfPQUQRaEug_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	NI64 counter;
	NI64 x;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* e;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** identToReplace;
	NIM_BOOL isPure;
	NIM_BOOL T20_;
	tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
	NIM_BOOL hasNull;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
		goto BeforeRet_;
	}
	goto LA1_;
	LA4_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T7_ == ((NI) 1))) goto LA8_;
		result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		goto BeforeRet_;
	}
	goto LA1_;
	LA8_: ;
	LA1_: ;
	counter = (NI64)0;
	x = (NI64)0;
	e = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	base = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	identToReplace = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
	counter = IL64(0);
	base = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14), prev, c);
	asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 150), (*n).info));
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
	{
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T18_;
		NI64 T19_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA12_;
		base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		{
			if (!!(((*base).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14)))) goto LA16_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_546), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_547, NIM_FALSE);
		}
		LA16_: ;
		T18_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, base);
		T19_ = (NI64)0;
		T19_ = toInt64__1szweXXq3RBN50owrYu2Xw(T18_);
		counter = (NI64)(T19_ + IL64(1));
	}
	LA12_: ;
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, base, NIM_TRUE);
	T20_ = (NIM_BOOL)0;
	T20_ = !(((*result).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T20_)) goto LA21_;
	T20_ = (((*(*result).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0);
	LA21_: ;
	isPure = T20_;
	nimZeroMem((void*)(&symbols), sizeof(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA));
	{
		if (!isPure) goto LA24_;
		initStrTable__2n9b6ELeZfbbP5wqNYm7VyA((&symbols));
	}
	LA24_: ;
	hasNull = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA28;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* symNode;
					{
						if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA32_;
						goto LA29;
					}
					LA32_: ;
					switch ((*(*n)._kind_6.sons->data[i]).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 151):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* strVal;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T40_;
						{
							if (!((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA37_;
							e = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20), (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], c);
							identToReplace = &(*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
							pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, e, (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_548, NIM_FALSE);
						}
						goto LA35_;
						LA37_: ;
						{
							e = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20), (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], c);
							identToReplace = &(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)];
						}
						LA35_: ;
						v = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]);
						strVal = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
						T40_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T40_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*v).typ, IL64(36134350135273488));
						switch ((*T40_).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
						{
							{
								NI T44_;
								T44_ = (NI)0;
								T44_ = len__P89cqdlERShb9alU3iC0yj8wast(v);
								if (!(T44_ == ((NI) 2))) goto LA45_;
								strVal = (*v)._kind_6.sons->data[((NI) 1)];
								{
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
									tyObject_Int128__9a9axPfb75jdWY25AamJewkA T59_;
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
									T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
									T49_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*strVal).typ, IL64(36134350135273744));
									if (!((805306368 &((NU64)1<<((NU)((*T49_).kind)&63U)))!=0)) goto LA50_;
									{
										NIM_BOOL T54_;
										NimStringDesc* T57_;
										NimStringDesc* T58_;
										T54_ = (NIM_BOOL)0;
										T54_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA((*(*v)._kind_6.sons->data[((NI) 0)]).typ, NIM_TRUE);
										if (!!(T54_)) goto LA55_;
										T57_ = (NimStringDesc*)0;
										T58_ = (NimStringDesc*)0;
										T58_ = typeToString__QlvraUan7WbHowhAbvDvdA((*(*v)._kind_6.sons->data[((NI) 0)]).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
										T57_ = rawNewString((T58_ ? T58_->Sup.len : 0) + 30);
appendString(T57_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_549));
appendString(T57_, T58_);
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*v)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T57_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_550, NIM_FALSE);
									}
									LA55_: ;
									T59_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*v)._kind_6.sons->data[((NI) 0)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
									x = toInt64__1szweXXq3RBN50owrYu2Xw(T59_);
									T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
									T60_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
									asgnRef((void**) (&(*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)]), newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(x, T60_));
								}
								goto LA47_;
								LA50_: ;
								{
									liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*strVal).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_319), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_551, NIM_FALSE);
								}
								LA47_: ;
							}
							goto LA42_;
							LA45_: ;
							{
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_553, NIM_FALSE);
							}
							LA42_: ;
						}
						break;
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
						{
							strVal = v;
							x = counter;
						}
						break;
						default:
						{
							tyObject_Int128__9a9axPfb75jdWY25AamJewkA T72_;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T73_;
							{
								NIM_BOOL T67_;
								NimStringDesc* T70_;
								NimStringDesc* T71_;
								T67_ = (NIM_BOOL)0;
								T67_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA((*v).typ, NIM_TRUE);
								if (!!(T67_)) goto LA68_;
								T70_ = (NimStringDesc*)0;
								T71_ = (NimStringDesc*)0;
								T71_ = typeToString__QlvraUan7WbHowhAbvDvdA((*v).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
								T70_ = rawNewString((T71_ ? T71_->Sup.len : 0) + 30);
appendString(T70_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_549));
appendString(T70_, T71_);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T70_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_554, NIM_FALSE);
							}
							LA68_: ;
							T72_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(v, Max__zlJMNfqX7LwCYj0PF6ncWQ);
							x = toInt64__1szweXXq3RBN50owrYu2Xw(T72_);
							T73_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T73_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
							asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(x, T73_));
						}
						break;
						}
						{
							if (!!((i == ((NI) 1)))) goto LA76_;
							{
								if (!!((x == counter))) goto LA80_;
								(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 5)) & 63);
							}
							LA80_: ;
							{
								NimStringDesc* T86_;
								if (!(x < counter)) goto LA84_;
								T86_ = (NimStringDesc*)0;
								T86_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_555), (*(*e).name).s);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T86_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_556, NIM_FALSE);
								x = counter;
							}
							LA84_: ;
						}
						LA76_: ;
						asgnRef((void**) (&(*e).ast), strVal);
						counter = x;
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
					{
						e = (*(*n)._kind_6.sons->data[i])._kind_4.sym;
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
					{
						e = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20), (*n)._kind_6.sons->data[i], c);
						identToReplace = &(*n)._kind_6.sons->data[i];
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
					{
						e = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20), (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], c);
						pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, e, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_548, NIM_FALSE);
						identToReplace = &(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)];
					}
					break;
					default:
					{
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw((*n)._kind_6.sons->data[i], (*(*c).graph).config);
					}
					break;
					}
					asgnRef((void**) (&(*e).typ), result);
					(*e).position = ((NI) (counter));
					symNode = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(e);
					{
						NIM_BOOL T93_;
						NIM_BOOL T94_;
						T93_ = (NIM_BOOL)0;
						T94_ = (NIM_BOOL)0;
						T94_ = !((((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 47))&63U)))!=0));
						if (!(T94_)) goto LA95_;
						T94_ = !((identToReplace == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**) NIM_NIL)));
						LA95_: ;
						T93_ = T94_;
						if (!(T93_)) goto LA96_;
						T93_ = !(((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8)));
						LA96_: ;
						if (!T93_) goto LA97_;
						unsureAsgnRef((void**) (&(*identToReplace)), symNode);
					}
					LA97_: ;
					{
						if (!((*e).position == ((NI) 0))) goto LA101_;
						hasNull = NIM_TRUE;
					}
					LA101_: ;
					{
						NIM_BOOL T105_;
						T105_ = (NIM_BOOL)0;
						T105_ = !(((*result).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T105_)) goto LA106_;
						T105_ = (((*(*result).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0);
						LA106_: ;
						if (!T105_) goto LA107_;
						(*e).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
						(*e).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1)) & 63);
						{
							if (!!(isPure)) goto LA111_;
							strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), e);
						}
						LA111_: ;
					}
					LA107_: ;
					add__P8dDSotTW25BkfbyspojGg((*result).n, symNode);
					{
						if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA115_;
						nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*e).info, e, (*e).kind);
					}
					LA115_: ;
					{
						if (!!((((*e).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA119_;
						{
							if (!!(isPure)) goto LA123_;
							addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, e);
						}
						goto LA121_;
						LA123_: ;
						{
							importPureEnumField__qTKM3Dk2MEIWKGK9aoCIRwg(c, e);
						}
						LA121_: ;
					}
					LA119_: ;
					{
						NIM_BOOL T128_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* conflict;
						T128_ = (NIM_BOOL)0;
						T128_ = isPure;
						if (!(T128_)) goto LA129_;
						conflict = strTableInclReportConflict__tsV7rrfL6ZnfCXBjJk0jUA((&symbols), e, NIM_FALSE);
						T128_ = !((conflict == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						LA129_: ;
						if (!T128_) goto LA130_;
						wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*e).info, (*(*e).name).s, (*conflict).info);
					}
					LA130_: ;
					counter += ((NI) 1);
				} LA29: ;
				i_2 += ((NI) 1);
			} LA28: ;
		}
	}
	{
		NIM_BOOL T134_;
		T134_ = (NIM_BOOL)0;
		T134_ = (((*(*e).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
		if (!(T134_)) goto LA135_;
		T134_ = !(hasNull);
		LA135_: ;
		if (!T134_) goto LA136_;
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 18)) & 63);
	}
	LA136_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semStmtListType__O8zf75mcUwo9cfPQUQRaEug_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, (*n)._kind_6.sons->data[i], 0));
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NI T7_;
		NI T10_;
		NI T11_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 0) < T7_)) goto LA8_;
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[(NI)(T10_ - ((NI) 1))], prev);
		asgnRef((void**) (&(*n).typ), result);
		T11_ = (NI)0;
		T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*(*n)._kind_6.sons->data[(NI)(T11_ - ((NI) 1))]).typ), result);
	}
	goto LA5_;
	LA8_: ;
	{
		result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semBlockType__O8zf75mcUwo9cfPQUQRaEug_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	(*(*c).p).nestedBlockCounter += ((NI) 1);
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T6_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA4_;
		T6_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T6_ = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22), (*n)._kind_6.sons->data[((NI) 0)], c);
		addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, T6_);
	}
	LA4_: ;
	result = semStmtListType__O8zf75mcUwo9cfPQUQRaEug_16(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
	asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 1)]).typ), result);
	asgnRef((void**) (&(*n).typ), result);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	(*(*c).p).nestedBlockCounter -= ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, semTypeNode__O8zf75mcUwo9cfPQUQRaEug)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	(*c).inTypeContext += ((NI) 1);
	{
		if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA3_;
		suggestExpr__wb6KhAx6bZ5NV37kY4bXJw(c, n);
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	{
		result = (*n).typ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
		result = semTypeof__O8zf75mcUwo9cfPQUQRaEug_2(c, (*n)._kind_6.sons->data[((NI) 0)], prev);
		{
			if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA9_;
			(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 29)) & 63);
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	{
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T14_ == ((NI) 1))) goto LA15_;
			result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], prev);
		}
		goto LA12_;
		LA15_: ;
		{
			result = semAnonTuple__O8zf75mcUwo9cfPQUQRaEug_3(c, n, prev);
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		result = semAnonTuple__O8zf75mcUwo9cfPQUQRaEug_3(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		x = (*n)._kind_6.sons->data[((NI) 0)];
		switch ((*x).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
		{
			ident = (*x)._kind_5.ident;
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
		{
			ident = (*(*x)._kind_4.sym).name;
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
		{
			ident = (*(*(*x)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name;
		}
		break;
		default:
		{
			ident = ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL);
		}
		break;
		}
		{
			NIM_BOOL T26_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
			T26_ = (NIM_BOOL)0;
			T26_ = !((ident == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
			if (!(T26_)) goto LA27_;
			T26_ = eqStrings((*ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_26));
			LA27_: ;
			if (!T26_) goto LA28_;
			b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), (*n).info);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA32;
						i = i_2;
						add__P8dDSotTW25BkfbyspojGg(b, (*n)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA32: ;
				}
			}
			result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, b, prev);
		}
		goto LA24_;
		LA28_: ;
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = !((ident == ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL)));
			if (!(T34_)) goto LA35_;
			T34_ = ((*ident).Sup.id == ((NI) 71));
			LA35_: ;
			if (!T34_) goto LA36_;
			result = semRangeAux__O8zf75mcUwo9cfPQUQRaEug_4(c, n, prev);
		}
		goto LA24_;
		LA36_: ;
		{
			NIM_BOOL T39_;
			NI T41_;
			T39_ = (NIM_BOOL)0;
			T39_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			if (!(T39_)) goto LA40_;
			T41_ = (NI)0;
			T41_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T39_ = (T41_ == ((NI) 2));
			LA40_: ;
			if (!T39_) goto LA42_;
			result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T46_;
				T46_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T46_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(result, IL64(105553116268560));
				if (!((IL64(1125900550673920) &((NU64)1<<((NU)((*T46_).kind)&63U)))!=0)) goto LA47_;
				{
					if (!(((*result).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0)) goto LA51_;
					result = freshType__MYPl0kqQUBUN3G45LDt6rwsem(result, prev);
					(*result).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17)) & 63));
				}
				LA51_: ;
			}
			goto LA44_;
			LA47_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_38), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_39, NIM_FALSE);
			}
			LA44_: ;
		}
		goto LA24_;
		LA42_: ;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56)))) goto LA55_;
			result = semTypeExpr__O8zf75mcUwo9cfPQUQRaEug_5(c, n, prev);
		}
		goto LA24_;
		LA55_: ;
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* op;
			op = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			{
				NIM_BOOL T60_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2;
				T60_ = (NIM_BOOL)0;
				T60_ = ((*op).Sup.id == ((NI) 2) || (*op).Sup.id == ((NI) 47));
				if (T60_) goto LA61_;
				T60_ = eqStrings((*op).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_42));
				LA61_: ;
				if (!T60_) goto LA62_;
				checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 3), (*(*c).graph).config);
				t1 = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				t2 = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 2)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				{
					if (!(t1 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA66_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_43, NIM_FALSE);
					result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
				}
				goto LA64_;
				LA66_: ;
				{
					if (!(t2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA69_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 2)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_44, NIM_FALSE);
					result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
				}
				goto LA64_;
				LA69_: ;
				{
					{
						if (!((*op).Sup.id == ((NI) 2))) goto LA74_;
						result = makeAndType__9b4dTSY3d7uIjSch9cj9cGP1w(c, t1, t2);
					}
					goto LA72_;
					LA74_: ;
					{
						result = makeOrType__9b4dTSY3d7uIjSch9cj9cGP1w_2(c, t1, t2);
					}
					LA72_: ;
				}
				LA64_: ;
			}
			goto LA58_;
			LA62_: ;
			{
				NI T80_;
				if (!((*op).Sup.id == ((NI) 43))) goto LA78_;
				T80_ = (NI)0;
				T80_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				switch (T80_) {
				case ((NI) 3):
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* resolvedType;
					result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
					{
						NIM_BOOL T84_;
						T84_ = (NIM_BOOL)0;
						T84_ = ((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
						if (!(T84_)) goto LA85_;
						T84_ = !((((*result).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0));
						LA85_: ;
						if (!T84_) goto LA86_;
						result = base__PfgI9ap7WOnsRfFV4znQ27w(result);
					}
					LA86_: ;
					{
						if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)))) goto LA90_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_45), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_46, NIM_FALSE);
					}
					LA90_: ;
					{
						if (!!((((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 5))&15U)))!=0))) goto LA94_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_47), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_48, NIM_FALSE);
					}
					LA94_: ;
					resolvedType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(result, IL64(105553116268560));
					switch ((*resolvedType).kind) {
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
					{
						tyArray__jlWPjgtbdjE069arIWHC9c9bg T97_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T98_;
						nimZeroMem((void*)T97_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
						T97_[0] = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
						T98_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T98_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 128), T97_, 1);
						result = makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T98_);
					}
					break;
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30):
					case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50):
					{
						result = freshType__MYPl0kqQUBUN3G45LDt6rwsem(result, prev);
						(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17)) & 63);
					}
					break;
					default:
					{
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_38), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_49, NIM_FALSE);
					}
					break;
					}
				}
				break;
				case ((NI) 2):
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* negated;
					negated = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
					result = makeNotType__UPDD9aO4WRk8hLMnfpJZudg(c, negated);
				}
				break;
				default:
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_38), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_50, NIM_FALSE);
				}
				break;
				}
			}
			goto LA58_;
			LA78_: ;
			{
				if (!((*op).Sup.id == ((NI) 50))) goto LA104_;
				result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), prev);
			}
			goto LA58_;
			LA104_: ;
			{
				if (!((*op).Sup.id == ((NI) 52))) goto LA107_;
				result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), prev);
			}
			goto LA58_;
			LA107_: ;
			{
				if (!((*op).Sup.id == ((NI) 60))) goto LA110_;
				checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
				result = semTypeof__O8zf75mcUwo9cfPQUQRaEug_2(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
			}
			goto LA58_;
			LA110_: ;
			{
				NIM_BOOL T113_;
				NIM_BOOL T114_;
				T113_ = (NIM_BOOL)0;
				T114_ = (NIM_BOOL)0;
				T114_ = eqStrings((*op).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_467));
				if (!(T114_)) goto LA115_;
				T114_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				LA115_: ;
				T113_ = T114_;
				if (!(T113_)) goto LA116_;
				T113_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18));
				LA116_: ;
				if (!T113_) goto LA117_;
				result = semTypeof2__O8zf75mcUwo9cfPQUQRaEug_6(c, n, prev);
			}
			goto LA58_;
			LA117_: ;
			{
				NIM_BOOL T120_;
				NIM_BOOL T121_;
				NI T124_;
				T120_ = (NIM_BOOL)0;
				T121_ = (NIM_BOOL)0;
				T121_ = eqStrings((*op).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_469));
				if (!(T121_)) goto LA122_;
				T121_ = !((((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0));
				LA122_: ;
				T120_ = T121_;
				if (!(T120_)) goto LA123_;
				T124_ = (NI)0;
				T124_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				T120_ = (T124_ == ((NI) 2));
				LA123_: ;
				if (!T120_) goto LA125_;
				result = semTypeExpr__O8zf75mcUwo9cfPQUQRaEug_5(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
			}
			goto LA58_;
			LA125_: ;
			{
				{
					NIM_BOOL T130_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T134_;
					T130_ = (NIM_BOOL)0;
					T130_ = (((NI) 0) < (*c).inGenericContext);
					if (!(T130_)) goto LA131_;
					T130_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27));
					LA131_: ;
					if (!T130_) goto LA132_;
					T134_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T134_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
					result = makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T134_);
				}
				goto LA128_;
				LA132_: ;
				{
					result = semTypeExpr__O8zf75mcUwo9cfPQUQRaEug_5(c, n, prev);
				}
				LA128_: ;
			}
			LA58_: ;
		}
		LA24_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* whenResult;
		whenResult = semWhen__5C4HPXQuhxlMYIzPbe36lg(c, n, NIM_FALSE);
		{
			if (!((*whenResult).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA139_;
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(whenResult, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 128));
		}
		LA139_: ;
		result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, whenResult, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* head;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
		head = (*n)._kind_6.sons->data[((NI) 0)];
		{
			if (!!(((*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*head).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)))) goto LA144_;
			s = semTypeIdent__AO57Q9bSpsZiuv7kwwoM7yw(c, head);
		}
		goto LA142_;
		LA144_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T147_;
			T147_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T147_ = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, head, 0);
			s = symFromExpectedTypeNode__AO57Q9bSpsZiuv7kwwoM7yw_2(c, T147_);
		}
		LA142_: ;
		switch ((*s).magic) {
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 156):
		{
			result = semArray__O8zf75mcUwo9cfPQUQRaEug_7(c, n, prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 157):
		{
			result = semContainer__9c9cJm09bVJhp6JDeDwpDcllw(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_488), prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 267):
		{
			result = semContainer__9c9cJm09bVJhp6JDeDwpDcllw(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_489), prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 158):
		{
			result = semRange__O8zf75mcUwo9cfPQUQRaEug_8(c, n, prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 159):
		{
			result = semSet__O8zf75mcUwo9cfPQUQRaEug_9(c, n, prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 168):
		{
			result = semOrdinal__O8zf75mcUwo9cfPQUQRaEug_10(c, n, prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 160):
		{
			result = semContainer__9c9cJm09bVJhp6JDeDwpDcllw(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_505), prev);
			{
				if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA157_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
			}
			LA157_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 161):
		{
			result = semVarargs__O8zf75mcUwo9cfPQUQRaEug_11(c, n, prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 191):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 17):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T161_;
			T161_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T161_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			result = makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, T161_);
			(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 29)) & 63);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 24):
		{
			result = semStaticType__DMAavRw02YcIRkO3yZ1XeQ(c, (*n)._kind_6.sons->data[((NI) 1)], prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 189):
		{
			result = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T168_;
				if (!!((result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA166_;
				T168_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T168_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
				result = copyType__4O4aYoscFPo2FRSh4rP9ayg(result, T168_, NIM_FALSE);
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_4 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T172_;
							if (!(i_4 < colontmp__2)) goto LA171;
							i_3 = i_4;
							T172_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T172_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[i_3], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
							rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T172_, NIM_TRUE);
							i_4 += ((NI) 1);
						} LA171: ;
					}
				}
			}
			LA166_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 165):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T174_;
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13), prev, c);
			T174_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T174_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T174_);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 164):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23), prev, c);
			base = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			{
				if (!((IL64(140737496743936) &((NU64)1<<((NU)((*base).kind)&63U)))!=0)) goto LA178_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_508), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_509, NIM_FALSE);
				base = (*base).sons->data[((NI) 0)];
			}
			LA178_: ;
			addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, base);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 162):
		{
			result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 163):
		{
			result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), prev);
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 167):
		{
			result = semTuple__O8zf75mcUwo9cfPQUQRaEug_12(c, n, prev);
		}
		break;
		default:
		{
			result = semGeneric__nGXSqtv2avLRNyfQXJjLWw(c, n, s, prev);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeExpr;
		typeExpr = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, 0);
		{
			if (!((*typeExpr).typ == 0)) goto LA187_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_530), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_531, NIM_FALSE);
			result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		}
		goto LA185_;
		LA187_: ;
		{
			if (!((*(*typeExpr).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61))) goto LA190_;
			result = (*typeExpr).typ;
		}
		goto LA185_;
		LA190_: ;
		{
			if (!!(((*(*typeExpr).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA193_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_532, NIM_FALSE);
			result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
		}
		goto LA185_;
		LA193_: ;
		{
			result = base__PfgI9ap7WOnsRfFV4znQ27w((*typeExpr).typ);
			{
				NIM_BOOL T198_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* preprocessed;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T202_;
				T198_ = (NIM_BOOL)0;
				T198_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(result);
				if (!(T198_)) goto LA199_;
				T198_ = !(((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52)));
				LA199_: ;
				if (!T198_) goto LA200_;
				preprocessed = semGenericStmt__7YxUILpPxooC5qqa89a54dw_7(c, n);
				T202_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T202_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(preprocessed);
				result = makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T202_);
			}
			goto LA196_;
			LA200_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* alias;
				alias = maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg(c, result, prev);
				{
					if (!!((alias == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA206_;
					result = alias;
				}
				LA206_: ;
			}
			LA196_: ;
		}
		LA185_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		s_2 = semTypeIdent__AO57Q9bSpsZiuv7kwwoM7yw(c, n);
		{
			if (!((*s_2).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA211_;
			{
				if (!!(((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0)))) goto LA215_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_533, NIM_FALSE);
			}
			LA215_: ;
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
		}
		goto LA209_;
		LA211_: ;
		{
			NIM_BOOL T218_;
			T218_ = (NIM_BOOL)0;
			T218_ = ((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
			if (!(T218_)) goto LA219_;
			T218_ = ((*(*s_2).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			LA219_: ;
			if (!T218_) goto LA220_;
			{
				NIM_BOOL T224_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T225_;
				NimStringDesc* argX60gensym1448_;
				T224_ = (NIM_BOOL)0;
				T225_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T225_ = base__PfgI9ap7WOnsRfFV4znQ27w((*s_2).typ);
				T224_ = !(((*T225_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
				if (!(T224_)) goto LA226_;
				T224_ = (prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA226_: ;
				if (!!(T224_)) goto LA227_;
				argX60gensym1448_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_534);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1448_, TM__rF9caJawfOjYTjsgLVUSGFA_534);
			}
			LA227_: ;
			result = base__PfgI9ap7WOnsRfFV4znQ27w((*s_2).typ);
		}
		goto LA209_;
		LA220_: ;
		{
			if (!(prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA230_;
			result = (*s_2).typ;
		}
		goto LA209_;
		LA230_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* alias_2;
			alias_2 = maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg(c, (*s_2).typ, prev);
			{
				if (!!((alias_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA235_;
				result = alias_2;
			}
			goto LA233_;
			LA235_: ;
			{
				assignType__RDstL9c8H9bSHUphDz0iB0hg(prev, (*s_2).typ);
				{
					if (!!(((IL64(35182224605190) &((NU64)1<<((NU)((*(*s_2).typ).kind)&63U)))!=0))) goto LA240_;
					(*prev).Sup.id = (*(*s_2).typ).Sup.id;
				}
				LA240_: ;
				result = prev;
			}
			LA233_: ;
		}
		LA209_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_3;
		s_3 = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, (*n)._kind_4.sym);
		{
			NIM_BOOL T245_;
			NIM_BOOL T247_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* alias_3;
			T245_ = (NIM_BOOL)0;
			T245_ = !(((*s_3).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T245_)) goto LA246_;
			T247_ = (NIM_BOOL)0;
			T247_ = ((*s_3).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
			if (T247_) goto LA248_;
			T247_ = ((*(*s_3).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			LA248_: ;
			T245_ = T247_;
			LA246_: ;
			if (!T245_) goto LA249_;
			{
				if (!((*s_3).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7))) goto LA253_;
				t = (*s_3).typ;
			}
			goto LA251_;
			LA253_: ;
			{
				{
					NIM_BOOL T258_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T259_;
					NimStringDesc* argX60gensym1455_;
					T258_ = (NIM_BOOL)0;
					T259_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T259_ = base__PfgI9ap7WOnsRfFV4znQ27w((*s_3).typ);
					T258_ = !(((*T259_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
					if (!(T258_)) goto LA260_;
					T258_ = (prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					LA260_: ;
					if (!!(T258_)) goto LA261_;
					argX60gensym1455_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_535);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1455_, TM__rF9caJawfOjYTjsgLVUSGFA_535);
				}
				LA261_: ;
				t = base__PfgI9ap7WOnsRfFV4znQ27w((*s_3).typ);
			}
			LA251_: ;
			alias_3 = maybeAliasType__xPYGnx9aHNqBtfJgpdvk0Eg(c, t, prev);
			{
				if (!!((alias_3 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA265_;
				result = alias_3;
			}
			goto LA263_;
			LA265_: ;
			{
				if (!(prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA268_;
				result = t;
			}
			goto LA263_;
			LA268_: ;
			{
				assignType__RDstL9c8H9bSHUphDz0iB0hg(prev, t);
				result = prev;
			}
			LA263_: ;
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, (*n)._kind_4.sym);
		}
		goto LA243_;
		LA249_: ;
		{
			{
				if (!!(((*s_3).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0)))) goto LA274_;
				{
					tyArray__nHXaesL0DJZHyVS07ARPRA T280_;
					NimStringDesc* T281_;
					if (!((*s_3).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA278_;
					nimZeroMem((void*)T280_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
					T280_[0] = copyString((*(*s_3).name).s);
					T281_ = (NimStringDesc*)0;
					T281_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_536), T280_, 1);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T281_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_537, NIM_FALSE);
				}
				goto LA276_;
				LA278_: ;
				{
					tyArray__Re75IspeoxXy2oCZHwcRrA T283_;
					NimStringDesc* T284_;
					nimZeroMem((void*)T283_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T283_[0] = copyString((*(*s_3).name).s);
					T283_[1] = substr__iGg0RIKceRvsmvq8FUHOEw(reprEnum((NI)(*s_3).kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_)), ((NI) 2));
					T284_ = (NimStringDesc*)0;
					T284_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_538), T283_, 2);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T284_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_539, NIM_FALSE);
				}
				LA276_: ;
			}
			LA274_: ;
			result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
		}
		LA243_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133):
	{
		result = semObjectNode__T23bTYnaXqU9cKlZ7Ag9bdBg(c, n, prev, NIM_FALSE);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 134):
	{
		result = semTuple__O8zf75mcUwo9cfPQUQRaEug_12(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 135):
	{
		result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 136):
	{
		result = semTypeClass__O8zf75mcUwo9cfPQUQRaEug_13(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 141):
	{
		result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 142):
	{
		result = semAnyRef__WkfdPzqjIHjpNCHcK8ViDg(c, n, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 143):
	{
		result = semVarOutType__kPfUv0X9aI6AfGcdSb9aYz9cA(c, n, prev, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 146):
	{
		result = semDistinct__O8zf75mcUwo9cfPQUQRaEug_14(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 137):
	{
		result = semStaticType__DMAavRw02YcIRkO3yZ1XeQ(c, (*n)._kind_6.sons->data[((NI) 0)], prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 148):
	{
		{
			NI T297_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* child;
			T297_ = (NI)0;
			T297_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T297_ == ((NI) 0))) goto LA298_;
			result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51), c);
			child = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25), c);
			(*child).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15)) & 63);
			addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, child);
		}
		goto LA295_;
		LA298_: ;
		{
			result = semProcTypeWithScope__HVX0MCOg4yL8PRkNzdiEmQ(c, n, prev, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
			{
				if (!((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25))) goto LA303_;
				(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15)) & 63);
				{
					NIM_BOOL T307_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T308_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T310_;
					T307_ = (NIM_BOOL)0;
					T308_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T308_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
					T307_ = ((*T308_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90));
					if (!(T307_)) goto LA309_;
					T310_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T310_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
					T307_ = hasPragma__oSJ8Ge9caDJrmJG9brFCzlOg(T310_, ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 143));
					LA309_: ;
					if (!T307_) goto LA311_;
					(*result).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5);
				}
				goto LA305_;
				LA311_: ;
				{
					(*result).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
				}
				LA305_: ;
			}
			LA303_: ;
		}
		LA295_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 147):
	{
		{
			NI T317_;
			T317_ = (NI)0;
			T317_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T317_ == ((NI) 0))) goto LA318_;
			result = newConstraint__QGpv9bqfXWWeJjJoCL6cRRA(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		}
		goto LA315_;
		LA318_: ;
		{
			result = semProcTypeWithScope__HVX0MCOg4yL8PRkNzdiEmQ(c, n, prev, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
		}
		LA315_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 150):
	{
		result = semEnum__O8zf75mcUwo9cfPQUQRaEug_15(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	{
		result = (*n).typ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 128):
	{
		result = semStmtListType__O8zf75mcUwo9cfPQUQRaEug_16(c, n, prev);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 129):
	{
		result = semBlockType__O8zf75mcUwo9cfPQUQRaEug_17(c, n, prev);
	}
	break;
	default:
	{
		NimStringDesc* T326_;
		NimStringDesc* T327_;
		T326_ = (NimStringDesc*)0;
		T327_ = (NimStringDesc*)0;
		T327_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T326_ = rawNewString((T327_ ? T327_->Sup.len : 0) + 24);
appendString(T326_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_557));
appendString(T326_, T327_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T326_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_558, NIM_FALSE);
		result = newOrPrevType__JrQ1aXbJ5BgQ3oCvDDFJ1Q(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50), prev, c);
	}
	break;
	}
	asgnRef((void**) (&(*n).typ), result);
	(*c).inTypeContext -= ((NI) 1);
	{
		if (!NIM_FALSE) goto LA330_;
		instAllTypeBoundOp__Qpi3NgGJ9aSfcPm9cZqhFJUg(c, (*n).info);
	}
	LA330_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAfterMacroCall__Hw66264lMkoOE49a7wqbwsQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* macroResult, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
	NI T6_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T55_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*(*(*c).graph).config).evalTemplateCounter += ((NI) 1);
	{
		if (!(((NI) 1000) < (*(*(*c).graph).config).evalTemplateCounter)) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_13), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_14, NIM_FALSE);
	}
	LA3_: ;
	T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T5_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ((*s).owner);
	asgnRef((void**) (&(*c).friendModules), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).friendModules), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T6_ = (*c).friendModules->Sup.len++;
	asgnRef((void**) (&(*c).friendModules->data[T6_]), T5_);
	idSynchronizationPoint__o9blMKDNUEgfiqOxiffy8Tw(((NI) 5000));
	result = macroResult;
	resetSemFlag__sIxO9bj7Xwv3qFTK7z9b5jSg(result);
	{
		if (!((*(*s).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA9_;
		result = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, result, flags);
	}
	goto LA7_;
	LA9_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType;
		retType = (*(*s).typ).sons->data[((NI) 0)];
		{
			NIM_BOOL T14_;
			NIM_BOOL T15_;
			NI T18_;
			T14_ = (NIM_BOOL)0;
			T15_ = (NIM_BOOL)0;
			T15_ = ((*retType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			if (!(T15_)) goto LA16_;
			T15_ = (((*retType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0);
			LA16_: ;
			T14_ = T15_;
			if (!(T14_)) goto LA17_;
			T18_ = (NI)0;
			T18_ = len__5mJADrRYkP3r9auuiuDZN9cQast(retType);
			T14_ = (T18_ == ((NI) 1));
			LA17_: ;
			if (!T14_) goto LA19_;
			retType = (*retType).sons->data[((NI) 0)];
		}
		LA19_: ;
		switch ((*retType).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6):
		{
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, flags);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
		{
			result = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, result, flags);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA26_;
				transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 128));
			}
			LA26_: ;
			typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, result, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			{
				NimStringDesc* T32_;
				NimStringDesc* T33_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T34_;
				if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA30_;
				T32_ = (NimStringDesc*)0;
				T33_ = (NimStringDesc*)0;
				T33_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
				T32_ = rawNewString((T33_ ? T33_->Sup.len : 0) + 24);
appendString(T32_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_65));
appendString(T32_, T33_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*result).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_559, NIM_FALSE);
				T34_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T34_ = errorSym__CLMmoDuBHkJLvNsKvljGNw(c, result);
				result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T34_);
			}
			goto LA28_;
			LA30_: ;
			{
				asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, typ));
			}
			LA28_: ;
		}
		break;
		default:
		{
			{
				NIM_BOOL T39_;
				tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q paramTypes;
				T39_ = (NIM_BOOL)0;
				T39_ = !(((*(*s).ast)._kind_6.sons->data[((NI) 2)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
				if (!(T39_)) goto LA40_;
				T39_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(retType);
				LA40_: ;
				if (!T39_) goto LA41_;
				nimZeroMem((void*)(&paramTypes), sizeof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q));
				newIdTable__Vn79aD3eLpwW0W0F5ymtWkw((&paramTypes));
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
					param = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					value = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					gp = (*(*s).ast)._kind_6.sons->data[((NI) 2)];
					{
						NI i;
						NI colontmp_;
						NI i_2;
						i = (NI)0;
						colontmp_ = (NI)0;
						colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
						i_2 = ((NI) 0);
						{
							while (1) {
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericParam;
								NI posInCall;
								NI T47_;
								if (!(i_2 < colontmp_)) goto LA46;
								i = i_2;
								genericParam = (*(*gp)._kind_6.sons->data[i])._kind_4.sym;
								T47_ = (NI)0;
								T47_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
								posInCall = (NI)(T47_ + i);
								{
									NI T50_;
									tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T53_;
									RootObj* T54_;
									T50_ = (NI)0;
									T50_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
									if (!(posInCall < T50_)) goto LA51_;
									param = genericParam;
									value = (*call)._kind_6.sons->data[posInCall];
									T53_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
									T53_ = &(*param).typ->Sup;
									T54_ = (RootObj*)0;
									T54_ = &(*value).typ->Sup.Sup;
									idTablePut__anELyz7VLsjbCIoxLpxbfQ((&paramTypes), T53_, T54_);
								}
								LA51_: ;
								i_2 += ((NI) 1);
							} LA46: ;
						}
					}
				}
				retType = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, paramTypes, (*macroResult).info, retType);
			}
			LA41_: ;
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, flags);
			result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, retType, result, (*result).info);
		}
		break;
		}
	}
	LA7_: ;
	(*(*(*c).graph).config).evalTemplateCounter -= ((NI) 1);
	T55_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T55_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).friendModules));
	(void)(T55_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	NI genericParams;
	NI suppliedParams;
	NI T6_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*nOrig).info, (*(*sym).name).s);
	info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
	markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, sym);
	{
		NimStringDesc* T5_;
		if (!(sym == (*(*c).p).owner)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_9), (*(*sym).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_10, NIM_FALSE);
	}
	LA3_: ;
	genericParams = len__P89cqdlERShb9alU3iC0yj8wast((*(*sym).ast)._kind_6.sons->data[((NI) 2)]);
	T6_ = (NI)0;
	T6_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
	suppliedParams = (((NI)(T6_ - ((NI) 1)) >= ((NI) 0)) ? (NI)(T6_ - ((NI) 1)) : ((NI) 0));
	{
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		if (!(suppliedParams < genericParams)) goto LA9_;
		T11_ = (NimStringDesc*)0;
		T11_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T12_ = (NimStringDesc*)0;
		T12_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_11), T11_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T12_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_12, NIM_FALSE);
	}
	LA9_: ;
	result = evalMacroCall__6SgKdna0C4CEFxNnRELlUg((*c).module, (*c).graph, (*c).templInstCounter, n, nOrig, sym);
	{
		if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 13))&31U)))!=0))) goto LA15_;
		result = semAfterMacroCall__Hw66264lMkoOE49a7wqbwsQ(c, n, result, sym, flags);
	}
	LA15_: ;
	{
		NIM_BOOL T19_;
		NimStringDesc* T22_;
		T19_ = (NIM_BOOL)0;
		T19_ = nsthasKey((*(*(*c).graph).config).macrosToExpand, (*(*sym).name).s);
		if (!T19_) goto LA20_;
		T22_ = (NimStringDesc*)0;
		T22_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 0);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*nOrig).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 79), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_560, NIM_FALSE);
	}
	LA20_: ;
	result = wrapInComesFrom__Cb09cvJMrK2DzloKNIynCQQ((*nOrig).info, sym, result);
	popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSym__20OKsvfFnNZXONk4IBzYgg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, sym);
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s).typ, IL64(36134350135273488));
		switch ((*typ).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		{
			{
				if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA5_;
				result = inlineConst__a1Z9a4khB42QCtmKBL9cckKAsem(c, n, s);
			}
			goto LA3_;
			LA5_: ;
			{
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA3_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			{
				NI T11_;
				T11_ = (NI)0;
				T11_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*s).ast);
				if (!(T11_ == ((NI) 0))) goto LA12_;
				result = inlineConst__a1Z9a4khB42QCtmKBL9cckKAsem(c, n, s);
			}
			goto LA9_;
			LA12_: ;
			{
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA9_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
		{
			{
				if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA18_;
				result = (*typ).n;
				asgnRef((void**) (&(*result).typ), base__PfgI9ap7WOnsRfFV4znQ27w(typ));
			}
			goto LA16_;
			LA18_: ;
			{
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA16_: ;
		}
		break;
		default:
		{
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
	{
		{
			NIM_BOOL T25_;
			NIM_BOOL T26_;
			NI T28_;
			NIM_BOOL T30_;
			NI T32_;
			T25_ = (NIM_BOOL)0;
			T26_ = (NIM_BOOL)0;
			T26_ = ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 14))&31U)))!=0);
			if (!(T26_)) goto LA27_;
			T28_ = (NI)0;
			T28_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*s).ast)._kind_6.sons->data[((NI) 2)]);
			T26_ = (((NI) 0) < T28_);
			LA27_: ;
			T25_ = T26_;
			if (T25_) goto LA29_;
			T30_ = (NIM_BOOL)0;
			T30_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)));
			if (!(T30_)) goto LA31_;
			T32_ = (NI)0;
			T32_ = requiredParams__knh7oe6js9clE7mbQBo9aJGA(s);
			T30_ = (((NI) 0) < T32_);
			LA31_: ;
			T25_ = T30_;
			LA29_: ;
			if (!T25_) goto LA33_;
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
		}
		goto LA23_;
		LA33_: ;
		{
			result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, n, n, s, flags);
		}
		LA23_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		{
			NIM_BOOL T39_;
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			NI T43_;
			NIM_BOOL T45_;
			NI T47_;
			tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
			T39_ = (NIM_BOOL)0;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = ((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 14))&31U)))!=0);
			if (!(T41_)) goto LA42_;
			T43_ = (NI)0;
			T43_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*s).ast)._kind_6.sons->data[((NI) 2)]);
			T41_ = (((NI) 0) < T43_);
			LA42_: ;
			T40_ = T41_;
			if (T40_) goto LA44_;
			T45_ = (NIM_BOOL)0;
			T45_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)));
			if (!(T45_)) goto LA46_;
			T47_ = (NI)0;
			T47_ = requiredParams__knh7oe6js9clE7mbQBo9aJGA(s);
			T45_ = (((NI) 0) < T47_);
			LA46_: ;
			T40_ = T45_;
			LA44_: ;
			T39_ = T40_;
			if (T39_) goto LA48_;
			T39_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0);
			LA48_: ;
			if (!T39_) goto LA49_;
			info = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, s);
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
		}
		goto LA37_;
		LA49_: ;
		{
			result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, n, s, flags);
		}
		LA37_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		{
			NIM_BOOL T55_;
			NIM_BOOL T56_;
			T55_ = (NIM_BOOL)0;
			T56_ = (NIM_BOOL)0;
			T56_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T56_)) goto LA57_;
			T56_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
			LA57_: ;
			T55_ = T56_;
			if (!(T55_)) goto LA58_;
			T55_ = !(((*(*s).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA58_: ;
			if (!T55_) goto LA59_;
			result = (*(*s).typ).n;
			goto BeforeRet_;
		}
		goto LA53_;
		LA59_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0)) goto LA62_;
			{
				NimStringDesc* argX60gensym4370_;
				if (!!(!(((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))))) goto LA66_;
				argX60gensym4370_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_561);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4370_, TM__rF9caJawfOjYTjsgLVUSGFA_561);
			}
			LA66_: ;
		}
		goto LA53_;
		LA62_: ;
		LA53_: ;
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21):
	{
		{
			if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 259))) goto LA71_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_562), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_563, NIM_FALSE);
		}
		LA71_: ;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
	{
		{
			if (!((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA76_;
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			asgnRef((void**) (&(*result).typ), (*s).typ);
		}
		goto LA74_;
		LA76_: ;
		{
			if (!!(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA79_;
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*s).ast, 0);
		}
		goto LA74_;
		LA79_: ;
		{
			asgnRef((void**) (&(*n).typ), (*s).typ);
			result = n;
			goto BeforeRet_;
		}
		LA74_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		{
			NIM_BOOL T85_;
			NIM_BOOL T86_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T88_;
			T85_ = (NIM_BOOL)0;
			T86_ = (NIM_BOOL)0;
			T86_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
			if (!(T86_)) goto LA87_;
			T88_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T88_ = base__PfgI9ap7WOnsRfFV4znQ27w((*s).typ);
			T86_ = !(((*T88_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
			LA87_: ;
			T85_ = T86_;
			if (!(T85_)) goto LA89_;
			T85_ = !(((*(*s).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA89_: ;
			if (!T85_) goto LA90_;
			result = (*(*s).typ).n;
			goto BeforeRet_;
		}
		LA90_: ;
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, (*s).typ));
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19):
	{
		tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
		p = (*c).p;
		{
			while (1) {
				NIM_BOOL T95_;
				T95_ = (NIM_BOOL)0;
				T95_ = !((p == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)));
				if (!(T95_)) goto LA96_;
				T95_ = ((*p).selfSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
				LA96_: ;
				if (!T95_) goto LA94;
				p = (*p).next;
			} LA94: ;
		}
		{
			NIM_BOOL T99_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* check;
			T99_ = (NIM_BOOL)0;
			T99_ = !((p == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)));
			if (!(T99_)) goto LA100_;
			T99_ = !(((*p).selfSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA100_: ;
			if (!T99_) goto LA101_;
			ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*p).selfSym).typ, IL64(246290619303952));
			{
				while (1) {
					if (!(((*ty).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 32))&63U)))!=0)) goto LA104;
					ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ty, 8192);
				} LA104: ;
			}
			check = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			{
				if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA107_;
				{
					while (1) {
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
						check = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
						f = lookupInRecordAndBuildCheck__h4jJjDt0klDz9b1Aq9bwK14A(c, n, (*ty).n, (*s).name, &check);
						{
							NIM_BOOL T113_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T121_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T122_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T123_;
							T113_ = (NIM_BOOL)0;
							T113_ = !((f == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
							if (!(T113_)) goto LA114_;
							T113_ = fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch(c, f);
							LA114_: ;
							if (!T113_) goto LA115_;
							{
								if (!!((f == s))) goto LA119_;
								failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_564));
							}
							LA119_: ;
							markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, f);
							result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45), (*n).info, (*f).typ);
							T121_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T121_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*p).selfSym);
							T122_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T122_ = makeDeref__wWBimsBS4M6UZBvTRDlQTQ(T121_);
							add__P8dDSotTW25BkfbyspojGg(result, T122_);
							T123_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T123_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f);
							add__P8dDSotTW25BkfbyspojGg(result, T123_);
							{
								if (!!((check == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA126_;
								asgnRef((void**) (&(*check)._kind_6.sons->data[((NI) 0)]), result);
								asgnRef((void**) (&(*check).typ), (*result).typ);
								result = check;
							}
							LA126_: ;
							goto BeforeRet_;
						}
						LA115_: ;
						{
							if (!((*ty).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA130_;
							goto LA109;
						}
						LA130_: ;
						ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*ty).sons->data[((NI) 0)], IL64(36275087638268176));
					}
				} LA109: ;
			}
			LA107_: ;
		}
		LA101_: ;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
	}
	break;
	default:
	{
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info_2;
		info_2 = getCallLineInfo__oiqk14Y4OLEhcR9bJBpfCag(n);
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, info_2, s);
		result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, info_2);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFieldAccess__vJZwz9bfROKrfrtM50y74CQ_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = builtinFieldAccess__vJZwz9bfROKrfrtM50y74CQ_5(c, n, flags);
	{
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = dotTransformation__7YxUILpPxooC5qqa89a54dw_29(c, n);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStaticExpr__7YxUILpPxooC5qqa89a54dw_33)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*c).inStaticContext += ((NI) 1);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	a = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 0);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	(*c).inStaticContext -= ((NI) 1);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T4_;
		T4_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T4_ = findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2(a);
		if (!!((T4_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA5_;
		result = a;
		goto BeforeRet_;
	}
	LA5_: ;
	result = evalStaticExpr__ajRaPV9aInq6ZNnUYn0DaVw((*c).module, (*c).graph, a, (*(*c).p).owner);
	{
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		if (!(result == 0)) goto LA9_;
		T11_ = (NimStringDesc*)0;
		T11_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T12_ = (NimStringDesc*)0;
		T12_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_349), T11_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T12_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_570, NIM_FALSE);
		result = (*(*c).graph).emptyNode;
	}
	goto LA7_;
	LA9_: ;
	{
		result = fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA(c, result, a);
	}
	LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, maybeLiftType__K7SXxqU6fIMYb9b4D3wV5CQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** t, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lifted;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), info);
	lifted = liftParamType__IED6yzEuxOVbtiDk639cvjw(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), T2_, (*t), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_571), info, NIM_FALSE);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	{
		if (!!((lifted == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA5_;
		unsureAsgnRef((void**) (&(*t)), lifted);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOwnedSym__iY9a3KG6T9aTt3fJH8J6BrJQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, 0);
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_469));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, inferWithMetatype__2aIGqt1c0rX64kF16cP4Pw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, NIM_BOOL coerceDistincts) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, formal, (&m));
	m.coerceDistincts = coerceDistincts;
	result = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA((&m), formal, (*arg).typ, arg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = m.genericConverter;
		if (!(T3_)) goto LA4_;
		T3_ = !((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		instGenericConvertersArg__OiEXsRRJbWjgfYLWIAKYYQ(c, result, (&m));
	}
	LA5_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA9_;
		T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(formal, IL64(18014398509481984));
		asgnRef((void**) (&(*result).typ), generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, m.bindings, (*arg).info, T11_));
	}
	goto LA7_;
	LA9_: ;
	{
		typeMismatch__1xxyFIws27lai2cG4n31Ow((*(*c).graph).config, (*arg).info, formal, (*arg).typ);
		result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
		asgnRef((void**) (&(*result).typ), formal);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw, checkConversionBetweenObjects__IxznSNSPzSVAXeEIIkymSA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* castDest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src, NI pointers) {
	tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw result;
	NI diff;
{	result = (tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw)0;
	diff = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(castDest, src);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (diff == ((NI) IL64(9223372036854775807)));
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((NI) 1) < pointers);
		if (!(T5_)) goto LA6_;
		T5_ = !((diff == ((NI) 0)));
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 2);
	}
	goto LA1_;
	LA7_: ;
	{
		result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 0);
	}
	LA1_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__zYqwL8gLoyye80MYuubU4Qsystem)(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ s, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ, dotdot___zEl0oB35FYImlhRYJ1IWBwsystem)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw a, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw b) {
	tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NIM_BOOL, contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, tyObject_Int128__9a9axPfb75jdWY25AamJewkA value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2((*s).a, value);
	if (!(T1_)) goto LA2_;
	T1_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(value, (*s).b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw, dotdot___SGmrVHErX3j2AKHYB8sGjgsystem)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b) {
	tyObject_HSlice__fqLtJsaN5foHLgxLTScotw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NIM_BOOL, contains__JskUST5Zl4jxh9cOha2CJ8Qsystem)(tyObject_HSlice__fqLtJsaN5foHLgxLTScotw* s, NI64 value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___nr9cP9b0OL9cabygV9bo19cJgZA((*s).a, value);
	if (!(T1_)) goto LA2_;
	T1_ = lteq___xL5gyZrjbGMarSdRAXOo9ag(value, (*s).b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b) {
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw, checkConvertible__wqYfe9cPnmcuZgfMqqBjkkA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetTyp, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src) {
	tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* srcTyp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* d;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* s;
	NI pointers;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetBaseTyp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* srcBaseTyp;
{	result = (tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw)0;
	srcTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*src).typ, IL64(1152921504606846976));
	result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameType__3isNyHKb0U1OCnClmflXSg(targetTyp, srcTyp, 0);
		if (!(T3_)) goto LA4_;
		T3_ = ((*targetTyp).sym == (*srcTyp).sym);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!!(((IL64(35182225670150) &((NU64)1<<((NU)((*targetTyp).kind)&63U)))!=0))) goto LA9_;
			result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 1);
		}
		LA9_: ;
		goto BeforeRet_;
	}
	LA5_: ;
	d = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(targetTyp, IL64(36275087632017680));
	s = srcTyp;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((IL64(13510798882111488) &((NU64)1<<((NU)((*s).kind)&63U)))!=0);
		if (!(T13_)) goto LA14_;
		T13_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
		LA14_: ;
		if (!T13_) goto LA15_;
		s = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(s);
	}
	LA15_: ;
	s = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(s, IL64(36239903259928592));
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = ((*s).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45));
		if (!(T19_)) goto LA20_;
		T19_ = !(((*d).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
		LA20_: ;
		if (!T19_) goto LA21_;
		s = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(s);
	}
	LA21_: ;
	pointers = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T25_;
			T25_ = (NIM_BOOL)0;
			T25_ = !((d == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T25_)) goto LA26_;
			T25_ = ((IL64(35184378380288) &((NU64)1<<((NU)((*d).kind)&63U)))!=0);
			LA26_: ;
			if (!T25_) goto LA24;
			{
				NIM_BOOL T29_;
				T29_ = (NIM_BOOL)0;
				T29_ = ((*s).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45));
				if (!(T29_)) goto LA30_;
				T29_ = !(((*d).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
				LA30_: ;
				if (!T29_) goto LA31_;
				s = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(s);
			}
			goto LA27_;
			LA31_: ;
			{
				if (!!(((*d).kind == (*s).kind))) goto LA34_;
				goto LA23;
			}
			goto LA27_;
			LA34_: ;
			{
				d = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(d);
				s = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(s);
			}
			LA27_: ;
			pointers += ((NI) 1);
		} LA24: ;
	} LA23: ;
	targetBaseTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(targetTyp, IL64(36134350144710928));
	srcBaseTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(srcTyp, IL64(36134350144710672));
	{
		if (!(d == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA39_;
		result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 2);
	}
	goto LA37_;
	LA39_: ;
	{
		NIM_BOOL T42_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T45_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T48_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
		T42_ = (NIM_BOOL)0;
		T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T43_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(d, IL64(36134350135273744));
		T42_ = ((*T43_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		if (!(T42_)) goto LA44_;
		T45_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T45_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(s, IL64(36134350135273744));
		T42_ = ((*T45_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		LA44_: ;
		if (!T42_) goto LA46_;
		T48_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T48_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(d, IL64(36134350135273744));
		T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T49_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(s, IL64(36134350135273744));
		result = checkConversionBetweenObjects__IxznSNSPzSVAXeEIIkymSA(T48_, T49_, pointers);
	}
	goto LA37_;
	LA46_: ;
	{
		NIM_BOOL T51_;
		T51_ = (NIM_BOOL)0;
		T51_ = ((IL64(35182224621574) &((NU64)1<<((NU)((*targetBaseTyp).kind)&63U)))!=0);
		if (!(T51_)) goto LA52_;
		T51_ = ((IL64(35182224621574) &((NU64)1<<((NU)((*srcBaseTyp).kind)&63U)))!=0);
		LA52_: ;
		if (!T51_) goto LA53_;
		{
			if (!((*targetTyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1))) goto LA57_;
		}
		goto LA55_;
		LA57_: ;
		{
			NIM_BOOL T60_;
			T60_ = (NIM_BOOL)0;
			T60_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(targetTyp, NIM_FALSE);
			if (!T60_) goto LA61_;
			{
				NIM_BOOL T65_;
				tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ T66_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T68_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T69_;
				tyObject_HSlice__fqLtJsaN5foHLgxLTScotw T70_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T71_;
				NIM_BOOL T72_;
				T65_ = (NIM_BOOL)0;
				T66_ = dotdot___zEl0oB35FYImlhRYJ1IWBwsystem(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
				T65_ = contains__zYqwL8gLoyye80MYuubU4Qsystem(T66_, (*src).kind);
				if (!(T65_)) goto LA67_;
				T68_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, targetTyp);
				T69_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, targetTyp);
				T70_ = dotdot___SGmrVHErX3j2AKHYB8sGjgsystem(T68_, T69_);
				T71_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(src);
				T72_ = (NIM_BOOL)0;
				T72_ = contains__7Sy9cDQTm9cs7zSfkcqgIQdwsystem((&T70_), T71_);
				T65_ = !(T72_);
				LA67_: ;
				if (!T65_) goto LA73_;
				result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 3);
			}
			goto LA63_;
			LA73_: ;
			{
				NIM_BOOL T76_;
				tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ T77_;
				NIM_BOOL T79_;
				tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA T80_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T82_;
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T83_;
				tyObject_HSlice__fqLtJsaN5foHLgxLTScotw T84_;
				NIM_BOOL T85_;
				T76_ = (NIM_BOOL)0;
				T77_ = dotdot___zEl0oB35FYImlhRYJ1IWBwsystem(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
				T76_ = contains__zYqwL8gLoyye80MYuubU4Qsystem(T77_, (*src).kind);
				if (!(T76_)) goto LA78_;
				T79_ = (NIM_BOOL)0;
				T80_ = (tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA)0;
				T80_ = classify__x3IKzrz1VNvfZbypScSTXg((*src)._kind_2.floatVal);
				T79_ = ((112 &((NU8)1<<((NU)(T80_)&7U)))!=0);
				if (T79_) goto LA81_;
				T82_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, targetTyp);
				T83_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, targetTyp);
				T84_ = dotdot___SGmrVHErX3j2AKHYB8sGjgsystem(T82_, T83_);
				T85_ = (NIM_BOOL)0;
				T85_ = contains__JskUST5Zl4jxh9cOha2CJ8Qsystem((&T84_), ((NI64) ((*src)._kind_2.floatVal)));
				T79_ = !(T85_);
				LA81_: ;
				T76_ = T79_;
				LA78_: ;
				if (!T76_) goto LA86_;
				result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 3);
			}
			goto LA63_;
			LA86_: ;
			LA63_: ;
		}
		goto LA55_;
		LA61_: ;
		{
			tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T89_;
			NIM_BOOL T90_;
			T89_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38));
			T90_ = (NIM_BOOL)0;
			T90_ = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T89_, (*targetBaseTyp).kind);
			if (!T90_) goto LA91_;
			{
				NIM_BOOL T95_;
				tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ T96_;
				NIM_BOOL T98_;
				T95_ = (NIM_BOOL)0;
				T96_ = dotdot___zEl0oB35FYImlhRYJ1IWBwsystem(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18));
				T95_ = contains__zYqwL8gLoyye80MYuubU4Qsystem(T96_, (*src).kind);
				if (!(T95_)) goto LA97_;
				T98_ = (NIM_BOOL)0;
				T98_ = floatRangeCheck__RTbq1U5r9aGXeN20T54YASg((*src)._kind_2.floatVal, targetTyp);
				T95_ = !(T98_);
				LA97_: ;
				if (!T95_) goto LA99_;
				result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 3);
			}
			goto LA93_;
			LA99_: ;
			{
				NIM_BOOL T102_;
				tyObject_HSlice__Y6rFxyyPl2aa6Yog9bZj9c9bQ T103_;
				NIM_BOOL T105_;
				T102_ = (NIM_BOOL)0;
				T103_ = dotdot___zEl0oB35FYImlhRYJ1IWBwsystem(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
				T102_ = contains__zYqwL8gLoyye80MYuubU4Qsystem(T103_, (*src).kind);
				if (!(T102_)) goto LA104_;
				T105_ = (NIM_BOOL)0;
				T105_ = floatRangeCheck__RTbq1U5r9aGXeN20T54YASg(((NF) ((*src)._kind_1.intVal)), targetTyp);
				T102_ = !(T105_);
				LA104_: ;
				if (!T102_) goto LA106_;
				result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 3);
			}
			goto LA93_;
			LA106_: ;
			LA93_: ;
		}
		goto LA55_;
		LA91_: ;
		LA55_: ;
	}
	goto LA37_;
	LA53_: ;
	{
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T109_;
		T109_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
		T109_ = cmpTypes__6LyhcPFOyQXLaZFXoqJM1w(c, d, s);
		switch (T109_) {
		case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0):
		case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8):
		{
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T113_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T114_;
				NIM_BOOL T115_;
				T113_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T113_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(targetTyp, IL64(36275087632017680));
				T114_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T114_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(srcTyp, IL64(35184372088832));
				T115_ = (NIM_BOOL)0;
				T115_ = compareTypes__oyXq5u7iL4RjsT9bovvTE9cg(T113_, T114_, ((tyEnum_TDistinctCompare__9bNKHGs63atuMFXnAleTveg) 1), 0);
				if (!!(T115_)) goto LA116_;
				result = ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 2);
			}
			LA116_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	LA37_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConv__7YxUILpPxooC5qqa89a54dw_32)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetType;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 2)))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_567), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_568, NIM_FALSE);
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60), (*n).info);
	targetType = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	switch ((*targetType).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	{
		{
			NI T9_;
			NimStringDesc* argX60gensym3670_;
			T9_ = (NI)0;
			T9_ = len__5mJADrRYkP3r9auuiuDZN9cQast(targetType);
			if (!!((((NI) 0) < T9_))) goto LA10_;
			argX60gensym3670_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_569);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3670_, TM__rF9caJawfOjYTjsgLVUSGFA_569);
		}
		LA10_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T14_;
			T14_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T14_ = base__PfgI9ap7WOnsRfFV4znQ27w(targetType);
			if (!((*T14_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA15_;
			result = semTypeOf__7YxUILpPxooC5qqa89a54dw_15(c, n);
			goto BeforeRet_;
		}
		goto LA12_;
		LA15_: ;
		{
			targetType = base__PfgI9ap7WOnsRfFV4znQ27w(targetType);
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated;
		evaluated = semStaticExpr__7YxUILpPxooC5qqa89a54dw_33(c, (*n)._kind_6.sons->data[((NI) 1)]);
		{
			NIM_BOOL T21_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T25_;
			T21_ = (NIM_BOOL)0;
			T21_ = ((*evaluated).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4));
			if (T21_) goto LA22_;
			T21_ = ((*(*evaluated).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			LA22_: ;
			if (!T21_) goto LA23_;
			result = n;
			T25_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T25_ = semStaticType__DMAavRw02YcIRkO3yZ1XeQ(c, evaluated, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, T25_));
			goto BeforeRet_;
		}
		goto LA19_;
		LA23_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T27_;
			T27_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T27_ = base__PfgI9ap7WOnsRfFV4znQ27w(targetType);
			if (!((*T27_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA28_;
			result = evaluated;
			goto BeforeRet_;
		}
		goto LA19_;
		LA28_: ;
		{
			targetType = base__PfgI9ap7WOnsRfFV4znQ27w(targetType);
		}
		LA19_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	maybeLiftType__K7SXxqU6fIMYb9b4D3wV5CQ(&targetType, c, (*(*n)._kind_6.sons->data[((NI) 0)]).info);
	{
		NIM_BOOL T34_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T38_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		T34_ = (NIM_BOOL)0;
		T34_ = ((IL64(211106232532992) &((NU64)1<<((NU)((*targetType).kind)&63U)))!=0);
		if (T34_) goto LA35_;
		T34_ = isOwnedSym__iY9a3KG6T9aTt3fJH8J6BrJQ_2(c, (*n)._kind_6.sons->data[((NI) 0)]);
		LA35_: ;
		if (!T34_) goto LA36_;
		T38_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T38_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		baseType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T38_, 256);
		t = newTypeS__xb5E2cGIynZweqWlCP8Tig((*targetType).kind, c);
		{
			if (!((*targetType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA41_;
			(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63);
		}
		LA41_: ;
		rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2(t, baseType);
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*n).info);
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, t));
		goto BeforeRet_;
	}
	LA36_: ;
	T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T43_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, T43_);
	{
		NIM_BOOL T46_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T48_;
		T46_ = (NIM_BOOL)0;
		T46_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33));
		if (!(T46_)) goto LA47_;
		T48_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T48_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(targetType, IL64(36275087638309136));
		T46_ = ((*T48_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		LA47_: ;
		if (!T46_) goto LA49_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_572), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_573, NIM_FALSE);
	}
	LA49_: ;
	op = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 0);
	{
		NIM_BOOL T53_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* final;
		T53_ = (NIM_BOOL)0;
		T53_ = !(((*targetType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
		if (!(T53_)) goto LA54_;
		T53_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(targetType);
		LA54_: ;
		if (!T53_) goto LA55_;
		final = inferWithMetatype__2aIGqt1c0rX64kF16cP4Pw(c, targetType, op, NIM_TRUE);
		add__P8dDSotTW25BkfbyspojGg(result, final);
		asgnRef((void**) (&(*result).typ), (*final).typ);
		goto BeforeRet_;
	}
	LA55_: ;
	asgnRef((void**) (&(*result).typ), targetType);
	add__P8dDSotTW25BkfbyspojGg(result, op);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T61_;
		if (!((*targetType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA59_;
		T61_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T61_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(result);
		asgnRef((void**) (&(*result).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, T61_));
		goto BeforeRet_;
	}
	LA59_: ;
	{
		NIM_BOOL T64_;
		tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw status;
		T64_ = (NIM_BOOL)0;
		T64_ = isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem(op);
		if (!!(T64_)) goto LA65_;
		status = checkConvertible__wqYfe9cPnmcuZgfMqqBjkkA(c, (*result).typ, op);
		switch (status) {
		case ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 0):
		{
			{
				NIM_BOOL T70_;
				T70_ = (NIM_BOOL)0;
				T70_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T70_)) goto LA71_;
				T70_ = isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA((*op)._kind_4.sym);
				LA71_: ;
				if (!T70_) goto LA72_;
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*result).typ, (*result)._kind_6.sons->data[((NI) 1)], (*result).info));
			}
			goto LA68_;
			LA72_: ;
			{
				NIM_BOOL T75_;
				T75_ = (NIM_BOOL)0;
				T75_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
				if (!(T75_)) goto LA76_;
				T75_ = ((*targetType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
				LA76_: ;
				if (!T75_) goto LA77_;
				op = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, targetType, op, (*result).info);
			}
			goto LA68_;
			LA77_: ;
			LA68_: ;
		}
		break;
		case ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 1):
		{
			NimStringDesc* T80_;
			T80_ = (NimStringDesc*)0;
			T80_ = typeToString__QlvraUan7WbHowhAbvDvdA((*result).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 59), T80_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_574, NIM_FALSE);
		}
		break;
		case ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 2):
		{
			result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, (*result).typ, (*result)._kind_6.sons->data[((NI) 1)], (*result).info);
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T86_;
				NimStringDesc* T87_;
				if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA84_;
				nimZeroMem((void*)T86_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T86_[0] = typeToString__QlvraUan7WbHowhAbvDvdA((*op).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T86_[1] = typeToString__QlvraUan7WbHowhAbvDvdA((*result).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T87_ = (NimStringDesc*)0;
				T87_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_575), T86_, 2);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T87_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_576, NIM_FALSE);
			}
			LA84_: ;
		}
		break;
		case ((tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw) 3):
		{
			NimStringDesc* value;
			NimStringDesc* T96_;
			NimStringDesc* T97_;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T93_;
				if (!((*op).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*op).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15))) goto LA91_;
				T93_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(op);
				value = dollar___W2wbDjPGDCaBwLQM6yLUQg(T93_);
			}
			goto LA89_;
			LA91_: ;
			{
				NF T95_;
				T95_ = (NF)0;
				T95_ = getFloat__dgNNhprrT2HlJglL2Nc3EA(op);
				value = nimFloatToStr(T95_);
			}
			LA89_: ;
			T96_ = (NimStringDesc*)0;
			T97_ = (NimStringDesc*)0;
			T97_ = typeToString__QlvraUan7WbHowhAbvDvdA((*result).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T96_ = rawNewString((value ? value->Sup.len : 0) + (T97_ ? T97_->Sup.len : 0) + 23);
appendString(T96_, value);
appendString(T96_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_577));
appendString(T96_, T97_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T96_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_578, NIM_FALSE);
		}
		break;
		}
	}
	goto LA62_;
	LA65_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(op);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					tyEnum_TConvStatus__GXWKwypnpPcXHHdgiz4mmw status_2;
					if (!(i_2 < colontmp_)) goto LA101;
					i = i_2;
					it = (*op)._kind_6.sons->data[i];
					status_2 = checkConvertible__wqYfe9cPnmcuZgfMqqBjkkA(c, (*result).typ, it);
					{
						if (!((3 &((NU8)1<<((NU)(status_2)&7U)))!=0)) goto LA104_;
						markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, (*it)._kind_4.sym);
						markIndirect__OGrPg9bGc5rou9aBRgLK606Qsemdata(c, (*it)._kind_4.sym);
						result = it;
						goto BeforeRet_;
					}
					LA104_: ;
					i_2 += ((NI) 1);
				} LA101: ;
			}
		}
		errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw(c, (*n).info, (*(*op)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	}
	LA62_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semObjConstr__vJZwz9bfROKrfrtM50y74CQ_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw constrCtx;
	tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ initResult;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	t = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38), (*n).info, t);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
		child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					child = (*n)._kind_6.sons->data[i];
					add__P8dDSotTW25BkfbyspojGg(result, child);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_579), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_580, NIM_FALSE);
		goto BeforeRet_;
	}
	LA7_: ;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(105553116268560));
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22))) goto LA11_;
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(105553116268560));
		{
			if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA15_;
			asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
			(*(*result).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63);
		}
		LA15_: ;
	}
	LA11_: ;
	{
		if (!!(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)))) goto LA19_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_579), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_581, NIM_FALSE);
		goto BeforeRet_;
	}
	LA19_: ;
	nimZeroMem((void*)(&constrCtx), sizeof(tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw));
	initConstrContext__RYPHxM9aTf8uWaAnZ0rNc2A(t, result, (&constrCtx));
	initResult = semConstructTypeAux__sAwB0gQrQ1keYlqxdq08bQ(c, (&constrCtx), flags);
	{
		NI T23_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T26_;
		NimStringDesc* T27_;
		T23_ = (constrCtx.missingFields ? constrCtx.missingFields->Sup.len : 0);
		if (!(((NI) 0) < T23_)) goto LA24_;
		nimZeroMem((void*)T26_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T26_[0] = copyString((*(*(*t).sym).name).s);
		T26_[1] = listSymbolNames__8Z1zCwaGnI7ov1q9bc6s4uQ(constrCtx.missingFields->data, (constrCtx.missingFields ? constrCtx.missingFields->Sup.len : 0));
		T27_ = (NimStringDesc*)0;
		T27_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_582), T26_, 2);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*result).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T27_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_583, NIM_FALSE);
	}
	LA24_: ;
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(result);
		i_4 = ((NI) 1);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA30;
				i_3 = i_4;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
					field = (*result)._kind_6.sons->data[i_3];
					{
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id;
						NimStringDesc* T48_;
						if (!!((((*field).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7))&31U)))!=0))) goto LA34_;
						{
							if (!!(((*field).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA38_;
							invalidObjConstr__NRIJDWZtATzMum7OEjYC2g_9(c, field);
							goto LA31;
						}
						LA38_: ;
						id = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*field)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						{
							NI j;
							NI i_5;
							j = (NI)0;
							i_5 = ((NI) 1);
							{
								while (1) {
									tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* prevId;
									if (!(i_5 < i_3)) goto LA42;
									j = i_5;
									prevId = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*(*result)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
									{
										NimStringDesc* T47_;
										if (!((*prevId).Sup.id == (*id).Sup.id)) goto LA45_;
										T47_ = (NimStringDesc*)0;
										T47_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_584), (*id).s);
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*field).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T47_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_585, NIM_FALSE);
										goto BeforeRet_;
									}
									LA45_: ;
									i_5 += ((NI) 1);
								} LA42: ;
							}
						}
						T48_ = (NimStringDesc*)0;
						T48_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_368), (*id).s);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*field).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T48_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_586, NIM_FALSE);
						goto BeforeRet_;
					}
					LA34_: ;
				} LA31: ;
				i_4 += ((NI) 1);
			} LA30: ;
		}
	}
	{
		if (!(initResult == ((tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ) 1))) goto LA51_;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 1)) & 31);
	}
	LA51_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDefined__7YxUILpPxooC5qqa89a54dw_34)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	NIM_BOOL T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], n);
	T2_ = (NIM_BOOL)0;
	T2_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*c).graph).config, (*T1_).s);
	(*result)._kind_1.intVal = ((NI64) (T2_));
	(*result).info = (*n).info;
	asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setMs__YdV8xmi8UjdS8ox7bsgtGw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s));
	(*(*n)._kind_6.sons->data[((NI) 0)]).info = (*n).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookUpForDeclared__ejqqZ7JpeaJqZ9aJjvnjSXw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL onlyCurrentScope) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T6_;
			if (!onlyCurrentScope) goto LA4_;
			T6_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T6_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			result = localSearchInScope__Drn1sJCJSwUUo03qKJigUw_2(c, T6_);
		}
		goto LA2_;
		LA4_: ;
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T8_;
			T8_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T8_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			result = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, T8_);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		{
			if (!onlyCurrentScope) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		m = lookUpForDeclared__ejqqZ7JpeaJqZ9aJjvnjSXw(c, (*n)._kind_6.sons->data[((NI) 0)], onlyCurrentScope);
		{
			NIM_BOOL T16_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
			T16_ = (NIM_BOOL)0;
			T16_ = !((m == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T16_)) goto LA17_;
			T16_ = ((*m).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
			LA17_: ;
			if (!T16_) goto LA18_;
			ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], n);
			{
				if (!(m == (*c).module)) goto LA22_;
				result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*c).topLevelScope).symbols, ident);
			}
			goto LA20_;
			LA22_: ;
			{
				result = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*m)._kind_3.tab, ident);
			}
			LA20_: ;
		}
		LA18_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*n)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	{
		result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	}
	break;
	default:
	{
		NimStringDesc* T28_;
		NimStringDesc* T29_;
		T28_ = (NimStringDesc*)0;
		T29_ = (NimStringDesc*)0;
		T29_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T28_ = rawNewString((T29_ ? T29_->Sup.len : 0) + 30);
appendString(T28_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_587));
appendString(T28_, T29_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T28_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_588, NIM_FALSE);
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDeclared__ssxiU9aPj4i6xXfLbEm3Reg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL onlyCurrentScope) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = lookUpForDeclared__ejqqZ7JpeaJqZ9aJjvnjSXw(c, (*n)._kind_6.sons->data[((NI) 1)], onlyCurrentScope);
	(*result)._kind_1.intVal = ((NI64) (!((T1_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))));
	(*result).info = (*n).info;
	asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryExpr__vJZwz9bfROKrfrtM50y74CQ_17)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile result;
	NI oldErrorCount;
	NI oldErrorMax;
	NI oldCompilesId;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* oldScope;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T5_;
	NI oldOwnerLen;
	NI T6_;
	tySequence__jWKvSdankQPoT5bw9cBU9aiw* oldGenerics;
	tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA oldErrorOutputs;
	NI oldContextLen;
	NI oldInGenericContext;
	NI oldInUnrolledContext;
	NI oldInGenericInst;
	NI oldInStaticContext;
	tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* oldProcCon;
	NimStringDesc* err;
	TSafePoint TM__rF9caJawfOjYTjsgLVUSGFA_589;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	oldErrorCount = (*(*(*c).graph).config).errorCounter;
	oldErrorMax = (*(*(*c).graph).config).errorMax;
	oldCompilesId = (*c).compilesContextId;
	{
		if (!((*c).compilesContextId == ((NI) 0))) goto LA3_;
		(*c).compilesContextIdGenerator += ((NI) 1);
		(*c).compilesContextId = (*c).compilesContextIdGenerator;
	}
	LA3_: ;
	(*(*(*c).graph).config).errorMax = ((NI) IL64(9223372036854775807));
	oldScope = (*c).currentScope;
	T5_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T5_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	T6_ = ((*(*c).graph).owners ? (*(*c).graph).owners->Sup.len : 0);
	oldOwnerLen = T6_;
	oldGenerics = (*c).generics;
	oldErrorOutputs = (*(*(*c).graph).config).m.errorOutputs;
	{
		if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0))) goto LA9_;
		(*(*(*c).graph).config).m.errorOutputs = 0;
	}
	LA9_: ;
	oldContextLen = getInfoContextLen__QY5gXnIUBOUa79b5tGece0A((*(*c).graph).config);
	oldInGenericContext = (*c).inGenericContext;
	oldInUnrolledContext = (*c).inUnrolledContext;
	oldInGenericInst = (*c).inGenericInst;
	oldInStaticContext = (*c).inStaticContext;
	oldProcCon = (*c).p;
	if ((*c).generics) { nimGCunrefNoCycle((*c).generics); (*c).generics = NIM_NIL; }
	err = (NimStringDesc*)0;
	pushSafePoint(&TM__rF9caJawfOjYTjsgLVUSGFA_589);
	TM__rF9caJawfOjYTjsgLVUSGFA_589.status = _setjmp(TM__rF9caJawfOjYTjsgLVUSGFA_589.context);
	if (TM__rF9caJawfOjYTjsgLVUSGFA_589.status == 0) {
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, flags);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T13_)) goto LA14_;
		T13_ = !(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 17))&31U)))!=0));
		LA14_: ;
		if (!T13_) goto LA15_;
		trackStmt__QaQdy9beybDhOWYNIJD0SGA(c, (*c).module, result, NIM_FALSE);
	}
	LA15_: ;
	{
		if (!!(((*(*(*c).graph).config).errorCounter == oldErrorCount))) goto LA19_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	LA19_: ;
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__IxbcvonC7TQkv166Uvdu1g_))) {
			TM__rF9caJawfOjYTjsgLVUSGFA_589.status = 0;
			popCurrentException();
		}
	}
	if (TM__rF9caJawfOjYTjsgLVUSGFA_589.status != 0) reraiseException();
	(*c).compilesContextId = oldCompilesId;
	genericSeqAssign((&(*c).generics), oldGenerics, (&NTI__jWKvSdankQPoT5bw9cBU9aiw_));
	(*c).inGenericContext = oldInGenericContext;
	(*c).inUnrolledContext = oldInUnrolledContext;
	(*c).inGenericInst = oldInGenericInst;
	(*c).inStaticContext = oldInStaticContext;
	asgnRef((void**) (&(*c).p), oldProcCon);
	setInfoContextLen__JRH1QeGlTzlBOChAZ7bvoQ((*(*c).graph).config, oldContextLen);
	asgnRef((void**) (&(*(*c).graph).owners), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*(*c).graph).owners)->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) (oldOwnerLen))));
	asgnRef((void**) (&(*c).currentScope), oldScope);
	(*(*(*c).graph).config).m.errorOutputs = oldErrorOutputs;
	(*(*(*c).graph).config).errorCounter = oldErrorCount;
	(*(*(*c).graph).config).errorMax = oldErrorMax;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCompiles__vJZwz9bfROKrfrtM50y74CQ_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 2)))) goto LA4_;
		result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
		goto BeforeRet_;
	}
	LA4_: ;
	T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T6_ = tryExpr__vJZwz9bfROKrfrtM50y74CQ_17(c, (*n)._kind_6.sons->data[((NI) 1)], flags);
	result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (!((T6_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))))));
	(*result).info = (*n).info;
	asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixupStaticType__NRIJDWZtATzMum7OEjYC2g_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T5_;
		tySequence__Ef05srmQTDulnBdXR4Ja6Q* T6_;
		if (!!(((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60)))) goto LA3_;
		T5_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T5_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		T6_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
		T6_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
		asgnRef((void**) (&T6_->data[0]), (*n).typ);
		asgnRef((void**) (&(*n).typ), newTypeWithSons__aSykZlHQuGR9almJ1ehcUew(T5_, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T6_));
		asgnRef((void**) (&(*(*n).typ).n), n);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, isOpImpl__vJZwz9bfROKrfrtM50y74CQ_19)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL res;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t1;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T5_;
		NimStringDesc* argX60gensym3735_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (T5_ == ((NI) 3));
		if (!(T4_)) goto LA6_;
		T4_ = !(((*(*n)._kind_6.sons->data[((NI) 1)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA6_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*n)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22) || (*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4));
		LA7_: ;
		if (!!(T3_)) goto LA8_;
		argX60gensym3735_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_592);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3735_, TM__rF9caJawfOjYTjsgLVUSGFA_592);
	}
	LA8_: ;
	res = NIM_FALSE;
	t1 = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
	t2 = (*(*n)._kind_6.sons->data[((NI) 2)]).typ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*t1).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		if (!(T12_)) goto LA13_;
		T12_ = !(((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
		LA13_: ;
		if (!T12_) goto LA14_;
		t1 = base__PfgI9ap7WOnsRfFV4znQ27w(t1);
	}
	LA14_: ;
	{
		NimStringDesc* T20_;
		if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*n)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA18_;
		T20_ = (NimStringDesc*)0;
		T20_ = nsuNormalize((*(*n)._kind_6.sons->data[((NI) 2)])._kind_3.strVal);
		if (eqStrings(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_593))) goto LA21_;
		if (eqStrings(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_594))) goto LA22_;
		goto LA23_;
		LA21_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t1, IL64(36134350136322320));
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T27_)) goto LA28_;
			T27_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = !((((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0));
			LA29_: ;
			res = T26_;
		}
		goto LA24_;
		LA22_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
			NIM_BOOL T31_;
			NIM_BOOL T32_;
			t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t1, IL64(36134350136322320));
			T31_ = (NIM_BOOL)0;
			T32_ = (NIM_BOOL)0;
			T32_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T32_)) goto LA33_;
			T32_ = ((*t_2).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA33_: ;
			T31_ = T32_;
			if (!(T31_)) goto LA34_;
			T31_ = (((*t_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0);
			LA34_: ;
			res = T31_;
		}
		goto LA24_;
		LA23_: ;
		{
			res = NIM_FALSE;
		}
		LA24_: ;
	}
	goto LA16_;
	LA18_: ;
	{
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T47_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T39_;
			T39_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T39_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t1, IL64(70368744187920));
			if (!!(((*T39_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10)))) goto LA40_;
			maybeLiftType__K7SXxqU6fIMYb9b4D3wV5CQ(&t2, c, (*n).info);
		}
		goto LA37_;
		LA40_: ;
		{
		}
		LA37_: ;
		nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, t2, (&m));
		{
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9))&31U)))!=0)) goto LA45_;
			m.diagnostics = NIM_NIL;
			m.diagnosticsEnabled = NIM_TRUE;
		}
		LA45_: ;
		T47_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
		T47_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&m), t2, t1, 0);
		res = (((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3) <= T47_);
	}
	LA16_: ;
	result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (res)));
	asgnRef((void**) (&(*result).typ), (*n).typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIs__vJZwz9bfROKrfrtM50y74CQ_18)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boolType;
	NIM_BOOL liftLhs;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* lhsType;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 3)))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_590), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_591, NIM_FALSE);
	}
	LA4_: ;
	boolType = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
	result = n;
	asgnRef((void**) (&(*n).typ), boolType);
	liftLhs = NIM_TRUE;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 258));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t2;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*n)._kind_6.sons->data[((NI) 2)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22)))) goto LA8_;
		t2 = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 2)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*(*n)._kind_6.sons->data[((NI) 2)]).info, t2));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated;
			if (!((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA12_;
			evaluated = tryConstExpr__7YxUILpPxooC5qqa89a54dw_30(c, (*n)._kind_6.sons->data[((NI) 1)]);
			{
				if (!!((evaluated == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA16_;
				fixupStaticType__NRIJDWZtATzMum7OEjYC2g_10(c, evaluated);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), evaluated);
			}
			goto LA14_;
			LA16_: ;
			{
				result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
				asgnRef((void**) (&(*result).typ), boolType);
				goto BeforeRet_;
			}
			LA14_: ;
		}
		goto LA10_;
		LA12_: ;
		{
			NIM_BOOL T20_;
			NIM_BOOL T22_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
			T20_ = (NIM_BOOL)0;
			T20_ = ((*t2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
			if (!(T20_)) goto LA21_;
			T22_ = (NIM_BOOL)0;
			T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T23_ = base__PfgI9ap7WOnsRfFV4znQ27w(t2);
			T22_ = ((*T23_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0));
			if (T22_) goto LA24_;
			T22_ = (((*t2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 29))&63U)))!=0);
			LA24_: ;
			T20_ = T22_;
			LA21_: ;
			if (!T20_) goto LA25_;
			liftLhs = NIM_FALSE;
		}
		goto LA10_;
		LA25_: ;
		LA10_: ;
	}
	goto LA6_;
	LA8_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 2)], 0));
	}
	LA6_: ;
	lhsType = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
	{
		if (!!(((*lhsType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA30_;
		{
			if (!liftLhs) goto LA34_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), makeTypeSymNode__L4oMECPyC3ttpx9cr0kf9a9bw(c, lhsType, (*(*n)._kind_6.sons->data[((NI) 1)]).info));
			lhsType = (*(*n)._kind_6.sons->data[((NI) 1)]).typ;
		}
		LA34_: ;
	}
	goto LA28_;
	LA30_: ;
	{
		{
			NIM_BOOL T39_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T40_;
			NIM_BOOL T42_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T44_;
			T39_ = (NIM_BOOL)0;
			T40_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T40_ = base__PfgI9ap7WOnsRfFV4znQ27w(lhsType);
			T39_ = ((*T40_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0));
			if (T39_) goto LA41_;
			T42_ = (NIM_BOOL)0;
			T42_ = (((NI) 0) < (*c).inGenericContext);
			if (!(T42_)) goto LA43_;
			T44_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T44_ = base__PfgI9ap7WOnsRfFV4znQ27w(lhsType);
			T42_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(T44_);
			LA43_: ;
			T39_ = T42_;
			LA41_: ;
			if (!T39_) goto LA45_;
			goto BeforeRet_;
		}
		LA45_: ;
	}
	LA28_: ;
	result = isOpImpl__vJZwz9bfROKrfrtM50y74CQ_19(c, n, flags);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpandToAst__7YxUILpPxooC5qqa89a54dw_35)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* macroCall;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	macroCall = (*n)._kind_6.sons->data[((NI) 1)];
	{
		NIM_BOOL T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol;
		NI cands;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* cand;
		tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* symx;
		T3_ = (NIM_BOOL)0;
		T3_ = isCallExpr__CZaoTkWCFI9acor4BmYF3Yw_2(macroCall);
		if (!T3_) goto LA4_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(macroCall);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					asgnRef((void**) (&(*macroCall)._kind_6.sons->data[i]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*macroCall)._kind_6.sons->data[i], 0));
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
		headSymbol = (*macroCall)._kind_6.sons->data[((NI) 0)];
		cands = ((NI) 0);
		cand = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
		symx = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, headSymbol);
		{
			while (1) {
				if (!!((symx == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
				{
					NIM_BOOL T13_;
					NI T15_;
					NI T16_;
					T13_ = (NIM_BOOL)0;
					T13_ = ((393216 &((NU32)1<<((NU)((*symx).kind)&31U)))!=0);
					if (!(T13_)) goto LA14_;
					T15_ = (NI)0;
					T15_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*symx).typ);
					T16_ = (NI)0;
					T16_ = len__P89cqdlERShb9alU3iC0yj8wast(macroCall);
					T13_ = (T15_ == T16_);
					LA14_: ;
					if (!T13_) goto LA17_;
					cand = symx;
					cands += ((NI) 1);
				}
				LA17_: ;
				symx = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
			} LA10: ;
		}
		{
			NimStringDesc* T23_;
			NI T24_;
			NimStringDesc* T25_;
			if (!(cands == ((NI) 0))) goto LA21_;
			T23_ = (NimStringDesc*)0;
			T24_ = (NI)0;
			T24_ = len__P89cqdlERShb9alU3iC0yj8wast(macroCall);
			T25_ = (NimStringDesc*)0;
			T25_ = nimIntToStr((NI)(T24_ - ((NI) 1)));
			T23_ = rawNewString((T25_ ? T25_->Sup.len : 0) + 41);
appendString(T23_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_595));
appendString(T23_, T25_);
appendString(T23_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_596));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T23_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_597, NIM_FALSE);
		}
		goto LA19_;
		LA21_: ;
		{
			NimStringDesc* T29_;
			NimStringDesc* T30_;
			if (!(((NI) 2) <= cands)) goto LA27_;
			T29_ = (NimStringDesc*)0;
			T30_ = (NimStringDesc*)0;
			T30_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(macroCall);
			T29_ = rawNewString((T30_ ? T30_->Sup.len : 0) + 38);
appendString(T29_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_598));
appendString(T29_, T30_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T29_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_599, NIM_FALSE);
		}
		goto LA19_;
		LA27_: ;
		{
			tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
			info = (*(*macroCall)._kind_6.sons->data[((NI) 0)]).info;
			asgnRef((void**) (&(*macroCall)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(cand, info));
			markUsed__QlWTWY7567sCdiTkeUTTDA(c, info, cand);
		}
		LA19_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* T33_;
		NimStringDesc* T34_;
		T33_ = (NimStringDesc*)0;
		T34_ = (NimStringDesc*)0;
		T34_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
		T33_ = rawNewString((T34_ ? T34_->Sup.len : 0) + 29);
appendString(T33_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_600));
appendString(T33_, T34_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T33_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_601, NIM_FALSE);
	}
	LA1_: ;
	{
		NimStringDesc* argX60gensym4733_;
		if (!!(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 27)))) goto LA37_;
		argX60gensym4733_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_602);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym4733_, TM__rF9caJawfOjYTjsgLVUSGFA_602);
	}
	LA37_: ;
	{
		NIM_BOOL T41_;
		NI T43_;
		T41_ = (NIM_BOOL)0;
		T41_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
		if (!(T41_)) goto LA42_;
		T43_ = (NI)0;
		T43_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T41_ = (T43_ == ((NI) 1));
		LA42_: ;
		if (!T41_) goto LA44_;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA39_;
	LA44_: ;
	{
		result = n;
	}
	LA39_: ;
	asgnRef((void**) (&(*result).typ), sysTypeFromName__tS9cwSHSUZLgy9baxOcGRlCQ((*c).graph, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_93)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpandToAst__QP3kds6GlqvnvsFXvC0yvw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* magicSym, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 2))) goto LA4_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(magicSym, (*n).info));
		result = semExpandToAst__7YxUILpPxooC5qqa89a54dw_35(c, n);
	}
	goto LA1_;
	LA4_: ;
	{
		result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectString__zUJc3JNayUkQ8i11jOQJeQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
{	result = (NimStringDesc*)0;
	n_2 = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, n);
	{
		if (!((*n_2).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*n_2).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA3_;
		result = copyString((*n_2)._kind_3.strVal);
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n_2).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_319), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_605, NIM_FALSE);
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newAnonSym__w5lZcsHUDOEnXuinSWI8ww)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(kind, (*(*c).cache).idAnon, T1_, info, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processQuotations__JHIMJhmDecu8Q5MfBu4NEQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, NimStringDesc* op, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** quotes, tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** ids) {
{	{
		if (!((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30))) goto LA3_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw((*n), ((NI) 2), (*(*c).graph).config);
		{
			NimStringDesc* examinedOp;
			if (!((*(*(*n))._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA7_;
			examinedOp = copyString((*(*(*(*n))._kind_6.sons->data[((NI) 0)])._kind_5.ident).s);
			{
				NI T13_;
				NI T14_;
				NimStringDesc* T15_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T16_;
				NI T17_;
				if (!eqStrings(examinedOp, op)) goto LA11_;
				unsureAsgnRef((void**) (&(*quotes)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*quotes)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
				T13_ = (*quotes)->Sup.len++;
				asgnRef((void**) (&(*quotes)->data[T13_]), (*(*n))._kind_6.sons->data[((NI) 1)]);
				T14_ = ((*quotes) ? (*quotes)->Sup.len : 0);
				T15_ = (NimStringDesc*)0;
				T15_ = nimIntToStr(T14_);
				T16_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T16_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T15_);
				unsureAsgnRef((void**) (&(*n)), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T16_, (*(*n)).info));
				unsureAsgnRef((void**) (&(*ids)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*ids)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
				T17_ = (*ids)->Sup.len++;
				asgnRef((void**) (&(*ids)->data[T17_]), (*n));
				goto BeforeRet_;
			}
			goto LA9_;
			LA11_: ;
			{
				NIM_BOOL T19_;
				NimStringDesc* T22_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T23_;
				T19_ = (NIM_BOOL)0;
				T19_ = nsuStartsWith(examinedOp, op);
				if (!T19_) goto LA20_;
				T22_ = (NimStringDesc*)0;
				T22_ = substr__iGg0RIKceRvsmvq8FUHOEw(examinedOp, (op ? op->Sup.len : 0));
				T23_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T23_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T22_);
				asgnRef((void**) (&(*(*n))._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T23_, (*(*n)).info));
			}
			goto LA9_;
			LA20_: ;
			LA9_: ;
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T25_;
		NI T29_;
		NI T30_;
		NimStringDesc* T31_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T32_;
		NI T33_;
		T25_ = (NIM_BOOL)0;
		T25_ = ((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53));
		if (!(T25_)) goto LA26_;
		T25_ = eqStrings(op, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_606));
		LA26_: ;
		if (!T25_) goto LA27_;
		unsureAsgnRef((void**) (&(*quotes)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*quotes)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
		T29_ = (*quotes)->Sup.len++;
		asgnRef((void**) (&(*quotes)->data[T29_]), (*(*n))._kind_6.sons->data[((NI) 0)]);
		T30_ = ((*quotes) ? (*quotes)->Sup.len : 0);
		T31_ = (NimStringDesc*)0;
		T31_ = nimIntToStr(T30_);
		T32_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T32_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T31_);
		unsureAsgnRef((void**) (&(*n)), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T32_, (*(*n)).info));
		unsureAsgnRef((void**) (&(*ids)), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*ids)), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
		T33_ = (*ids)->Sup.len++;
		asgnRef((void**) (&(*ids)->data[T33_]), (*n));
		goto BeforeRet_;
	}
	goto LA1_;
	LA27_: ;
	{
		if (!((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA35_;
		{
			if (!eqStrings((*(*(*n))._kind_5.ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96))) goto LA39_;
			unsureAsgnRef((void**) (&(*n)), (*ids)->data[((NI) 0)]);
		}
		LA39_: ;
	}
	goto LA1_;
	LA35_: ;
	LA1_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*n));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA43;
				i = i_2;
				processQuotations__JHIMJhmDecu8Q5MfBu4NEQ(c, &(*(*n))._kind_6.sons->data[i], op, quotes, ids);
				i_2 += ((NI) 1);
			} LA43: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodyDirty__DuioLh4uofptxEKissr2sw_3)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA4_;
			{
				NIM_BOOL T8_;
				T8_ = (NIM_BOOL)0;
				T8_ = ((*s).owner == (*c).owner);
				if (!(T8_)) goto LA9_;
				T8_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA9_: ;
				if (!T8_) goto LA10_;
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			goto LA6_;
			LA10_: ;
			{
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s).Sup.id);
				if (!T13_) goto LA14_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
			}
			goto LA6_;
			LA14_: ;
			LA6_: ;
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 55):
	{
		result = semTemplBodyDirty__DuioLh4uofptxEKissr2sw_3(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 122):
	{
		result = semBindStmt__9askHuPxNsdv5Fi00VcmrXQ((*c).c, n, (&(*c).toBind));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
	}
	break;
	default:
	{
		{
			NIM_BOOL T22_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45));
			if (T22_) goto LA23_;
			T22_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53));
			LA23_: ;
			if (!T22_) goto LA24_;
			s_2 = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = !((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T28_)) goto LA29_;
				T28_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s_2).Sup.id);
				LA29_: ;
				if (!T28_) goto LA30_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
				goto BeforeRet_;
			}
			LA30_: ;
		}
		LA24_: ;
		result = n;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA34;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semTemplBodyDirty__DuioLh4uofptxEKissr2sw_3(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA34: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplSymbol__v9aCQGt9cWiikzASIttxYkOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isField) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw(c, s);
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0):
	{
		result = n;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1), isField);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
	{
		{
			NIM_BOOL T6_;
			T6_ = (NIM_BOOL)0;
			T6_ = isField;
			if (!(T6_)) goto LA7_;
			T6_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
			LA7_: ;
			if (!T6_) goto LA8_;
			result = n;
		}
		goto LA4_;
		LA8_: ;
		{
			result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
		}
		LA4_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
	{
		result = n;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	{
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = isField;
			if (!(T15_)) goto LA16_;
			T15_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
			LA16_: ;
			if (!T15_) goto LA17_;
			result = n;
		}
		goto LA13_;
		LA17_: ;
		{
			result = newSymNodeTypeDesc__gg6DZ4kb59aQbmKe4ytsnvA(s, (*n).info);
		}
		LA13_: ;
	}
	break;
	default:
	{
		{
			NIM_BOOL T23_;
			T23_ = (NIM_BOOL)0;
			T23_ = isField;
			if (!(T23_)) goto LA24_;
			T23_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
			LA24_: ;
			if (!T23_) goto LA25_;
			result = n;
		}
		goto LA21_;
		LA25_: ;
		{
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
		}
		LA21_: ;
		{
			if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA30_;
			styleCheckUse__k3cqh606mJPYNzLXdtZjIg((*(*c).graph).config, (*n).info, s);
		}
		LA30_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodySons__DuioLh4uofptxEKissr2sw_5)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[i]));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openScope__v8rOnBcZIF3O8b3uSd4HeA)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw((*c).c);
}
N_LIB_PRIVATE N_NIMCALL(void, closeScope__v8rOnBcZIF3O8b3uSd4HeA_2)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c) {
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w((*c).c);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBodyScope__DuioLh4uofptxEKissr2sw_6)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
	result = semTemplBody__DuioLh4uofptxEKissr2sw_4(c, n);
	closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw, symBinding__lRF6a2VbcNtMQTglYy3orA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw result;
{	result = (tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA6_;
					key = (*it)._kind_6.sons->data[((NI) 0)];
				}
				goto LA4_;
				LA6_: ;
				{
					key = it;
				}
				LA4_: ;
				{
					tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T13_;
					if (!((*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA11_;
					T13_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
					T13_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*key)._kind_5.ident);
					switch (T13_) {
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 206):
					{
						result = ((tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw) 1);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 207):
					{
						result = ((tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw) 2);
						goto BeforeRet_;
					}
					break;
					default:
					{
					}
					break;
					}
				}
				LA11_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, onlyReplaceParams__DuioLh4uofptxEKissr2sw_7)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA3_;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = ((*s).owner == (*c).owner);
				if (!(T11_)) goto LA12_;
				T11_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA12_: ;
				if (!T11_) goto LA13_;
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA13_: ;
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), onlyReplaceParams__DuioLh4uofptxEKissr2sw_7(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getIdentNode__DuioLh4uofptxEKissr2sw_8)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		result = getIdentNode__DuioLh4uofptxEKissr2sw_8(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		result = getIdentNode__DuioLh4uofptxEKissr2sw_8(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		result = n;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA6_;
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = ((*s).owner == (*c).owner);
				if (!(T10_)) goto LA11_;
				T10_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA11_: ;
				if (!T10_) goto LA12_;
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA12_: ;
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = n;
	}
	break;
	default:
	{
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*(*c).c).graph).config);
		result = n;
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, isTemplParam__XVOXP9ay7a7Pj2tMnC3DpKQsem)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T3_)) goto LA4_;
	T3_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = ((*(*n)._kind_4.sym).owner == (*c).owner);
	LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA6_;
	T1_ = (((*(*n)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 39))&63U)))!=0);
	LA6_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s) {
	switch ((*(*n)).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ(c, &(*(*n))._kind_6.sons->data[((NI) 1)], s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ(c, &(*(*n))._kind_6.sons->data[((NI) 0)], s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		unsureAsgnRef((void**) (&(*n)), s);
	}
	break;
	default:
	{
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw((*n), (*(*c).graph).config);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newGenSym__pZY5bxiuLRGzLAtcZwPJyQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(kind, T1_, (*c).owner, (*n).info, 0);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36)) & 63);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 25)) & 63);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
{	{
		NIM_BOOL T3_;
		tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ident;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43));
		if (!(T3_)) goto LA4_;
		T5_ = (tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw)0;
		T5_ = symBinding__lRF6a2VbcNtMQTglYy3orA((*(*n))._kind_6.sons->data[((NI) 1)]);
		T3_ = (T5_ == ((tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		x = (*(*n))._kind_6.sons->data[((NI) 0)];
		{
			while (1) {
				switch ((*x).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
				{
					x = (*x)._kind_6.sons->data[((NI) 1)];
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
				{
					x = (*x)._kind_6.sons->data[((NI) 0)];
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
				{
					goto LA8;
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
				{
					unsureAsgnRef((void**) (&(*n)), onlyReplaceParams__DuioLh4uofptxEKissr2sw_7(c, (*n)));
					goto BeforeRet_;
				}
				break;
				default:
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(x, (*(*(*c).c).graph).config);
				}
				break;
				}
			}
		} LA8: ;
		ident = getIdentNode__DuioLh4uofptxEKissr2sw_8(c, x);
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = isTemplParam__XVOXP9ay7a7Pj2tMnC3DpKQsem((&(*c)), ident);
			if (!!(T17_)) goto LA18_;
			incl__jENnK9c9bPE73pKmo2vYjpqg((&(*c).toInject), (*(*x)._kind_5.ident).Sup.id);
		}
		goto LA15_;
		LA18_: ;
		{
			replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ((*c).c, n, ident);
		}
		LA15_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ident_2;
		{
			NIM_BOOL T24_;
			NIM_BOOL T25_;
			NI T27_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaNode;
			T24_ = (NIM_BOOL)0;
			T25_ = (NIM_BOOL)0;
			T25_ = ((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43));
			if (!(T25_)) goto LA26_;
			T27_ = (NI)0;
			T27_ = len__P89cqdlERShb9alU3iC0yj8wast((*n));
			T25_ = (((NI) 2) <= T27_);
			LA26_: ;
			T24_ = T25_;
			if (!(T24_)) goto LA28_;
			T24_ = ((*(*(*n))._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90));
			LA28_: ;
			if (!T24_) goto LA29_;
			pragmaNode = (*(*n))._kind_6.sons->data[((NI) 1)];
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(pragmaNode);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA33;
						i = i_2;
						openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
						asgnRef((void**) (&(*pragmaNode)._kind_6.sons->data[i]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*pragmaNode)._kind_6.sons->data[i]));
						closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
						i_2 += ((NI) 1);
					} LA33: ;
				}
			}
		}
		LA29_: ;
		ident_2 = getIdentNode__DuioLh4uofptxEKissr2sw_8(c, (*n));
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = isTemplParam__XVOXP9ay7a7Pj2tMnC3DpKQsem((&(*c)), ident_2);
			if (!!(T36_)) goto LA37_;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* local;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T47_;
				if (!!(((*(*n)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA41_;
				local = newGenSym__pZY5bxiuLRGzLAtcZwPJyQ(k, ident_2, c);
				addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4((*c).c, local);
				{
					if (!!(((49152 & (*(*(*(*c).c).graph).config).globalOptions) == 0))) goto LA45_;
					nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*(*c).c).graph).config, (*(*n)).info, local, (*local).kind);
				}
				LA45_: ;
				T47_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T47_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(local, (*(*n)).info);
				replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ((*c).c, n, T47_);
				{
					NIM_BOOL T50_;
					T50_ = (NIM_BOOL)0;
					T50_ = (k == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
					if (!(T50_)) goto LA51_;
					T50_ = (((NI) 0) < (*c).inTemplateHeader);
					LA51_: ;
					if (!T50_) goto LA52_;
					(*local).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 39)) & 63);
				}
				LA52_: ;
			}
			LA41_: ;
		}
		goto LA34_;
		LA37_: ;
		{
			replaceIdentBySym__f9bg4q9aUFEI1VrFUdopr7oQ((*c).c, n, ident_2);
		}
		LA34_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, semTemplSomeDecl__7l8P1u9cbRbmxfIqmTswe6Q)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, NI start) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					NI T15_;
					NI T16_;
					NI T17_;
					NI T18_;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA7_;
						goto LA4;
					}
					LA7_: ;
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = !(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35)));
						if (!(T11_)) goto LA12_;
						T11_ = !(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)));
						LA12_: ;
						if (!T11_) goto LA13_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*(*c).c).graph).config);
					}
					LA13_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*(*c).c).graph).config);
					T15_ = (NI)0;
					T15_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					T16_ = (NI)0;
					T16_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					asgnRef((void**) (&(*a)._kind_6.sons->data[(NI)(T15_ - ((NI) 2))]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a)._kind_6.sons->data[(NI)(T16_ - ((NI) 2))]));
					T17_ = (NI)0;
					T17_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					T18_ = (NI)0;
					T18_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					asgnRef((void**) (&(*a)._kind_6.sons->data[(NI)(T17_ - ((NI) 1))]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a)._kind_6.sons->data[(NI)(T18_ - ((NI) 1))]));
					{
						NI j;
						NI colontmp__2;
						NI T20_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T20_ = (NI)0;
						T20_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__2 = (NI)(T20_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								if (!(i_3 < colontmp__2)) goto LA22;
								j = i_3;
								addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*a)._kind_6.sons->data[j], symKind);
								i_3 += ((NI) 1);
							} LA22: ;
						}
					}
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRoutineInTemplName__DuioLh4uofptxEKissr2sw_9)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA3_;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
			{
				NIM_BOOL T11_;
				NIM_BOOL T13_;
				T11_ = (NIM_BOOL)0;
				T11_ = ((*s).owner == (*c).owner);
				if (!(T11_)) goto LA12_;
				T13_ = (NIM_BOOL)0;
				T13_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				if (T13_) goto LA14_;
				T13_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
				LA14_: ;
				T11_ = T13_;
				LA12_: ;
				if (!T11_) goto LA15_;
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			LA15_: ;
		}
		LA7_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA20;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semRoutineInTemplName__DuioLh4uofptxEKissr2sw_9(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 7), (*(*(*c).c).graph).config);
	{
		NIM_BOOL T3_;
		tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ident;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52)));
		if (!(T3_)) goto LA4_;
		T5_ = (tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw)0;
		T5_ = symBinding__lRF6a2VbcNtMQTglYy3orA((*n)._kind_6.sons->data[((NI) 4)]);
		T3_ = (T5_ == ((tyEnum_TSymBinding__djea3jD0GJNy3LfTycW4Gw) 1));
		LA4_: ;
		if (!T3_) goto LA6_;
		ident = getIdentNode__DuioLh4uofptxEKissr2sw_8(c, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T10_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			T10_ = (NIM_BOOL)0;
			T10_ = isTemplParam__XVOXP9ay7a7Pj2tMnC3DpKQsem((&(*c)), ident);
			if (!!(T10_)) goto LA11_;
			s = newGenSym__pZY5bxiuLRGzLAtcZwPJyQ(k, ident, c);
			asgnRef((void**) (&(*s).ast), n);
			addPrelimDecl__aPXKqZJT9c7r7gT8X3uZAHw_4((*c).c, s);
			{
				if (!!(((49152 & (*(*(*(*c).c).graph).config).globalOptions) == 0))) goto LA15_;
				nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*(*c).c).graph).config, (*n).info, s, (*s).kind);
			}
			LA15_: ;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*(*n)._kind_6.sons->data[((NI) 0)]).info));
		}
		goto LA8_;
		LA11_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), ident);
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semRoutineInTemplName__DuioLh4uofptxEKissr2sw_9(c, (*n)._kind_6.sons->data[((NI) 0)]));
	}
	LA1_: ;
	openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				if (!(res <= ((NI) 2))) goto LA21;
				i = res;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[i]));
				res += ((NI) 1);
			} LA21: ;
		}
	}
	{
		if (!(k == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18))) goto LA24_;
		(*c).inTemplateHeader += ((NI) 1);
	}
	LA24_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 3)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 3)]));
	{
		if (!(k == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18))) goto LA28_;
		(*c).inTemplateHeader -= ((NI) 1);
	}
	LA28_: ;
	{
		NI i_2;
		NI res_2;
		i_2 = (NI)0;
		res_2 = ((NI) 4);
		{
			while (1) {
				if (!(res_2 <= ((NI) 5))) goto LA32;
				i_2 = res_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i_2]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[i_2]));
				res_2 += ((NI) 1);
			} LA32: ;
		}
	}
	(*c).scopeN += ((NI) 1);
	openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 6)]));
	closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	(*c).scopeN -= ((NI) 1);
	closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplBody__DuioLh4uofptxEKissr2sw_4)(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toInject), (*(*n)._kind_5.ident).Sup.id);
			if (!T4_) goto LA5_;
			result = n;
			goto BeforeRet_;
		}
		LA5_: ;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9_;
			{
				NIM_BOOL T13_;
				NIM_BOOL T14_;
				T13_ = (NIM_BOOL)0;
				T14_ = (NIM_BOOL)0;
				T14_ = ((*s).owner == (*c).owner);
				if (!(T14_)) goto LA15_;
				T14_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA15_: ;
				T13_ = T14_;
				if (!(T13_)) goto LA16_;
				T13_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 39))&63U)))!=0);
				LA16_: ;
				if (!T13_) goto LA17_;
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			goto LA11_;
			LA17_: ;
			{
				NIM_BOOL T20_;
				T20_ = (NIM_BOOL)0;
				T20_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s).Sup.id);
				if (!T20_) goto LA21_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), (((NI) 0) < (*c).noGenSym));
			}
			goto LA11_;
			LA21_: ;
			{
				NIM_BOOL T24_;
				T24_ = (NIM_BOOL)0;
				T24_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toMixin), (*(*s).name).Sup.id);
				if (!T24_) goto LA25_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2), (((NI) 0) < (*c).noGenSym));
			}
			goto LA11_;
			LA25_: ;
			{
				NIM_BOOL T28_;
				NIM_BOOL T29_;
				T28_ = (NIM_BOOL)0;
				T29_ = (NIM_BOOL)0;
				T29_ = ((*s).owner == (*c).owner);
				if (!(T29_)) goto LA30_;
				T29_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0);
				LA30_: ;
				T28_ = T29_;
				if (!(T28_)) goto LA31_;
				T28_ = ((*c).noGenSym == ((NI) 0));
				LA31_: ;
				if (!T28_) goto LA32_;
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
			}
			goto LA11_;
			LA32_: ;
			{
				result = semTemplSymbol__v9aCQGt9cWiikzASIttxYkOQ((*c).c, n, s, (((NI) 0) < (*c).noGenSym));
			}
			LA11_: ;
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 55):
	{
		result = semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 122):
	{
		result = semBindStmt__9askHuPxNsdv5Fi00VcmrXQ((*c).c, n, (&(*c).toBind));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 123):
	{
		{
			if (!(((NI) 0) < (*c).scopeN)) goto LA40_;
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
		}
		goto LA38_;
		LA40_: ;
		{
			result = semMixinStmt__gk1t9bC9cmwHRhVJXF0sVfqA((*c).c, n, (&(*c).toMixin));
		}
		LA38_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					if (!(i_2 < colontmp_)) goto LA47;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						NI T50_;
						T50_ = (NI)0;
						T50_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						if (!(T50_ == ((NI) 2))) goto LA51_;
						openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
						asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*it)._kind_6.sons->data[((NI) 0)]));
						asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*it)._kind_6.sons->data[((NI) 1)]));
						closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
					}
					goto LA48_;
					LA51_: ;
					{
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semTemplBodyScope__DuioLh4uofptxEKissr2sw_6(c, it));
					}
					LA48_: ;
					i_2 += ((NI) 1);
				} LA47: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA57;
					i_3 = i_4;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[i_3]));
					i_4 += ((NI) 1);
				} LA57: ;
			}
		}
		closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					NI T66_;
					NI T67_;
					if (!(i_6 < colontmp__3)) goto LA61;
					i_5 = i_6;
					a = (*n)._kind_6.sons->data[i_5];
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 1), (*(*(*c).c).graph).config);
					{
						NI j;
						NI colontmp__4;
						NI T63_;
						NI i_7;
						j = (NI)0;
						colontmp__4 = (NI)0;
						T63_ = (NI)0;
						T63_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__4 = (NI)(T63_ - ((NI) 1));
						i_7 = ((NI) 0);
						{
							while (1) {
								if (!(i_7 < colontmp__4)) goto LA65;
								j = i_7;
								asgnRef((void**) (&(*a)._kind_6.sons->data[j]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a)._kind_6.sons->data[j]));
								i_7 += ((NI) 1);
							} LA65: ;
						}
					}
					T66_ = (NI)0;
					T66_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					T67_ = (NI)0;
					T67_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					asgnRef((void**) (&(*a)._kind_6.sons->data[(NI)(T66_ - ((NI) 1))]), semTemplBodyScope__DuioLh4uofptxEKissr2sw_6(c, (*a)._kind_6.sons->data[(NI)(T67_ - ((NI) 1))]));
					i_6 += ((NI) 1);
				} LA61: ;
			}
		}
		closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		NI T69_;
		NI T70_;
		NI T84_;
		NI T85_;
		openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
		T69_ = (NI)0;
		T69_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T70_ = (NI)0;
		T70_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T69_ - ((NI) 2))]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[(NI)(T70_ - ((NI) 2))]));
		{
			NI i_8;
			NI colontmp__5;
			NI T72_;
			NI i_9;
			i_8 = (NI)0;
			colontmp__5 = (NI)0;
			T72_ = (NI)0;
			T72_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp__5 = (NI)(T72_ - ((NI) 2));
			i_9 = ((NI) 0);
			{
				while (1) {
					if (!(i_9 < colontmp__5)) goto LA74;
					i_8 = i_9;
					{
						if (!((*(*n)._kind_6.sons->data[i_8]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA77_;
						{
							NI j_2;
							NI colontmp__6;
							NI T80_;
							NI i_10;
							j_2 = (NI)0;
							colontmp__6 = (NI)0;
							T80_ = (NI)0;
							T80_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i_8]);
							colontmp__6 = (NI)(T80_ - ((NI) 1));
							i_10 = ((NI) 0);
							{
								while (1) {
									if (!(i_10 < colontmp__6)) goto LA82;
									j_2 = i_10;
									addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*(*n)._kind_6.sons->data[i_8])._kind_6.sons->data[j_2], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21));
									i_10 += ((NI) 1);
								} LA82: ;
							}
						}
					}
					goto LA75_;
					LA77_: ;
					{
						addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*n)._kind_6.sons->data[i_8], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21));
					}
					LA75_: ;
					i_9 += ((NI) 1);
				} LA74: ;
			}
		}
		openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
		T84_ = (NI)0;
		T84_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T85_ = (NI)0;
		T85_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T84_ - ((NI) 1))]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[(NI)(T85_ - ((NI) 1))]));
		closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
		closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 129):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*(*c).c).graph).config);
		openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA89_;
			addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22));
		}
		LA89_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 1)]));
		closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*(*c).c).graph).config);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semTemplBodyScope__DuioLh4uofptxEKissr2sw_6(c, (*n)._kind_6.sons->data[((NI) 0)]));
		{
			NI i_11;
			NI colontmp__7;
			NI i_12;
			i_11 = (NI)0;
			colontmp__7 = (NI)0;
			colontmp__7 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_12 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
					NI T105_;
					NI T106_;
					if (!(i_12 < colontmp__7)) goto LA94;
					i_11 = i_12;
					a_2 = (*n)._kind_6.sons->data[i_11];
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a_2, ((NI) 1), (*(*(*c).c).graph).config);
					openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
					{
						NI j_3;
						NI colontmp__8;
						NI T96_;
						NI i_13;
						j_3 = (NI)0;
						colontmp__8 = (NI)0;
						T96_ = (NI)0;
						T96_ = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
						colontmp__8 = (NI)(T96_ - ((NI) 1));
						i_13 = ((NI) 0);
						{
							while (1) {
								if (!(i_13 < colontmp__8)) goto LA98;
								j_3 = i_13;
								{
									NIM_BOOL T101_;
									T101_ = (NIM_BOOL)0;
									T101_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*a_2)._kind_6.sons->data[j_3]);
									if (!T101_) goto LA102_;
									addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*(*a_2)._kind_6.sons->data[j_3])._kind_6.sons->data[((NI) 2)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
									asgnRef((void**) (&(*(*a_2)._kind_6.sons->data[j_3])._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*(*a_2)._kind_6.sons->data[j_3])._kind_6.sons->data[((NI) 1)]));
								}
								goto LA99_;
								LA102_: ;
								{
									asgnRef((void**) (&(*a_2)._kind_6.sons->data[j_3]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_2)._kind_6.sons->data[j_3]));
								}
								LA99_: ;
								i_13 += ((NI) 1);
							} LA98: ;
						}
					}
					T105_ = (NI)0;
					T105_ = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
					T106_ = (NI)0;
					T106_ = len__P89cqdlERShb9alU3iC0yj8wast(a_2);
					asgnRef((void**) (&(*a_2)._kind_6.sons->data[(NI)(T105_ - ((NI) 1))]), semTemplBodyScope__DuioLh4uofptxEKissr2sw_6(c, (*a_2)._kind_6.sons->data[(NI)(T106_ - ((NI) 1))]));
					closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
					i_12 += ((NI) 1);
				} LA94: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	{
		semTemplSomeDecl__7l8P1u9cbRbmxfIqmTswe6Q(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), ((NI) 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		semTemplSomeDecl__7l8P1u9cbRbmxfIqmTswe6Q(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9), ((NI) 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*(*c).c).graph).config);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]));
		semTemplSomeDecl__7l8P1u9cbRbmxfIqmTswe6Q(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), ((NI) 1));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		{
			NI i_14;
			NI colontmp__9;
			NI i_15;
			i_14 = (NI)0;
			colontmp__9 = (NI)0;
			colontmp__9 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_15 = ((NI) 0);
			{
				while (1) {
					if (!(i_15 < colontmp__9)) goto LA113;
					i_14 = i_15;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_3;
						a_3 = (*n)._kind_6.sons->data[i_14];
						{
							if (!((*a_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA117_;
							goto LA114;
						}
						LA117_: ;
						{
							if (!!(((*a_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102)))) goto LA121_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_3, (*(*(*c).c).graph).config);
						}
						LA121_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_3, ((NI) 3), (*(*(*c).c).graph).config);
						addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*a_3)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
						asgnRef((void**) (&(*a_3)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_3)._kind_6.sons->data[((NI) 1)]));
						asgnRef((void**) (&(*a_3)._kind_6.sons->data[((NI) 2)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_3)._kind_6.sons->data[((NI) 2)]));
					} LA114: ;
					i_15 += ((NI) 1);
				} LA113: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	{
		{
			NI i_16;
			NI colontmp__10;
			NI i_17;
			i_16 = (NI)0;
			colontmp__10 = (NI)0;
			colontmp__10 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_17 = ((NI) 0);
			{
				while (1) {
					if (!(i_17 < colontmp__10)) goto LA126;
					i_16 = i_17;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_4;
						a_4 = (*n)._kind_6.sons->data[i_16];
						{
							if (!((*a_4).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA130_;
							goto LA127;
						}
						LA130_: ;
						{
							if (!!(((*a_4).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA134_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_4, (*(*(*c).c).graph).config);
						}
						LA134_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_4, ((NI) 3), (*(*(*c).c).graph).config);
						addLocalDecl__w8tQ2g9cGJTRX1sc4tPkZhw(c, &(*a_4)._kind_6.sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
					} LA127: ;
					i_17 += ((NI) 1);
				} LA126: ;
			}
		}
		{
			NI i_18;
			NI colontmp__11;
			NI i_19;
			i_18 = (NI)0;
			colontmp__11 = (NI)0;
			colontmp__11 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_19 = ((NI) 0);
			{
				while (1) {
					if (!(i_19 < colontmp__11)) goto LA138;
					i_18 = i_19;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_5;
						a_5 = (*n)._kind_6.sons->data[i_18];
						{
							if (!((*a_5).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA142_;
							goto LA139;
						}
						LA142_: ;
						{
							if (!!(((*a_5).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA146_;
							illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a_5, (*(*(*c).c).graph).config);
						}
						LA146_: ;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a_5, ((NI) 3), (*(*(*c).c).graph).config);
						{
							if (!!(((*(*a_5)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA150_;
							openScope__v8rOnBcZIF3O8b3uSd4HeA(c);
							asgnRef((void**) (&(*a_5)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_5)._kind_6.sons->data[((NI) 1)]));
							asgnRef((void**) (&(*a_5)._kind_6.sons->data[((NI) 2)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_5)._kind_6.sons->data[((NI) 2)]));
							closeScope__v8rOnBcZIF3O8b3uSd4HeA_2(c);
						}
						goto LA148_;
						LA150_: ;
						{
							asgnRef((void**) (&(*a_5)._kind_6.sons->data[((NI) 2)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_5)._kind_6.sons->data[((NI) 2)]));
						}
						LA148_: ;
					} LA139: ;
					i_19 += ((NI) 1);
				} LA138: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		result = semRoutineInTemplBody__tZ0y3BLqy4d0VbZugMb29cw(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	{
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 1)]));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_20;
				NI colontmp__12;
				NI i_21;
				i_20 = (NI)0;
				colontmp__12 = (NI)0;
				colontmp__12 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_21 = ((NI) 0);
				{
					while (1) {
						if (!(i_21 < colontmp__12)) goto LA166;
						i_20 = i_21;
						x = (*n)._kind_6.sons->data[i_20];
						{
							if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA169_;
							asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*x)._kind_6.sons->data[((NI) 1)]));
						}
						LA169_: ;
						i_21 += ((NI) 1);
					} LA166: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T172_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T173_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n0;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T172_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T172_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_26));
		T173_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T173_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T172_, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T173_);
		{
			NI i_22;
			NI colontmp__13;
			NI i_23;
			i_22 = (NI)0;
			colontmp__13 = (NI)0;
			colontmp__13 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_23 = ((NI) 0);
			{
				while (1) {
					if (!(i_23 < colontmp__13)) goto LA176;
					i_22 = i_23;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i_22]);
					i_23 += ((NI) 1);
				} LA176: ;
			}
		}
		n0 = semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]);
		result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, result);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T178_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T179_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T178_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T178_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_114));
		T179_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T179_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T178_, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T179_);
		{
			NI i_24;
			NI colontmp__14;
			NI i_25;
			i_24 = (NI)0;
			colontmp__14 = (NI)0;
			colontmp__14 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_25 = ((NI) 0);
			{
				while (1) {
					if (!(i_25 < colontmp__14)) goto LA182;
					i_24 = i_25;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i_24]);
					i_25 += ((NI) 1);
				} LA182: ;
			}
		}
		result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, result);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_6;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw k;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*(*c).c).graph).config);
		a_6 = (*n)._kind_6.sons->data[((NI) 0)];
		b = (*n)._kind_6.sons->data[((NI) 1)];
		k = (*a_6).kind;
		switch (k) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T185_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T186_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a0;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
			T185_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T185_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_119));
			T186_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T186_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T185_, (*n).info);
			add__P8dDSotTW25BkfbyspojGg(result, T186_);
			{
				NI i_26;
				NI colontmp__15;
				NI i_27;
				i_26 = (NI)0;
				colontmp__15 = (NI)0;
				colontmp__15 = len__P89cqdlERShb9alU3iC0yj8wast(a_6);
				i_27 = ((NI) 0);
				{
					while (1) {
						if (!(i_27 < colontmp__15)) goto LA189;
						i_26 = i_27;
						add__P8dDSotTW25BkfbyspojGg(result, (*a_6)._kind_6.sons->data[i_26]);
						i_27 += ((NI) 1);
					} LA189: ;
				}
			}
			add__P8dDSotTW25BkfbyspojGg(result, b);
			a0 = semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*a_6)._kind_6.sons->data[((NI) 0)]);
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, result);
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
		{
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T191_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T192_;
			result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
			T191_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T191_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_118));
			T192_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T192_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T191_, (*n).info);
			add__P8dDSotTW25BkfbyspojGg(result, T192_);
			{
				NI i_28;
				NI colontmp__16;
				NI i_29;
				i_28 = (NI)0;
				colontmp__16 = (NI)0;
				colontmp__16 = len__P89cqdlERShb9alU3iC0yj8wast(a_6);
				i_29 = ((NI) 0);
				{
					while (1) {
						if (!(i_29 < colontmp__16)) goto LA195;
						i_28 = i_29;
						add__P8dDSotTW25BkfbyspojGg(result, (*a_6)._kind_6.sons->data[i_28]);
						i_29 += ((NI) 1);
					} LA195: ;
				}
			}
			add__P8dDSotTW25BkfbyspojGg(result, b);
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, result);
		}
		break;
		default:
		{
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			NIM_BOOL T200_;
			T200_ = (NIM_BOOL)0;
			T200_ = isRunnableExamples__CZaoTkWCFI9acor4BmYF3Yw_3((*n)._kind_6.sons->data[((NI) 0)]);
			if (!!(T200_)) goto LA201_;
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
		}
		LA201_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		s_2 = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag((*c).c, n, 0);
		{
			if (!!((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA206_;
			{
				NIM_BOOL T210_;
				NIM_BOOL T211_;
				NIM_BOOL T212_;
				NI T216_;
				T210_ = (NIM_BOOL)0;
				T211_ = (NIM_BOOL)0;
				T212_ = (NIM_BOOL)0;
				T212_ = ((*s_2).owner == (*c).owner);
				if (!(T212_)) goto LA213_;
				T212_ = ((*s_2).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
				LA213_: ;
				T211_ = T212_;
				if (!(T211_)) goto LA214_;
				T211_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53));
				LA214_: ;
				T210_ = T211_;
				if (!(T210_)) goto LA215_;
				T216_ = (NI)0;
				T216_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				T210_ = (T216_ == ((NI) 1));
				LA215_: ;
				if (!T210_) goto LA217_;
				(*s_2).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s_2, (*n).info);
				goto BeforeRet_;
			}
			goto LA208_;
			LA217_: ;
			{
				NIM_BOOL T220_;
				T220_ = (NIM_BOOL)0;
				T220_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toBind), (*s_2).Sup.id);
				if (!T220_) goto LA221_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), (((NI) 0) < (*c).noGenSym));
				goto BeforeRet_;
			}
			goto LA208_;
			LA221_: ;
			{
				NIM_BOOL T224_;
				T224_ = (NIM_BOOL)0;
				T224_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).toMixin), (*(*s_2).name).Sup.id);
				if (!T224_) goto LA225_;
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 2), (((NI) 0) < (*c).noGenSym));
				goto BeforeRet_;
			}
			goto LA208_;
			LA225_: ;
			{
				result = symChoice__ce08GbPIDAcM29cbr3lVUxg((*c).c, n, s_2, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 1), (((NI) 0) < (*c).noGenSym));
				goto BeforeRet_;
			}
			LA208_: ;
		}
		LA206_: ;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA230_;
			result = n;
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]));
			(*c).noGenSym += ((NI) 1);
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 1)]));
			(*c).noGenSym -= ((NI) 1);
		}
		goto LA228_;
		LA230_: ;
		{
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
		}
		LA228_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33):
	{
		{
			NI T236_;
			T236_ = (NI)0;
			T236_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T236_ == ((NI) 2))) goto LA237_;
			(*c).noGenSym += ((NI) 1);
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 0)]));
			(*c).noGenSym -= ((NI) 1);
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semTemplBody__DuioLh4uofptxEKissr2sw_4(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA234_;
		LA237_: ;
		{
			result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
		}
		LA234_: ;
	}
	break;
	default:
	{
		result = semTemplBodySons__DuioLh4uofptxEKissr2sw_5(c, n);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTemplateDef__7YxUILpPxooC5qqa89a54dw_37)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T25_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
	NIM_BOOL allUntyped;
	tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw ctx;
	tyTuple__jdFwpivBCgGar3GHRE8kKQ T84_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* proto;
	NIM_BOOL comesFromShadowscope;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!T3_) goto LA4_;
		s = semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18), (*n)._kind_6.sons->data[((NI) 0)], 2);
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
	}
	goto LA1_;
	LA4_: ;
	{
		s = semIdentVis__gSt4lwrAK8GOXOIIBgGsog_2(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18), (*n)._kind_6.sons->data[((NI) 0)], 0);
	}
	LA1_: ;
	{
		if (!!(((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9_;
		{
			NIM_BOOL T13_;
			NIM_BOOL T14_;
			NIM_BOOL T17_;
			T13_ = (NIM_BOOL)0;
			T14_ = (NIM_BOOL)0;
			T14_ = (((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
			if (!(T14_)) goto LA15_;
			T14_ = contains__MghwuKjQqmVLYE8A59cNGHgsystem(names__yCnDYwFZyTz3YBJ4ma9adZQ, 8, (*(*s).name).s);
			LA15_: ;
			T13_ = T14_;
			if (T13_) goto LA16_;
			T17_ = (NIM_BOOL)0;
			T17_ = eqStrings((*(*(*s).owner).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_616));
			if (!(T17_)) goto LA18_;
			T17_ = eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_617));
			LA18_: ;
			T13_ = T17_;
			LA16_: ;
			if (!T13_) goto LA19_;
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 35)) & 63);
		}
		LA19_: ;
	}
	LA9_: ;
	{
		if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA23_;
		nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*s).info, s, (*s).kind);
	}
	LA23_: ;
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
	T25_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T25_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*(*n)._kind_6.sons->data[((NI) 0)]).info));
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA28_;
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 4)], TM__rF9caJawfOjYTjsgLVUSGFA_618, NIM_FALSE);
	}
	LA28_: ;
	gp = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA32_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), semGenericParamList__00ZJT6x0WT6z8eBqr79cipw(c, (*n)._kind_6.sons->data[((NI) 2)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		gp = (*n)._kind_6.sons->data[((NI) 2)];
	}
	goto LA30_;
	LA32_: ;
	{
		gp = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75), (*n).info);
	}
	LA30_: ;
	allUntyped = NIM_TRUE;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA37_;
		semParamList__HJ2sXcKFjirzvqsZjMcpTg(c, (*n)._kind_6.sons->data[((NI) 3)], gp, s);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*s).typ).n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					if (!(i_2 < colontmp_)) goto LA41;
					i = i_2;
					param = (*(*(*(*s).typ).n)._kind_6.sons->data[i])._kind_4.sym;
					(*param).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 39)) & 63);
					(*param).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36)) & 63));
					{
						if (!!(((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6)))) goto LA44_;
						allUntyped = NIM_FALSE;
					}
					LA44_: ;
					i_2 += ((NI) 1);
				} LA41: ;
			}
		}
		{
			NI T48_;
			T48_ = (NI)0;
			T48_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
			if (!(((NI) 0) < T48_)) goto LA49_;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA53_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), gp);
			}
			LA53_: ;
		}
		LA49_: ;
	}
	goto LA35_;
	LA37_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T56_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T57_;
		asgnRef((void**) (&(*s).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25), c));
		asgnRef((void**) (&(*(*s).typ).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), (*n).info));
		T56_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T56_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*s).typ, T56_, NIM_TRUE);
		T57_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T57_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*n).info, (*(*s).typ).sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg((*(*s).typ).n, T57_);
	}
	LA35_: ;
	{
		if (!allUntyped) goto LA60_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9)) & 63);
	}
	LA60_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA64_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semPattern__7YxUILpPxooC5qqa89a54dw_9(c, (*n)._kind_6.sons->data[((NI) 1)]));
	}
	LA64_: ;
	nimZeroMem((void*)(&ctx), sizeof(tyObject_TemplCtx__nh9bf8hW4pDvkirLeE4rmdw));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toBind));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toMixin));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ctx.toInject));
	ctx.c = c;
	ctx.owner = s;
	{
		if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0)) goto LA68_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), semTemplBodyDirty__DuioLh4uofptxEKissr2sw_3((&ctx), (*n)._kind_6.sons->data[((NI) 6)]));
	}
	goto LA66_;
	LA68_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 6)]), semTemplBody__DuioLh4uofptxEKissr2sw_4((&ctx), (*n)._kind_6.sons->data[((NI) 6)]));
	}
	LA66_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	asgnRef((void**) (&(*s).ast), n);
	result = n;
	{
		if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0)) goto LA73_;
		{
			NimStringDesc* T79_;
			if (!!(((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA77_;
			T79_ = (NimStringDesc*)0;
			T79_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_201), (*(*s).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 6)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T79_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_619, NIM_FALSE);
		}
		LA77_: ;
	}
	goto LA71_;
	LA73_: ;
	{
		NimStringDesc* T83_;
		if (!((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA81_;
		T83_ = (NimStringDesc*)0;
		T83_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*s).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T83_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_620, NIM_FALSE);
	}
	goto LA71_;
	LA81_: ;
	LA71_: ;
	nimZeroMem((void*)(&T84_), sizeof(tyTuple__jdFwpivBCgGar3GHRE8kKQ));
	searchForProc__onRsQxI12p1JaTFcIxF6cA(c, (*c).currentScope, s, (&T84_));
	proto = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	proto = T84_.Field0;
	comesFromShadowscope = (NIM_BOOL)0;
	comesFromShadowscope = T84_.Field1;
	{
		if (!(proto == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA87_;
		addInterfaceOverloadableSymAt__HcojHyPBYsbchSQtmBqThg(c, (*c).currentScope, s);
	}
	goto LA85_;
	LA87_: ;
	{
		if (!!(comesFromShadowscope)) goto LA90_;
		symTabReplace__mq4tDXMjV9aoOV0jJhDFqKA((&(*(*c).currentScope).symbols), proto, s);
	}
	goto LA85_;
	LA90_: ;
	LA85_: ;
	{
		NI T96_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA94_;
		asgnRef((void**) (&(*c).patterns), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).patterns), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
		T96_ = (*c).patterns->Sup.len++;
		asgnRef((void**) (&(*c).patterns->data[T96_]), s);
	}
	LA94_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semQuoteAst__7YxUILpPxooC5qqa89a54dw_36)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* quotedBlock;
	NI T9_;
	NimStringDesc* op;
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* quotes;
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* ids;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T20_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dummyTemplate;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T21_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tmpl;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* identNodeSym;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* identNode;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T41_;
	tyArray__AB6yfoUgfWM2NtGe9bzkCmw T42_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T43_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T4_ == ((NI) 2)));
		if (!(T3_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T6_ == ((NI) 3)));
		LA5_: ;
		if (!T3_) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_603), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_604, NIM_FALSE);
		result = n;
		goto BeforeRet_;
	}
	LA7_: ;
	T9_ = (NI)0;
	T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	quotedBlock = (*n)._kind_6.sons->data[(NI)(T9_ - ((NI) 1))];
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T12_ == ((NI) 3))) goto LA13_;
		op = expectString__zUJc3JNayUkQ8i11jOQJeQ_2(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA10_;
	LA13_: ;
	{
		op = copyString(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_606));
	}
	LA10_: ;
	quotes = newSeq__rWQEUE6RvOVfamepP2TwPw(((NI) 2));
	ids = newSeq__rWQEUE6RvOVfamepP2TwPw(((NI) 1));
	{
		if (!!(((*quotedBlock).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115)))) goto LA18_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_607), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_608, NIM_FALSE);
	}
	LA18_: ;
	T20_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T20_ = newAnonSym__w5lZcsHUDOEnXuinSWI8ww(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), (*n).info);
	asgnRef((void**) (&ids->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T20_));
	processQuotations__JHIMJhmDecu8Q5MfBu4NEQ(c, &quotedBlock, op, (&quotes), (&ids));
	T21_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T21_ = newAnonSym__w5lZcsHUDOEnXuinSWI8ww(c, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18), (*n).info);
	T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T22_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T21_);
	dummyTemplate = newProcNode__g5PEkYP0A0RT03uHbJ6wKQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83), (*quotedBlock).info, quotedBlock, (*(*c).graph).emptyNode, T22_, (*(*c).graph).emptyNode, (*(*c).graph).emptyNode, (*(*c).graph).emptyNode, (*(*c).graph).emptyNode);
	{
		NI T25_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T28_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T30_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
		NI T32_;
		NI T33_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T34_;
		T25_ = (ids ? ids->Sup.len : 0);
		if (!(((NI) 0) < T25_)) goto LA26_;
		asgnRef((void**) (&(*dummyTemplate)._kind_6.sons->data[((NI) 3)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), (*n).info));
		T28_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T28_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*c).graph, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_609));
		T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T29_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T28_);
		add__P8dDSotTW25BkfbyspojGg((*dummyTemplate)._kind_6.sons->data[((NI) 3)], T29_);
		T30_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T30_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*c).graph, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_609));
		T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T31_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T30_);
		ids = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)(ids), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
		T32_ = ids->Sup.len++;
		asgnRef((void**) (&ids->data[T32_]), T31_);
		ids = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)(ids), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
		T33_ = ids->Sup.len++;
		asgnRef((void**) (&ids->data[T33_]), (*(*c).graph).emptyNode);
		T34_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T34_ = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*n).info, ids->data, (ids ? ids->Sup.len : 0));
		add__P8dDSotTW25BkfbyspojGg((*dummyTemplate)._kind_6.sons->data[((NI) 3)], T34_);
	}
	LA26_: ;
	tmpl = semTemplateDef__7YxUILpPxooC5qqa89a54dw_37(c, dummyTemplate);
	asgnRef((void**) (&quotes->data[((NI) 0)]), (*tmpl)._kind_6.sons->data[((NI) 0)]);
	identNodeSym = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*c).graph, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_621));
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T39_;
		if (!(identNodeSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA37_;
		T39_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T39_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_621));
		identNode = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T39_, (*n).info);
	}
	goto LA35_;
	LA37_: ;
	{
		identNode = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(identNodeSym);
	}
	LA35_: ;
	nimZeroMem((void*)T41_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T41_[0] = identNode;
	T41_[1] = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_96));
	asgnRef((void**) (&quotes->data[((NI) 1)]), newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T41_, 2));
	nimZeroMem((void*)T42_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
	T43_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T43_ = createMagic__MzNJxZ0htpjW89c9b2wBN5rQ((*c).graph, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_622), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 27));
	T42_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T43_);
	T42_[1] = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, quotes->data, (quotes ? quotes->Sup.len : 0));
	result = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, T42_, 2);
	result = semExpandToAst__7YxUILpPxooC5qqa89a54dw_35(c, result);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createFlowVar__FNAdkkRAZAzuZfvQrY8ffg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9), (*c).module);
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*c).graph, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_625));
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, (*T1_).typ);
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, t);
	result = instGenericContainer__sJO8n9aXqgecj24tOSPjmow(c, info, result, NIM_FALSE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, instantiateCreateFlowVarCall__xO2UfktRDKCUWUorFz9cLYA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
	tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q bindings;
	tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T5_;
	RootObj* T6_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	sym = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*c).graph, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_626));
	{
		if (!(sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_627), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_628, NIM_FALSE);
	}
	LA3_: ;
	nimZeroMem((void*)(&bindings), sizeof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q));
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&bindings));
	T5_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
	T5_ = &(*(*(*(*sym).ast)._kind_6.sons->data[((NI) 2)])._kind_6.sons->data[((NI) 0)]).typ->Sup;
	T6_ = (RootObj*)0;
	T6_ = &t->Sup.Sup;
	idTablePut__anELyz7VLsjbCIoxLpxbfQ((&bindings), T5_, T6_);
	result = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, sym, bindings, info, (*c).semGenerateInstance.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_629)((*c).semGenerateInstance.ClP_0))(c, sym, bindings, info);
	{
		if (!(((*result).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 18))&63U)))!=0)) goto LA9_;
		(*result).flags = ((*result).flags & ~ 262336);
		asgnRef((void**) (&(*result).loc.r), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSizeof__7YxUILpPxooC5qqa89a54dw_38)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* configX60gensym4800_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodeX60gensym4800_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym4800_;
	NI64 sizeX60gensym4800_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		NimStringDesc* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T3_ == ((NI) 2)))) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_313), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_630));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_631, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 256));
	}
	LA1_: ;
	asgnRef((void**) (&(*n).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
	configX60gensym4800_ = (*(*c).graph).config;
	nodeX60gensym4800_ = n;
	typX60gensym4800_ = (*(*nodeX60gensym4800_)._kind_6.sons->data[((NI) 1)]).typ;
	computeSizeAlign__Nur2IEN9ayDXYT9aVdBUPsYQ(configX60gensym4800_, typX60gensym4800_);
	sizeX60gensym4800_ = (*typX60gensym4800_).size;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* resX60gensym4800_;
		if (!(IL64(0) <= sizeX60gensym4800_)) goto LA10_;
		resX60gensym4800_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), sizeX60gensym4800_);
		(*resX60gensym4800_).info = (*nodeX60gensym4800_).info;
		asgnRef((void**) (&(*resX60gensym4800_).typ), (*nodeX60gensym4800_).typ);
		result = resX60gensym4800_;
	}
	goto LA8_;
	LA10_: ;
	{
		result = n;
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMagic__NYxU2DkHA0Gt5fsL9bYZdog_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*s).magic) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 16):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*(*n)._kind_6.sons->data[((NI) 0)]).info));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semAddrArg__kiPmghV1gaPm718CtGyhQw(c, (*n)._kind_6.sons->data[((NI) 1)], eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_227))));
		asgnRef((void**) (&(*result).typ), makePtrType__PDWeh9cjpi22xXdNggYvsWA(c, (*(*result)._kind_6.sons->data[((NI) 1)]).typ));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = semTypeOf__7YxUILpPxooC5qqa89a54dw_15(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 1):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T4_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T4_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T4_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semDefined__7YxUILpPxooC5qqa89a54dw_34(c, T4_);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 2):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semDeclared__ssxiU9aPj4i6xXfLbEm3Reg(c, T6_, NIM_FALSE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 3):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semDeclared__ssxiU9aPj4i6xXfLbEm3Reg(c, T8_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 4):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T10_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semCompiles__vJZwz9bfROKrfrtM50y74CQ_16(c, T10_, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 14):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T12_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semIs__vJZwz9bfROKrfrtM50y74CQ_18(c, T12_, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 21):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = semShallowCopy__vJZwz9bfROKrfrtM50y74CQ_11(c, n, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 27):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = semExpandToAst__QP3kds6GlqvnvsFXvC0yvw(c, n, s, flags);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 28):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = semQuoteAst__7YxUILpPxooC5qqa89a54dw_36(c, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 140):
	{
		NimStringDesc* T17_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		T17_ = (NimStringDesc*)0;
		T17_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*n)._kind_6.sons->data[((NI) 1)], 4);
		result = newStrNodeT__9cl7myBS6dfbP30fsccozTQ(T17_, n, (*c).graph);
		asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 141):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		{
			if (!!((((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 3))&15U)))!=0))) goto LA21_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_623), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_624, NIM_FALSE);
		}
		LA21_: ;
		result = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		x = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		{
			if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52))) goto LA25_;
			x = (*x)._kind_6.sons->data[((NI) 6)];
		}
		LA25_: ;
		(*c).inParallelStmt += ((NI) 1);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, x, 0));
		(*c).inParallelStmt -= ((NI) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 194):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		NI T31_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA30;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[i], 0));
					i_2 += ((NI) 1);
				} LA30: ;
			}
		}
		T31_ = (NI)0;
		T31_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		typ = (*(*result)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))]).typ;
		{
			NIM_BOOL T34_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T43_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
			T34_ = (NIM_BOOL)0;
			T34_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(typ);
			if (!!(T34_)) goto LA35_;
			{
				tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw T39_;
				T39_ = (tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw)0;
				T39_ = spawnResult__115WOpmSjJFT089amuDIXdA(typ, (((NI) 0) < (*c).inParallelStmt));
				if (!(T39_ == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 1))) goto LA40_;
				asgnRef((void**) (&(*result).typ), createFlowVar__FNAdkkRAZAzuZfvQrY8ffg(c, typ, (*n).info));
			}
			goto LA37_;
			LA40_: ;
			{
				asgnRef((void**) (&(*result).typ), typ);
			}
			LA37_: ;
			T43_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T43_ = instantiateCreateFlowVarCall__xO2UfktRDKCUWUorFz9cLYA_2(c, typ, (*n).info);
			T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T44_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T43_);
			add__P8dDSotTW25BkfbyspojGg(result, T44_);
		}
		goto LA32_;
		LA35_: ;
		{
			add__P8dDSotTW25BkfbyspojGg(result, (*(*c).graph).emptyNode);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 199):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		result = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 1)], 0));
		asgnRef((void**) (&(*result).typ), (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 19):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		nOrig = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
		result = semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA(c, n, nOrig, flags);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA50_;
			result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		}
		goto LA48_;
		LA50_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee;
			callee = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			{
				if (!((*callee).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA55_;
				semFinishOperands__wb6KhAx6bZ5NV37kY4bXJw_3(c, result);
			}
			LA55_: ;
			activate__NRIJDWZtATzMum7OEjYC2g_5(c, result);
			fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6(c, result);
			analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7(c, result);
			{
				if (!!(((*callee).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)))) goto LA59_;
				result = magicsAfterOverloadResolution__vJZwz9bfROKrfrtM50y74CQ_7(c, result, flags);
			}
			LA59_: ;
		}
		LA48_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 263):
	{
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		{
			NIM_BOOL T64_;
			NIM_BOOL T65_;
			NI T67_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T69_;
			T64_ = (NIM_BOOL)0;
			T65_ = (NIM_BOOL)0;
			T65_ = ((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 8));
			if (!(T65_)) goto LA66_;
			T67_ = (NI)0;
			T67_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T65_ = (((NI) 2) <= T67_);
			LA66_: ;
			T64_ = T65_;
			if (!(T64_)) goto LA68_;
			T69_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T69_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			T64_ = ((*T69_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
			LA68_: ;
			if (!T64_) goto LA70_;
			result = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		}
		goto LA62_;
		LA70_: ;
		{
			result = (*(*c).graph).emptyNode;
		}
		LA62_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 10):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T74_;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
		T74_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T74_ = setMs__YdV8xmi8UjdS8ox7bsgtGw(n, s);
		result = semSizeof__7YxUILpPxooC5qqa89a54dw_38(c, T74_);
	}
	break;
	default:
	{
		result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
	}
	break;
	}
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65), (*n).info, (*(*n).typ).sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, bracketedMacro__B9cQwIphxB9aXLurrc1x2XhQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		NI T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (((NI) 1) <= T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA5_: ;
		if (!T3_) goto LA6_;
		result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!!(((393216 &((NU32)1<<((NU)((*result).kind)&31U)))!=0))) goto LA10_;
			result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		}
		LA10_: ;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setGenericParams__NRIJDWZtATzMum7OEjYC2g_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[i], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, resolveIndirectCall__Ue9bfKSqSYcEhUFt1R9cJKjw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initCandidate__GPx9buyQn9cq0nARN4Amyarw(c, Result, t);
	matches__BxEsf1Gt7Hq3usrwPERzyA_2(c, n, nOrig, Result);
	{
		if (!!(((*Result).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 0))&15U)))!=0);
			if (!(T7_)) goto LA8_;
			T7_ = canDeref__crbaOhZgTohCnKAdtWPkSQ_2sem(n);
			LA8_: ;
			if (!T7_) goto LA9_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), tryDeref__wWBimsBS4M6UZBvTRDlQTQ_2((*n)._kind_6.sons->data[((NI) 1)]));
			initCandidate__GPx9buyQn9cq0nARN4Amyarw(c, Result, t);
			matches__BxEsf1Gt7Hq3usrwPERzyA_2(c, n, nOrig, Result);
		}
		LA9_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, overloadedCallOpr__7YxUILpPxooC5qqa89a54dw_39)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* par;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	par = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_198));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T3_;
		T3_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T3_ = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, par);
		if (!(T3_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA4_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T7_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(par, (*n).info);
		add__P8dDSotTW25BkfbyspojGg(result, T7_);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIndirectOp__vJZwz9bfROKrfrtM50y74CQ_20)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prc;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
	prc = (*n)._kind_6.sons->data[((NI) 0)];
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n0;
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA3_;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw((*n)._kind_6.sons->data[((NI) 0)], ((NI) 2), (*(*c).graph).config);
		n0 = semFieldAccess__vJZwz9bfROKrfrtM50y74CQ_14(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
		{
			if (!((*n0).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 25))) goto LA7_;
			result = n0;
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 27));
			(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 11)) & 31);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA11;
						i = i_2;
						add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA11: ;
				}
			}
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, flags);
			goto BeforeRet_;
		}
		goto LA5_;
		LA7_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), n0);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], 32768));
		t = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T16_)) goto LA17_;
			T16_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
			LA17_: ;
			if (!T16_) goto LA18_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings((*n)._kind_6.sons->data[((NI) 0)]));
		}
		goto LA14_;
		LA18_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42))) goto LA21_;
			s = bracketedMacro__B9cQwIphxB9aXLurrc1x2XhQ((*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA25_;
				setGenericParams__NRIJDWZtATzMum7OEjYC2g_11(c, (*n)._kind_6.sons->data[((NI) 0)]);
				result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
				goto BeforeRet_;
			}
			LA25_: ;
		}
		goto LA14_;
		LA21_: ;
		LA14_: ;
	}
	LA1_: ;
	nOrig = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(n);
	semOpAux__NRIJDWZtATzMum7OEjYC2g_3(c, n);
	t_2 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA29_;
		t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135265296));
	}
	LA29_: ;
	{
		NIM_BOOL T33_;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
		T33_ = (NIM_BOOL)0;
		T33_ = !((t_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T33_)) goto LA34_;
		T33_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		LA34_: ;
		if (!T33_) goto LA35_;
		nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		resolveIndirectCall__Ue9bfKSqSYcEhUFt1R9cJKjw(c, n, nOrig, t_2, (&m));
		{
			if (!!((m.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA39_;
			{
				if (!((*(*(*c).graph).config).m.errorOutputs == 0)) goto LA43_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_29), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__rF9caJawfOjYTjsgLVUSGFA_632, NIM_FALSE);
				result = (*(*c).graph).emptyNode;
				goto BeforeRet_;
			}
			goto LA41_;
			LA43_: ;
			{
				NIM_BOOL hasErrorType;
				NimStringDesc* msg;
				hasErrorType = NIM_FALSE;
				msg = copyString(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_273));
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_4 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* nt;
							NimStringDesc* T53_;
							if (!(i_4 < colontmp__2)) goto LA48;
							i_3 = i_4;
							{
								if (!(((NI) 1) < i_3)) goto LA51_;
								msg = resizeString(msg, 2);
appendString(msg, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_68));
							}
							LA51_: ;
							nt = (*(*n)._kind_6.sons->data[i_3]).typ;
							T53_ = (NimStringDesc*)0;
							T53_ = typeToString__QlvraUan7WbHowhAbvDvdA(nt, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
							msg = resizeString(msg, (T53_ ? T53_->Sup.len : 0) + 0);
appendString(msg, T53_);
							{
								if (!((*nt).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50))) goto LA56_;
								hasErrorType = NIM_TRUE;
								goto LA46;
							}
							LA56_: ;
							i_4 += ((NI) 1);
						} LA48: ;
					}
				} LA46: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					NimStringDesc* T62_;
					NimStringDesc* T63_;
					if (!!(hasErrorType)) goto LA60_;
					typ = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
					T62_ = (NimStringDesc*)0;
					T63_ = (NimStringDesc*)0;
					T63_ = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T62_ = rawNewString((T63_ ? T63_->Sup.len : 0) + 24);
appendString(T62_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_633));
appendString(T62_, T63_);
					msg = resizeString(msg, (T62_ ? T62_->Sup.len : 0) + 0);
appendString(msg, T62_);
					{
						NIM_BOOL T66_;
						NIM_BOOL T67_;
						NimStringDesc* T72_;
						NimStringDesc* T73_;
						T66_ = (NIM_BOOL)0;
						T67_ = (NIM_BOOL)0;
						T67_ = !(((*typ).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T67_)) goto LA68_;
						T67_ = !((((*(*typ).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0));
						LA68_: ;
						T66_ = T67_;
						if (!(T66_)) goto LA69_;
						T66_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
						LA69_: ;
						if (!T66_) goto LA70_;
						T72_ = (NimStringDesc*)0;
						T73_ = (NimStringDesc*)0;
						T73_ = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
						T72_ = rawNewString((T73_ ? T73_->Sup.len : 0) + 3);
appendString(T72_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_634));
appendString(T72_, T73_);
						msg = resizeString(msg, (T72_ ? T72_->Sup.len : 0) + 0);
appendString(msg, T72_);
					}
					LA70_: ;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), msg, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_635, NIM_FALSE);
				}
				LA60_: ;
				result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
				goto BeforeRet_;
			}
			LA41_: ;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		goto LA37_;
		LA39_: ;
		{
			result = m.call;
			instGenericConvertersSons__DyVfh0xLvP9cQgsc36rPgEA(c, result, (&m));
		}
		LA37_: ;
	}
	goto LA31_;
	LA35_: ;
	{
		NIM_BOOL T76_;
		T76_ = (NIM_BOOL)0;
		T76_ = !((t_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T76_)) goto LA77_;
		T76_ = ((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		LA77_: ;
		if (!T76_) goto LA78_;
		{
			NI T82_;
			T82_ = (NI)0;
			T82_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T82_ == ((NI) 1))) goto LA83_;
			result = semObjConstr__vJZwz9bfROKrfrtM50y74CQ_15(c, n, flags);
			goto BeforeRet_;
		}
		LA83_: ;
		result = semConv__7YxUILpPxooC5qqa89a54dw_32(c, n);
		goto BeforeRet_;
	}
	goto LA31_;
	LA78_: ;
	{
		result = overloadedCallOpr__7YxUILpPxooC5qqa89a54dw_39(c, n);
		{
			if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA88_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), prc);
			asgnRef((void**) (&(*nOrig)._kind_6.sons->data[((NI) 0)]), prc);
			(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 12)) & 31);
			result = semOverloadedCallAnalyseEffects__9b1JieByYAFP9bIuFhYqD8AA(c, n, nOrig, flags);
			{
				if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA92_;
				result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
				goto BeforeRet_;
			}
			LA92_: ;
		}
		goto LA86_;
		LA88_: ;
		{
			if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)))) goto LA95_;
			goto BeforeRet_;
		}
		goto LA86_;
		LA95_: ;
		LA86_: ;
	}
	LA31_: ;
	{
		if (!((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA99_;
		result = afterCallActions__Qn3T9bt6Cg4I7XaYRMg219aw(c, result, nOrig, flags);
	}
	goto LA97_;
	LA99_: ;
	{
		fixAbstractType__NRIJDWZtATzMum7OEjYC2g_6(c, result);
		analyseIfAddressTakenInCall__NRIJDWZtATzMum7OEjYC2g_7(c, result);
	}
	LA97_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldBeBracketExpr__OiccTa3ruRNl9anoSqZh2Sg_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
{	result = (NIM_BOOL)0;
	a = (*n)._kind_6.sons->data[((NI) 0)];
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA3_;
		b = (*a)._kind_6.sons->data[((NI) 0)];
		{
			if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA7_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA11;
						i = i_2;
						{
							NIM_BOOL T14_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* be;
							T14_ = (NIM_BOOL)0;
							T14_ = ((*(*b)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
							if (!(T14_)) goto LA15_;
							T14_ = ((*(*(*b)._kind_6.sons->data[i])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5));
							LA15_: ;
							if (!T14_) goto LA16_;
							be = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), (*n).info);
							{
								NI i_3;
								NI colontmp__2;
								NI i_4;
								i_3 = (NI)0;
								colontmp__2 = (NI)0;
								colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(a);
								i_4 = ((NI) 1);
								{
									while (1) {
										if (!(i_4 < colontmp__2)) goto LA20;
										i_3 = i_4;
										add__P8dDSotTW25BkfbyspojGg(be, (*a)._kind_6.sons->data[i_3]);
										i_4 += ((NI) 1);
									} LA20: ;
								}
							}
							asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), be);
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA16_: ;
						i_2 += ((NI) 1);
					} LA11: ;
				}
			}
		}
		LA7_: ;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, hoistParamsUsedInDefault__sVX3UeeBXUbUHp9a9cEcpxCw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** letSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** defExpr) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI paramPos;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*defExpr)).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*(*defExpr))._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((*(*(*defExpr))._kind_4.sym).owner == (*(*(*call))._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		LA6_: ;
		if (!T3_) goto LA7_;
		paramPos = (NI)((*(*(*defExpr))._kind_4.sym).position + ((NI) 1));
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* hoistedVarSym;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T13_;
			tyArray__T6RKPw8xfAeNaoei9aZGzXg T14_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
			if (!!(((*(*(*call))._kind_6.sons->data[paramPos]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA11_;
			T13_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T13_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_636));
			hoistedVarSym = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9), T13_, (*(*c).p).owner, (*(*letSection)).info, (*(*(*c).p).owner).options);
			asgnRef((void**) (&(*hoistedVarSym).typ), (*(*(*call))._kind_6.sons->data[paramPos]).typ);
			nimZeroMem((void*)T14_, sizeof(tyArray__T6RKPw8xfAeNaoei9aZGzXg));
			T14_[0] = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(hoistedVarSym);
			T14_[1] = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*(*letSection)).info);
			T14_[2] = (*(*call))._kind_6.sons->data[paramPos];
			T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T15_ = newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*(*letSection)).info, T14_, 3);
			add__P8dDSotTW25BkfbyspojGg((*letSection), T15_);
			asgnRef((void**) (&(*(*call))._kind_6.sons->data[paramPos]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(hoistedVarSym));
		}
		LA11_: ;
		unsureAsgnRef((void**) (&(*defExpr)), (*(*call))._kind_6.sons->data[paramPos]);
	}
	goto LA1_;
	LA7_: ;
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*defExpr));
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					hoistParamsUsedInDefault__sVX3UeeBXUbUHp9a9cEcpxCw(c, call, letSection, &(*(*defExpr))._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrayAccess__vJZwz9bfROKrfrtM50y74CQ_21)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semSubscript__vJZwz9bfROKrfrtM50y74CQ_9(c, n, flags);
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		T5_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T5_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_26));
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w(n, T5_);
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, T6_, 0);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg, checkPar__l5Y3wSn9c2wuzfpP3PtAptA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg result;
{	result = (tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 3);
	}
	goto LA1_;
	LA4_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T7_ == ((NI) 1))) goto LA8_;
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA12_;
			result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 2);
		}
		goto LA10_;
		LA12_: ;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA15_;
			result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 3);
		}
		goto LA10_;
		LA15_: ;
		{
			result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 1);
		}
		LA10_: ;
	}
	goto LA1_;
	LA8_: ;
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA21_;
			result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 2);
		}
		goto LA19_;
		LA21_: ;
		{
			result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 3);
		}
		LA19_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA26;
					i = i_2;
					{
						if (!(result == ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 2))) goto LA29_;
						{
							NIM_BOOL T33_;
							T33_ = (NIM_BOOL)0;
							T33_ = !(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)));
							if (T33_) goto LA34_;
							T33_ = !(((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53)));
							LA34_: ;
							if (!T33_) goto LA35_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_637), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_638, NIM_FALSE);
							result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 0);
							goto BeforeRet_;
						}
						LA35_: ;
					}
					goto LA27_;
					LA29_: ;
					{
						{
							if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA40_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_639), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_640, NIM_FALSE);
							result = ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 0);
							goto BeforeRet_;
						}
						LA40_: ;
					}
					LA27_: ;
					i_2 += ((NI) 1);
				} LA26: ;
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTuplePositionsConstr__vJZwz9bfROKrfrtM50y74CQ_23)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 160));
	typ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), c);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[i], (flags & 1024)));
				addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(typ, (*(*n)._kind_6.sons->data[i]).typ);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	asgnRef((void**) (&(*result).typ), typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTupleConstr__vJZwz9bfROKrfrtM50y74CQ_22)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tupexp;
	NIM_BOOL isTupleType;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	tupexp = semTuplePositionsConstr__vJZwz9bfROKrfrtM50y74CQ_23(c, n, flags);
	isTupleType = (NIM_BOOL)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(tupexp);
		if (!(((NI) 0) < T3_)) goto LA4_;
		isTupleType = ((*(*(*tupexp)._kind_6.sons->data[((NI) 0)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(tupexp);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					{
						if (!!((isTupleType == ((*(*(*tupexp)._kind_6.sons->data[i]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))))) goto LA11_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*tupexp)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_641), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_642, NIM_FALSE);
						result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		if (!isTupleType) goto LA15_;
		result = n;
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T17_, 256);
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, typ));
	}
	goto LA13_;
	LA15_: ;
	{
		result = tupexp;
	}
	LA13_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTupleFieldsConstr__vJZwz9bfROKrfrtM50y74CQ_24)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ids;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160), (*n).info);
	typ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18), c);
	asgnRef((void**) (&(*typ).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138), (*n).info));
	nimZeroMem((void*)(&ids), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&ids));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA6_;
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw((*n)._kind_6.sons->data[i], (*(*c).graph).config);
				}
				LA6_: ;
				id = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				{
					NIM_BOOL T10_;
					NimStringDesc* T13_;
					T10_ = (NIM_BOOL)0;
					T10_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&ids), (*id).Sup.id);
					if (!T10_) goto LA11_;
					T13_ = (NimStringDesc*)0;
					T13_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_584), (*id).s);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_643, NIM_FALSE);
				}
				LA11_: ;
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], (flags & 1024)));
				{
					if (!((*(*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA16_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_644), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_645, NIM_FALSE);
					asgnRef((void**) (&(*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
				}
				LA16_: ;
				f = newSymS__z0Xq7x7aKOzONyxr8mX73A_2(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], c);
				asgnRef((void**) (&(*f).typ), skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]).typ));
				(*f).position = i;
				rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(typ, (*f).typ, NIM_TRUE);
				T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T18_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f);
				add__P8dDSotTW25BkfbyspojGg((*typ).n, T18_);
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(f));
				add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[i]);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	asgnRef((void**) (&(*result).typ), typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semSetConstr__7YxUILpPxooC5qqa89a54dw_40)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39), (*n).info);
	asgnRef((void**) (&(*result).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19), c));
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*result).typ, T6_, NIM_TRUE);
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		typ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					{
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees((*n)._kind_6.sons->data[i]);
						if (!T13_) goto LA14_;
						checkSonsLen__EezdXeDvu4rB7fR84AJZgw((*n)._kind_6.sons->data[i], ((NI) 3), (*(*c).graph).config);
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], 0));
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 2)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 2)], 0));
						{
							if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA18_;
							typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]).typ, IL64(211106240956432));
						}
						LA18_: ;
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), (*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 2)]).typ);
					}
					goto LA11_;
					LA14_: ;
					{
						if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA21_;
						{
							if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA25_;
							typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).typ, IL64(211106240956432));
						}
						LA25_: ;
					}
					goto LA11_;
					LA21_: ;
					{
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[i], 0));
						{
							if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA30_;
							typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[i]).typ, IL64(211106240956432));
						}
						LA30_: ;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(typ, NIM_TRUE);
			if (!!(T34_)) goto LA35_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_302), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_646, NIM_FALSE);
			typ = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), IL64(65535), (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		}
		goto LA32_;
		LA35_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T38_;
			NIM_BOOL T39_;
			T38_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*c).graph).config, typ);
			T39_ = (NIM_BOOL)0;
			T39_ = lt___xL5gyZrjbGMarSdRAXOo9ag_3(IL64(65536), T38_);
			if (!T39_) goto LA40_;
			typ = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), IL64(65535), (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		}
		goto LA32_;
		LA40_: ;
		LA32_: ;
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ((*result).typ, typ);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
					tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
					if (!(i_4 < colontmp__2)) goto LA44;
					i_3 = i_4;
					m = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					info = (*(*n)._kind_6.sons->data[i_3]).info;
					{
						NIM_BOOL T47_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T50_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T51_;
						T47_ = (NIM_BOOL)0;
						T47_ = isRange__ZcP19cH3pVINjK9ckLU2rBeQtrees((*n)._kind_6.sons->data[i_3]);
						if (!T47_) goto LA48_;
						m = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), info);
						T50_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T50_ = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 1)], info);
						add__P8dDSotTW25BkfbyspojGg(m, T50_);
						T51_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T51_ = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 2)], info);
						add__P8dDSotTW25BkfbyspojGg(m, T51_);
					}
					goto LA45_;
					LA48_: ;
					{
						if (!((*(*n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA53_;
						m = (*n)._kind_6.sons->data[i_3];
					}
					goto LA45_;
					LA53_: ;
					{
						m = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*n)._kind_6.sons->data[i_3], info);
					}
					LA45_: ;
					add__P8dDSotTW25BkfbyspojGg(result, m);
					i_4 += ((NI) 1);
				} LA44: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semArrayConstr__vJZwz9bfROKrfrtM50y74CQ_25)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA firstIndex;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA lastIndex;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* indexType;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA lastValidIndex;
	NI64 T55_;
	NI64 T56_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*n).info);
	asgnRef((void**) (&(*result).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), c));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*result).typ, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), NIM_TRUE);
	nimZeroMem((void*)(&firstIndex), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
	nimZeroMem((void*)(&lastIndex), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
	indexType = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	lastValidIndex = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, indexType);
	{
		NI T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*result).typ, T6_, NIM_TRUE);
		lastIndex = toInt128__161i7kexvUAISxPtGBRWYw(((NI) -1));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* yy;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		x = (*n)._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T10_;
			NI T12_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
			if (!(T10_)) goto LA11_;
			T12_ = (NI)0;
			T12_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
			T10_ = (T12_ == ((NI) 2));
			LA11_: ;
			if (!T10_) goto LA13_;
			idx = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*x)._kind_6.sons->data[((NI) 0)]);
			{
				NIM_BOOL T17_;
				NimStringDesc* T20_;
				NimStringDesc* T21_;
				NimStringDesc* T22_;
				T17_ = (NIM_BOOL)0;
				T17_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA((*idx).typ, NIM_FALSE);
				if (!!(T17_)) goto LA18_;
				T20_ = (NimStringDesc*)0;
				T21_ = (NimStringDesc*)0;
				T21_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(idx, 0);
				T22_ = (NimStringDesc*)0;
				T22_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_648), T21_);
				T20_ = rawNewString((T22_ ? T22_->Sup.len : 0) + 33);
appendString(T20_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_647));
appendString(T20_, T22_);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*idx).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_649, NIM_FALSE);
			}
			goto LA15_;
			LA18_: ;
			{
				firstIndex = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(idx, Max__zlJMNfqX7LwCYj0PF6ncWQ);
				lastIndex = firstIndex;
				indexType = (*idx).typ;
				lastValidIndex = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, indexType);
				x = (*x)._kind_6.sons->data[((NI) 1)];
			}
			LA15_: ;
		}
		LA13_: ;
		yy = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, x, 0);
		typ = (*yy).typ;
		add__P8dDSotTW25BkfbyspojGg(result, yy);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xx;
					if (!(i_2 < colontmp_)) goto LA26;
					i = i_2;
					{
						NIM_BOOL T29_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* validIndex;
						NI64 T32_;
						NI64 T33_;
						NimStringDesc* T34_;
						tyArray__Re75IspeoxXy2oCZHwcRrA T35_;
						NI T36_;
						NimStringDesc* T37_;
						T29_ = (NIM_BOOL)0;
						T29_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(lastIndex, lastValidIndex);
						if (!T29_) goto LA30_;
						T32_ = (NI64)0;
						T32_ = toInt64__1szweXXq3RBN50owrYu2Xw(firstIndex);
						T33_ = (NI64)0;
						T33_ = toInt64__1szweXXq3RBN50owrYu2Xw(lastValidIndex);
						validIndex = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, T32_, T33_, (*n).info, indexType);
						T34_ = (NimStringDesc*)0;
						nimZeroMem((void*)T35_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
						T35_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(validIndex, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
						T36_ = (NI)0;
						T36_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						T35_[1] = nimIntToStr((NI)(T36_ - i));
						T37_ = (NimStringDesc*)0;
						T37_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_651), T35_, 2);
						T34_ = rawNewString((T37_ ? T37_->Sup.len : 0) + 37);
appendString(T34_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_650));
appendString(T34_, T37_);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T34_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_652, NIM_FALSE);
					}
					LA30_: ;
					x = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T40_;
						NI T42_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* idx_2;
						T40_ = (NIM_BOOL)0;
						T40_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
						if (!(T40_)) goto LA41_;
						T42_ = (NI)0;
						T42_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
						T40_ = (T42_ == ((NI) 2));
						LA41_: ;
						if (!T40_) goto LA43_;
						idx_2 = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*x)._kind_6.sons->data[((NI) 0)]);
						idx_2 = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, indexType, idx_2, (*x).info);
						{
							tyObject_Int128__9a9axPfb75jdWY25AamJewkA T47_;
							tyObject_Int128__9a9axPfb75jdWY25AamJewkA T48_;
							NIM_BOOL T49_;
							T47_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(lastIndex, IL64(1));
							T48_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ(idx_2, Max__zlJMNfqX7LwCYj0PF6ncWQ);
							T49_ = (NIM_BOOL)0;
							T49_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T47_, T48_);
							if (!!(T49_)) goto LA50_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_653), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_654, NIM_FALSE);
						}
						LA50_: ;
						x = (*x)._kind_6.sons->data[((NI) 1)];
					}
					LA43_: ;
					xx = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, x, (flags & 1024));
					add__P8dDSotTW25BkfbyspojGg(result, xx);
					typ = commonType__hfwrZ5ThSx8sbABQFEwdHg(typ, (*xx).typ);
					inc__Glh2geFlMs9aE78UZ1JZGAA((&lastIndex), ((NU32) 1));
					i_2 += ((NI) 1);
				} LA26: ;
			}
		}
		addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ((*result).typ, typ);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(result);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA54;
					i_3 = i_4;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_3]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*result)._kind_6.sons->data[i_3], (*(*result)._kind_6.sons->data[i_3]).info));
					i_4 += ((NI) 1);
				} LA54: ;
			}
		}
	}
	LA1_: ;
	T55_ = (NI64)0;
	T55_ = toInt64__1szweXXq3RBN50owrYu2Xw(firstIndex);
	T56_ = (NI64)0;
	T56_ = toInt64__1szweXXq3RBN50owrYu2Xw(lastIndex);
	asgnRef((void**) (&(*(*result).typ).sons->data[((NI) 0)]), makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, T55_, T56_, (*n).info, indexType));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLambda__vJZwz9bfROKrfrtM50y74CQ_26)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T11_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* gp;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semProcAnnotation__Uz9bZ6N7ZeTxuwI9b9cYeOeYw(c, n, TM__rF9caJawfOjYTjsgLVUSGFA_655);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 7), (*(*c).graph).config);
	s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T9_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA7_;
		T9_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T9_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		s = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), (*(*c).cache).idAnon, T9_, (*n).info, 0);
		asgnRef((void**) (&(*s).ast), n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s));
	}
	goto LA5_;
	LA7_: ;
	{
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	}
	LA5_: ;
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
	T11_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T11_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	gp = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA14_;
		gp = setGenericParamsMisc__7YxUILpPxooC5qqa89a54dw_6(c, n);
	}
	goto LA12_;
	LA14_: ;
	{
		gp = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 75), (*n).info);
	}
	LA12_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 3)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA19_;
		semParamList__HJ2sXcKFjirzvqsZjMcpTg(c, (*n)._kind_6.sons->data[((NI) 3)], gp, s);
		{
			NIM_BOOL T23_;
			NI T24_;
			T23_ = (NIM_BOOL)0;
			T24_ = (NI)0;
			T24_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
			T23_ = (((NI) 0) < T24_);
			if (!(T23_)) goto LA25_;
			T23_ = ((*(*n)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA25_: ;
			if (!T23_) goto LA26_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 2)]), gp);
		}
		LA26_: ;
	}
	goto LA17_;
	LA19_: ;
	{
		asgnRef((void**) (&(*s).typ), newProcType__5gg5mq4XYRQKbAkdLMpzGA(c, (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	}
	LA17_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA31_;
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*n)._kind_6.sons->data[((NI) 4)], TM__rF9caJawfOjYTjsgLVUSGFA_655, NIM_FALSE);
	}
	LA31_: ;
	(*s).options = (*(*(*c).graph).config).options;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA35_;
		{
			NimStringDesc* T41_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0)) goto LA39_;
			T41_ = (NimStringDesc*)0;
			T41_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_201), (*(*s).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 6)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T41_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_656, NIM_FALSE);
		}
		LA39_: ;
		{
			NIM_BOOL T44_;
			NI T45_;
			NIM_BOOL T47_;
			NI T48_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T52_;
			T44_ = (NIM_BOOL)0;
			T45_ = (NI)0;
			T45_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
			T44_ = (T45_ == ((NI) 0));
			if (T44_) goto LA46_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NI)0;
			T48_ = len__P89cqdlERShb9alU3iC0yj8wast(gp);
			T47_ = (T48_ == ((NI) 1));
			if (!(T47_)) goto LA49_;
			T47_ = (((*(*(*gp)._kind_6.sons->data[((NI) 0)]).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 11))&63U)))!=0);
			LA49_: ;
			T44_ = T47_;
			LA46_: ;
			if (!T44_) goto LA50_;
			pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3(c, s);
			addResult__n01jThJgoOr9aRxjZW5y9c7g(c, n, (*(*s).typ).sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
			T52_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T52_ = semProcBody__7YxUILpPxooC5qqa89a54dw_5(c, (*n)._kind_6.sons->data[((NI) 6)]);
			asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 6)]), hloBody__7YxUILpPxooC5qqa89a54dw_10(c, T52_));
			trackProc__P9bJkIGwY9beKGfhhcBedbpg(c, s, (*(*s).ast)._kind_6.sons->data[((NI) 6)]);
			popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
		}
		goto LA42_;
		LA50_: ;
		{
			if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 12))&31U)))!=0))) goto LA54_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_657), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_658, NIM_FALSE);
		}
		goto LA42_;
		LA54_: ;
		LA42_: ;
		sideEffectsCheck__PSSiITp8zAUcZ8z1k5AMLA_3(c, s);
	}
	goto LA33_;
	LA35_: ;
	{
		NimStringDesc* T57_;
		T57_ = (NimStringDesc*)0;
		T57_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*s).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T57_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_659, NIM_FALSE);
	}
	LA33_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	asgnRef((void**) (&(*result).typ), (*s).typ);
	{
		if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA60_;
		asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
	}
	LA60_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCastable__4z4DAkBJVF6o4ot6RWH9cXw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dst, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src_2;
	tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
	NI64 dstSize;
	NI64 srcSize;
{	result = (NIM_BOOL)0;
	src_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(src, IL64(13510798882111488));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(dst, IL64(36134350135273744));
		if (!((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27))) goto LA4_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(src_2, IL64(36134350135273488));
		if (!((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA9_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA9_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(dst, IL64(36134350135273744));
		if (!((*T13_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51))) goto LA14_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA14_: ;
	conf = (*(*c).graph).config;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* d;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* s;
		if (!((48 &((NU16)1<<((NU)((*conf).selectedGC)&15U)))!=0)) goto LA18_;
		d = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(dst, IL64(36134350135273744));
		s = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(src_2, IL64(36134350135273744));
		{
			NIM_BOOL T22_;
			NIM_BOOL T23_;
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T22_ = (NIM_BOOL)0;
			T23_ = (NIM_BOOL)0;
			T23_ = ((*d).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22));
			if (!(T23_)) goto LA24_;
			T23_ = ((*s).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22));
			LA24_: ;
			T22_ = T23_;
			if (!(T22_)) goto LA25_;
			T26_ = (NIM_BOOL)0;
			T26_ = isFinal__YPjOkGV9axAnGR3UfLeWZ1g_5((*s).sons->data[((NI) 0)]);
			T27_ = (NIM_BOOL)0;
			T27_ = isFinal__YPjOkGV9axAnGR3UfLeWZ1g_5((*d).sons->data[((NI) 0)]);
			T22_ = !((T26_ == T27_));
			LA25_: ;
			if (!T22_) goto LA28_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
		LA28_: ;
	}
	LA18_: ;
	dstSize = (NI64)0;
	srcSize = (NI64)0;
	dstSize = computeSize__vCG1GF2Iu043oALVyuJfOw_3(conf, dst);
	srcSize = computeSize__vCG1GF2Iu043oALVyuJfOw_3(conf, src_2);
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = (dstSize == IL64(-3));
		if (T32_) goto LA33_;
		T32_ = (srcSize == IL64(-3));
		LA33_: ;
		if (!T32_) goto LA34_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA34_: ;
	{
		if (!(dstSize < IL64(0))) goto LA38_;
		result = NIM_FALSE;
	}
	goto LA36_;
	LA38_: ;
	{
		if (!(srcSize < IL64(0))) goto LA41_;
		result = NIM_FALSE;
	}
	goto LA36_;
	LA41_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T44_;
		T44_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T44_ = typeAllowed__M8lM58Zr3lmYhlOsJv89cVw(dst, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), c, 0);
		if (!!((T44_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA45_;
		result = NIM_FALSE;
	}
	goto LA36_;
	LA45_: ;
	{
		NIM_BOOL T48_;
		NIM_BOOL T52_;
		T48_ = (NIM_BOOL)0;
		T48_ = ((*dst).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		if (!(T48_)) goto LA49_;
		T48_ = ((*dst).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA49_: ;
		if (!T48_) goto LA50_;
		T52_ = (NIM_BOOL)0;
		T52_ = ((*src_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
		if (!(T52_)) goto LA53_;
		T52_ = ((*src_2).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA53_: ;
		result = T52_;
	}
	goto LA36_;
	LA50_: ;
	{
		NIM_BOOL T55_;
		NIM_BOOL T56_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T58_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
		T55_ = (NIM_BOOL)0;
		T56_ = (NIM_BOOL)0;
		T56_ = (srcSize <= dstSize);
		if (T56_) goto LA57_;
		T58_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T58_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(dst, IL64(36134350135273744));
		T56_ = ((IL64(35182224621574) &((NU64)1<<((NU)((*T58_).kind)&63U)))!=0);
		LA57_: ;
		T55_ = T56_;
		if (T55_) goto LA59_;
		T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T60_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(src_2, IL64(36134350135273488));
		T55_ = ((IL64(35182224621574) &((NU64)1<<((NU)((*T60_).kind)&63U)))!=0);
		LA59_: ;
		result = T55_;
	}
	LA36_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = result;
		if (!(T63_)) goto LA64_;
		T63_ = ((*src_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
		LA64_: ;
		if (!T63_) goto LA65_;
		result = ((*dst).size <= ((NI64) ((*conf).target.ptrSize)));
	}
	LA65_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCast__7YxUILpPxooC5qqa89a54dw_41)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetType;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castedExpr;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	targetType = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	castedExpr = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 1)], 0);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!(((*targetType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21))&63U)))!=0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = typeToString__QlvraUan7WbHowhAbvDvdA(targetType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_660), T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_661, NIM_FALSE);
	}
	LA3_: ;
	{
		NIM_BOOL T9_;
		NimStringDesc* tar;
		NimStringDesc* alt;
		NimStringDesc* msg;
		NimStringDesc* T18_;
		T9_ = (NIM_BOOL)0;
		T9_ = isCastable__4z4DAkBJVF6o4ot6RWH9cXw(c, targetType, (*castedExpr).typ);
		if (!!(T9_)) goto LA10_;
		tar = typeToString__QlvraUan7WbHowhAbvDvdA(targetType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		alt = typeToString__QlvraUan7WbHowhAbvDvdA(targetType, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
		{
			NimStringDesc* T16_;
			if (!!(eqStrings(tar, alt))) goto LA14_;
			T16_ = (NimStringDesc*)0;
			T16_ = rawNewString((tar ? tar->Sup.len : 0) + (alt ? alt->Sup.len : 0) + 1);
appendString(T16_, tar);
appendString(T16_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_163));
appendString(T16_, alt);
			msg = T16_;
		}
		goto LA12_;
		LA14_: ;
		{
			msg = tar;
		}
		LA12_: ;
		T18_ = (NimStringDesc*)0;
		T18_ = rawNewString((msg ? msg->Sup.len : 0) + 29);
appendString(T18_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_662));
appendString(T18_, msg);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T18_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_663, NIM_FALSE);
	}
	LA10_: ;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61), (*n).info);
	asgnRef((void**) (&(*result).typ), targetType);
	T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T19_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, T19_);
	add__P8dDSotTW25BkfbyspojGg(result, castedExpr);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, flags);
	{
		if (!!(((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		{
			if (!((IL64(140737496743936) &((NU64)1<<((NU)((*(*result).typ).kind)&63U)))!=0)) goto LA7_;
			result = newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings(result);
		}
		LA7_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	NIM_BOOL T6_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	result = (NIM_BOOL)0;
	it = n;
	{
		while (1) {
			NIM_BOOL T3_;
			NI T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
			if (!(T3_)) goto LA4_;
			T5_ = (NI)0;
			T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
			T3_ = (((NI) 0) < T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			it = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
		} LA2: ;
	}
	T6_ = (NIM_BOOL)0;
	T6_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111));
	if (T6_) goto LA7_;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T9_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	if (!(T9_)) goto LA10_;
	T9_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	LA10_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA11_;
	T8_ = (((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16))&63U)))!=0);
	LA11_: ;
	T6_ = T8_;
	LA7_: ;
	result = T6_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, commonType__wEK756YRi9c3lsyIxi9aFXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5(y);
		if (!T3_) goto LA4_;
		result = x;
		goto BeforeRet_;
	}
	LA4_: ;
	result = commonType__hfwrZ5ThSx8sbABQFEwdHg(x, (*y).typ);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28(c, n, 0);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIf__vJZwz9bfROKrfrtM50y74CQ_27)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	NIM_BOOL hasElse;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T1_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T1_).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6);
	typ = T1_;
	hasElse = NIM_FALSE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NI T7_;
					tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T10_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
					T7_ = (NI)0;
					T7_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!(T7_ == ((NI) 2))) goto LA8_;
					T10_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
					T10_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
					T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T11_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*it)._kind_6.sons->data[((NI) 0)], 0);
					asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 0)]), forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T11_));
					asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 1)]), semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28(c, (*it)._kind_6.sons->data[((NI) 1)], flags));
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*it)._kind_6.sons->data[((NI) 1)]);
					closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
				}
				goto LA5_;
				LA8_: ;
				{
					NI T13_;
					T13_ = (NI)0;
					T13_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!(T13_ == ((NI) 1))) goto LA14_;
					hasElse = NIM_TRUE;
					asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 0)]), semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42(c, (*it)._kind_6.sons->data[((NI) 0)]));
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*it)._kind_6.sons->data[((NI) 0)]);
				}
				goto LA5_;
				LA14_: ;
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(it, (*(*c).graph).config);
				}
				LA5_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NIM_BOOL T19_;
		NIM_BOOL T20_;
		NIM_BOOL T23_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NIM_BOOL)0;
		T20_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(typ);
		if (T20_) goto LA21_;
		T20_ = ((96 &((NU64)1<<((NU)((*typ).kind)&63U)))!=0);
		LA21_: ;
		T19_ = T20_;
		if (T19_) goto LA22_;
		T23_ = (NIM_BOOL)0;
		T23_ = !(hasElse);
		if (!(T23_)) goto LA24_;
		T23_ = !(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0));
		LA24_: ;
		T19_ = T23_;
		LA22_: ;
		if (!T19_) goto LA25_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_2;
			it_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_4 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
						if (!(i_4 < colontmp__2)) goto LA30;
						i_3 = i_4;
						it_2 = (*n)._kind_6.sons->data[i_3];
						T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T31_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it_2);
						discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, T31_, flags);
						i_4 += ((NI) 1);
					} LA30: ;
				}
			}
		}
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 92));
		{
			if (!(typ == (*c).enforceVoidContext)) goto LA34_;
			asgnRef((void**) (&(*result).typ), (*c).enforceVoidContext);
		}
		LA34_: ;
	}
	goto LA17_;
	LA25_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it_3;
			it_3 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_6 = ((NI) 0);
				{
					while (1) {
						NI j;
						NI T41_;
						if (!(i_6 < colontmp__3)) goto LA40;
						i_5 = i_6;
						it_3 = (*n)._kind_6.sons->data[i_5];
						T41_ = (NI)0;
						T41_ = len__P89cqdlERShb9alU3iC0yj8wast(it_3);
						j = (NI)(T41_ - ((NI) 1));
						{
							NIM_BOOL T44_;
							T44_ = (NIM_BOOL)0;
							T44_ = endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5((*it_3)._kind_6.sons->data[j]);
							if (!!(T44_)) goto LA45_;
							asgnRef((void**) (&(*it_3)._kind_6.sons->data[j]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*it_3)._kind_6.sons->data[j], (*(*it_3)._kind_6.sons->data[j]).info));
						}
						LA45_: ;
						i_6 += ((NI) 1);
					} LA40: ;
				}
			}
		}
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 48));
		asgnRef((void**) (&(*result).typ), typ);
	}
	LA17_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTableConstr__7YxUILpPxooC5qqa89a54dw_43)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI lastKey;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*n).info);
	lastKey = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				x = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T6_;
					NI T8_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pair_2;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
					if (!(T6_)) goto LA7_;
					T8_ = (NI)0;
					T8_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
					T6_ = (T8_ == ((NI) 2));
					LA7_: ;
					if (!T6_) goto LA9_;
					{
						NI j;
						NI i_3;
						j = (NI)0;
						i_3 = lastKey;
						{
							while (1) {
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pair;
								if (!(i_3 < i)) goto LA13;
								j = i_3;
								pair = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160), (*x).info);
								add__P8dDSotTW25BkfbyspojGg(pair, (*n)._kind_6.sons->data[j]);
								add__P8dDSotTW25BkfbyspojGg(pair, (*x)._kind_6.sons->data[((NI) 1)]);
								add__P8dDSotTW25BkfbyspojGg(result, pair);
								i_3 += ((NI) 1);
							} LA13: ;
						}
					}
					pair_2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160), (*x).info);
					add__P8dDSotTW25BkfbyspojGg(pair_2, (*x)._kind_6.sons->data[((NI) 0)]);
					add__P8dDSotTW25BkfbyspojGg(pair_2, (*x)._kind_6.sons->data[((NI) 1)]);
					add__P8dDSotTW25BkfbyspojGg(result, pair_2);
					lastKey = (NI)(i + ((NI) 1));
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI T16_;
		T16_ = (NI)0;
		T16_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((lastKey == T16_))) goto LA17_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	LA17_: ;
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBlock__vJZwz9bfROKrfrtM50y74CQ_29)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	(*(*c).p).nestedBlockCounter += ((NI) 1);
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA4_;
		labl = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22), (*n)._kind_6.sons->data[((NI) 0)], c);
		{
			if (!!((((*labl).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA8_;
			addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, labl);
		}
		goto LA6_;
		LA8_: ;
		{
			if (!((*labl).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA11_;
			asgnRef((void**) (&(*labl).owner), (*(*c).p).owner);
		}
		goto LA6_;
		LA11_: ;
		LA6_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(labl, (*(*n)._kind_6.sons->data[((NI) 0)]).info));
		suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, labl, &(*(*c).graph).usageSym, NIM_TRUE);
		{
			if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA15_;
			nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*labl).info, labl, (*labl).kind);
		}
		LA15_: ;
	}
	LA4_: ;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 1)], flags));
	asgnRef((void**) (&(*n).typ), (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!T19_) goto LA20_;
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 112));
	}
	goto LA17_;
	LA20_: ;
	{
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 127));
	}
	LA17_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	(*(*c).p).nestedBlockCounter -= ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, inferConceptStaticParam__C0PRtNs0w318DTgRD2xT9cg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* inferred, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res;
	typ = (*inferred).typ;
	res = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, n);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		NIM_BOOL T4_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T7_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		NimStringDesc* T9_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = base__PfgI9ap7WOnsRfFV4znQ27w(typ);
		T4_ = (NIM_BOOL)0;
		T4_ = sameType__3isNyHKb0U1OCnClmflXSg((*res).typ, T3_, 0);
		if (!!(T4_)) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T7_[0] = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(inferred, 0);
		T7_[1] = typeToString__QlvraUan7WbHowhAbvDvdA((*res).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = base__PfgI9ap7WOnsRfFV4znQ27w(typ);
		T7_[2] = typeToString__QlvraUan7WbHowhAbvDvdA(T8_, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T9_ = (NimStringDesc*)0;
		T9_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_665), T7_, 3);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_666, NIM_FALSE);
	}
	LA5_: ;
	asgnRef((void**) (&(*typ).n), res);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmtList__vJZwz9bfROKrfrtM50y74CQ_30)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL voidContext;
	NI last;
	NI T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 115));
	voidContext = NIM_FALSE;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	last = (NI)(T1_ - ((NI) 1));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* expr;
					expr = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[i], flags);
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), expr);
					{
						NIM_BOOL T8_;
						NIM_BOOL T9_;
						NIM_BOOL T12_;
						T8_ = (NIM_BOOL)0;
						T9_ = (NIM_BOOL)0;
						T9_ = !(((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
						if (!(T9_)) goto LA10_;
						T9_ = !(((*expr).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
						LA10_: ;
						T8_ = T9_;
						if (!(T8_)) goto LA11_;
						T12_ = (NIM_BOOL)0;
						T12_ = !((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 17))&31U)))!=0));
						if (T12_) goto LA13_;
						T12_ = !((i == last));
						LA13_: ;
						T8_ = T12_;
						LA11_: ;
						if (!T8_) goto LA14_;
						switch ((*(*expr).typ).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* verdict;
							{
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = ((*expr).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
								if (!(T20_)) goto LA21_;
								T20_ = ((*(*expr)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
								LA21_: ;
								T19_ = T20_;
								if (!(T19_)) goto LA22_;
								T19_ = eqStrings((*(*(*(*expr)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_664));
								LA22_: ;
								if (!T19_) goto LA23_;
								{
									NIM_BOOL T27_;
									T27_ = (NIM_BOOL)0;
									T27_ = isUnresolvedStatic__aVxWxXLmf103vwE8uZ9cXRw_3((*(*expr)._kind_6.sons->data[((NI) 1)]).typ);
									if (!T27_) goto LA28_;
									inferConceptStaticParam__C0PRtNs0w318DTgRD2xT9cg(c, (*expr)._kind_6.sons->data[((NI) 1)], (*expr)._kind_6.sons->data[((NI) 2)]);
									goto LA5;
								}
								goto LA25_;
								LA28_: ;
								{
									NIM_BOOL T31_;
									T31_ = (NIM_BOOL)0;
									T31_ = isUnresolvedStatic__aVxWxXLmf103vwE8uZ9cXRw_3((*(*expr)._kind_6.sons->data[((NI) 2)]).typ);
									if (!T31_) goto LA32_;
									inferConceptStaticParam__C0PRtNs0w318DTgRD2xT9cg(c, (*expr)._kind_6.sons->data[((NI) 2)], (*expr)._kind_6.sons->data[((NI) 1)]);
									goto LA5;
								}
								goto LA25_;
								LA32_: ;
								LA25_: ;
							}
							LA23_: ;
							verdict = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, (*n)._kind_6.sons->data[i]);
							{
								NIM_BOOL T36_;
								NIM_BOOL T37_;
								T36_ = (NIM_BOOL)0;
								T37_ = (NIM_BOOL)0;
								T37_ = (verdict == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
								if (T37_) goto LA38_;
								T37_ = !(((*verdict).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)));
								LA38_: ;
								T36_ = T37_;
								if (T36_) goto LA39_;
								T36_ = ((*verdict)._kind_1.intVal == IL64(0));
								LA39_: ;
								if (!T36_) goto LA40_;
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*result).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_667), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_668, NIM_FALSE);
							}
							LA40_: ;
						}
						break;
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
						{
							goto LA5;
						}
						break;
						default:
						{
						}
						break;
						}
					}
					LA14_: ;
					{
						if (!((*(*n)._kind_6.sons->data[i]).typ == (*c).enforceVoidContext)) goto LA46_;
						voidContext = NIM_TRUE;
						asgnRef((void**) (&(*n).typ), (*c).enforceVoidContext);
					}
					LA46_: ;
					{
						NIM_BOOL T50_;
						NIM_BOOL T52_;
						NI T53_;
						T50_ = (NIM_BOOL)0;
						T50_ = (i == last);
						if (!(T50_)) goto LA51_;
						T52_ = (NIM_BOOL)0;
						T53_ = (NI)0;
						T53_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						T52_ = (T53_ == ((NI) 1));
						if (T52_) goto LA54_;
						T52_ = !(((2052 & flags) == 0));
						LA54_: ;
						T50_ = T52_;
						LA51_: ;
						if (!T50_) goto LA55_;
						asgnRef((void**) (&(*n).typ), (*(*n)._kind_6.sons->data[i]).typ);
						{
							NIM_BOOL T59_;
							T59_ = (NIM_BOOL)0;
							T59_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
							if (!!(T59_)) goto LA60_;
							transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 126));
						}
						LA60_: ;
					}
					goto LA48_;
					LA55_: ;
					{
						NIM_BOOL T63_;
						T63_ = (NIM_BOOL)0;
						T63_ = !((i == last));
						if (T63_) goto LA64_;
						T63_ = voidContext;
						LA64_: ;
						if (!T63_) goto LA65_;
						discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, (*n)._kind_6.sons->data[i], flags);
					}
					goto LA48_;
					LA65_: ;
					{
						asgnRef((void**) (&(*n).typ), (*(*n)._kind_6.sons->data[i]).typ);
						{
							NIM_BOOL T70_;
							T70_ = (NIM_BOOL)0;
							T70_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
							if (!!(T70_)) goto LA71_;
							transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(n, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 126));
						}
						LA71_: ;
					}
					LA48_: ;
					{
						NIM_BOOL T75_;
						NIM_BOOL T77_;
						NIM_BOOL T78_;
						T75_ = (NIM_BOOL)0;
						T75_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111));
						if (T75_) goto LA76_;
						T77_ = (NIM_BOOL)0;
						T78_ = (NIM_BOOL)0;
						T78_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
						if (!(T78_)) goto LA79_;
						T78_ = ((*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						LA79_: ;
						T77_ = T78_;
						if (!(T77_)) goto LA80_;
						T77_ = (((*(*(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16))&63U)))!=0);
						LA80_: ;
						T75_ = T77_;
						LA76_: ;
						if (!T75_) goto LA81_;
						{
							NI j;
							NI colontmp__2;
							NI colontmp__3;
							NI i_3;
							j = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__2 = (NI)(i + ((NI) 1));
							colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
							i_3 = colontmp__2;
							{
								while (1) {
									if (!(i_3 < colontmp__3)) goto LA85;
									j = i_3;
									switch ((*(*n)._kind_6.sons->data[j]).kind) {
									case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
									case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
									case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
									case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
									case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 157):
									{
									}
									break;
									default:
									{
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[j]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 38), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_669, NIM_FALSE);
									}
									break;
									}
									i_3 += ((NI) 1);
								} LA85: ;
							}
						}
					}
					goto LA73_;
					LA81_: ;
					{
					}
					LA73_: ;
				} LA5: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	{
		NIM_BOOL T91_;
		NIM_BOOL T92_;
		NIM_BOOL T93_;
		NI T94_;
		T91_ = (NIM_BOOL)0;
		T92_ = (NIM_BOOL)0;
		T93_ = (NIM_BOOL)0;
		T94_ = (NI)0;
		T94_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		T93_ = (T94_ == ((NI) 1));
		if (!(T93_)) goto LA95_;
		T93_ = ((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL));
		LA95_: ;
		T92_ = T93_;
		if (!(T92_)) goto LA96_;
		T92_ = !((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 16))&31U)))!=0));
		LA96_: ;
		T91_ = T92_;
		if (!(T91_)) goto LA97_;
		T91_ = !(((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 105)));
		LA97_: ;
		if (!T91_) goto LA98_;
		result = (*result)._kind_6.sons->data[((NI) 0)];
	}
	LA98_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semRaise__7YxUILpPxooC5qqa89a54dw_44)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
		typ = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A(typ, (*(*c).graph).config);
			if (!!(T7_)) goto LA8_;
			typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(35184372090896));
			{
				if (!!(((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22)))) goto LA12_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_670), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_671, NIM_FALSE);
			}
			LA12_: ;
			{
				NIM_BOOL T16_;
				NI T17_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
				NIM_BOOL T20_;
				tyArray__nHXaesL0DJZHyVS07ARPRA T23_;
				NimStringDesc* T24_;
				T16_ = (NIM_BOOL)0;
				T17_ = (NI)0;
				T17_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
				T16_ = (((NI) 0) < T17_);
				if (!(T16_)) goto LA18_;
				T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T19_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
				T20_ = (NIM_BOOL)0;
				T20_ = isException__YPjOkGV9axAnGR3UfLeWZ1g_13(T19_);
				T16_ = !(T20_);
				LA18_: ;
				if (!T16_) goto LA21_;
				nimZeroMem((void*)T23_, sizeof(tyArray__nHXaesL0DJZHyVS07ARPRA));
				T23_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T24_ = (NimStringDesc*)0;
				T24_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_672), T23_, 1);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T24_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_673, NIM_FALSE);
			}
			LA21_: ;
		}
		LA8_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semLowerLetVarCustomPragma__YnGuZwNZgNND9bMHSc9cGxzQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	b = (*a)._kind_6.sons->data[((NI) 0)];
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nodePragma;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* userPragma;
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* clash;
		tyArray__cypz0nHJsd9cnKgpO7fP5hQ T42_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ret;
		if (!((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA3_;
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast((*b)._kind_6.sons->data[((NI) 1)]);
			if (!!((T7_ == ((NI) 1)))) goto LA8_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA8_: ;
		nodePragma = (*(*b)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)];
		{
			if (!!(((*nodePragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*nodePragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53)))) goto LA12_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA12_: ;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, nodePragma, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		userPragma = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).userPragmas, ident);
		{
			if (!!((userPragma == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA16_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA16_: ;
		w = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(nodePragma);
		{
			NIM_BOOL T20_;
			NIM_BOOL T21_;
			NIM_BOOL T22_;
			NIM_BOOL T25_;
			NIM_BOOL T28_;
			T20_ = (NIM_BOOL)0;
			T21_ = (NIM_BOOL)0;
			T22_ = (NIM_BOOL)0;
			T22_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99));
			if (!(T22_)) goto LA23_;
			T22_ = ((TM__rF9caJawfOjYTjsgLVUSGFA_109[(NU)(w)>>3] &(1U<<((NU)(w)&7U)))!=0);
			LA23_: ;
			T21_ = T22_;
			if (T21_) goto LA24_;
			T25_ = (NIM_BOOL)0;
			T25_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100));
			if (!(T25_)) goto LA26_;
			T25_ = ((TM__rF9caJawfOjYTjsgLVUSGFA_109[(NU)(w)>>3] &(1U<<((NU)(w)&7U)))!=0);
			LA26_: ;
			T21_ = T25_;
			LA24_: ;
			T20_ = T21_;
			if (T20_) goto LA27_;
			T28_ = (NIM_BOOL)0;
			T28_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101));
			if (!(T28_)) goto LA29_;
			T28_ = ((TM__rF9caJawfOjYTjsgLVUSGFA_110[(NU)(w)>>3] &(1U<<((NU)(w)&7U)))!=0);
			LA29_: ;
			T20_ = T28_;
			LA27_: ;
			if (!T20_) goto LA30_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA30_: ;
		sym = searchInScopes__Drn1sJCJSwUUo03qKJigUw(c, ident);
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			if (T34_) goto LA35_;
			T34_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0);
			LA35_: ;
			if (!T34_) goto LA36_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA36_: ;
		lhs = (*b)._kind_6.sons->data[((NI) 0)];
		clash = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*c).currentScope).symbols, (*lhs)._kind_5.ident);
		{
			if (!!((clash == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA40_;
			wrongRedefinition__m38oZS3DB39a2RtTLWidA5w(c, (*lhs).info, (*(*lhs)._kind_5.ident).s, (*clash).info);
		}
		LA40_: ;
		nimZeroMem((void*)T42_, sizeof(tyArray__cypz0nHJsd9cnKgpO7fP5hQ));
		result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T42_, 0);
		{
			NimStringDesc* T47_;
			if (!!(((*nodePragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*nodePragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53)))) goto LA45_;
			T47_ = (NimStringDesc*)0;
			T47_ = rawNewString((reprEnum((NI)(*nodePragma).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*nodePragma).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 66);
appendString(T47_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_674));
appendString(T47_, reprEnum((NI)(*nodePragma).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(T47_);
		}
		LA45_: ;
		add__P8dDSotTW25BkfbyspojGg(result, nodePragma);
		add__P8dDSotTW25BkfbyspojGg(result, lhs);
		{
			if (!!(((*(*a)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA50_;
			add__P8dDSotTW25BkfbyspojGg(result, (*a)._kind_6.sons->data[((NI) 1)]);
		}
		goto LA48_;
		LA50_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T53_;
			T53_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T53_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23), (*a).info, (*(*c).graph).sysTypes[(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5))- 0]);
			add__P8dDSotTW25BkfbyspojGg(result, T53_);
		}
		LA48_: ;
		add__P8dDSotTW25BkfbyspojGg(result, (*a)._kind_6.sons->data[((NI) 2)]);
		(*result).info = (*a).info;
		ret = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*a).info);
		add__P8dDSotTW25BkfbyspojGg(ret, result);
		result = semExprNoType__7YxUILpPxooC5qqa89a54dw_2(c, ret);
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasEmpty__7NKj1MHAV0sRlpGa31vf8w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		if (!((17367040 &((NU64)1<<((NU)((*typ).kind)&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = ((*T5_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA7_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** s;
			NI i;
			NI L;
			NI T10_;
			s = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i = ((NI) 0);
			T10_ = ((*typ).sons ? (*typ).sons->Sup.len : 0);
			L = T10_;
			{
				while (1) {
					NIM_BOOL T13_;
					if (!(i < L)) goto LA12;
					s = &(*typ).sons->data[i];
					T13_ = (NIM_BOOL)0;
					T13_ = result;
					if (T13_) goto LA14_;
					T13_ = hasEmpty__7NKj1MHAV0sRlpGa31vf8w((*s));
					LA14_: ;
					result = T13_;
					i += ((NI) 1);
				} LA12: ;
			}
		}
	}
	goto LA1_;
	LA7_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToVarSection__rATgbLzWCudr6icucCz5hA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* identDefs) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* value;
	NI T1_;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(identDefs);
	value = (*identDefs)._kind_6.sons->data[(NI)(T1_ - ((NI) 1))];
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* o;
		if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA4_;
		o = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(orig);
		add__P8dDSotTW25BkfbyspojGg(o, identDefs);
		add__P8dDSotTW25BkfbyspojGg(result, o);
	}
	goto LA2_;
	LA4_: ;
	{
		add__P8dDSotTW25BkfbyspojGg(result, identDefs);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillPartialObject__kJjN1gd8ISazJd7RmyND3A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	{
		NI T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* y;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 2))) goto LA4_;
		x = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
		y = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*x).typ, IL64(36275087638309136));
		{
			NIM_BOOL T8_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T12_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((*obj).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
			if (!(T8_)) goto LA9_;
			T8_ = (((*obj).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 16))&63U)))!=0);
			LA9_: ;
			if (!T8_) goto LA10_;
			T12_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T12_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, (*y).s);
			field = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T12_, (*obj).sym, (*(*n)._kind_6.sons->data[((NI) 1)]).info, 0);
			asgnRef((void**) (&(*field).typ), skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(typ));
			(*field).position = len__P89cqdlERShb9alU3iC0yj8wast((*obj).n);
			T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T13_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(field);
			add__P8dDSotTW25BkfbyspojGg((*obj).n, T13_);
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), makeDeref__wWBimsBS4M6UZBvTRDlQTQ(x));
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(field));
			asgnRef((void**) (&(*n).typ), (*field).typ);
		}
		goto LA6_;
		LA10_: ;
		{
			NimStringDesc* T15_;
			NimStringDesc* T16_;
			T15_ = (NimStringDesc*)0;
			T16_ = (NimStringDesc*)0;
			T16_ = typeToString__QlvraUan7WbHowhAbvDvdA(obj, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + 71);
appendString(T15_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_683));
appendString(T15_, T16_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_684, NIM_FALSE);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_685), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_686, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!eqStrings((*(*v).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_687))) goto LA3_;
		(*v).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36)) & 63);
		result = NIM_TRUE;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, findShadowedVar__X80n25ArIa9aG019bZhPbmzw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*(*c).currentScope).parent;
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* shadowed;
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA6_;
					goto LA1;
				}
				LA6_: ;
				shadowed = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*scope).symbols, (*v).name);
				{
					NIM_BOOL T10_;
					T10_ = (NIM_BOOL)0;
					T10_ = !((shadowed == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T10_)) goto LA11_;
					T10_ = ((2099976 &((NU32)1<<((NU)((*shadowed).kind)&31U)))!=0);
					LA11_: ;
					if (!T10_) goto LA12_;
					result = shadowed;
					goto BeforeRet_;
				}
				LA12_: ;
				current = (*current).parent;
			} LA3: ;
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setVarType__2vD75zhrXW5EMFzUU9a9cEUQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NimStringDesc* T8_;
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*v).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = sameTypeOrNil__3isNyHKb0U1OCnClmflXSg_2((*v).typ, typ, 0);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = (NimStringDesc*)0;
		T9_ = (NimStringDesc*)0;
		T9_ = typeToString__QlvraUan7WbHowhAbvDvdA((*v).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
		T10_ = (NimStringDesc*)0;
		T10_ = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 1));
		T8_ = rawNewString(((*(*v).name).s ? (*(*v).name).s->Sup.len : 0) + (T9_ ? T9_->Sup.len : 0) + (T10_ ? T10_->Sup.len : 0) + 82);
appendString(T8_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_691));
appendString(T8_, (*(*v).name).s);
appendString(T8_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_692));
appendString(T8_, T9_);
appendString(T8_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_693));
appendString(T8_, T10_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_694, NIM_FALSE);
	}
	LA6_: ;
	asgnRef((void**) (&(*v).typ), typ);
}
N_LIB_PRIVATE N_NIMCALL(void, defaultConstructionError__SDnpDS6VfoCU9aBUYR8UoFg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType;
	tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw constrCtx;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
	tyEnum_InitStatus__smZpQZ1Iq7YmllUO9aDjzwQ initResult;
	tyArray__Re75IspeoxXy2oCZHwcRrA T4_;
	NimStringDesc* T5_;
	objType = t;
	{
		while (1) {
			if (!!(((*objType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)))) goto LA2;
			objType = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(objType);
		} LA2: ;
	}
	nimZeroMem((void*)(&constrCtx), sizeof(tyObject_ObjConstrContext__9baThpYqCcrX9ahozMBSUCQw));
	T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T3_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38), info);
	initConstrContext__RYPHxM9aTf8uWaAnZ0rNc2A(objType, T3_, (&constrCtx));
	initResult = semConstructTypeAux__sAwB0gQrQ1keYlqxdq08bQ(c, (&constrCtx), 0);
	nimZeroMem((void*)T4_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T4_[0] = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
	T4_[1] = listSymbolNames__8Z1zCwaGnI7ov1q9bc6s4uQ(constrCtx.missingFields->data, (constrCtx.missingFields ? constrCtx.missingFields->Sup.len : 0));
	T5_ = (NimStringDesc*)0;
	T5_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_695), T4_, 2);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T5_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_696, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, checkNilable__L1S5GkGOJih9bnTgycxmzAQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((72 & (*v).flags) == 8);
		if (!(T3_)) goto LA4_;
		T3_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ((*v).typ);
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
			T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T9_ = astdef__PBkjYIaAGbtrZ8DiUArHcw(v);
			if (!(T9_ == 0)) goto LA10_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 34), (*(*v).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_697, NIM_FALSE);
		}
		goto LA7_;
		LA10_: ;
		{
			NIM_BOOL T13_;
			NIM_BOOL T14_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
			T13_ = (NIM_BOOL)0;
			T14_ = (NIM_BOOL)0;
			T14_ = (((*(*v).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
			if (!(T14_)) goto LA15_;
			T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T16_ = astdef__PBkjYIaAGbtrZ8DiUArHcw(v);
			T14_ = !(((*T16_).typ == 0));
			LA15_: ;
			T13_ = T14_;
			if (!(T13_)) goto LA17_;
			T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T18_ = astdef__PBkjYIaAGbtrZ8DiUArHcw(v);
			T13_ = !((((*(*T18_).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
			LA17_: ;
			if (!T13_) goto LA19_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 34), (*(*v).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_698, NIM_FALSE);
		}
		goto LA7_;
		LA19_: ;
		LA7_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semVarOrLet__9aaeuZC3SovMoEd6yN1pUdg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symkind) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ == ((NI) 1))) goto LA4_;
		result = semLowerLetVarCustomPragma__YnGuZwNZgNND9bMHSc9cGxzQ(c, (*n)._kind_6.sons->data[((NI) 0)], n);
		{
			if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA8_;
			goto BeforeRet_;
		}
		LA8_: ;
	}
	LA4_: ;
	b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA12;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg typFlags;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tup;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA16_;
						suggestStmt__wb6KhAx6bZ5NV37kY4bXJw_4(c, a);
					}
					LA16_: ;
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA20_;
						goto LA13;
					}
					LA20_: ;
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA24_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA24_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*c).graph).config);
					typ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
					{
						NI T28_;
						NI T31_;
						T28_ = (NI)0;
						T28_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!!(((*(*a)._kind_6.sons->data[(NI)(T28_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA29_;
						T31_ = (NI)0;
						T31_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[(NI)(T31_ - ((NI) 2))], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					}
					LA29_: ;
					nimZeroMem((void*)(&typFlags), sizeof(tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg));
					def = (*(*c).graph).emptyNode;
					{
						NI T34_;
						NI T37_;
						T34_ = (NI)0;
						T34_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!!(((*(*a)._kind_6.sons->data[(NI)(T34_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA35_;
						T37_ = (NI)0;
						T37_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						def = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*a)._kind_6.sons->data[(NI)(T37_ - ((NI) 1))], 1024);
						{
							NIM_BOOL T40_;
							T40_ = (NIM_BOOL)0;
							T40_ = ((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
							if (!(T40_)) goto LA41_;
							T40_ = ((393216 &((NU32)1<<((NU)((*(*def)._kind_4.sym).kind)&31U)))!=0);
							LA41_: ;
							if (!T40_) goto LA42_;
							typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 5)) & 7);
						}
						goto LA38_;
						LA42_: ;
						{
							NIM_BOOL T45_;
							T45_ = (NIM_BOOL)0;
							T45_ = ((*(*def).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
							if (!(T45_)) goto LA46_;
							T45_ = !(((*(*(*c).p).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
							LA46_: ;
							if (!T45_) goto LA47_;
							typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 6)) & 7);
						}
						goto LA38_;
						LA47_: ;
						LA38_: ;
						{
							if (!!((typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA51_;
							{
								NIM_BOOL T55_;
								T55_ = (NIM_BOOL)0;
								T55_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(typ);
								if (!T55_) goto LA56_;
								def = inferWithMetatype__2aIGqt1c0rX64kF16cP4Pw(c, typ, def, NIM_FALSE);
								typ = (*def).typ;
							}
							goto LA53_;
							LA56_: ;
							{
								def = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, def, (*def).info);
							}
							LA53_: ;
						}
						goto LA49_;
						LA51_: ;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
							T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T60_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*def).typ, IL64(1152991873351024640));
							typ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T60_);
							{
								NIM_BOOL T63_;
								T63_ = (NIM_BOOL)0;
								T63_ = ((IL64(13510798882111488) &((NU64)1<<((NU)((*typ).kind)&63U)))!=0);
								if (!(T63_)) goto LA64_;
								T63_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0);
								LA64_: ;
								if (!T63_) goto LA65_;
								typ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
							}
							LA65_: ;
							{
								NIM_BOOL T69_;
								NimStringDesc* T72_;
								NimStringDesc* T73_;
								T69_ = (NIM_BOOL)0;
								T69_ = hasEmpty__7NKj1MHAV0sRlpGa31vf8w(typ);
								if (!T69_) goto LA70_;
								T72_ = (NimStringDesc*)0;
								T72_ = toHumanStr__8clA3iQh1Lbc5cnapppbXQ((*typ).kind);
								T73_ = (NimStringDesc*)0;
								T73_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_675), T72_);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*def).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T73_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_676, NIM_FALSE);
							}
							goto LA67_;
							LA70_: ;
							{
								NIM_BOOL T75_;
								NimStringDesc* T79_;
								NimStringDesc* T80_;
								T75_ = (NIM_BOOL)0;
								T75_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
								if (!(T75_)) goto LA76_;
								T75_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0);
								LA76_: ;
								if (!T75_) goto LA77_;
								T79_ = (NimStringDesc*)0;
								T79_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(def, 0);
								T80_ = (NimStringDesc*)0;
								T80_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_677), T79_);
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*def).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T80_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_678, NIM_FALSE);
							}
							goto LA67_;
							LA77_: ;
							LA67_: ;
						}
						LA49_: ;
					}
					LA35_: ;
					{
						if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA83_;
						goto LA13;
					}
					LA83_: ;
					{
						if (!!(((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)))) goto LA87_;
						typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 2)) & 7);
					}
					LA87_: ;
					typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q(c, (*a).info, typ, symkind, typFlags);
					instAllTypeBoundOp__Qpi3NgGJ9aSfcPm9cZqhFJUg(c, (*a).info);
					tup = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(70368744179728));
					{
						NI T102_;
						NI T103_;
						NI T104_;
						NI T105_;
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA91_;
						{
							if (!!(((*tup).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)))) goto LA95_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_679), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_680, NIM_FALSE);
						}
						goto LA93_;
						LA95_: ;
						{
							NI T98_;
							NI T99_;
							T98_ = (NI)0;
							T98_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
							T99_ = (NI)0;
							T99_ = len__5mJADrRYkP3r9auuiuDZN9cQast(tup);
							if (!!(((NI)(T98_ - ((NI) 2)) == T99_))) goto LA100_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_681, NIM_FALSE);
						}
						goto LA93_;
						LA100_: ;
						LA93_: ;
						b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36), (*a).info);
						T102_ = (NI)0;
						T102_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						newSons__Bu9cqnssJjx4jfWBeiR9albg(b, T102_);
						T103_ = (NI)0;
						T103_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
						T104_ = (NI)0;
						T104_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						asgnRef((void**) (&(*b)._kind_6.sons->data[(NI)(T103_ - ((NI) 2))]), (*a)._kind_6.sons->data[(NI)(T104_ - ((NI) 2))]);
						T105_ = (NI)0;
						T105_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
						asgnRef((void**) (&(*b)._kind_6.sons->data[(NI)(T105_ - ((NI) 1))]), def);
						addToVarSection__rATgbLzWCudr6icucCz5hA(c, result, n, b);
					}
					goto LA89_;
					LA91_: ;
					{
						NIM_BOOL T107_;
						NIM_BOOL T108_;
						NIM_BOOL T109_;
						NI T113_;
						T107_ = (NIM_BOOL)0;
						T108_ = (NIM_BOOL)0;
						T109_ = (NIM_BOOL)0;
						T109_ = ((*tup).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
						if (!(T109_)) goto LA110_;
						T109_ = ((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
						LA110_: ;
						T108_ = T109_;
						if (!(T108_)) goto LA111_;
						T108_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35));
						LA111_: ;
						T107_ = T108_;
						if (!(T107_)) goto LA112_;
						T113_ = (NI)0;
						T113_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						T107_ = (((NI) 3) < T113_);
						LA112_: ;
						if (!T107_) goto LA114_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 31), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_682, NIM_FALSE);
					}
					goto LA89_;
					LA114_: ;
					LA89_: ;
					{
						NI j;
						NI colontmp__2;
						NI T117_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T117_ = (NI)0;
						T117_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__2 = (NI)(T117_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								if (!(i_3 < colontmp__2)) goto LA119;
								j = i_3;
								{
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
									{
										tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T125_;
										if (!((*(*a)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA123_;
										T125_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
										{
											if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA128_;
											T125_ = typ;
										}
										goto LA126_;
										LA128_: ;
										{
											T125_ = (*tup).sons->data[j];
										}
										LA126_: ;
										fillPartialObject__kJjN1gd8ISazJd7RmyND3A(c, (*a)._kind_6.sons->data[j], T125_);
										addToVarSection__rATgbLzWCudr6icucCz5hA(c, result, n, a);
										goto LA120;
									}
									LA123_: ;
									v = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, (*a)._kind_6.sons->data[j], symkind);
									{
										if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA133_;
										nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*v).info, v, (*v).kind);
									}
									LA133_: ;
									{
										if (!!((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA137_;
										{
											NIM_BOOL T141_;
											T141_ = (NIM_BOOL)0;
											T141_ = isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g(v);
											if (!!(T141_)) goto LA142_;
											addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, v);
										}
										LA142_: ;
									}
									goto LA135_;
									LA137_: ;
									{
										{
											if (!((*v).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA147_;
											asgnRef((void**) (&(*v).owner), (*(*c).p).owner);
										}
										LA147_: ;
									}
									LA135_: ;
									{
										if (!(((NI) 0) < (*c).inUnrolledContext)) goto LA151_;
										(*v).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 25)) & 63);
									}
									goto LA149_;
									LA151_: ;
									{
										tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* shadowed;
										shadowed = findShadowedVar__X80n25ArIa9aG019bZhPbmzw(c, v);
										{
											if (!!((shadowed == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA156_;
											(*shadowed).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 25)) & 63);
											{
												NIM_BOOL T160_;
												T160_ = (NIM_BOOL)0;
												T160_ = ((*shadowed).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
												if (!(T160_)) goto LA161_;
												T160_ = !((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0));
												LA161_: ;
												if (!T160_) goto LA162_;
												liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 46), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_688, NIM_FALSE);
											}
											LA162_: ;
										}
										LA156_: ;
									}
									LA149_: ;
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T182_;
										NI T183_;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T184_;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
										NI T193_;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T194_;
										if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA166_;
										{
											if (!!(((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA170_;
											{
												if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26))&63U)))!=0)) goto LA174_;
												liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*def).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_689), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_690, NIM_FALSE);
											}
											LA174_: ;
										}
										LA170_: ;
										setVarType__2vD75zhrXW5EMFzUU9a9cEUQ(c, v, typ);
										b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*a).info);
										{
											NIM_BOOL T178_;
											NimStringDesc* T181_;
											T178_ = (NIM_BOOL)0;
											T178_ = importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions((*(*c).graph).config);
											if (!T178_) goto LA179_;
											T181_ = (NimStringDesc*)0;
											T181_ = (*b).comment; (*b).comment = copyStringRC1((*a).comment);
											if (T181_) nimGCunrefNoCycle(T181_);
										}
										LA179_: ;
										T182_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T182_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
										add__P8dDSotTW25BkfbyspojGg(b, T182_);
										T183_ = (NI)0;
										T183_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
										add__P8dDSotTW25BkfbyspojGg(b, (*a)._kind_6.sons->data[(NI)(T183_ - ((NI) 2))]);
										T184_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T184_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(def);
										add__P8dDSotTW25BkfbyspojGg(b, T184_);
										addToVarSection__rATgbLzWCudr6icucCz5hA(c, result, n, b);
										ast = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*a).info);
										{
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T189_;
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T190_;
											if (!((*(*a)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA187_;
											p = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43), (*a).info);
											T189_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
											T189_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
											add__P8dDSotTW25BkfbyspojGg(p, T189_);
											T190_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
											T190_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*a)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]);
											add__P8dDSotTW25BkfbyspojGg(p, T190_);
											add__P8dDSotTW25BkfbyspojGg(ast, p);
										}
										goto LA185_;
										LA187_: ;
										{
											tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T192_;
											T192_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
											T192_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
											add__P8dDSotTW25BkfbyspojGg(ast, T192_);
										}
										LA185_: ;
										T193_ = (NI)0;
										T193_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
										T194_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T194_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*a)._kind_6.sons->data[(NI)(T193_ - ((NI) 2))]);
										add__P8dDSotTW25BkfbyspojGg(ast, T194_);
										add__P8dDSotTW25BkfbyspojGg(ast, def);
										asgnRef((void**) (&(*v).ast), ast);
									}
									goto LA164_;
									LA166_: ;
									{
										{
											if (!((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA198_;
											asgnRef((void**) (&(*v).ast), (*def)._kind_6.sons->data[j]);
										}
										LA198_: ;
										{
											if (!((*tup).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA202_;
											setVarType__2vD75zhrXW5EMFzUU9a9cEUQ(c, v, (*tup).sons->data[j]);
										}
										goto LA200_;
										LA202_: ;
										{
											asgnRef((void**) (&(*v).typ), tup);
										}
										LA200_: ;
										asgnRef((void**) (&(*b)._kind_6.sons->data[j]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v));
									}
									LA164_: ;
									{
										tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actualType;
										if (!((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA207_;
										actualType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*v).typ, IL64(9007199254743056));
										{
											NIM_BOOL T211_;
											T211_ = (NIM_BOOL)0;
											T211_ = ((*actualType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
											if (!(T211_)) goto LA212_;
											T211_ = requiresInit__Llr9bijDgXUyn9cJR9cvIJBfQ(actualType);
											LA212_: ;
											if (!T211_) goto LA213_;
											defaultConstructionError__SDnpDS6VfoCU9aBUYR8UoFg(c, (*v).typ, (*v).info);
										}
										goto LA209_;
										LA213_: ;
										{
											checkNilable__L1S5GkGOJih9bnTgycxmzAQ(c, v);
										}
										LA209_: ;
										{
											NIM_BOOL T218_;
											T218_ = (NIM_BOOL)0;
											T218_ = ((*v).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
											if (!(T218_)) goto LA219_;
											T218_ = !((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
											LA219_: ;
											if (!T218_) goto LA220_;
											liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_699), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_700, NIM_FALSE);
										}
										LA220_: ;
									}
									LA207_: ;
									{
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
										if (!(((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA224_;
										x = newNodeI__vokyXY9cZDshCSxFKChhG9bg((*result).kind, (*v).info);
										add__P8dDSotTW25BkfbyspojGg(x, (*result)._kind_6.sons->data[i]);
										setupCompileTimeVar__zQ7dn9aEDgIq1IbBIE9cxsxg((*c).module, (*c).graph, x);
									}
									LA224_: ;
									{
										if (!(((*v).flags & 67108872) == 8)) goto LA228_;
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*v).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 78), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_701, NIM_FALSE);
									}
									LA228_: ;
								} LA120: ;
								i_3 += ((NI) 1);
							} LA119: ;
						}
					}
				} LA13: ;
				i_2 += ((NI) 1);
			} LA12: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, fitRemoveHiddenConv__wMJQkaeAPG0iIuqYsMdZgQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, n, (*n).info);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r1;
		if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) || (*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59))) goto LA3_;
		r1 = (*result)._kind_6.sons->data[((NI) 1)];
		{
			NIM_BOOL T7_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*r1).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) && (*r1).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
			if (!(T7_)) goto LA8_;
			T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350136322320));
			T7_ = ((IL64(1030792151040) &((NU64)1<<((NU)((*T9_).kind)&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA10_;
			result = newFloatNode__FUOXigLcQdNOaWKUo0hkTg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16), ((NF) ((*r1)._kind_1.intVal)));
			(*result).info = (*n).info;
			asgnRef((void**) (&(*result).typ), typ);
			{
				NIM_BOOL T14_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T17_;
				NimStringDesc* T18_;
				T14_ = (NIM_BOOL)0;
				T14_ = floatRangeCheck__RTbq1U5r9aGXeN20T54YASg((*result)._kind_2.floatVal, typ);
				if (!!(T14_)) goto LA15_;
				nimZeroMem((void*)T17_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T17_[0] = nimFloatToStr((*result)._kind_2.floatVal);
				T17_[1] = typeToString__QlvraUan7WbHowhAbvDvdA(typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
				T18_ = (NimStringDesc*)0;
				T18_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_90), T17_, 2);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T18_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_702, NIM_FALSE);
			}
			LA15_: ;
		}
		goto LA5_;
		LA10_: ;
		{
			changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, r1, typ, NIM_TRUE);
			result = r1;
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = sameType__3isNyHKb0U1OCnClmflXSg((*result).typ, typ, 0);
		if (!!(T21_)) goto LA22_;
		changeType__sF9cXBCC3k8saS0PTBUB9b8A(c, result, typ, NIM_FALSE);
	}
	goto LA1_;
	LA22_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConst__7YxUILpPxooC5qqa89a54dw_45)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	(*c).inStaticContext += ((NI) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg typFlags;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					NI T23_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA7_;
						suggestStmt__wb6KhAx6bZ5NV37kY4bXJw_4(c, a);
					}
					LA7_: ;
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA11_;
						goto LA4;
					}
					LA11_: ;
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA15_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA15_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*c).graph).config);
					typ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
					{
						NI T19_;
						NI T22_;
						T19_ = (NI)0;
						T19_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!!(((*(*a)._kind_6.sons->data[(NI)(T19_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA20_;
						T22_ = (NI)0;
						T22_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[(NI)(T22_ - ((NI) 2))], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					}
					LA20_: ;
					nimZeroMem((void*)(&typFlags), sizeof(tySet_tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg));
					T23_ = (NI)0;
					T23_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					def = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*a)._kind_6.sons->data[(NI)(T23_ - ((NI) 1))], 0);
					{
						NIM_BOOL T26_;
						T26_ = (NIM_BOOL)0;
						T26_ = ((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T26_)) goto LA27_;
						T26_ = ((393216 &((NU32)1<<((NU)((*(*def)._kind_4.sym).kind)&31U)))!=0);
						LA27_: ;
						if (!T26_) goto LA28_;
						typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 5)) & 7);
					}
					goto LA24_;
					LA28_: ;
					{
						NIM_BOOL T31_;
						T31_ = (NIM_BOOL)0;
						T31_ = ((*(*def).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
						if (!(T31_)) goto LA32_;
						T31_ = !(((*(*(*c).p).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17)));
						LA32_: ;
						if (!T31_) goto LA33_;
						typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 6)) & 7);
					}
					goto LA24_;
					LA33_: ;
					LA24_: ;
					{
						if (!!((typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA37_;
						{
							NIM_BOOL T41_;
							T41_ = (NIM_BOOL)0;
							T41_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(typ);
							if (!T41_) goto LA42_;
							def = inferWithMetatype__2aIGqt1c0rX64kF16cP4Pw(c, typ, def, NIM_FALSE);
							typ = (*def).typ;
						}
						goto LA39_;
						LA42_: ;
						{
							def = fitRemoveHiddenConv__wMJQkaeAPG0iIuqYsMdZgQ(c, typ, def);
						}
						LA39_: ;
					}
					goto LA35_;
					LA37_: ;
					{
						typ = (*def).typ;
					}
					LA35_: ;
					def = semConstExpr__7YxUILpPxooC5qqa89a54dw(c, def);
					{
						NI T50_;
						if (!(def == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA48_;
						T50_ = (NI)0;
						T50_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[(NI)(T50_ - ((NI) 1))]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_703, NIM_FALSE);
						goto LA4;
					}
					LA48_: ;
					{
						if (!!(((*def).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23)))) goto LA53_;
						{
							if (!!(((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)))) goto LA57_;
							typFlags |= ((NU8)1)<<((((tyEnum_TTypeAllowedFlag__JBIyoJI1E5LVXKYAX3xeBg) 2)) & 7);
						}
						LA57_: ;
						typeAllowedCheck__8UmYxmpeXz12fVl9azJmJ2Q(c, (*a).info, typ, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10), typFlags);
					}
					LA53_: ;
					b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					{
						NI T72_;
						NI T73_;
						NI T74_;
						NI T75_;
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA61_;
						{
							if (!!(((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)))) goto LA65_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_679), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_704, NIM_FALSE);
						}
						goto LA63_;
						LA65_: ;
						{
							NI T68_;
							NI T69_;
							T68_ = (NI)0;
							T68_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
							T69_ = (NI)0;
							T69_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
							if (!!(((NI)(T68_ - ((NI) 2)) == T69_))) goto LA70_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_705, NIM_FALSE);
						}
						goto LA63_;
						LA70_: ;
						LA63_: ;
						b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36), (*a).info);
						T72_ = (NI)0;
						T72_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						newSons__Bu9cqnssJjx4jfWBeiR9albg(b, T72_);
						T73_ = (NI)0;
						T73_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
						T74_ = (NI)0;
						T74_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						asgnRef((void**) (&(*b)._kind_6.sons->data[(NI)(T73_ - ((NI) 2))]), (*a)._kind_6.sons->data[(NI)(T74_ - ((NI) 2))]);
						T75_ = (NI)0;
						T75_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
						asgnRef((void**) (&(*b)._kind_6.sons->data[(NI)(T75_ - ((NI) 1))]), def);
					}
					LA61_: ;
					{
						NI j;
						NI colontmp__2;
						NI T77_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T77_ = (NI)0;
						T77_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						colontmp__2 = (NI)(T77_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
								if (!(i_3 < colontmp__2)) goto LA79;
								j = i_3;
								v = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, (*a)._kind_6.sons->data[j], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
								{
									if (!!((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA82_;
									addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, v);
								}
								goto LA80_;
								LA82_: ;
								{
									if (!((*v).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA85_;
									asgnRef((void**) (&(*v).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
								}
								goto LA80_;
								LA85_: ;
								LA80_: ;
								{
									if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA89_;
									nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*v).info, v, (*v).kind);
								}
								LA89_: ;
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T101_;
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T102_;
									if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA93_;
									setVarType__2vD75zhrXW5EMFzUU9a9cEUQ(c, v, typ);
									asgnRef((void**) (&(*v).ast), def);
									b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102), (*a).info);
									{
										NIM_BOOL T97_;
										NimStringDesc* T100_;
										T97_ = (NIM_BOOL)0;
										T97_ = importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions((*(*c).graph).config);
										if (!T97_) goto LA98_;
										T100_ = (NimStringDesc*)0;
										T100_ = (*b).comment; (*b).comment = copyStringRC1((*a).comment);
										if (T100_) nimGCunrefNoCycle(T100_);
									}
									LA98_: ;
									T101_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T101_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
									add__P8dDSotTW25BkfbyspojGg(b, T101_);
									add__P8dDSotTW25BkfbyspojGg(b, (*a)._kind_6.sons->data[((NI) 1)]);
									T102_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
									T102_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(def);
									add__P8dDSotTW25BkfbyspojGg(b, T102_);
								}
								goto LA91_;
								LA93_: ;
								{
									setVarType__2vD75zhrXW5EMFzUU9a9cEUQ(c, v, (*typ).sons->data[j]);
									{
										if (!!(((*(*def)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA106_;
										asgnRef((void**) (&(*v).ast), (*def)._kind_6.sons->data[j]);
									}
									goto LA104_;
									LA106_: ;
									{
										asgnRef((void**) (&(*v).ast), (*(*def)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)]);
									}
									LA104_: ;
									asgnRef((void**) (&(*b)._kind_6.sons->data[j]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v));
								}
								LA91_: ;
								i_3 += ((NI) 1);
							} LA79: ;
						}
					}
					add__P8dDSotTW25BkfbyspojGg(result, b);
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	(*c).inStaticContext -= ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, typeDefLeftSidePass__Sbx6MQrOoMPnRUYXOXA3NA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeSection, NI i) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeDef_1;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	typeDef_1 = (*typeSection)._kind_6.sons->data[i];
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(typeDef_1, ((NI) 3), (*(*c).graph).config);
	name = (*typeDef_1)._kind_6.sons->data[((NI) 0)];
	s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* pkgName;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* typName;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* pkg;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*name).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*typeDef_1)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133));
		LA4_: ;
		if (!T3_) goto LA5_;
		pkgName = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*name)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		typName = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*name)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		pkg = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*c).graph).packageSyms, pkgName);
		{
			NIM_BOOL T9_;
			NimStringDesc* T13_;
			T9_ = (NIM_BOOL)0;
			T9_ = (pkg == 0);
			if (T9_) goto LA10_;
			T9_ = !(((*pkg).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 24)));
			LA10_: ;
			if (!T9_) goto LA11_;
			T13_ = (NimStringDesc*)0;
			T13_ = rawNewString(((*pkgName).s ? (*pkgName).s->Sup.len : 0) + 22);
appendString(T13_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_706));
appendString(T13_, (*pkgName).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_707, NIM_FALSE);
		}
		goto LA7_;
		LA11_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* typsym;
			typsym = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*pkg)._kind_3.tab, typName);
			{
				if (!(typsym == 0)) goto LA17_;
				s = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, (*name)._kind_6.sons->data[((NI) 1)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
				asgnRef((void**) (&(*s).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17), c));
				asgnRef((void**) (&(*(*s).typ).sym), s);
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63);
				strTableAdd__tyTgUybFIoow4CX2l5beug((&(*pkg)._kind_3.tab), s);
				addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, s);
			}
			goto LA15_;
			LA17_: ;
			{
				NIM_BOOL T20_;
				T20_ = (NIM_BOOL)0;
				T20_ = ((*typsym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
				if (!(T20_)) goto LA21_;
				T20_ = (((*typsym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0);
				LA21_: ;
				if (!T20_) goto LA22_;
				s = typsym;
				addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, s);
			}
			goto LA15_;
			LA22_: ;
			{
				NimStringDesc* T25_;
				T25_ = (NimStringDesc*)0;
				T25_ = rawNewString(((*(*typsym).name).s ? (*(*typsym).name).s->Sup.len : 0) + 36);
appendString(T25_, (*(*typsym).name).s);
appendString(T25_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_708));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T25_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_709, NIM_FALSE);
				s = typsym;
			}
			LA15_: ;
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		s = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, name, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		asgnRef((void**) (&(*s).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30), c));
		asgnRef((void**) (&(*(*s).typ).sym), s);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rewritten;
			if (!((*name).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA29_;
			rewritten = applyTypeSectionPragmas__n3MU2Z4B9cngRayLYQCel5A(c, (*name)._kind_6.sons->data[((NI) 1)], typeDef_1);
			{
				if (!!((rewritten == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA33_;
				asgnRef((void**) (&(*typeSection)._kind_6.sons->data[i]), rewritten);
				typeDefLeftSidePass__Sbx6MQrOoMPnRUYXOXA3NA(c, typeSection, i);
				goto BeforeRet_;
			}
			LA33_: ;
			pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, s, (*name)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_433, NIM_FALSE);
		}
		LA29_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* pkg_2;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0)) goto LA37_;
			pkg_2 = (*(*c).module).owner;
			{
				NIM_BOOL T41_;
				NIM_BOOL T42_;
				T41_ = (NIM_BOOL)0;
				T42_ = (NIM_BOOL)0;
				T42_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
				T41_ = !(T42_);
				if (T41_) goto LA43_;
				T41_ = (pkg_2 == 0);
				LA43_: ;
				if (!T41_) goto LA44_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_710), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_711, NIM_FALSE);
			}
			goto LA39_;
			LA44_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* typsym_2;
				typsym_2 = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*pkg_2)._kind_3.tab, (*s).name);
				{
					if (!!((typsym_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA49_;
					{
						NIM_BOOL T53_;
						T53_ = (NIM_BOOL)0;
						T53_ = !((((*typsym_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0));
						if (T53_) goto LA54_;
						T53_ = !((((*typsym_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0));
						LA54_: ;
						if (!T53_) goto LA55_;
						(*typsym_2).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10)) & 63);
						(*typsym_2).info = (*s).info;
					}
					goto LA51_;
					LA55_: ;
					{
						NimStringDesc* T58_;
						NimStringDesc* T59_;
						T58_ = (NimStringDesc*)0;
						T59_ = (NimStringDesc*)0;
						T59_ = dollar___aQsiZUvE4SFfnWyKx1JgKA((*(*c).graph).config, (*typsym_2).info);
						T58_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + (T59_ ? T59_->Sup.len : 0) + 66);
appendString(T58_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_712));
appendString(T58_, (*(*s).name).s);
appendString(T58_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_713));
appendString(T58_, T59_);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T58_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_714, NIM_FALSE);
					}
					LA51_: ;
					s = typsym_2;
				}
				LA49_: ;
			}
			LA39_: ;
		}
		LA37_: ;
		{
			if (!!((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA62_;
			addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, s);
		}
		goto LA60_;
		LA62_: ;
		{
			if (!((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA65_;
			asgnRef((void**) (&(*s).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
		}
		goto LA60_;
		LA65_: ;
		LA60_: ;
	}
	LA1_: ;
	{
		if (!((*name).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA69_;
		asgnRef((void**) (&(*(*typeDef_1)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s));
	}
	goto LA67_;
	LA69_: ;
	{
		asgnRef((void**) (&(*typeDef_1)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s));
	}
	LA67_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, typeSectionLeftSidePass__NRIJDWZtATzMum7OEjYC2g_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA7_;
						goto LA4;
					}
					LA7_: ;
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA11_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA11_: ;
					typeDefLeftSidePass__Sbx6MQrOoMPnRUYXOXA3NA(c, n, i);
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, typeSectionTypeName__7YxUILpPxooC5qqa89a54dw_47)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA3_;
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T7_ == ((NI) 0))) goto LA8_;
			illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
		}
		LA8_: ;
		result = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA13_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NI size) {
	(*(*m).typ).kind = kind;
	(*(*m).typ).size = ((NI64) (size));
	(*(*m).typ).align = ((NI16) (size));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((IL64(19071802277888) &((NU64)1<<((NU)(kind)&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (size == ((NI) 8));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*(*m).typ).align = floatInt64Align__Nm9cs6Kn6ltGLynV4vNsRgw(conf);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, NI size) {
	setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2(conf, m, kind, size);
	(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, processMagicType__gPoEwHdu4chIAfwrKhjTjA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m) {
	switch ((*m).magic) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 169):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), (*(*(*c).graph).config).target.intSize);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 170):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32), ((NI) 1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 171):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33), ((NI) 2));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 172):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34), ((NI) 4));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 173):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35), ((NI) 8));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 174):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), (*(*(*c).graph).config).target.intSize);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 175):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41), ((NI) 1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 176):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42), ((NI) 2));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 177):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43), ((NI) 4));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 178):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44), ((NI) 8));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 179):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36), (*(*(*c).graph).config).target.floatSize);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 180):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37), ((NI) 4));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 181):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38), ((NI) 8));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 182):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39), ((NI) 16));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 183):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1), ((NI) 1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 184):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2), ((NI) 1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 185):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28), ((NI) -1));
		T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T18_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*m).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2));
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T18_, NIM_TRUE);
		{
			if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA21_;
			(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
		}
		LA21_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 186):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29), (*(*(*c).graph).config).target.ptrSize);
		T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T24_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*m).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2));
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T24_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 187):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26), (*(*(*c).graph).config).target.ptrSize);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 188):
	{
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5), (*(*(*c).graph).config).target.ptrSize);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 189):
	{
		{
			if (!eqStrings((*(*m).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_716))) goto LA30_;
			setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59), ((NI) 0));
		}
		goto LA28_;
		LA30_: ;
		{
			setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6), ((NI) 0));
		}
		LA28_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 190):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7), ((NI) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 191):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 17):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T35_;
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8), ((NI) 0));
		T35_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T35_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T35_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 24):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), ((NI) 0));
		T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T37_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T37_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 192):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63), ((NI) 0));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 156):
	{
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), ((NI) -1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 157):
	{
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27), ((NI) -1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 161):
	{
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48), ((NI) -1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 158):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T43_;
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), ((NI) -1));
		T43_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T43_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T43_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 159):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19), ((NI) -1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 267):
	{
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49), ((NI) -1));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 160):
	{
		setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24), ((NI) -1));
		{
			if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0)) goto LA49_;
			(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31)) & 63);
		}
		LA49_: ;
		asgnRef((void**) (&(*(*c).graph).sysTypes[(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24))- 0]), (*m).typ);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 168):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T52_;
		setMagicIntegral__FuNrknGP1Vshc6r9b9af0PQw((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15), ((NI) -1));
		T52_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T52_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*m).typ, T52_, NIM_TRUE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 193):
	{
		(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 33)) & 63);
		(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 38)) & 63);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 264):
	{
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 265):
	{
		if (eqStrings((*(*m).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_717))) goto LA56_;
		if (eqStrings((*(*m).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_718))) goto LA57_;
		if (eqStrings((*(*m).name).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_469))) goto LA58_;
		goto LA59_;
		LA56_: ;
		{
			setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47), (*(*(*c).graph).config).target.ptrSize);
		}
		goto LA60_;
		LA57_: ;
		{
			setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46), ((NI) -1));
		}
		goto LA60_;
		LA58_: ;
		{
			setMagicType__FuNrknGP1Vshc6r9b9af0PQw_2((*(*c).graph).config, m, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45), (*(*(*c).graph).config).target.ptrSize);
			(*(*m).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63);
		}
		goto LA60_;
		LA59_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*m).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_719, NIM_FALSE);
		}
		LA60_: ;
	}
	break;
	default:
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*m).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_23), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_720, NIM_FALSE);
	}
	break;
	}
}
static N_NIMCALL(void, Marker_tyRef__hW0nFkOHm9b8Hn43XRoDtzQ)(void* p, NI op) {
	tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw* a;
	a = (tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*)p;
	nimGCvisit((void*)(*a).genericType1, op);
}
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, void* ClE_0) {
	NIM_BOOL result;
	tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw* colonenvP_;
{	result = (NIM_BOOL)0;
	colonenvP_ = (tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*) ClE_0;
	result = NIM_FALSE;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	{
		(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 36)) & 63);
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
			field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*t).n);
				i_2 = ((NI) 0);
				{
					while (1) {
						NIM_BOOL subX60gensym2963_;
						tyProc__9c12O79biRoLGSQrMfBJEQDg T7_;
						NIM_BOOL T8_;
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						field = (*(*t).n)._kind_6.sons->data[i];
						nimZeroMem((void*)(&T7_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
						T7_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T7_.ClE_0 = colonenvP_;
						subX60gensym2963_ = T7_.ClE_0? T7_.ClP_0(c, (*field).typ, T7_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_722)(T7_.ClP_0))(c, (*field).typ);
						T8_ = (NIM_BOOL)0;
						T8_ = result;
						if (T8_) goto LA9_;
						T8_ = subX60gensym2963_;
						LA9_: ;
						result = T8_;
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyProc__9c12O79biRoLGSQrMfBJEQDg T11_;
		nimZeroMem((void*)(&T11_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
		T11_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T11_.ClE_0 = colonenvP_;
		result = T11_.ClE_0? T11_.ClP_0(c, (*t).sons->data[((NI) 1)], T11_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_723)(T11_.ClP_0))(c, (*t).sons->data[((NI) 1)]);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** subType;
			NI i_3;
			NI L;
			NI T14_;
			subType = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i_3 = ((NI) 0);
			T14_ = ((*t).sons ? (*t).sons->Sup.len : 0);
			L = T14_;
			{
				while (1) {
					if (!(i_3 < L)) goto LA16;
					subType = &(*t).sons->data[i_3];
					{
						NIM_BOOL subX60gensym2966_;
						tyProc__9c12O79biRoLGSQrMfBJEQDg T21_;
						NIM_BOOL T22_;
						if (!!(((*subType) == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA19_;
						nimZeroMem((void*)(&T21_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
						T21_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T21_.ClE_0 = colonenvP_;
						subX60gensym2966_ = T21_.ClE_0? T21_.ClP_0(c, (*subType), T21_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_724)(T21_.ClP_0))(c, (*subType));
						T22_ = (NIM_BOOL)0;
						T22_ = result;
						if (T22_) goto LA23_;
						T22_ = subX60gensym2966_;
						LA23_: ;
						result = T22_;
					}
					LA19_: ;
					i_3 += ((NI) 1);
				} LA16: ;
			}
		}
		{
			NimStringDesc* T28_;
			NimStringDesc* T29_;
			if (!result) goto LA26_;
			T28_ = (NimStringDesc*)0;
			T29_ = (NimStringDesc*)0;
			T29_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T28_ = rawNewString((T29_ ? T29_->Sup.len : 0) + 46);
appendString(T28_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_725));
appendString(T28_, T29_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*colonenvP_).genericType1).sym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T28_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_726, NIM_FALSE);
		}
		LA26_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyProc__9c12O79biRoLGSQrMfBJEQDg T31_;
		nimZeroMem((void*)(&T31_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
		T31_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T31_.ClE_0 = colonenvP_;
		result = T31_.ClE_0? T31_.ClP_0(c, (*t).sons->data[((NI) 0)], T31_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_727)(T31_.ClP_0))(c, (*t).sons->data[((NI) 0)]);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* targetBody;
		targetBody = (*t).sons->data[((NI) 0)];
		{
			NI i_4;
			NI colontmp__2;
			NI i_5;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_5 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* param;
					if (!(i_5 < colontmp__2)) goto LA35;
					i_4 = i_5;
					param = (*t).sons->data[i_4];
					{
						if (!((*param).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA38_;
						{
							tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw formalFlags;
							if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35))&63U)))!=0)) goto LA42_;
							formalFlags = (*(*targetBody).sons->data[(NI)(i_4 - ((NI) 1))]).flags;
							{
								NimStringDesc* T48_;
								if (!!(((formalFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35))&63U)))!=0))) goto LA46_;
								T48_ = (NimStringDesc*)0;
								T48_ = rawNewString(((*(*(*param).sym).name).s ? (*(*(*param).sym).name).s->Sup.len : 0) + 51);
appendString(T48_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_728));
appendString(T48_, (*(*(*param).sym).name).s);
appendString(T48_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_729));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*colonenvP_).genericType1).sym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T48_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_730, NIM_FALSE);
							}
							goto LA44_;
							LA46_: ;
							{
								if (!((formalFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 36))&63U)))!=0)) goto LA50_;
								(*param).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 36)) & 63);
							}
							goto LA44_;
							LA50_: ;
							LA44_: ;
							result = NIM_TRUE;
						}
						goto LA40_;
						LA42_: ;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formalParam;
							if (!(((*param).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 37))&63U)))!=0)) goto LA53_;
							formalParam = (*(*targetBody).sons->data[(NI)(i_4 - ((NI) 1))]).sym;
							{
								NimStringDesc* T59_;
								if (!!((((*(*formalParam).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 37))&63U)))!=0))) goto LA57_;
								T59_ = (NimStringDesc*)0;
								T59_ = rawNewString(((*(*(*param).sym).name).s ? (*(*(*param).sym).name).s->Sup.len : 0) + 59);
appendString(T59_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_731));
appendString(T59_, (*(*(*param).sym).name).s);
appendString(T59_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_732));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*colonenvP_).genericType1).sym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T59_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_733, NIM_FALSE);
							}
							LA57_: ;
							result = NIM_TRUE;
						}
						goto LA40_;
						LA53_: ;
						LA40_: ;
					}
					goto LA36_;
					LA38_: ;
					{
						NIM_BOOL subX60gensym2990_;
						tyProc__9c12O79biRoLGSQrMfBJEQDg T61_;
						NIM_BOOL T62_;
						nimZeroMem((void*)(&T61_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
						T61_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T61_.ClE_0 = colonenvP_;
						subX60gensym2990_ = T61_.ClE_0? T61_.ClP_0(c, param, T61_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_734)(T61_.ClP_0))(c, param);
						T62_ = (NIM_BOOL)0;
						T62_ = result;
						if (T62_) goto LA63_;
						T62_ = subX60gensym2990_;
						LA63_: ;
						result = T62_;
					}
					LA36_: ;
					i_5 += ((NI) 1);
				} LA35: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	{
		NimStringDesc* T65_;
		NimStringDesc* T66_;
		T65_ = (NimStringDesc*)0;
		T66_ = (NimStringDesc*)0;
		T66_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T65_ = rawNewString((T66_ ? T66_->Sup.len : 0) + 63);
appendString(T65_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_735));
appendString(T65_, T66_);
appendString(T65_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_115));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*colonenvP_).genericType1).sym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T65_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_736, NIM_FALSE);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*colonenvP_).genericType1).sym).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_737), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_738, NIM_FALSE);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** fieldType;
			NI i_6;
			NI L_2;
			NI T70_;
			fieldType = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i_6 = ((NI) 0);
			T70_ = ((*t).sons ? (*t).sons->Sup.len : 0);
			L_2 = T70_;
			{
				while (1) {
					NIM_BOOL subX60gensym3000_;
					tyProc__9c12O79biRoLGSQrMfBJEQDg T73_;
					NIM_BOOL T74_;
					if (!(i_6 < L_2)) goto LA72;
					fieldType = &(*t).sons->data[i_6];
					nimZeroMem((void*)(&T73_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
					T73_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T73_.ClE_0 = colonenvP_;
					subX60gensym3000_ = T73_.ClE_0? T73_.ClP_0(c, (*fieldType), T73_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_739)(T73_.ClP_0))(c, (*fieldType));
					T74_ = (NIM_BOOL)0;
					T74_ = result;
					if (T74_) goto LA75_;
					T74_ = subX60gensym3000_;
					LA75_: ;
					result = T74_;
					i_6 += ((NI) 1);
				} LA72: ;
			}
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		tyProc__9c12O79biRoLGSQrMfBJEQDg T82_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T83_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T79_;
			T79_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T79_ = base__PfgI9ap7WOnsRfFV4znQ27w(t);
			if (!((*T79_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA80_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA80_: ;
		nimZeroMem((void*)(&T82_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
		T82_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T82_.ClE_0 = colonenvP_;
		T83_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T83_ = base__PfgI9ap7WOnsRfFV4znQ27w(t);
		result = T82_.ClE_0? T82_.ClP_0(c, T83_, T82_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_740)(T82_.ClP_0))(c, T83_);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyProc__9c12O79biRoLGSQrMfBJEQDg T85_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T86_;
		nimZeroMem((void*)(&T85_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
		T85_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T85_.ClE_0 = colonenvP_;
		T86_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T86_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		result = T85_.ClE_0? T85_.ClP_0(c, T86_, T85_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_741)(T85_.ClP_0))(c, T86_);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		{
			NimStringDesc* argX60gensym3002_;
			if (!NIM_TRUE) goto LA90_;
			argX60gensym3002_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_742);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3002_, TM__rF9caJawfOjYTjsgLVUSGFA_742);
		}
		LA90_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkCovariantParamsUsages__fJHDVHP75aONSHseylETAw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genericType) {
	tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw* colonenv_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* body;
	NI T1_;
	tyProc__9c12O79biRoLGSQrMfBJEQDg T2_;
	NIM_BOOL T3_;
	colonenv_ = (tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*)0;
	colonenv_ = (tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*) newObj((&NTI__hW0nFkOHm9b8Hn43XRoDtzQ_), sizeof(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw));
	(*colonenv_).Sup.m_type = (&NTI__GnXaFIlVxvDpiKnOUsLlMw_);
	asgnRef((void**) (&(*colonenv_).genericType1), genericType);
	T1_ = (NI)0;
	T1_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*colonenv_).genericType1);
	body = (*(*colonenv_).genericType1).sons->data[(NI)(T1_ - ((NI) 1))];
	nimZeroMem((void*)(&T2_), sizeof(tyProc__9c12O79biRoLGSQrMfBJEQDg));
	T2_.ClP_0 = traverseSubTypes__Pkr5yx0YVtVYHazxo9a3x2g; T2_.ClE_0 = colonenv_;
	T3_ = (NIM_BOOL)0;
	T3_ = T2_.ClE_0? T2_.ClP_0(c, body, T2_.ClE_0):((TM__rF9caJawfOjYTjsgLVUSGFA_743)(T2_.ClP_0))(c, body);
	(void)(T3_);
}
N_LIB_PRIVATE N_NIMCALL(void, typeSectionRightSidePass__NRIJDWZtATzMum7OEjYC2g_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* aa;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA7_;
						goto LA4;
					}
					LA7_: ;
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 103)))) goto LA11_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA11_: ;
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(a, ((NI) 3), (*(*c).graph).config);
					name = typeSectionTypeName__7YxUILpPxooC5qqa89a54dw_47(c, (*a)._kind_6.sons->data[((NI) 0)]);
					s = (*name)._kind_4.sym;
					{
						NIM_BOOL T15_;
						NimStringDesc* T19_;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
						if (!(T15_)) goto LA16_;
						T15_ = ((*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
						LA16_: ;
						if (!T15_) goto LA17_;
						T19_ = (NimStringDesc*)0;
						T19_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*s).name).s);
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_715, NIM_FALSE);
					}
					LA17_: ;
					{
						if (!!(((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)))) goto LA22_;
						processMagicType__gPoEwHdu4chIAfwrKhjTjA(c, s);
					}
					LA22_: ;
					{
						tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T28_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* body;
						if (!!(((*(*a)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA26_;
						T28_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
						T28_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
						pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
						{
							if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA31_;
							(*(*s).typ).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10);
						}
						LA31_: ;
						asgnRef((void**) (&(*(*s).typ).n), semGenericParamList__00ZJT6x0WT6z8eBqr79cipw(c, (*a)._kind_6.sons->data[((NI) 1)], (*s).typ));
						asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 1)]), (*(*s).typ).n);
						(*(*s).typ).size = IL64(-1);
						T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T33_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0), c);
						rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*s).typ, T33_, NIM_TRUE);
						asgnRef((void**) (&(*s).ast), a);
						(*c).inGenericContext += ((NI) 1);
						body = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[((NI) 2)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
						(*c).inGenericContext -= ((NI) 1);
						{
							NI T38_;
							if (!!((body == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA36_;
							asgnRef((void**) (&(*body).sym), s);
							(*body).size = IL64(-1);
							T38_ = (NI)0;
							T38_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
							asgnRef((void**) (&(*(*s).typ).sons->data[(NI)(T38_ - ((NI) 1))]), body);
							{
								if (!(((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35))&63U)))!=0)) goto LA41_;
								checkCovariantParamsUsages__fJHDVHP75aONSHseylETAw(c, (*s).typ);
								{
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* body_2;
									if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0)) goto LA45_;
									body_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ((*s).typ);
									{
										if (!((*body_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA49_;
										if ((*(*body_2).n)._kind_6.sons) { nimGCunrefNoCycle((*(*body_2).n)._kind_6.sons); (*(*body_2).n)._kind_6.sons = NIM_NIL; }
									}
									LA49_: ;
								}
								LA45_: ;
							}
							LA41_: ;
						}
						LA36_: ;
						popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
						closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
					}
					goto LA24_;
					LA26_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
						if (!!(((*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA52_;
						pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
						t = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[((NI) 2)], (*s).typ);
						{
							if (!((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA56_;
							asgnRef((void**) (&(*s).typ), t);
						}
						goto LA54_;
						LA56_: ;
						{
							NIM_BOOL T59_;
							NIM_BOOL T61_;
							T59_ = (NIM_BOOL)0;
							T59_ = !((t == (*s).typ));
							if (!(T59_)) goto LA60_;
							T61_ = (NIM_BOOL)0;
							T61_ = ((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
							if (T61_) goto LA62_;
							T61_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4)));
							LA62_: ;
							T59_ = T61_;
							LA60_: ;
							if (!T59_) goto LA63_;
							assignType__RDstL9c8H9bSHUphDz0iB0hg((*s).typ, t);
						}
						goto LA54_;
						LA63_: ;
						LA54_: ;
						asgnRef((void**) (&(*s).ast), a);
						popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
						{
							if (!((*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*(*a)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA67_;
							(*(*a)._kind_6.sons->data[((NI) 2)]).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7)) & 31);
						}
						LA67_: ;
					}
					goto LA24_;
					LA52_: ;
					LA24_: ;
					{
						NIM_BOOL T71_;
						T71_ = (NIM_BOOL)0;
						T71_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7))&63U)))!=0);
						if (!(T71_)) goto LA72_;
						T71_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4));
						LA72_: ;
						if (!T71_) goto LA73_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_744), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_745, NIM_FALSE);
					}
					LA73_: ;
					{
						NIM_BOOL T77_;
						T77_ = (NIM_BOOL)0;
						T77_ = (((*(*s).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 32))&63U)))!=0);
						if (!(T77_)) goto LA78_;
						T77_ = !(((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13)));
						LA78_: ;
						if (!T77_) goto LA79_;
						(*(*s).typ).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 32)) & 63));
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*name).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_746), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_747, NIM_FALSE);
					}
					LA79_: ;
					aa = (*a)._kind_6.sons->data[((NI) 2)];
					{
						NIM_BOOL T83_;
						NIM_BOOL T84_;
						NI T86_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* st;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* obj;
						NimStringDesc* T103_;
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T104_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T105_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* symNode;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T113_;
						T83_ = (NIM_BOOL)0;
						T84_ = (NIM_BOOL)0;
						T84_ = ((*aa).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 141) || (*aa).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 142));
						if (!(T84_)) goto LA85_;
						T86_ = (NI)0;
						T86_ = len__P89cqdlERShb9alU3iC0yj8wast(aa);
						T84_ = (T86_ == ((NI) 1));
						LA85_: ;
						T83_ = T84_;
						if (!(T83_)) goto LA87_;
						T83_ = ((*(*aa)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133));
						LA87_: ;
						if (!T83_) goto LA88_;
						st = (*s).typ;
						{
							if (!((*st).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10))) goto LA92_;
							st = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(st);
						}
						LA92_: ;
						{
							NimStringDesc* argX60gensym3047_;
							if (!!(((6291456 &((NU64)1<<((NU)((*st).kind)&63U)))!=0))) goto LA96_;
							argX60gensym3047_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_748);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3047_, TM__rF9caJawfOjYTjsgLVUSGFA_748);
						}
						LA96_: ;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T100_;
							NimStringDesc* argX60gensym3050_;
							T100_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T100_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(st);
							if (!!(((*T100_).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA101_;
							argX60gensym3050_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_749);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3050_, TM__rF9caJawfOjYTjsgLVUSGFA_749);
						}
						LA101_: ;
						(*st).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 34)) & 63);
						T103_ = (NimStringDesc*)0;
						T103_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 11);
appendString(T103_, (*(*s).name).s);
appendString(T103_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_750));
						T104_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
						T104_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, T103_);
						T105_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T105_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
						obj = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), T104_, T105_, (*s).info, 0);
						symNode = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(obj);
						asgnRef((void**) (&(*obj).ast), shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(a));
						switch ((*(*a)._kind_6.sons->data[((NI) 0)]).kind) {
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
						{
							asgnRef((void**) (&(*(*obj).ast)._kind_6.sons->data[((NI) 0)]), symNode);
						}
						break;
						case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
						{
							asgnRef((void**) (&(*(*obj).ast)._kind_6.sons->data[((NI) 0)]), shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3((*a)._kind_6.sons->data[((NI) 0)]));
							asgnRef((void**) (&(*(*(*obj).ast)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]), symNode);
							asgnRef((void**) (&(*(*(*obj).ast)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]), (*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
						}
						break;
						default:
						{
						}
						break;
						}
						asgnRef((void**) (&(*(*obj).ast)._kind_6.sons->data[((NI) 1)]), (*a)._kind_6.sons->data[((NI) 1)]);
						asgnRef((void**) (&(*(*obj).ast)._kind_6.sons->data[((NI) 2)]), (*(*a)._kind_6.sons->data[((NI) 2)])._kind_6.sons->data[((NI) 0)]);
						{
							if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0)) goto LA111_;
							(*obj).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11)) & 63);
						}
						LA111_: ;
						asgnRef((void**) (&(*obj).typ), lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(st));
						T113_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T113_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(st);
						asgnRef((void**) (&(*T113_).sym), obj);
					}
					LA88_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, checkMeta__ZPW6MqdUk6rECHJvUIgrnA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(t);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !((((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 25))&63U)))!=0));
		LA6_: ;
		if (!T3_) goto LA7_;
		{
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			NI T14_;
			NimStringDesc* T18_;
			NimStringDesc* T19_;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51));
			if (!(T12_)) goto LA13_;
			T14_ = (NI)0;
			T14_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			T12_ = (T14_ == ((NI) 1));
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA15_;
			T11_ = ((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA15_: ;
			if (!T11_) goto LA16_;
			T18_ = (NimStringDesc*)0;
			T18_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T19_ = (NimStringDesc*)0;
			T19_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_751), T18_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_752, NIM_FALSE);
		}
		goto LA9_;
		LA16_: ;
		{
			NimStringDesc* T21_;
			NimStringDesc* T22_;
			T21_ = (NimStringDesc*)0;
			T21_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T22_ = (NimStringDesc*)0;
			T22_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_484), T21_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T22_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_753, NIM_FALSE);
		}
		LA9_: ;
	}
	LA7_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkForMetaFields__NRIJDWZtATzMum7OEjYC2g_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
{	{
		if (!(n == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
			s = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i = i_2;
						s = (*n)._kind_6.sons->data[i];
						checkForMetaFields__NRIJDWZtATzMum7OEjYC2g_15(c, s);
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
		T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T11_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		checkForMetaFields__NRIJDWZtATzMum7OEjYC2g_15(c, T11_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		t = (*(*n)._kind_4.sym).typ;
		switch ((*t).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
		{
			NI start;
			start = ((2560 &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
				i_4 = start;
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA16;
						i_3 = i_4;
						checkMeta__ZPW6MqdUk6rECHJvUIgrnA_2(c, n, (*t).sons->data[i_3]);
						i_4 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		break;
		default:
		{
			checkMeta__ZPW6MqdUk6rECHJvUIgrnA_2(c, n, t);
		}
		break;
		}
	}
	break;
	default:
	{
		{
			NimStringDesc* argX60gensym3082_;
			if (!NIM_TRUE) goto LA21_;
			argX60gensym3082_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__rF9caJawfOjYTjsgLVUSGFA_754);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym3082_, TM__rF9caJawfOjYTjsgLVUSGFA_754);
		}
		LA21_: ;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, typeSectionFinalPass__NRIJDWZtATzMum7OEjYC2g_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA7_;
						goto LA4;
					}
					LA7_: ;
					name = typeSectionTypeName__7YxUILpPxooC5qqa89a54dw_47(c, (*a)._kind_6.sons->data[((NI) 0)]);
					s = (*name)._kind_4.sym;
					{
						if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA11_;
						nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*s).info, s, (*s).kind);
					}
					LA11_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
						if (!((*(*a)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA15_;
						x = (*a)._kind_6.sons->data[((NI) 2)];
						{
							NIM_BOOL T19_;
							T19_ = (NIM_BOOL)0;
							T19_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
							if (!(T19_)) goto LA20_;
							T19_ = (((*x).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7))&31U)))!=0);
							LA20_: ;
							if (!T19_) goto LA21_;
						}
						goto LA17_;
						LA21_: ;
						{
							{
								while (1) {
									NIM_BOOL T26_;
									NI T28_;
									T26_ = (NIM_BOOL)0;
									T26_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
									if (!(T26_)) goto LA27_;
									T28_ = (NI)0;
									T28_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
									T26_ = (((NI) 0) < T28_);
									LA27_: ;
									if (!T26_) goto LA25;
									x = lastSon__UPSW0jLTX5qJL51YMUAHgw(x);
								} LA25: ;
							}
							{
								NIM_BOOL T31_;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
								T31_ = (NIM_BOOL)0;
								T31_ = !(((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 133) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 146) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 150) || (*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
								if (!(T31_)) goto LA32_;
								T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
								T33_ = safeSkipTypes__qgwlffIIb2pFkSZek4igDA((*s).typ, IL64(36275087638309136));
								T31_ = !(((147456 &((NU64)1<<((NU)((*T33_).kind)&63U)))!=0));
								LA32_: ;
								if (!T31_) goto LA34_;
								t = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, x, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
								{
									NIM_BOOL T38_;
									T38_ = (NIM_BOOL)0;
									T38_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
									if (!(T38_)) goto LA39_;
									T38_ = !(((IL64(70368744177680) &((NU64)1<<((NU)((*(*s).typ).kind)&63U)))!=0));
									LA39_: ;
									if (!T38_) goto LA40_;
									{
										NIM_BOOL T44_;
										NIM_BOOL T46_;
										T44_ = (NIM_BOOL)0;
										T44_ = ((33556480 &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
										if (!(T44_)) goto LA45_;
										T46_ = (NIM_BOOL)0;
										T46_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(t);
										T44_ = !(T46_);
										LA45_: ;
										if (!T44_) goto LA47_;
										assignType__RDstL9c8H9bSHUphDz0iB0hg((*s).typ, t);
										(*(*s).typ).Sup.id = (*t).Sup.id;
									}
									goto LA42_;
									LA47_: ;
									{
										if (!((155648 &((NU64)1<<((NU)((*t).kind)&63U)))!=0)) goto LA50_;
										assignType__RDstL9c8H9bSHUphDz0iB0hg((*s).typ, t);
										(*(*s).typ).Sup.id = (*t).Sup.id;
									}
									goto LA42_;
									LA50_: ;
									LA42_: ;
								}
								LA40_: ;
							}
							LA34_: ;
							checkConstructedType__09chTcGpP9cwUssGPOfkWIGw((*(*c).graph).config, (*s).info, (*s).typ);
							{
								NIM_BOOL T54_;
								T54_ = (NIM_BOOL)0;
								T54_ = ((393216 &((NU64)1<<((NU)((*(*s).typ).kind)&63U)))!=0);
								if (!(T54_)) goto LA55_;
								T54_ = !(((*(*s).typ).n == 0));
								LA55_: ;
								if (!T54_) goto LA56_;
								checkForMetaFields__NRIJDWZtATzMum7OEjYC2g_15(c, (*(*s).typ).n);
								{
									NIM_BOOL T60_;
									NIM_BOOL T62_;
									T60_ = (NIM_BOOL)0;
									T60_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
									if (!(T60_)) goto LA61_;
									T62_ = (NIM_BOOL)0;
									T62_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
									T60_ = !(T62_);
									LA61_: ;
									if (!T60_) goto LA63_;
									(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36)) & 63);
								}
								LA63_: ;
							}
							LA56_: ;
						}
						LA17_: ;
					}
					LA15_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTypeSection__7YxUILpPxooC5qqa89a54dw_46)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0));
		if (T3_) goto LA4_;
		T3_ = !((((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7))&31U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*c).inTypeContext += ((NI) 1);
		typeSectionLeftSidePass__NRIJDWZtATzMum7OEjYC2g_12(c, n);
		typeSectionRightSidePass__NRIJDWZtATzMum7OEjYC2g_13(c, n);
		typeSectionFinalPass__NRIJDWZtATzMum7OEjYC2g_14(c, n);
		(*c).inTypeContext -= ((NI) 1);
	}
	LA5_: ;
	result = n;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semDiscard__7YxUILpPxooC5qqa89a54dw_48)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* sonType;
		tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw sonKind;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
		sonType = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
		sonKind = (*(*n)._kind_6.sons->data[((NI) 0)]).kind;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(sonType);
			if (T8_) goto LA9_;
			T8_ = ((257 &((NU64)1<<((NU)((*sonType).kind)&63U)))!=0);
			LA9_: ;
			T7_ = T8_;
			if (T7_) goto LA10_;
			T7_ = (sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132));
			LA10_: ;
			if (!T7_) goto LA11_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_755), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_756, NIM_FALSE);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			NimStringDesc* T19_;
			NimStringDesc* T20_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((*sonType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T15_)) goto LA16_;
			T15_ = !((sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || sonKind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)));
			LA16_: ;
			if (!T15_) goto LA17_;
			T19_ = (NimStringDesc*)0;
			T20_ = (NimStringDesc*)0;
			T20_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A((*n)._kind_6.sons->data[((NI) 0)]);
			T19_ = rawNewString((T20_ ? T20_->Sup.len : 0) + 38);
appendString(T19_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_757));
appendString(T19_, T20_);
appendString(T19_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_198));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_758, NIM_FALSE);
		}
		LA17_: ;
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semWhile__vJZwz9bfROKrfrtM50y74CQ_31)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T2_));
	(*(*c).p).nestedLoopCounter += ((NI) 1);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, (*n)._kind_6.sons->data[((NI) 1)], flags));
	(*(*c).p).nestedLoopCounter -= ((NI) 1);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).typ == (*c).enforceVoidContext)) goto LA5_;
		asgnRef((void**) (&(*result).typ), (*c).enforceVoidContext);
	}
	goto LA3_;
	LA5_: ;
	{
		if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0)) goto LA8_;
		asgnRef((void**) (&(*result).typ), (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	}
	goto LA3_;
	LA8_: ;
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semTry__vJZwz9bfROKrfrtM50y74CQ_32)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg check;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	NI last;
	NI T2_;
	NI catchAllExcepts;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&check), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&check));
	result = n;
	(*(*c).p).inTryStmt += ((NI) 1);
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T1_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T1_).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6);
	typ = T1_;
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42(c, (*n)._kind_6.sons->data[((NI) 0)]));
	typ = commonType__hfwrZ5ThSx8sbABQFEwdHg(typ, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
	T2_ = (NI)0;
	T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	last = (NI)(T2_ - ((NI) 1));
	catchAllExcepts = ((NI) 0);
	{
		NI i;
		NI res;
		i = (NI)0;
		res = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T6_;
				NI T98_;
				NI T99_;
				if (!(res <= last)) goto LA5;
				i = res;
				a = (*n)._kind_6.sons->data[i];
				checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 1), (*(*c).graph).config);
				T6_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
				T6_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
				{
					if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87))) goto LA9_;
					{
						NIM_BOOL T13_;
						NI T14_;
						tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T18_;
						T13_ = (NIM_BOOL)0;
						T14_ = (NI)0;
						T14_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						T13_ = (T14_ == ((NI) 2));
						if (!(T13_)) goto LA15_;
						T13_ = ((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
						LA15_: ;
						if (!T13_) goto LA16_;
						T18_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), ((NI) 0));
						X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*a)._kind_6.sons), T18_, (*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data, ((*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons ? (*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->Sup.len : 0));
					}
					LA16_: ;
					{
						NIM_BOOL T21_;
						NI T22_;
						NIM_BOOL isImported;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym2311_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T26_;
						NIM_BOOL isImportedX60gensym2311_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* symbol;
						T21_ = (NIM_BOOL)0;
						T22_ = (NI)0;
						T22_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						T21_ = (T22_ == ((NI) 2));
						if (!(T21_)) goto LA23_;
						T21_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*a)._kind_6.sons->data[((NI) 0)]);
						LA23_: ;
						if (!T21_) goto LA24_;
						T26_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T26_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
						typX60gensym2311_ = toObject__IIQZtbSxQZOu2WmBJ9bnpCg_2(T26_);
						isImportedX60gensym2311_ = NIM_FALSE;
						{
							NIM_BOOL T29_;
							T29_ = (NIM_BOOL)0;
							T29_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A(typX60gensym2311_, (*(*c).graph).config);
							if (!T29_) goto LA30_;
							isImportedX60gensym2311_ = NIM_TRUE;
						}
						goto LA27_;
						LA30_: ;
						{
							NIM_BOOL T33_;
							T33_ = (NIM_BOOL)0;
							T33_ = isException__YPjOkGV9axAnGR3UfLeWZ1g_13(typX60gensym2311_);
							if (!!(T33_)) goto LA34_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_670), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_759, NIM_FALSE);
						}
						goto LA27_;
						LA34_: ;
						LA27_: ;
						{
							NIM_BOOL T38_;
							T38_ = (NIM_BOOL)0;
							T38_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&check), (*typX60gensym2311_).Sup.id);
							if (!T38_) goto LA39_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_760), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_761, NIM_FALSE);
						}
						LA39_: ;
						asgnRef((void**) (&(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]), newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).info, typX60gensym2311_));
						isImported = isImportedX60gensym2311_;
						symbol = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9), (*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 2)], c);
						{
							if (!isImported) goto LA43_;
							asgnRef((void**) (&(*symbol).typ), (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).typ);
						}
						goto LA41_;
						LA43_: ;
						{
							asgnRef((void**) (&(*symbol).typ), toRef__IIQZtbSxQZOu2WmBJ9bnpCg((*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).typ));
						}
						LA41_: ;
						addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, symbol);
						asgnRef((void**) (&(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 2)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(symbol, (*(*(*a)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 2)]).info));
					}
					goto LA19_;
					LA24_: ;
					{
						NI T47_;
						T47_ = (NI)0;
						T47_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!(T47_ == ((NI) 1))) goto LA48_;
						catchAllExcepts += ((NI) 1);
					}
					goto LA19_;
					LA48_: ;
					{
						NIM_BOOL isNative;
						NIM_BOOL isImported_2;
						{
							if (!(((NI) 0) < catchAllExcepts)) goto LA53_;
							catchAllExcepts += ((NI) 1);
						}
						LA53_: ;
						isNative = (NIM_BOOL)0;
						isImported_2 = (NIM_BOOL)0;
						{
							NI j;
							NI colontmp_;
							NI T56_;
							NI i_2;
							j = (NI)0;
							colontmp_ = (NI)0;
							T56_ = (NI)0;
							T56_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
							colontmp_ = (NI)(T56_ - ((NI) 1));
							i_2 = ((NI) 0);
							{
								while (1) {
									NIM_BOOL tmp;
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typX60gensym2331_;
									tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T59_;
									NIM_BOOL isImportedX60gensym2331_;
									if (!(i_2 < colontmp_)) goto LA58;
									j = i_2;
									T59_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
									T59_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[j], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
									typX60gensym2331_ = toObject__IIQZtbSxQZOu2WmBJ9bnpCg_2(T59_);
									isImportedX60gensym2331_ = NIM_FALSE;
									{
										NIM_BOOL T62_;
										T62_ = (NIM_BOOL)0;
										T62_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A(typX60gensym2331_, (*(*c).graph).config);
										if (!T62_) goto LA63_;
										isImportedX60gensym2331_ = NIM_TRUE;
									}
									goto LA60_;
									LA63_: ;
									{
										NIM_BOOL T66_;
										T66_ = (NIM_BOOL)0;
										T66_ = isException__YPjOkGV9axAnGR3UfLeWZ1g_13(typX60gensym2331_);
										if (!!(T66_)) goto LA67_;
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_670), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_759, NIM_FALSE);
									}
									goto LA60_;
									LA67_: ;
									LA60_: ;
									{
										NIM_BOOL T71_;
										T71_ = (NIM_BOOL)0;
										T71_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&check), (*typX60gensym2331_).Sup.id);
										if (!T71_) goto LA72_;
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[j]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_760), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_761, NIM_FALSE);
									}
									LA72_: ;
									asgnRef((void**) (&(*a)._kind_6.sons->data[j]), newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*(*a)._kind_6.sons->data[j]).info, typX60gensym2331_));
									tmp = isImportedX60gensym2331_;
									{
										if (!tmp) goto LA76_;
										isImported_2 = NIM_TRUE;
									}
									goto LA74_;
									LA76_: ;
									{
										isNative = NIM_TRUE;
									}
									LA74_: ;
									i_2 += ((NI) 1);
								} LA58: ;
							}
						}
						{
							NIM_BOOL T81_;
							T81_ = (NIM_BOOL)0;
							T81_ = isNative;
							if (!(T81_)) goto LA82_;
							T81_ = isImported_2;
							LA82_: ;
							if (!T81_) goto LA83_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*a)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_762), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_763, NIM_FALSE);
						}
						LA83_: ;
					}
					LA19_: ;
				}
				goto LA7_;
				LA9_: ;
				{
					if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA86_;
					{
						NI T90_;
						T90_ = (NI)0;
						T90_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						if (!!((i == (NI)(T90_ - ((NI) 1))))) goto LA91_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_764), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_765, NIM_FALSE);
					}
					LA91_: ;
				}
				goto LA7_;
				LA86_: ;
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
				}
				LA7_: ;
				{
					if (!(((NI) 1) < catchAllExcepts)) goto LA96_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_766), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_767, NIM_FALSE);
				}
				LA96_: ;
				T98_ = (NI)0;
				T98_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
				T99_ = (NI)0;
				T99_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
				asgnRef((void**) (&(*a)._kind_6.sons->data[(NI)(T98_ - ((NI) 1))]), semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42(c, (*a)._kind_6.sons->data[(NI)(T99_ - ((NI) 1))]));
				{
					NI T104_;
					if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107)))) goto LA102_;
					T104_ = (NI)0;
					T104_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*a)._kind_6.sons->data[(NI)(T104_ - ((NI) 1))]);
				}
				goto LA100_;
				LA102_: ;
				{
					last -= ((NI) 1);
				}
				LA100_: ;
				closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
				res += ((NI) 1);
			} LA5: ;
		}
	}
	(*(*c).p).inTryStmt -= ((NI) 1);
	{
		NIM_BOOL T108_;
		T108_ = (NIM_BOOL)0;
		T108_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(typ);
		if (T108_) goto LA109_;
		T108_ = ((96 &((NU64)1<<((NU)((*typ).kind)&63U)))!=0);
		LA109_: ;
		if (!T108_) goto LA110_;
		discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, (*n)._kind_6.sons->data[((NI) 0)], flags);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T115_;
					if (!(i_4 < colontmp__2)) goto LA114;
					i_3 = i_4;
					T115_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T115_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
					discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, T115_, flags);
					i_4 += ((NI) 1);
				} LA114: ;
			}
		}
		{
			if (!(typ == (*c).enforceVoidContext)) goto LA118_;
			asgnRef((void**) (&(*result).typ), (*c).enforceVoidContext);
		}
		LA118_: ;
	}
	goto LA106_;
	LA110_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T123_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T126_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T127_;
			T123_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T123_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			if (!((*T123_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107))) goto LA124_;
			T126_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T126_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			T127_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T127_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(T126_);
			discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, T127_, flags);
		}
		LA124_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*n)._kind_6.sons->data[((NI) 0)], (*(*n)._kind_6.sons->data[((NI) 0)]).info));
		{
			NI i_5;
			NI res_2;
			i_5 = (NI)0;
			res_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					NI j_2;
					NI T131_;
					if (!(res_2 <= last)) goto LA130;
					i_5 = res_2;
					it = (*n)._kind_6.sons->data[i_5];
					T131_ = (NI)0;
					T131_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					j_2 = (NI)(T131_ - ((NI) 1));
					{
						NIM_BOOL T134_;
						T134_ = (NIM_BOOL)0;
						T134_ = endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5((*it)._kind_6.sons->data[j_2]);
						if (!!(T134_)) goto LA135_;
						asgnRef((void**) (&(*it)._kind_6.sons->data[j_2]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*it)._kind_6.sons->data[j_2], (*(*it)._kind_6.sons->data[j_2]).info));
					}
					LA135_: ;
					res_2 += ((NI) 1);
				} LA130: ;
			}
		}
		asgnRef((void**) (&(*result).typ), typ);
	}
	LA106_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semBreakOrContinue__7YxUILpPxooC5qqa89a54dw_49)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111)))) goto LA7_;
			s = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			switch ((*(*n)._kind_6.sons->data[((NI) 0)]).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
			{
				s = lookUp__CLMmoDuBHkJLvNsKvljGNw_2(c, (*n)._kind_6.sons->data[((NI) 0)]);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
			{
				s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
			}
			break;
			default:
			{
				illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
			}
			break;
			}
			s = getGenSym__pT6glwCH57hiSrY6Jp4rug(c, s);
			{
				NIM_BOOL T14_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
				T14_ = (NIM_BOOL)0;
				T14_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22));
				if (!(T14_)) goto LA15_;
				T14_ = ((*(*s).owner).Sup.id == (*(*(*c).p).owner).Sup.id);
				LA15_: ;
				if (!T14_) goto LA16_;
				x = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(s);
				(*x).info = (*n).info;
				(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), x);
				suggestSym__c4UsAt49bYALbZKCjgqOrCQsigmatch((*(*c).graph).config, (*x).info, s, &(*(*c).graph).usageSym, NIM_TRUE);
			}
			goto LA12_;
			LA16_: ;
			{
				NimStringDesc* T19_;
				T19_ = (NimStringDesc*)0;
				T19_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_768), (*(*s).name).s);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T19_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_769, NIM_FALSE);
			}
			LA12_: ;
		}
		goto LA5_;
		LA7_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_770), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_771, NIM_FALSE);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T22_;
		NIM_BOOL T24_;
		NimStringDesc* T28_;
		NimStringDesc* T29_;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*(*c).p).nestedLoopCounter <= ((NI) 0));
		if (!(T22_)) goto LA23_;
		T24_ = (NIM_BOOL)0;
		T24_ = ((*(*c).p).nestedBlockCounter <= ((NI) 0));
		if (T24_) goto LA25_;
		T24_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111));
		LA25_: ;
		T22_ = T24_;
		LA23_: ;
		if (!T22_) goto LA26_;
		T28_ = (NimStringDesc*)0;
		T28_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
		T29_ = (NimStringDesc*)0;
		T29_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_768), T28_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T29_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_772, NIM_FALSE);
	}
	goto LA1_;
	LA26_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleStmtMacro__15J7kYDEVfuA6C4REjC7dA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* selector, NimStringDesc* magicType, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* maType;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* headSymbol;
		tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* match;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* symx;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callExpr;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T33_;
		if (!((*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*selector).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA3_;
		maType = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*c).graph, magicType);
		{
			if (!(maType == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA7_;
			goto BeforeRet_;
		}
		LA7_: ;
		headSymbol = (*selector)._kind_6.sons->data[((NI) 0)];
		nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
		match = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		symx = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, headSymbol);
		{
			while (1) {
				if (!!((symx == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
				{
					if (!((393216 &((NU32)1<<((NU)((*symx).kind)&31U)))!=0)) goto LA13_;
					{
						NIM_BOOL T17_;
						NI T18_;
						T17_ = (NIM_BOOL)0;
						T18_ = (NI)0;
						T18_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*symx).typ);
						T17_ = (T18_ == ((NI) 2));
						if (!(T17_)) goto LA19_;
						T17_ = ((*(*symx).typ).sons->data[((NI) 1)] == (*maType).typ);
						LA19_: ;
						if (!T17_) goto LA20_;
						{
							if (!(match == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA24_;
							match = symx;
						}
						goto LA22_;
						LA24_: ;
						{
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T27_;
							NimStringDesc* T28_;
							nimZeroMem((void*)T27_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T27_[0] = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, match, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
							T27_[1] = getProcHeader__bRG2xX9ar5tfMW3c7xo9ccKQ((*(*c).graph).config, symx, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0), NIM_TRUE);
							T27_[2] = dollar___qX5C9b0n9bOP7jk69amC8dA7A(selector);
							T28_ = (NimStringDesc*)0;
							T28_ = nsuFormatOpenArray(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_377), T27_, 3);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T28_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_773, NIM_FALSE);
						}
						LA22_: ;
					}
					LA20_: ;
				}
				LA13_: ;
				symx = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, headSymbol);
			} LA10: ;
		}
		{
			if (!(match == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA31_;
			goto BeforeRet_;
		}
		LA31_: ;
		callExpr = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
		T33_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T33_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(match);
		add__P8dDSotTW25BkfbyspojGg(callExpr, T33_);
		add__P8dDSotTW25BkfbyspojGg(callExpr, n);
		switch ((*match).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
		{
			result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, callExpr, callExpr, match, flags);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
		{
			result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, callExpr, match, flags);
		}
		break;
		default:
		{
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		break;
		}
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleForLoopMacro__vJZwz9bfROKrfrtM50y74CQ_34)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	result = handleStmtMacro__15J7kYDEVfuA6C4REjC7dA(c, n, (*n)._kind_6.sons->data[(NI)(T1_ - ((NI) 2))], ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_774), flags);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprNoDeref__vJZwz9bfROKrfrtM50y74CQ_35)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semExprCheck__vJZwz9bfROKrfrtM50y74CQ_2(c, n, flags);
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_775), T5_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_776, NIM_FALSE);
		asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrivalStmtExpr__OiccTa3ruRNl9anoSqZh2Sg_6)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T2_ - ((NI) 1));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA7_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA7_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA3_;
		m = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		m = n;
	}
	LA1_: ;
	result = newSymG__z0Xq7x7aKOzONyxr8mX73A(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21), m, c);
	{
		if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA8_;
		nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*result).info, result, (*result).kind);
	}
	LA8_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43))) goto LA12_;
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, result, (*n)._kind_6.sons->data[((NI) 1)], TM__rF9caJawfOjYTjsgLVUSGFA_778, NIM_FALSE);
	}
	LA12_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semForVars__vJZwz9bfROKrfrtM50y74CQ_36)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* iterBase;
	NI T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* iter;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* iterAfterVarLent;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T138_;
	NI T139_;
	NI T140_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	iterBase = (*(*n)._kind_6.sons->data[(NI)(T1_ - ((NI) 2))]).typ;
	iter = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(iterBase, IL64(105553116268560));
	iterAfterVarLent = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(iter, IL64(140737496746000));
	{
		NIM_BOOL T4_;
		NI T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*iterAfterVarLent).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18)));
		if (T4_) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (T6_ == ((NI) 3));
		LA5_: ;
		if (!T4_) goto LA7_;
		{
			NI T11_;
			T11_ = (NI)0;
			T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T11_ == ((NI) 3))) goto LA12_;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA16_;
				{
					NI T20_;
					NI T21_;
					T20_ = (NI)0;
					T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 0)]);
					T21_ = (NI)0;
					T21_ = len__5mJADrRYkP3r9auuiuDZN9cQast(iterAfterVarLent);
					if (!!(((NI)(T20_ - ((NI) 1)) == T21_))) goto LA22_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_777, NIM_FALSE);
				}
				LA22_: ;
				{
					NI i;
					NI colontmp_;
					NI T25_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					T25_ = (NI)0;
					T25_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 0)]);
					colontmp_ = (NI)(T25_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
							if (!(i_2 < colontmp_)) goto LA27;
							i = i_2;
							v = symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[i]);
							{
								tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T30_;
								T30_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
								T30_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
								if (!((*T30_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA31_;
								(*v).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
							}
							LA31_: ;
							switch ((*iter).kind) {
							case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
							case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
							{
								asgnRef((void**) (&(*v).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig((*iter).kind, c));
								add__9a8CdZqChTyqzq5bpSL3TzA((*v).typ, (*iterAfterVarLent).sons->data[i]);
								{
									if (!(((*iter).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0)) goto LA36_;
									(*(*v).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
								}
								LA36_: ;
							}
							break;
							default:
							{
								asgnRef((void**) (&(*v).typ), (*iter).sons->data[i]);
							}
							break;
							}
							asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[i]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v));
							{
								NIM_BOOL T41_;
								NIM_BOOL T43_;
								T41_ = (NIM_BOOL)0;
								T41_ = !((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0));
								if (!(T41_)) goto LA42_;
								T43_ = (NIM_BOOL)0;
								T43_ = isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g(v);
								T41_ = !(T43_);
								LA42_: ;
								if (!T41_) goto LA44_;
								addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, v);
							}
							goto LA39_;
							LA44_: ;
							{
								if (!((*v).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA47_;
								asgnRef((void**) (&(*v).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
							}
							goto LA39_;
							LA47_: ;
							LA39_: ;
							i_2 += ((NI) 1);
						} LA27: ;
					}
				}
			}
			goto LA14_;
			LA16_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v_2;
				v_2 = symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3(c, (*n)._kind_6.sons->data[((NI) 0)]);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T52_;
					T52_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T52_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
					if (!((*T52_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA53_;
					(*v_2).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
				}
				LA53_: ;
				asgnRef((void**) (&(*v_2).typ), iterBase);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v_2));
				{
					NIM_BOOL T57_;
					NIM_BOOL T59_;
					T57_ = (NIM_BOOL)0;
					T57_ = !((((*v_2).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0));
					if (!(T57_)) goto LA58_;
					T59_ = (NIM_BOOL)0;
					T59_ = isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g(v_2);
					T57_ = !(T59_);
					LA58_: ;
					if (!T57_) goto LA60_;
					addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, v_2);
				}
				goto LA55_;
				LA60_: ;
				{
					if (!((*v_2).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA63_;
					asgnRef((void**) (&(*v_2).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
				}
				goto LA55_;
				LA63_: ;
				LA55_: ;
			}
			LA14_: ;
		}
		goto LA9_;
		LA12_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_779, NIM_FALSE);
		}
		LA9_: ;
	}
	goto LA2_;
	LA7_: ;
	{
		NI T67_;
		NI T68_;
		T67_ = (NI)0;
		T67_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T68_ = (NI)0;
		T68_ = len__5mJADrRYkP3r9auuiuDZN9cQast(iterAfterVarLent);
		if (!!(((NI)(T67_ - ((NI) 2)) == T68_))) goto LA69_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_780, NIM_FALSE);
	}
	goto LA2_;
	LA69_: ;
	{
		{
			NI i_3;
			NI colontmp__2;
			NI T73_;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			T73_ = (NI)0;
			T73_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp__2 = (NI)(T73_ - ((NI) 2));
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA75;
					i_3 = i_4;
					{
						NIM_BOOL mutable_1;
						NIM_BOOL isLent;
						if (!((*(*n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA78_;
						mutable_1 = NIM_FALSE;
						isLent = NIM_FALSE;
						switch ((*(*iter).sons->data[i_3]).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
						{
							mutable_1 = NIM_TRUE;
							asgnRef((void**) (&(*iter).sons->data[i_3]), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*iter).sons->data[i_3], 8388608));
						}
						break;
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
						{
							isLent = NIM_TRUE;
							asgnRef((void**) (&(*iter).sons->data[i_3]), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*iter).sons->data[i_3], IL64(140737488355328)));
						}
						break;
						default:
						{
						}
						break;
						}
						{
							NI T85_;
							NI T86_;
							T85_ = (NI)0;
							T85_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i_3]);
							T86_ = (NI)0;
							T86_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*iter).sons->data[i_3]);
							if (!!(((NI)(T85_ - ((NI) 1)) == T86_))) goto LA87_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[i_3]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_781, NIM_FALSE);
						}
						LA87_: ;
						{
							NI j;
							NI colontmp__3;
							NI T90_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T90_ = (NI)0;
							T90_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i_3]);
							colontmp__3 = (NI)(T90_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v_3;
									if (!(i_5 < colontmp__3)) goto LA92;
									j = i_5;
									v_3 = symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3(c, (*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[j]);
									{
										tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T95_;
										T95_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
										T95_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
										if (!((*T95_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA96_;
										(*v_3).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
									}
									LA96_: ;
									{
										if (!mutable_1) goto LA100_;
										asgnRef((void**) (&(*v_3).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23), c));
										add__9a8CdZqChTyqzq5bpSL3TzA((*v_3).typ, (*(*iter).sons->data[i_3]).sons->data[j]);
									}
									goto LA98_;
									LA100_: ;
									{
										if (!isLent) goto LA103_;
										asgnRef((void**) (&(*v_3).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47), c));
										add__9a8CdZqChTyqzq5bpSL3TzA((*v_3).typ, (*(*iter).sons->data[i_3]).sons->data[j]);
									}
									goto LA98_;
									LA103_: ;
									{
										asgnRef((void**) (&(*v_3).typ), (*(*iter).sons->data[i_3]).sons->data[j]);
									}
									LA98_: ;
									asgnRef((void**) (&(*(*n)._kind_6.sons->data[i_3])._kind_6.sons->data[j]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v_3));
									{
										NIM_BOOL T108_;
										T108_ = (NIM_BOOL)0;
										T108_ = isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g(v_3);
										if (!!(T108_)) goto LA109_;
										addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, v_3);
									}
									goto LA106_;
									LA109_: ;
									{
										if (!((*v_3).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA112_;
										asgnRef((void**) (&(*v_3).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
									}
									goto LA106_;
									LA112_: ;
									LA106_: ;
									i_5 += ((NI) 1);
								} LA92: ;
							}
						}
					}
					goto LA76_;
					LA78_: ;
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v_4;
						v_4 = symForVar__AO57Q9bSpsZiuv7kwwoM7yw_3(c, (*n)._kind_6.sons->data[i_3]);
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T117_;
							T117_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T117_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
							if (!((*T117_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA118_;
							(*v_4).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
						}
						LA118_: ;
						switch ((*iter).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
						{
							asgnRef((void**) (&(*v_4).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig((*iter).kind, c));
							add__9a8CdZqChTyqzq5bpSL3TzA((*v_4).typ, (*iterAfterVarLent).sons->data[i_3]);
							{
								if (!(((*iter).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20))&63U)))!=0)) goto LA123_;
								(*(*v_4).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
							}
							LA123_: ;
						}
						break;
						default:
						{
							asgnRef((void**) (&(*v_4).typ), (*iter).sons->data[i_3]);
						}
						break;
						}
						asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v_4));
						{
							if (!!((((*v_4).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 36))&63U)))!=0))) goto LA128_;
							{
								NIM_BOOL T132_;
								T132_ = (NIM_BOOL)0;
								T132_ = isDiscardUnderscore__Brh9b6lg9c65wJVd9bszm1D1g(v_4);
								if (!!(T132_)) goto LA133_;
								addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, v_4);
							}
							LA133_: ;
						}
						goto LA126_;
						LA128_: ;
						{
							if (!((*v_4).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA136_;
							asgnRef((void**) (&(*v_4).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
						}
						goto LA126_;
						LA136_: ;
						LA126_: ;
					}
					LA76_: ;
					i_4 += ((NI) 1);
				} LA75: ;
			}
		}
	}
	LA2_: ;
	(*(*c).p).nestedLoopCounter += ((NI) 1);
	T138_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T138_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	T139_ = (NI)0;
	T139_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T140_ = (NI)0;
	T140_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T139_ - ((NI) 1))]), semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28(c, (*n)._kind_6.sons->data[(NI)(T140_ - ((NI) 1))], flags));
	{
		NI T145_;
		if (!!(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0))) goto LA143_;
		T145_ = (NI)0;
		T145_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, (*n)._kind_6.sons->data[(NI)(T145_ - ((NI) 1))], flags);
	}
	LA143_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	(*(*c).p).nestedLoopCounter -= ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, instFieldLoopBody__NWigU6dr5apz5g827GjO4w)(tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forLoop) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*c).field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*(*c).field).typ);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		goto BeforeRet_;
	}
	LA5_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
		result = n;
		ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		{
			if (!(*c).replaceByFieldName) goto LA11_;
			{
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T15_;
				NimStringDesc* fieldName;
				T15_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T15_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, (*forLoop)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				if (!((*ident).Sup.id == (*T15_).Sup.id)) goto LA16_;
				{
					if (!((*c).tupleType == 0)) goto LA20_;
					fieldName = (*(*(*c).field).name).s;
				}
				goto LA18_;
				LA20_: ;
				{
					NimStringDesc* T25_;
					NimStringDesc* T26_;
					if (!((*(*c).tupleType).n == 0)) goto LA23_;
					T25_ = (NimStringDesc*)0;
					T26_ = (NimStringDesc*)0;
					T26_ = nimIntToStr((*c).tupleIndex);
					T25_ = rawNewString((T26_ ? T26_->Sup.len : 0) + 5);
appendString(T25_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_789));
appendString(T25_, T26_);
					fieldName = T25_;
				}
				goto LA18_;
				LA23_: ;
				{
					fieldName = (*(*(*(*(*(*c).tupleType).n)._kind_6.sons->data[(*c).tupleIndex])._kind_4.sym).name).s;
				}
				LA18_: ;
				result = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), fieldName);
				goto BeforeRet_;
			}
			LA16_: ;
		}
		LA11_: ;
		{
			NI i;
			NI colontmp_;
			NI colontmp__2;
			NI T29_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp__2 = (NI)0;
			colontmp_ = (*c).replaceByFieldName;
			T29_ = (NI)0;
			T29_ = len__P89cqdlERShb9alU3iC0yj8wast(forLoop);
			colontmp__2 = (NI)(T29_ - ((NI) 2));
			i_2 = colontmp_;
			{
				while (1) {
					if (!(i_2 < colontmp__2)) goto LA31;
					i = i_2;
					{
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T34_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
						NI T37_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tupl;
						T34_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
						T34_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*c).c, (*forLoop)._kind_6.sons->data[i], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						if (!((*ident).Sup.id == (*T34_).Sup.id)) goto LA35_;
						T37_ = (NI)0;
						T37_ = len__P89cqdlERShb9alU3iC0yj8wast(forLoop);
						call = (*forLoop)._kind_6.sons->data[(NI)(T37_ - ((NI) 2))];
						tupl = (*call)._kind_6.sons->data[(NI)((NI)(i + ((NI) 1)) - (*c).replaceByFieldName)];
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
							if (!((*c).field == 0)) goto LA40_;
							result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42), (*n).info);
							add__P8dDSotTW25BkfbyspojGg(result, tupl);
							T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T42_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) ((*c).tupleIndex)));
							add__P8dDSotTW25BkfbyspojGg(result, T42_);
						}
						goto LA38_;
						LA40_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
							result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45), (*n).info);
							add__P8dDSotTW25BkfbyspojGg(result, tupl);
							T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T44_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*c).field, (*n).info);
							add__P8dDSotTW25BkfbyspojGg(result, T44_);
						}
						LA38_: ;
						goto LA28;
					}
					LA35_: ;
					i_2 += ((NI) 1);
				} LA31: ;
			}
		} LA28: ;
	}
	break;
	default:
	{
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111))) goto LA48_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*c).c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_790), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_791, NIM_FALSE);
		}
		LA48_: ;
		result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(n);
		{
			NI i_3;
			NI colontmp__3;
			NI i_4;
			i_3 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__3)) goto LA52;
					i_3 = i_4;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i_3]), instFieldLoopBody__NWigU6dr5apz5g827GjO4w(c, (*n)._kind_6.sons->data[i_3], forLoop));
					i_4 += ((NI) 1);
				} LA52: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ)(tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forLoop, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father) {
{	switch ((*typ).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA fc;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T2_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T3_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T4_;
		nimZeroMem((void*)(&fc), sizeof(tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA));
		fc.c = c.c;
		fc.field = (*typ)._kind_4.sym;
		fc.replaceByFieldName = (c.m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 129));
		T2_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T2_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c.c);
		(*c.c).inUnrolledContext += ((NI) 1);
		T3_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T3_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(forLoop);
		body = instFieldLoopBody__NWigU6dr5apz5g827GjO4w((&fc), T3_, forLoop);
		T4_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T4_ = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c.c, body, 0);
		add__P8dDSotTW25BkfbyspojGg(father, T4_);
		(*c.c).inUnrolledContext -= ((NI) 1);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c.c);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
		NI T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* caseStmt;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* access;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(forLoop);
		call = (*forLoop)._kind_6.sons->data[(NI)(T7_ - ((NI) 2))];
		{
			NI T10_;
			T10_ = (NI)0;
			T10_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
			if (!(((NI) 2) < T10_)) goto LA11_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c.c).graph).config, (*forLoop).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_792), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_793, NIM_FALSE);
			goto BeforeRet_;
		}
		LA11_: ;
		semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ(c, (*typ)._kind_6.sons->data[((NI) 0)], forLoop, father);
		caseStmt = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97), (*forLoop).info);
		access = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45), (*forLoop).info, ((NI) 2));
		asgnRef((void**) (&(*access)._kind_6.sons->data[((NI) 0)]), (*call)._kind_6.sons->data[((NI) 1)]);
		asgnRef((void**) (&(*access)._kind_6.sons->data[((NI) 1)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*(*typ)._kind_6.sons->data[((NI) 0)])._kind_4.sym, (*forLoop).info));
		T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T13_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c.c, access, 0);
		add__P8dDSotTW25BkfbyspojGg(caseStmt, T13_);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(typ);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* branch;
					NI T17_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
					NI T19_;
					if (!(i_2 < colontmp_)) goto LA16;
					i = i_2;
					branch = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*typ)._kind_6.sons->data[i]);
					T17_ = (NI)0;
					T17_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					asgnRef((void**) (&(*branch)._kind_6.sons->data[(NI)(T17_ - ((NI) 1))]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*forLoop).info));
					T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T18_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*typ)._kind_6.sons->data[i]);
					T19_ = (NI)0;
					T19_ = len__P89cqdlERShb9alU3iC0yj8wast(branch);
					semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ(c, T18_, forLoop, (*branch)._kind_6.sons->data[(NI)(T19_ - ((NI) 1))]);
					add__P8dDSotTW25BkfbyspojGg(caseStmt, branch);
					i_2 += ((NI) 1);
				} LA16: ;
			}
		}
		add__P8dDSotTW25BkfbyspojGg(father, caseStmt);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* t;
			t = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(typ);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA24;
						i_3 = i_4;
						t = (*typ)._kind_6.sons->data[i_3];
						semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ(c, t, forLoop, father);
						i_4 += ((NI) 1);
					} LA24: ;
				}
			}
		}
	}
	break;
	default:
	{
		illFormedAstLocal__aOnJJ9cXkOooTyUuLmnc09bw_2(typ, (*(*c.c).graph).config);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semForFields__7e8kUc3a9a4gEAcnG7wUcyQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* trueSymbol;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stmts;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	NI T8_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tupleTypeA;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96), (*n).info, ((NI) 2));
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_782));
	trueSymbol = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*(*c).graph).systemModule)._kind_3.tab, T1_);
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T6_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		if (!(trueSymbol == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_783), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_784, NIM_FALSE);
		T6_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T6_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_782));
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		trueSymbol = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T6_, T7_, (*n).info, 0);
		asgnRef((void**) (&(*trueSymbol).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1)));
	}
	LA4_: ;
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(trueSymbol, (*n).info));
	stmts = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), stmts);
	T8_ = (NI)0;
	T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	call = (*n)._kind_6.sons->data[(NI)(T8_ - ((NI) 2))];
	{
		NI T11_;
		NI T12_;
		T11_ = (NI)0;
		T11_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
		if (!!(((NI)(T11_ - ((NI) 2)) == (NI)((NI)(T12_ - ((NI) 1)) + (m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 129)))))) goto LA13_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_552), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_786, NIM_FALSE);
		goto BeforeRet_;
	}
	LA13_: ;
	tupleTypeA = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*call)._kind_6.sons->data[((NI) 1)]).typ, IL64(49785886514128912));
	{
		if (!!(((393216 &((NU64)1<<((NU)((*tupleTypeA).kind)&63U)))!=0))) goto LA17_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_787), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_788, NIM_FALSE);
		goto BeforeRet_;
	}
	LA17_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(call);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tupleTypeB;
				if (!(i_2 < colontmp_)) goto LA21;
				i = i_2;
				tupleTypeB = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*call)._kind_6.sons->data[i]).typ, IL64(49785886514128912));
				{
					NIM_BOOL T24_;
					T24_ = (NIM_BOOL)0;
					T24_ = sameType__3isNyHKb0U1OCnClmflXSg(tupleTypeA, tupleTypeB, 0);
					if (!!(T24_)) goto LA25_;
					typeMismatch__1xxyFIws27lai2cG4n31Ow((*(*c).graph).config, (*(*call)._kind_6.sons->data[i]).info, tupleTypeA, tupleTypeB);
				}
				LA25_: ;
				i_2 += ((NI) 1);
			} LA21: ;
		}
	}
	(*(*c).p).nestedLoopCounter += ((NI) 1);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
		NI T31_;
		if (!((*tupleTypeA).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA29_;
		T31_ = (NI)0;
		T31_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		loopBody = (*n)._kind_6.sons->data[(NI)(T31_ - ((NI) 1))];
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(tupleTypeA);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T35_;
					tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA fc;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
					if (!(i_4 < colontmp__2)) goto LA34;
					i_3 = i_4;
					T35_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
					T35_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
					nimZeroMem((void*)(&fc), sizeof(tyObject_TFieldInstCtx__GtjfcSJJiOiQ0USEydDBBA));
					fc.tupleType = tupleTypeA;
					fc.tupleIndex = i_3;
					fc.c = c;
					fc.replaceByFieldName = (m == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 129));
					body = instFieldLoopBody__NWigU6dr5apz5g827GjO4w((&fc), loopBody, n);
					(*c).inUnrolledContext += ((NI) 1);
					T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T36_ = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, body, 0);
					add__P8dDSotTW25BkfbyspojGg(stmts, T36_);
					(*c).inUnrolledContext -= ((NI) 1);
					closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
					i_4 += ((NI) 1);
				} LA34: ;
			}
		}
	}
	goto LA27_;
	LA29_: ;
	{
		tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw fc_2;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		nimZeroMem((void*)(&fc_2), sizeof(tyObject_TFieldsCtx__Oumniq9anVI0B7eyXhL1U9cw));
		fc_2.m = m;
		fc_2.c = c;
		t = tupleTypeA;
		{
			while (1) {
				if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA39;
				semForObjectFields__QePBJ9bHaUde9cnkvf6xqUYQ(fc_2, (*t).n, n, stmts);
				{
					if (!((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA42_;
					goto LA38;
				}
				LA42_: ;
				t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[((NI) 0)], IL64(36275087638268176));
			} LA39: ;
		} LA38: ;
	}
	LA27_: ;
	(*(*c).p).nestedLoopCounter -= ((NI) 1);
	{
		NIM_BOOL T46_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T49_;
		T46_ = (NIM_BOOL)0;
		T46_ = containsNode__3PkUvehQ5keciM9cue9ayMTw(stmts, TM__rF9caJawfOjYTjsgLVUSGFA_794);
		if (!T46_) goto LA47_;
		b = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110), (*n).info);
		T49_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T49_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
		add__P8dDSotTW25BkfbyspojGg(b, T49_);
		add__P8dDSotTW25BkfbyspojGg(stmts, b);
	}
	goto LA44_;
	LA47_: ;
	{
		result = stmts;
	}
	LA44_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isClosureIterator__EhCVbB6PynSh7XFAFVMiJA_3ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T2_)) goto LA3_;
	T2_ = (((*typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 15))&63U)))!=0);
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, implicitIterator__p09bRKOzs8qJ4GcAQ9czOv9bQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NimStringDesc* it, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*arg).info);
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, it);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T1_, (*arg).info);
	add__P8dDSotTW25BkfbyspojGg(result, T2_);
	{
		NIM_BOOL T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*arg).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*(*arg).typ).kind)&63U)))!=0);
		LA6_: ;
		if (!T5_) goto LA7_;
		T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T9_ = newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings(arg);
		add__P8dDSotTW25BkfbyspojGg(result, T9_);
	}
	goto LA3_;
	LA7_: ;
	{
		add__P8dDSotTW25BkfbyspojGg(result, arg);
	}
	LA3_: ;
	result = semExprNoDeref__vJZwz9bfROKrfrtM50y74CQ_35(c, result, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFor__vJZwz9bfROKrfrtM50y74CQ_33)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T5_;
	NI T6_;
	NI T7_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	NI T8_;
	NIM_BOOL isCallExpr;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 3), (*(*c).graph).config);
	result = handleForLoopMacro__vJZwz9bfROKrfrtM50y74CQ_34(c, n, flags);
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T5_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	result = n;
	T6_ = (NI)0;
	T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T7_ = (NI)0;
	T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T6_ - ((NI) 2))]), semExprNoDeref__vJZwz9bfROKrfrtM50y74CQ_35(c, (*n)._kind_6.sons->data[(NI)(T7_ - ((NI) 2))], 2));
	T8_ = (NI)0;
	T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	call = (*n)._kind_6.sons->data[(NI)(T8_ - ((NI) 2))];
	{
		NIM_BOOL T11_;
		NI T15_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126));
		if (!(T11_)) goto LA12_;
		T11_ = isTrivalStmtExpr__OiccTa3ruRNl9anoSqZh2Sg_6(call);
		LA12_: ;
		if (!T11_) goto LA13_;
		call = lastSon__UPSW0jLTX5qJL51YMUAHgw(call);
		T15_ = (NI)0;
		T15_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T15_ - ((NI) 2))]), call);
	}
	LA13_: ;
	isCallExpr = ((*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	{
		NIM_BOOL T18_;
		NIM_BOOL T19_;
		T18_ = (NIM_BOOL)0;
		T19_ = (NIM_BOOL)0;
		T19_ = isCallExpr;
		if (!(T19_)) goto LA20_;
		T19_ = ((*(*call)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA20_: ;
		T18_ = T19_;
		if (!(T18_)) goto LA21_;
		T18_ = ((*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 128) || (*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 129) || (*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 130));
		LA21_: ;
		if (!T18_) goto LA22_;
		{
			if (!((*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 130))) goto LA26_;
			result = semForVars__vJZwz9bfROKrfrtM50y74CQ_36(c, n, flags);
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 95));
		}
		goto LA24_;
		LA26_: ;
		{
			result = semForFields__7e8kUc3a9a4gEAcnG7wUcyQ_2(c, n, (*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic);
		}
		LA24_: ;
	}
	goto LA16_;
	LA22_: ;
	{
		NIM_BOOL T30_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T32_;
		T30_ = (NIM_BOOL)0;
		T30_ = isCallExpr;
		if (!(T30_)) goto LA31_;
		T32_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T32_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*call)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		T30_ = isClosureIterator__EhCVbB6PynSh7XFAFVMiJA_3ast(T32_);
		LA31_: ;
		if (!T30_) goto LA33_;
		result = semForVars__vJZwz9bfROKrfrtM50y74CQ_36(c, n, flags);
	}
	goto LA16_;
	LA33_: ;
	{
		NIM_BOOL T36_;
		NIM_BOOL T37_;
		T36_ = (NIM_BOOL)0;
		T37_ = (NIM_BOOL)0;
		T37_ = !(isCallExpr);
		if (T37_) goto LA38_;
		T37_ = !(((*(*call)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		LA38_: ;
		T36_ = T37_;
		if (T36_) goto LA39_;
		T36_ = !(((*(*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)));
		LA39_: ;
		if (!T36_) goto LA40_;
		{
			NI T44_;
			NI T47_;
			NI T48_;
			T44_ = (NI)0;
			T44_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T44_ == ((NI) 3))) goto LA45_;
			T47_ = (NI)0;
			T47_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T48_ = (NI)0;
			T48_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T47_ - ((NI) 2))]), implicitIterator__p09bRKOzs8qJ4GcAQ9czOv9bQ(c, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_795), (*n)._kind_6.sons->data[(NI)(T48_ - ((NI) 2))]));
		}
		goto LA42_;
		LA45_: ;
		{
			NI T50_;
			NI T53_;
			NI T54_;
			T50_ = (NI)0;
			T50_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T50_ == ((NI) 4))) goto LA51_;
			T53_ = (NI)0;
			T53_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T54_ = (NI)0;
			T54_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			asgnRef((void**) (&(*n)._kind_6.sons->data[(NI)(T53_ - ((NI) 2))]), implicitIterator__p09bRKOzs8qJ4GcAQ9czOv9bQ(c, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_796), (*n)._kind_6.sons->data[(NI)(T54_ - ((NI) 2))]));
		}
		goto LA42_;
		LA51_: ;
		{
			NI T56_;
			T56_ = (NI)0;
			T56_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[(NI)(T56_ - ((NI) 2))]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_797), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_798, NIM_FALSE);
		}
		LA42_: ;
		result = semForVars__vJZwz9bfROKrfrtM50y74CQ_36(c, n, flags);
	}
	goto LA16_;
	LA40_: ;
	{
		result = semForVars__vJZwz9bfROKrfrtM50y74CQ_36(c, n, flags);
	}
	LA16_: ;
	{
		NI T60_;
		T60_ = (NI)0;
		T60_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!((*(*n)._kind_6.sons->data[(NI)(T60_ - ((NI) 1))]).typ == (*c).enforceVoidContext)) goto LA61_;
		asgnRef((void**) (&(*result).typ), (*c).enforceVoidContext);
	}
	goto LA58_;
	LA61_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T66_;
		if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0)) goto LA64_;
		T66_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T66_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(result);
		asgnRef((void**) (&(*result).typ), (*T66_).typ);
	}
	goto LA58_;
	LA64_: ;
	LA58_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, handleCaseStmtMacro__vJZwz9bfROKrfrtM50y74CQ_38)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* toResolve;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	tySequence__0dpGN6F4ocevqUQGsaf41w* errors;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA r;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	toResolve = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_799));
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T1_, (*n).info);
	add__P8dDSotTW25BkfbyspojGg(toResolve, T2_);
	add__P8dDSotTW25BkfbyspojGg(toResolve, (*n)._kind_6.sons->data[((NI) 0)]);
	errors = (tySequence__0dpGN6F4ocevqUQGsaf41w*)0;
	nimZeroMem((void*)(&r), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	resolveOverloads__deoiEhU508ju9btmg2AXeFw(c, toResolve, toResolve, 393216, 0, (&errors), NIM_FALSE, (&r));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* match;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* toExpand;
		if (!(r.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1))) goto LA5_;
		match = r.calleeSym;
		markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*(*n)._kind_6.sons->data[((NI) 0)]).info, match);
		asgnRef((void**) (&(*r.call)._kind_6.sons->data[((NI) 1)]), n);
		toExpand = semResolvedCall__tI9alV34Tv2MGPKAeQ6xsmw(c, (&r), r.call, 0);
		switch ((*match).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
		{
			result = semMacroExpr__GFpnqBAgGBu4p8rc0WsOTw(c, toExpand, toExpand, match, flags);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
		{
			result = semTemplateExpr__NYxU2DkHA0Gt5fsL9bYZdog(c, toExpand, match, flags);
		}
		break;
		default:
		{
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		break;
		}
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCase__vJZwz9bfROKrfrtM50y74CQ_37)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	NIM_BOOL chckCovered;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA covered;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	NIM_BOOL hasElse;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* caseTyp;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	pushCaseContext__Hz1YayV9c9aSkUcvf7h2lHXQ(c, n);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
	chckCovered = NIM_FALSE;
	covered = toInt128__161i7kexvUAISxPtGBRWYw(((NI) 0));
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T2_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T2_).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6);
	typ = T2_;
	hasElse = NIM_FALSE;
	caseTyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087632017424));
	switch ((*caseTyp).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		chckCovered = NIM_TRUE;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
			T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*caseTyp).sons->data[((NI) 0)], IL64(36134350135273744));
			if (!((IL64(16559246426118) &((NU64)1<<((NU)((*T7_).kind)&63U)))!=0)) goto LA8_;
			chckCovered = NIM_TRUE;
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50):
	{
	}
	break;
	default:
	{
		popCaseContext__9aY89b9aR25iMJ8fPdM84CvQg_3(c);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
		{
			if (!(((*c).features &((NU16)1<<((NU)(((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 8))&15U)))!=0)) goto LA14_;
			result = handleCaseStmtMacro__vJZwz9bfROKrfrtM50y74CQ_38(c, n, flags);
			{
				if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA18_;
				goto BeforeRet_;
			}
			LA18_: ;
		}
		LA14_: ;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_800), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_801, NIM_FALSE);
		goto BeforeRet_;
	}
	break;
	}
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
				if (!(i_2 < colontmp_)) goto LA22;
				i = i_2;
				setCaseContextIdx__jiOUhpYURJJFfrdMgAQxPQ(c, i);
				x = (*n)._kind_6.sons->data[i];
				switch ((*x).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
				{
					NI last;
					NI T24_;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(x, ((NI) 2), (*(*c).graph).config);
					semCaseBranch__v9aNPEhC9bTKfOzSbulyV4jw(c, n, x, i, (&covered));
					T24_ = (NI)0;
					T24_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
					last = (NI)(T24_ - ((NI) 1));
					asgnRef((void**) (&(*x)._kind_6.sons->data[last]), semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42(c, (*x)._kind_6.sons->data[last]));
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*x)._kind_6.sons->data[last]);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
				{
					tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T26_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
					chckCovered = NIM_FALSE;
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(x, ((NI) 2), (*(*c).graph).config);
					T26_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
					T26_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
					T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T27_ = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*x)._kind_6.sons->data[((NI) 0)], 0);
					asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 0)]), forceBool__7YxUILpPxooC5qqa89a54dw_4(c, T27_));
					asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 1)]), semExprBranch__vJZwz9bfROKrfrtM50y74CQ_28(c, (*x)._kind_6.sons->data[((NI) 1)], 0));
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*x)._kind_6.sons->data[((NI) 1)]);
					closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
				{
					checkSonsLen__EezdXeDvu4rB7fR84AJZgw(x, ((NI) 1), (*(*c).graph).config);
					asgnRef((void**) (&(*x)._kind_6.sons->data[((NI) 0)]), semExprBranchScope__7YxUILpPxooC5qqa89a54dw_42(c, (*x)._kind_6.sons->data[((NI) 0)]));
					typ = commonType__wEK756YRi9c3lsyIxi9aFXSg(typ, (*x)._kind_6.sons->data[((NI) 0)]);
					{
						NIM_BOOL T31_;
						NIM_BOOL T32_;
						tyObject_Int128__9a9axPfb75jdWY25AamJewkA T34_;
						T31_ = (NIM_BOOL)0;
						T32_ = (NIM_BOOL)0;
						T32_ = chckCovered;
						if (!(T32_)) goto LA33_;
						T34_ = toCover__VyVU6SDhkTqKxSsQUZSePg(c, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
						T32_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(covered, T34_);
						LA33_: ;
						T31_ = T32_;
						if (T31_) goto LA35_;
						T31_ = hasElse;
						LA35_: ;
						if (!T31_) goto LA36_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 37), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_802, NIM_FALSE);
					}
					LA36_: ;
					hasElse = NIM_TRUE;
					chckCovered = NIM_FALSE;
				}
				break;
				default:
				{
					illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(x, (*(*c).graph).config);
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA22: ;
		}
	}
	{
		if (!chckCovered) goto LA41_;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T45_;
			NIM_BOOL T46_;
			T45_ = toCover__VyVU6SDhkTqKxSsQUZSePg(c, (*(*n)._kind_6.sons->data[((NI) 0)]).typ);
			T46_ = (NIM_BOOL)0;
			T46_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(covered, T45_);
			if (!T46_) goto LA47_;
			hasElse = NIM_TRUE;
		}
		goto LA43_;
		LA47_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
			NimStringDesc* T53_;
			NimStringDesc* T54_;
			T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T50_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350136322320));
			if (!((16388 &((NU64)1<<((NU)((*T50_).kind)&63U)))!=0)) goto LA51_;
			T53_ = (NimStringDesc*)0;
			T53_ = formatMissingEnums__zUJc3JNayUkQ8i11jOQJeQ(c, n);
			T54_ = (NimStringDesc*)0;
			T54_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_420), T53_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T54_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_803, NIM_FALSE);
		}
		goto LA43_;
		LA51_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_425), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_804, NIM_FALSE);
		}
		LA43_: ;
	}
	LA41_: ;
	popCaseContext__9aY89b9aR25iMJ8fPdM84CvQg_3(c);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	{
		NIM_BOOL T58_;
		NIM_BOOL T59_;
		NIM_BOOL T62_;
		T58_ = (NIM_BOOL)0;
		T59_ = (NIM_BOOL)0;
		T59_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(typ);
		if (T59_) goto LA60_;
		T59_ = ((96 &((NU64)1<<((NU)((*typ).kind)&63U)))!=0);
		LA60_: ;
		T58_ = T59_;
		if (T58_) goto LA61_;
		T62_ = (NIM_BOOL)0;
		T62_ = !(hasElse);
		if (!(T62_)) goto LA63_;
		T62_ = !(((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 2))&31U)))!=0));
		LA63_: ;
		T58_ = T62_;
		LA61_: ;
		if (!T58_) goto LA64_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T69_;
					if (!(i_4 < colontmp__2)) goto LA68;
					i_3 = i_4;
					T69_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T69_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
					discardCheck__tp7yV6CFb40nVuGT1TBFpw(c, T69_, flags);
					i_4 += ((NI) 1);
				} LA68: ;
			}
		}
		{
			if (!(typ == (*c).enforceVoidContext)) goto LA72_;
			asgnRef((void**) (&(*result).typ), (*c).enforceVoidContext);
		}
		LA72_: ;
	}
	goto LA56_;
	LA64_: ;
	{
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_6 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					NI j;
					NI T78_;
					if (!(i_6 < colontmp__3)) goto LA77;
					i_5 = i_6;
					it = (*n)._kind_6.sons->data[i_5];
					T78_ = (NI)0;
					T78_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					j = (NI)(T78_ - ((NI) 1));
					{
						NIM_BOOL T81_;
						T81_ = (NIM_BOOL)0;
						T81_ = endsInNoReturn__OiccTa3ruRNl9anoSqZh2Sg_5((*it)._kind_6.sons->data[j]);
						if (!!(T81_)) goto LA82_;
						asgnRef((void**) (&(*it)._kind_6.sons->data[j]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, typ, (*it)._kind_6.sons->data[j], (*(*it)._kind_6.sons->data[j]).info));
					}
					LA82_: ;
					i_6 += ((NI) 1);
				} LA77: ;
			}
		}
		asgnRef((void**) (&(*result).typ), typ);
	}
	LA56_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semReturn__7YxUILpPxooC5qqa89a54dw_50)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((225280 &((NU32)1<<((NU)((*(*(*c).p).owner).kind)&31U)))!=0);
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*(*c).p).owner).typ == 0));
		if (!(T5_)) goto LA6_;
		T5_ = isClosureIterator__EhCVbB6PynSh7XFAFVMiJA_3ast((*(*(*c).p).owner).typ);
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA7_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA11_;
			{
				NIM_BOOL T15_;
				NIM_BOOL T16_;
				T15_ = (NIM_BOOL)0;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73));
				if (!(T16_)) goto LA17_;
				T16_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				LA17_: ;
				T15_ = T16_;
				if (!(T15_)) goto LA18_;
				T15_ = ((*(*c).p).resultSym == (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)])._kind_4.sym);
				LA18_: ;
				if (!T15_) goto LA19_;
			}
			goto LA13_;
			LA19_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
				if (!!(((*(*c).p).resultSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA22_;
				a = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*(*n)._kind_6.sons->data[((NI) 0)]).info);
				T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T24_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*c).p).resultSym);
				add__P8dDSotTW25BkfbyspojGg(a, T24_);
				add__P8dDSotTW25BkfbyspojGg(a, (*n)._kind_6.sons->data[((NI) 0)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), a);
			}
			goto LA13_;
			LA22_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_805), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_806, NIM_FALSE);
				goto BeforeRet_;
			}
			LA13_: ;
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 0)));
			{
				NIM_BOOL T28_;
				T28_ = (NIM_BOOL)0;
				T28_ = ((*(*(*result)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
				if (!(T28_)) goto LA29_;
				T28_ = ((*(*(*result)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_4.sym == (*(*c).p).resultSym);
				LA29_: ;
				if (!T28_) goto LA30_;
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), (*(*c).graph).emptyNode);
			}
			LA30_: ;
		}
		LA11_: ;
	}
	goto LA1_;
	LA7_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_807), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_808, NIM_FALSE);
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semUsing__7YxUILpPxooC5qqa89a54dw_51)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = (*(*c).graph).emptyNode;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!!(T3_)) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_809));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_810, NIM_FALSE);
	}
	LA4_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					a = (*n)._kind_6.sons->data[i];
					{
						if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA13_;
						suggestStmt__wb6KhAx6bZ5NV37kY4bXJw_4(c, a);
					}
					LA13_: ;
					{
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA17_;
						goto LA10;
					}
					LA17_: ;
					{
						if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102)))) goto LA21_;
						illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(a, (*(*c).graph).config);
					}
					LA21_: ;
					checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(a, ((NI) 3), (*(*c).graph).config);
					{
						NI T25_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
						NI T28_;
						T25_ = (NI)0;
						T25_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!!(((*(*a)._kind_6.sons->data[(NI)(T25_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA26_;
						T28_ = (NI)0;
						T28_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						typ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, (*a)._kind_6.sons->data[(NI)(T28_ - ((NI) 2))], ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
						{
							NI j;
							NI colontmp__2;
							NI T30_;
							NI i_3;
							j = (NI)0;
							colontmp__2 = (NI)0;
							T30_ = (NI)0;
							T30_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
							colontmp__2 = (NI)(T30_ - ((NI) 2));
							i_3 = ((NI) 0);
							{
								while (1) {
									tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
									NIM_BOOL T37_;
									if (!(i_3 < colontmp__2)) goto LA32;
									j = i_3;
									v = semIdentDef__L2b79bZBCkiyCHeJkLWxPlQ(c, (*a)._kind_6.sons->data[j], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
									{
										if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA35_;
										nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw((*(*c).graph).config, (*v).info, v, (*v).kind);
									}
									LA35_: ;
									asgnRef((void**) (&(*v).typ), typ);
									T37_ = (NIM_BOOL)0;
									T37_ = strTableIncl__4C9ciVlXutN6a0CSSeSkVDA((&(*c).signatures), v, NIM_FALSE);
									i_3 += ((NI) 1);
								} LA32: ;
							}
						}
					}
					goto LA23_;
					LA26_: ;
					{
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_811), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_812, NIM_FALSE);
					}
					LA23_: ;
					def = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					{
						NI T41_;
						T41_ = (NI)0;
						T41_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
						if (!!(((*(*a)._kind_6.sons->data[(NI)(T41_ - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA42_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_813), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_814, NIM_FALSE);
					}
					LA42_: ;
				} LA10: ;
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsm__7YxUILpPxooC5qqa89a54dw_52)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_CHAR marker;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	marker = pragmaAsm__BMqa01f86BatswrKktaxCw(c, (*n)._kind_6.sons->data[((NI) 0)]);
	{
		if (!((NU8)(marker) == (NU8)(0))) goto LA3_;
		marker = 96;
	}
	LA3_: ;
	result = semAsmOrEmit__7on6juYQ5yDeHojpmzlBFg(c, n, marker);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semYieldVarResult__RmzIhIZBxhW1YDiKMLOGcQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* restype) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(restype, IL64(70368744179728));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		(*t).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59))) goto LA4_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]);
		}
		LA4_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ(c, (*n)._kind_6.sons->data[((NI) 0)], ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* e;
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					e = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t).sons->data[i], IL64(70368744179728));
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tupleConstr;
						if (!((IL64(140737496743936) &((NU64)1<<((NU)((*e).kind)&63U)))!=0)) goto LA12_;
						(*e).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
						{
							if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59))) goto LA16_;
							tupleConstr = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
						}
						goto LA14_;
						LA16_: ;
						{
							tupleConstr = (*n)._kind_6.sons->data[((NI) 0)];
						}
						LA14_: ;
						{
							if (!((*tupleConstr).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*tupleConstr).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA21_;
							{
								if (!((*(*tupleConstr)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA25_;
								asgnRef((void**) (&(*(*tupleConstr)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ(c, (*(*tupleConstr)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], ((*e).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))));
							}
							goto LA23_;
							LA25_: ;
							{
								asgnRef((void**) (&(*tupleConstr)._kind_6.sons->data[i]), takeImplicitAddr__x3K9b1cKzX9bI8nPJA1N22wQ(c, (*tupleConstr)._kind_6.sons->data[i], ((*e).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))));
							}
							LA23_: ;
						}
						goto LA19_;
						LA21_: ;
						{
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 4), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_819), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_820, NIM_FALSE);
						}
						LA19_: ;
					}
					LA12_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semYield__7YxUILpPxooC5qqa89a54dw_53)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*c).p).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*(*(*c).p).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)));
		LA4_: ;
		if (!T3_) goto LA5_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_815), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_816, NIM_FALSE);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* iterType;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* restype;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA8_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
		iterType = (*(*(*c).p).owner).typ;
		restype = (*iterType).sons->data[((NI) 0)];
		{
			if (!!((restype == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA12_;
			{
				if (!!(((*restype).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6)))) goto LA16_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), fitNode__3gQ9buvlr7tPLmWwfmGV7fw(c, restype, (*n)._kind_6.sons->data[((NI) 0)], (*n).info));
			}
			LA16_: ;
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 0)]).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA20_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_817), TM__rF9caJawfOjYTjsgLVUSGFA_818);
			}
			LA20_: ;
			{
				NIM_BOOL T24_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inferred;
				T24_ = (NIM_BOOL)0;
				T24_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(restype);
				if (!(T24_)) goto LA25_;
				T24_ = !(((*restype).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
				LA25_: ;
				if (!T24_) goto LA26_;
				inferred = (*(*n)._kind_6.sons->data[((NI) 0)]).typ;
				asgnRef((void**) (&(*iterType).sons->data[((NI) 0)]), inferred);
				{
					if (!!(((*(*c).p).resultSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA30_;
					asgnRef((void**) (&(*(*(*c).p).resultSym).typ), inferred);
				}
				LA30_: ;
			}
			LA26_: ;
			semYieldVarResult__RmzIhIZBxhW1YDiKMLOGcQ(c, n, restype);
		}
		goto LA10_;
		LA12_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_821), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_822, NIM_FALSE);
		}
		LA10_: ;
	}
	goto LA1_;
	LA8_: ;
	{
		if (!!(((*(*(*(*c).p).owner).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA34_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_823), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_824, NIM_FALSE);
	}
	goto LA1_;
	LA34_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semIterator__7YxUILpPxooC5qqa89a54dw_54)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		asgnRef((void**) (&(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).owner), getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c));
		transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym, ((tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg) 15));
	}
	LA3_: ;
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15), TM__rF9caJawfOjYTjsgLVUSGFA_826, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	{
		if (!!(((*result).kind == (*n).kind))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	s = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	t = (*s).typ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (!(T11_)) goto LA12_;
		T11_ = !(((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)));
		LA12_: ;
		if (!T11_) goto LA13_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_827), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_828, NIM_FALSE);
	}
	LA13_: ;
	{
		if (!((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA17_;
		(*(*s).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 12)) & 63);
	}
	goto LA15_;
	LA17_: ;
	{
		(*(*s).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5);
	}
	LA15_: ;
	{
		NIM_BOOL T22_;
		NimStringDesc* T26_;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		if (!(T22_)) goto LA23_;
		T22_ = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
		LA23_: ;
		if (!T22_) goto LA24_;
		T26_ = (NimStringDesc*)0;
		T26_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*s).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_829, NIM_FALSE);
	}
	LA24_: ;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = (((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0);
		if (!(T29_)) goto LA30_;
		T29_ = !(((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA30_: ;
		if (!T29_) goto LA31_;
		asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
		(*(*result).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
	}
	LA31_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semProc__7YxUILpPxooC5qqa89a54dw_55)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), TM__rF9caJawfOjYTjsgLVUSGFA_830, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semFunc__7YxUILpPxooC5qqa89a54dw_56)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13), TM__rF9caJawfOjYTjsgLVUSGFA_830, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMethod__7YxUILpPxooC5qqa89a54dw_57)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disp;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!!(T3_)) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_831));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_832, NIM_FALSE);
	}
	LA4_: ;
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14), TM__rF9caJawfOjYTjsgLVUSGFA_833, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	{
		NI T9_;
		T9_ = (NI)0;
		T9_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
		if (!(T9_ <= ((NI) 0))) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80)))) goto LA14_;
		goto BeforeRet_;
	}
	LA14_: ;
	s = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	disp = getDispatcher__L29cJgZ3WUDC7PfTSciv49cw(s);
	{
		NIM_BOOL T18_;
		NIM_BOOL T19_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ret;
		T18_ = (NIM_BOOL)0;
		T19_ = (NIM_BOOL)0;
		T19_ = !((disp == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T19_)) goto LA20_;
		T19_ = !(((*(*disp).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA20_: ;
		T18_ = T19_;
		if (!(T18_)) goto LA21_;
		T18_ = ((*(*(*disp).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
		LA21_: ;
		if (!T18_) goto LA22_;
		ret = (*(*s).typ).sons->data[((NI) 0)];
		asgnRef((void**) (&(*(*disp).typ).sons->data[((NI) 0)]), ret);
		{
			if (!((*(*(*disp).ast)._kind_6.sons->data[((NI) 7)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA26_;
			{
				NIM_BOOL T30_;
				T30_ = (NIM_BOOL)0;
				T30_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(ret);
				if (!T30_) goto LA31_;
				asgnRef((void**) (&(*(*disp).ast)._kind_6.sons->data[((NI) 7)]), (*(*c).graph).emptyNode);
			}
			goto LA28_;
			LA31_: ;
			{
				asgnRef((void**) (&(*(*(*(*disp).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym).typ), ret);
			}
			LA28_: ;
		}
		LA26_: ;
	}
	LA22_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConverterDef__7YxUILpPxooC5qqa89a54dw_58)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
		if (!!(T3_)) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_834));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_835, NIM_FALSE);
	}
	LA4_: ;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 7), (*(*c).graph).config);
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16), TM__rF9caJawfOjYTjsgLVUSGFA_830, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	{
		NI T9_;
		T9_ = (NI)0;
		T9_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
		if (!(T9_ <= ((NI) 0))) goto LA10_;
		goto BeforeRet_;
	}
	LA10_: ;
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81)))) goto LA14_;
		goto BeforeRet_;
	}
	LA14_: ;
	s = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	t = (*s).typ;
	{
		NimStringDesc* T20_;
		if (!((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA18_;
		T20_ = (NimStringDesc*)0;
		T20_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_836), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_834));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T20_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_837, NIM_FALSE);
	}
	LA18_: ;
	{
		NI T23_;
		T23_ = (NI)0;
		T23_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
		if (!!((T23_ == ((NI) 2)))) goto LA24_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_838), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_839, NIM_FALSE);
	}
	LA24_: ;
	addConverter__ymX9afTGg7YU9b9aXV3gliVtA(c, s);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semMacroDef__7YxUILpPxooC5qqa89a54dw_59)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NIM_BOOL allUntyped;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 7), (*(*c).graph).config);
	result = semProcAux__HtuGXsziiAueY6wARBVVAA(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17), TM__rF9caJawfOjYTjsgLVUSGFA_840, ((tyEnum_TProcCompilationSteps__2LY1MARGn5z4Y5kU8eJFMg) 0));
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(result);
		if (!(T3_ <= ((NI) 0))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		if (!!(((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82)))) goto LA8_;
		goto BeforeRet_;
	}
	LA8_: ;
	s = (*(*result)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	t = (*s).typ;
	allUntyped = NIM_TRUE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*t).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
				if (!(i_2 < colontmp_)) goto LA12;
				i = i_2;
				param = (*(*(*t).n)._kind_6.sons->data[i])._kind_4.sym;
				{
					if (!!(((*(*param).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6)))) goto LA15_;
					allUntyped = NIM_FALSE;
				}
				LA15_: ;
				i_2 += ((NI) 1);
			} LA12: ;
		}
	}
	{
		if (!allUntyped) goto LA19_;
		(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9)) & 63);
	}
	LA19_: ;
	{
		NimStringDesc* T25_;
		if (!((*(*n)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA23_;
		T25_ = (NimStringDesc*)0;
		T25_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_357), (*(*s).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T25_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_841, NIM_FALSE);
	}
	LA23_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incMod__AE9a7ubTroOu3uw1tThDp7g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* includeStmtResult) {
	NI32 f;
	f = checkModuleName__fDy39b69bb9cFVEyPkMJp3GTg((*(*c).graph).config, it, NIM_TRUE);
	{
		if (!!((f == ((NI32) -1)))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringDesc* T10_;
			NimStringDesc* T11_;
			T7_ = (NIM_BOOL)0;
			T7_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).includedFiles), ((NI) (f)));
			if (!T7_) goto LA8_;
			T10_ = (NimStringDesc*)0;
			T10_ = toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw((*(*c).graph).config, f);
			T11_ = (NimStringDesc*)0;
			T11_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_9), T10_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T11_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_851, NIM_FALSE);
		}
		goto LA5_;
		LA8_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T13_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
			T13_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T13_ = (*(*c).graph).includeFileCallback((*c).graph, (*c).module, f);
			T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T14_ = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, T13_, 0);
			add__P8dDSotTW25BkfbyspojGg(includeStmtResult, T14_);
			excl__jENnK9c9bPE73pKmo2vYjpqg_2((&(*c).includedFiles), ((NI) (f)));
		}
		LA5_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalInclude__7YxUILpPxooC5qqa89a54dw_60)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	add__P8dDSotTW25BkfbyspojGg(result, n);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* imp;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				imp = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				it = (*n)._kind_6.sons->data[i];
				{
					NIM_BOOL T6_;
					NIM_BOOL T7_;
					NI T9_;
					NimStringDesc* T13_;
					T6_ = (NIM_BOOL)0;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
					if (!(T7_)) goto LA8_;
					T9_ = (NI)0;
					T9_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T7_ = (T9_ == ((NI) 3));
					LA8_: ;
					T6_ = T7_;
					if (!(T6_)) goto LA10_;
					T6_ = !(eqStrings((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_847)));
					LA10_: ;
					if (!T6_) goto LA11_;
					T13_ = (NimStringDesc*)0;
					T13_ = rawNewString(((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s ? (*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s->Sup.len : 0) + 27);
appendString(T13_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_848));
appendString(T13_, (*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s);
appendString(T13_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_849));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_850, NIM_FALSE);
				}
				LA11_: ;
				{
					NIM_BOOL T16_;
					NIM_BOOL T17_;
					NI T19_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* sep;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dir;
					T16_ = (NIM_BOOL)0;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
					if (!(T17_)) goto LA18_;
					T19_ = (NI)0;
					T19_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T17_ = (T19_ == ((NI) 3));
					LA18_: ;
					T16_ = T17_;
					if (!(T16_)) goto LA20_;
					T16_ = ((*(*it)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
					LA20_: ;
					if (!T16_) goto LA21_;
					sep = (*it)._kind_6.sons->data[((NI) 0)];
					dir = (*it)._kind_6.sons->data[((NI) 1)];
					imp = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29), (*it).info);
					add__P8dDSotTW25BkfbyspojGg(imp, sep);
					add__P8dDSotTW25BkfbyspojGg(imp, dir);
					add__P8dDSotTW25BkfbyspojGg(imp, sep);
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* colontmp__2;
						x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						colontmp__2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						colontmp__2 = (*it)._kind_6.sons->data[((NI) 2)];
						{
							NI i_3;
							NI colontmp__3;
							NI i_4;
							i_3 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__3 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(colontmp__2);
							i_4 = ((NI) 0);
							{
								while (1) {
									if (!(i_4 < colontmp__3)) goto LA26;
									i_3 = i_4;
									x = (*colontmp__2)._kind_6.sons->data[i_3];
									asgnRef((void**) (&(*imp)._kind_6.sons->data[((NI) 2)]), x);
									incMod__AE9a7ubTroOu3uw1tThDp7g(c, n, imp, result);
									i_4 += ((NI) 1);
								} LA26: ;
							}
						}
					}
				}
				goto LA14_;
				LA21_: ;
				{
					incMod__AE9a7ubTroOu3uw1tThDp7g(c, n, it, result);
				}
				LA14_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExport__7YxUILpPxooC5qqa89a54dw_61)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ o;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				nimZeroMem((void*)(&o), sizeof(tyObject_TOverloadIter__5JoRhlHqSIiHe1n9a5m6IAQ));
				s = initOverloadIter__yTTeeqtnENsm0xyCro9a61w((&o), c, a);
				{
					NimStringDesc* T8_;
					NimStringDesc* T9_;
					if (!(s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA6_;
					T8_ = (NimStringDesc*)0;
					T9_ = (NimStringDesc*)0;
					T9_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(a, 0);
					T8_ = rawNewString((T9_ ? T9_->Sup.len : 0) + 15);
appendString(T8_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_853));
appendString(T8_, T9_);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_854, NIM_FALSE);
				}
				goto LA4_;
				LA6_: ;
				{
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg ti;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
					if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA11_;
					strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), s);
					nimZeroMem((void*)(&ti), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					it = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&ti), (*s)._kind_3.tab);
					{
						while (1) {
							if (!!((it == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA14;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
								if (!((43513792 &((NU32)1<<((NU)((*it).kind)&31U)))!=0)) goto LA17_;
								strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), it);
								T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T19_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(it, (*a).info);
								add__P8dDSotTW25BkfbyspojGg(result, T19_);
							}
							LA17_: ;
							it = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&ti), (*s)._kind_3.tab);
						} LA14: ;
					}
					markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
				}
				goto LA4_;
				LA11_: ;
				{
					{
						while (1) {
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA22;
							{
								NimStringDesc* T27_;
								NimStringDesc* T28_;
								if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20))) goto LA25_;
								T27_ = (NimStringDesc*)0;
								T28_ = (NimStringDesc*)0;
								T28_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(a, 0);
								T27_ = rawNewString((T28_ ? T28_->Sup.len : 0) + 59);
appendString(T27_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_853));
appendString(T27_, T28_);
appendString(T27_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_855));
								liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*a).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T27_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_856, NIM_FALSE);
							}
							LA25_: ;
							{
								NIM_BOOL T31_;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
								T31_ = (NIM_BOOL)0;
								T31_ = ((43513792 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
								if (!(T31_)) goto LA32_;
								T31_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24))&63U)))!=0));
								LA32_: ;
								if (!T31_) goto LA33_;
								T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T35_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*a).info);
								add__P8dDSotTW25BkfbyspojGg(result, T35_);
								strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), s);
								markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, s);
							}
							LA33_: ;
							s = nextOverloadIter__yTTeeqtnENsm0xyCro9a61w_2((&o), c, a);
						} LA22: ;
					}
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExportExcept__7YxUILpPxooC5qqa89a54dw_62)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* moduleName;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg exceptSet;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* exported;
	tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg i;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	moduleName = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*moduleName).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*moduleName)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
		LA4_: ;
		if (!T3_) goto LA5_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_858), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_859, NIM_FALSE);
		result = n;
		goto BeforeRet_;
	}
	LA5_: ;
	nimZeroMem((void*)(&exceptSet), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	readExceptSet__t9cI0oYChx2XYqk1hhh0lvA(c, n, (&exceptSet));
	exported = (*moduleName)._kind_4.sym;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118), (*n).info);
	strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), exported);
	nimZeroMem((void*)(&i), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
	s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&i), (*exported)._kind_3.tab);
	{
		while (1) {
			if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8;
			{
				NIM_BOOL T11_;
				NIM_BOOL T12_;
				NIM_BOOL T14_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
				T11_ = (NIM_BOOL)0;
				T12_ = (NIM_BOOL)0;
				T12_ = ((43513792 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
				if (!(T12_)) goto LA13_;
				T14_ = (NIM_BOOL)0;
				T14_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&exceptSet), (*(*s).name).Sup.id);
				T12_ = !(T14_);
				LA13_: ;
				T11_ = T12_;
				if (!(T11_)) goto LA15_;
				T11_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24))&63U)))!=0));
				LA15_: ;
				if (!T11_) goto LA16_;
				strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).module)._kind_3.tab), s);
				T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T18_ = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(s, (*n).info);
				add__P8dDSotTW25BkfbyspojGg(result, T18_);
			}
			LA16_: ;
			s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&i), (*exported)._kind_3.tab);
		} LA8: ;
	}
	markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*n).info, exported);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setLine__eTuk9brfDSpx17jJ53NDUag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				setLine__eTuk9brfDSpx17jJ53NDUag((*n)._kind_6.sons->data[i], info);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	(*n).info = info;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semPragmaBlock__7YxUILpPxooC5qqa89a54dw_63)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaList;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
	pragmaList = (*n)._kind_6.sons->data[((NI) 0)];
	pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), pragmaList, TM__rF9caJawfOjYTjsgLVUSGFA_860, NIM_TRUE);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 1)], 0));
	result = n;
	asgnRef((void**) (&(*result).typ), (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(pragmaList);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T4_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				T4_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
				T4_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw((*pragmaList)._kind_6.sons->data[i]);
				switch (T4_) {
				case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 123):
				{
					setLine__eTuk9brfDSpx17jJ53NDUag(result, (*(*pragmaList)._kind_6.sons->data[i]).info);
				}
				break;
				case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 186):
				{
					(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 6)) & 31);
				}
				break;
				default:
				{
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStaticStmt__7YxUILpPxooC5qqa89a54dw_64)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	(*c).inStaticContext += ((NI) 1);
	T1_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T1_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	a = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	(*c).inStaticContext -= ((NI) 1);
	asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), a);
	evalStaticStmt__4ISne8kQ4QKaNjEY5dqxUg((*c).module, (*c).graph, a, (*(*c).p).owner);
	result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114), (*n).info, ((NI) 1));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), (*(*c).graph).emptyNode);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExpr__vJZwz9bfROKrfrtM50y74CQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA3_;
		suggestExpr__wb6KhAx6bZ5NV37kY4bXJw(c, n);
	}
	LA3_: ;
	{
		if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7))&31U)))!=0)) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ checks;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		{
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 14))&31U)))!=0)) goto LA12_;
			checks = 10;
		}
		goto LA10_;
		LA12_: ;
		{
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 15))&31U)))!=0)) goto LA15_;
			checks = 14;
		}
		goto LA10_;
		LA15_: ;
		{
			checks = 15;
		}
		LA10_: ;
		s = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, checks);
		{
			if (!((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL))) goto LA20_;
			semCaptureSym__h6aJJZj4uWFwM8eXN4VDAw(s, (*(*c).p).owner);
		}
		LA20_: ;
		{
			if (!((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA24_;
			result = symChoice__ce08GbPIDAcM29cbr3lVUxg(c, n, s, ((tyEnum_TSymChoiceRule__lH3J6G7FTKg8Ow3uXV36OA) 0), NIM_FALSE);
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA28_;
				markIndirect__OGrPg9bGc5rou9aBRgLK606Qsemdata(c, (*result)._kind_4.sym);
			}
			LA28_: ;
			{
				if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA32_;
				asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
			}
			LA32_: ;
		}
		goto LA22_;
		LA24_: ;
		{
			result = semSym__20OKsvfFnNZXONk4IBzYgg(c, n, s, flags);
		}
		LA22_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = semSym__20OKsvfFnNZXONk4IBzYgg(c, n, (*n)._kind_4.sym, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA40_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5)));
		}
		LA40_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA45_;
			setIntLitType__JsZMQGDyZXnGr9cg0jxXW0w((*c).graph, result);
		}
		LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 7):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA50_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32)));
		}
		LA50_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 8):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA55_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33)));
		}
		LA55_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 9):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA60_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34)));
		}
		LA60_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA65_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35)));
		}
		LA65_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 11):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA70_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40)));
		}
		LA70_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 12):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA75_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41)));
		}
		LA75_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 13):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA80_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42)));
		}
		LA80_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 14):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA85_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43)));
		}
		LA85_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA90_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44)));
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 17):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA95_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37)));
		}
		LA95_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA100_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38)));
		}
		LA100_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA105_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39)));
		}
		LA105_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA110_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28)));
		}
		LA110_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5):
	{
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA115_;
			asgnRef((void**) (&(*result).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2)));
		}
		LA115_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		result = semFieldAccess__vJZwz9bfROKrfrtM50y74CQ_14(c, n, flags);
		{
			if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 25))) goto LA120_;
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 27));
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, flags);
		}
		LA120_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 55):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_565), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_566, NIM_FALSE);
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 134):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 135):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 141) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 150):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 137):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T144_;
		{
			NIM_BOOL T126_;
			NI T128_;
			tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag modifier;
			T126_ = (NIM_BOOL)0;
			T126_ = !(((*c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
			if (!(T126_)) goto LA127_;
			T128_ = (NI)0;
			T128_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T126_ = (T128_ == ((NI) 1));
			LA127_: ;
			if (!T126_) goto LA129_;
			switch ((*n).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 143):
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 141):
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 142):
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 137):
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60);
			}
			break;
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8);
			}
			break;
			default:
			{
				modifier = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0);
			}
			break;
			}
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T141_;
				tySequence__Ef05srmQTDulnBdXR4Ja6Q* T142_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T143_;
				if (!!((modifier == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)))) goto LA139_;
				T141_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T141_ = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], 0);
				baseType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*T141_).typ, 256);
				T142_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
				T142_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
				asgnRef((void**) (&T142_->data[0]), baseType);
				T143_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T143_ = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, modifier, T142_);
				asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, T143_));
				goto BeforeRet_;
			}
			LA139_: ;
		}
		LA129_: ;
		T144_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T144_ = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T144_, 256);
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, typ));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 128):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ_2;
		typ_2 = semTypeNode__O8zf75mcUwo9cfPQUQRaEug(c, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		asgnRef((void**) (&(*result).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, typ_2));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28):
	{
		tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ mode;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
		{
			if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 9))&31U)))!=0)) goto LA149_;
			mode = 0;
		}
		goto LA147_;
		LA149_: ;
		{
			mode = 2;
		}
		LA147_: ;
		s_2 = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, (*n)._kind_6.sons->data[((NI) 0)], mode);
		{
			if (!!((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA154_;
			switch ((*s_2).kind) {
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
			{
				result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
			{
				NIM_BOOL ambig;
				ambig = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*c).ambiguousSymbols), (*s_2).Sup.id);
				{
					NIM_BOOL T160_;
					NIM_BOOL T161_;
					NI T164_;
					T160_ = (NIM_BOOL)0;
					T161_ = (NIM_BOOL)0;
					T161_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
					if (!(T161_)) goto LA162_;
					T161_ = ambig;
					LA162_: ;
					T160_ = !(T161_);
					if (!(T160_)) goto LA163_;
					T164_ = (NI)0;
					T164_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					T160_ = (T164_ == ((NI) 2));
					LA163_: ;
					if (!T160_) goto LA165_;
					result = semConv__7YxUILpPxooC5qqa89a54dw_32(c, n);
				}
				goto LA158_;
				LA165_: ;
				{
					NIM_BOOL T168_;
					NI T170_;
					T168_ = (NIM_BOOL)0;
					T168_ = ambig;
					if (!(T168_)) goto LA169_;
					T170_ = (NI)0;
					T170_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					T168_ = (T170_ == ((NI) 1));
					LA169_: ;
					if (!T168_) goto LA171_;
					errorUseQualifier__t5EWYooFsFPeMiRTzdCWFw(c, (*n).info, s_2);
				}
				goto LA158_;
				LA171_: ;
				{
					NI T174_;
					T174_ = (NI)0;
					T174_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					if (!(T174_ == ((NI) 1))) goto LA175_;
					result = semObjConstr__vJZwz9bfROKrfrtM50y74CQ_15(c, n, flags);
				}
				goto LA158_;
				LA175_: ;
				{
					if (!((*s_2).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA178_;
					result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
				}
				goto LA158_;
				LA178_: ;
				{
					result = semMagic__NYxU2DkHA0Gt5fsL9bYZdog_2(c, n, s_2, flags);
				}
				LA158_: ;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15):
			{
				{
					if (!((*s_2).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA184_;
					result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
				}
				goto LA182_;
				LA184_: ;
				{
					result = semMagic__NYxU2DkHA0Gt5fsL9bYZdog_2(c, n, s_2, flags);
				}
				LA182_: ;
			}
			break;
			default:
			{
				result = semIndirectOp__vJZwz9bfROKrfrtM50y74CQ_20(c, n, flags);
			}
			break;
			}
		}
		goto LA152_;
		LA154_: ;
		{
			NIM_BOOL T189_;
			NIM_BOOL T190_;
			T189_ = (NIM_BOOL)0;
			T190_ = (NIM_BOOL)0;
			T190_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
			if (T190_) goto LA191_;
			T190_ = shouldBeBracketExpr__OiccTa3ruRNl9anoSqZh2Sg_4(n);
			LA191_: ;
			T189_ = T190_;
			if (!(T189_)) goto LA192_;
			T189_ = isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
			LA192_: ;
			if (!T189_) goto LA193_;
			setGenericParams__NRIJDWZtATzMum7OEjYC2g_11(c, (*n)._kind_6.sons->data[((NI) 0)]);
			result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
		}
		goto LA152_;
		LA193_: ;
		{
			NIM_BOOL T196_;
			T196_ = (NIM_BOOL)0;
			T196_ = isSymChoice__crbaOhZgTohCnKAdtWPkSQ_3sem((*n)._kind_6.sons->data[((NI) 0)]);
			if (T196_) goto LA197_;
			T196_ = (((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 9))&31U)))!=0);
			LA197_: ;
			if (!T196_) goto LA198_;
			result = semDirectOp__vJZwz9bfROKrfrtM50y74CQ_6(c, n, flags);
		}
		goto LA152_;
		LA198_: ;
		{
			result = semIndirectOp__vJZwz9bfROKrfrtM50y74CQ_20(c, n, flags);
		}
		LA152_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hoistedParams;
			tyArray__AB6yfoUgfWM2NtGe9bzkCmw T208_;
			if (!(((*result).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19))&31U)))!=0)) goto LA203_;
			result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(result);
			hoistedParams = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100), (*result).info);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
				i_2 = ((NI) 1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA207;
						i = i_2;
						hoistParamsUsedInDefault__sVX3UeeBXUbUHp9a9cEcpxCw(c, &result, &hoistedParams, &(*result)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA207: ;
				}
			}
			nimZeroMem((void*)T208_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
			T208_[0] = hoistedParams;
			T208_[1] = result;
			result = newTreeIT__iShdzoe9aISfAzry2HqGKqg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*result).info, (*result).typ, T208_, 2);
		}
		LA203_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		{
			if (!((flags &((NU32)1<<((NU)(((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 6))&31U)))!=0)) goto LA212_;
			result = semWhen__5C4HPXQuhxlMYIzPbe36lg(c, n, NIM_TRUE);
		}
		goto LA210_;
		LA212_: ;
		{
			result = semWhen__5C4HPXQuhxlMYIzPbe36lg(c, n, NIM_FALSE);
			{
				if (!(result == n)) goto LA217_;
				result = semWhen__5C4HPXQuhxlMYIzPbe36lg(c, n, NIM_TRUE);
			}
			goto LA215_;
			LA217_: ;
			{
				result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, flags);
			}
			LA215_: ;
		}
		LA210_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 1), (*(*c).graph).config);
		result = semArrayAccess__vJZwz9bfROKrfrtM50y74CQ_21(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 40):
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T222_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T223_;
		T222_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T222_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_114));
		T223_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T223_ = buildOverloadedSubscripts__nefR35PSczfhlx6FSH1N7w(n, T222_);
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, T223_, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* pragmaName;
		tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags_2;
		tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg finalNodeFlags;
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T225_;
		pragma = (*n)._kind_6.sons->data[((NI) 1)];
		pragmaName = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*pragma)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		flags_2 = flags;
		finalNodeFlags = 0;
		T225_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
		T225_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw(pragmaName);
		switch (T225_) {
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 220):
		{
			flags_2 |= ((NU32)1)<<((((tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ) 9)) & 31);
		}
		break;
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 162):
		{
			finalNodeFlags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 20)) & 31);
		}
		break;
		default:
		{
			invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
		}
		break;
		}
		result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], flags_2);
		(*result).flags = ((*result).flags | finalNodeFlags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg T230_;
		T230_ = (tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg)0;
		T230_ = checkPar__l5Y3wSn9c2wuzfpP3PtAptA(c, n);
		switch (T230_) {
		case ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 0):
		{
			result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		}
		break;
		case ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 3):
		{
			result = semTupleConstr__vJZwz9bfROKrfrtM50y74CQ_22(c, n, flags);
		}
		break;
		case ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 2):
		{
			result = semTupleFieldsConstr__vJZwz9bfROKrfrtM50y74CQ_24(c, n, flags);
		}
		break;
		case ((tyEnum_TParKind__halZ9aqjYDH0l2n5E6sCJdg) 1):
		{
			result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], flags);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	{
		result = semSetConstr__7YxUILpPxooC5qqa89a54dw_40(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		result = semArrayConstr__vJZwz9bfROKrfrtM50y74CQ_25(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	{
		result = semObjConstr__vJZwz9bfROKrfrtM50y74CQ_15(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	{
		result = semLambda__vJZwz9bfROKrfrtM50y74CQ_26(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	{
		result = semDeref__7YxUILpPxooC5qqa89a54dw_16(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	{
		result = n;
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), semAddrArg__kiPmghV1gaPm718CtGyhQw(c, (*n)._kind_6.sons->data[((NI) 0)], NIM_FALSE));
		asgnRef((void**) (&(*result).typ), makePtrType__PDWeh9cjpi22xXdNggYvsWA(c, (*(*result)._kind_6.sons->data[((NI) 0)]).typ));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], flags));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		result = semCast__7YxUILpPxooC5qqa89a54dw_41(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	{
		result = semIf__vJZwz9bfROKrfrtM50y74CQ_27(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 2), (*(*c).graph).config);
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 1), (*(*c).graph).config);
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	{
		checkSonsLen__EezdXeDvu4rB7fR84AJZgw(n, ((NI) 3), (*(*c).graph).config);
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		checkMinSonsLen__EezdXeDvu4rB7fR84AJZgw_2(n, ((NI) 2), (*(*c).graph).config);
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 54):
	{
		result = semTableConstr__7YxUILpPxooC5qqa89a54dw_43(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 62):
	{
		result = semStaticExpr__7YxUILpPxooC5qqa89a54dw_33(c, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	{
		result = semAsgn__mkzYzG9avRzHz5NmIFyZdRg(c, n, ((tyEnum_SemAsgnMode__e9aTobe3zFbbfTs9bHC7XMIQ) 0));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		result = semBlock__vJZwz9bfROKrfrtM50y74CQ_29(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		result = semStmtList__vJZwz9bfROKrfrtM50y74CQ_30(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		result = semRaise__7YxUILpPxooC5qqa89a54dw_44(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	{
		result = semVarOrLet__9aaeuZC3SovMoEd6yN1pUdg(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		result = semVarOrLet__9aaeuZC3SovMoEd6yN1pUdg(c, n, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		result = semConst__7YxUILpPxooC5qqa89a54dw_45(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	{
		result = semTypeSection__7YxUILpPxooC5qqa89a54dw_46(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	{
		result = semDiscard__7YxUILpPxooC5qqa89a54dw_48(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		result = semWhile__vJZwz9bfROKrfrtM50y74CQ_31(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		result = semTry__vJZwz9bfROKrfrtM50y74CQ_32(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111):
	{
		result = semBreakOrContinue__7YxUILpPxooC5qqa89a54dw_49(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		result = semFor__vJZwz9bfROKrfrtM50y74CQ_33(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		result = semCase__vJZwz9bfROKrfrtM50y74CQ_37(c, n, flags);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		result = semReturn__7YxUILpPxooC5qqa89a54dw_50(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 124):
	{
		result = semUsing__7YxUILpPxooC5qqa89a54dw_51(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89):
	{
		result = semAsm__7YxUILpPxooC5qqa89a54dw_52(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		result = semYield__7YxUILpPxooC5qqa89a54dw_53(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, (*(*c).p).owner, n, TM__rF9caJawfOjYTjsgLVUSGFA_825, NIM_TRUE);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		result = semIterator__7YxUILpPxooC5qqa89a54dw_54(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	{
		result = semProc__7YxUILpPxooC5qqa89a54dw_55(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		result = semFunc__7YxUILpPxooC5qqa89a54dw_56(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	{
		result = semMethod__7YxUILpPxooC5qqa89a54dw_57(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		result = semConverterDef__7YxUILpPxooC5qqa89a54dw_58(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		result = semMacroDef__7YxUILpPxooC5qqa89a54dw_59(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	{
		result = semTemplateDef__7YxUILpPxooC5qqa89a54dw_37(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	{
		{
			NimStringDesc* T282_;
			if (!((NI)(((NI) 2) + (*c).compilesContextId) < (*(*c).currentScope).depthLevel)) goto LA280_;
			T282_ = (NimStringDesc*)0;
			T282_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_842));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T282_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_843, NIM_FALSE);
		}
		LA280_: ;
		result = evalImport__xmufAMBjGiK9cy1UljniTyg(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 117):
	{
		{
			NIM_BOOL T286_;
			NimStringDesc* T289_;
			T286_ = (NIM_BOOL)0;
			T286_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
			if (!!(T286_)) goto LA287_;
			T289_ = (NimStringDesc*)0;
			T289_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_842));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T289_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_844, NIM_FALSE);
		}
		LA287_: ;
		result = evalImportExcept__xmufAMBjGiK9cy1UljniTyg_3(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 120):
	{
		{
			NIM_BOOL T293_;
			NimStringDesc* T296_;
			T293_ = (NIM_BOOL)0;
			T293_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
			if (!!(T293_)) goto LA294_;
			T296_ = (NimStringDesc*)0;
			T296_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_845));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T296_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_846, NIM_FALSE);
		}
		LA294_: ;
		result = evalFrom__xmufAMBjGiK9cy1UljniTyg_4(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	{
		result = evalInclude__7YxUILpPxooC5qqa89a54dw_60(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	{
		{
			NIM_BOOL T301_;
			NimStringDesc* T304_;
			T301_ = (NIM_BOOL)0;
			T301_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
			if (!!(T301_)) goto LA302_;
			T304_ = (NimStringDesc*)0;
			T304_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_104));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T304_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_852, NIM_FALSE);
		}
		LA302_: ;
		result = semExport__7YxUILpPxooC5qqa89a54dw_61(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 119):
	{
		{
			NIM_BOOL T308_;
			NimStringDesc* T311_;
			T308_ = (NIM_BOOL)0;
			T308_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
			if (!!(T308_)) goto LA309_;
			T311_ = (NimStringDesc*)0;
			T311_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_103), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_104));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T311_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_857, NIM_FALSE);
		}
		LA309_: ;
		result = semExportExcept__7YxUILpPxooC5qqa89a54dw_62(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 91):
	{
		result = semPragmaBlock__7YxUILpPxooC5qqa89a54dw_63(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	{
		result = semStaticStmt__7YxUILpPxooC5qqa89a54dw_64(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 105):
	{
		{
			if (!((*c).currentScope == (*c).topLevelScope)) goto LA317_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_861), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_862, NIM_FALSE);
		}
		LA317_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[((NI) 0)], 0));
		{
			NIM_BOOL T321_;
			NIM_BOOL T322_;
			NIM_BOOL T324_;
			T321_ = (NIM_BOOL)0;
			T322_ = (NIM_BOOL)0;
			T322_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*(*n)._kind_6.sons->data[((NI) 0)]).typ);
			T321_ = !(T322_);
			if (!(T321_)) goto LA323_;
			T324_ = (NIM_BOOL)0;
			T324_ = implicitlyDiscardable__OiccTa3ruRNl9anoSqZh2Sg((*n)._kind_6.sons->data[((NI) 0)]);
			T321_ = !(T324_);
			LA323_: ;
			if (!T321_) goto LA325_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_863), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_864, NIM_FALSE);
		}
		LA325_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 157):
	{
		{
			NIM_BOOL T330_;
			NI T331_;
			NI T333_;
			T330_ = (NIM_BOOL)0;
			T331_ = (NI)0;
			T331_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T330_ = !((T331_ == ((NI) 1)));
			if (!(T330_)) goto LA332_;
			T333_ = (NI)0;
			T333_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T330_ = !((T333_ == ((NI) 2)));
			LA332_: ;
			if (!T330_) goto LA334_;
			illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
		}
		LA334_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA338;
					i_3 = i_4;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i_3]), semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, (*n)._kind_6.sons->data[i_3], 0));
					i_4 += ((NI) 1);
				} LA338: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
	}
	break;
	default:
	{
		NimStringDesc* T341_;
		NimStringDesc* T342_;
		T341_ = (NimStringDesc*)0;
		T342_ = (NimStringDesc*)0;
		T342_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
		T341_ = rawNewString((T342_ ? T342_->Sup.len : 0) + 20);
appendString(T341_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_865));
appendString(T341_, T342_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T341_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_866, NIM_FALSE);
	}
	break;
	}
	{
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA345_;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7)) & 31);
	}
	LA345_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprCheck__vJZwz9bfROKrfrtM50y74CQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	LA3_: ;
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, (flags | 2048));
	{
		NimStringDesc* T9_;
		NimStringDesc* T10_;
		if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA7_;
		T9_ = (NimStringDesc*)0;
		T9_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
		T10_ = (NimStringDesc*)0;
		T10_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_775), T9_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T10_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_867, NIM_FALSE);
		result = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semExprWithType__vJZwz9bfROKrfrtM50y74CQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = semExprCheck__vJZwz9bfROKrfrtM50y74CQ_2(c, n, flags);
	{
		NIM_BOOL T3_;
		NimStringDesc* T7_;
		NimStringDesc* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*result).typ == (*c).enforceVoidContext);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NimStringDesc*)0;
		T7_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
		T8_ = (NimStringDesc*)0;
		T8_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_775), T7_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_868, NIM_FALSE);
		asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	}
	goto LA1_;
	LA5_: ;
	{
		{
			if (!((IL64(140737496743936) &((NU64)1<<((NU)((*(*result).typ).kind)&63U)))!=0)) goto LA12_;
			result = newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings(result);
		}
		LA12_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semConstExpr__7YxUILpPxooC5qqa89a54dw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	e = semExprWithType__vJZwz9bfROKrfrtM50y74CQ(c, n, 0);
	{
		if (!(e == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_869, NIM_FALSE);
		result = n;
		goto BeforeRet_;
	}
	LA3_: ;
	result = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, e, (*c).graph);
	{
		if (!(result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA7_;
		result = evalConstExpr__P8uF2QSxl7YdNpBnl0Ybqg((*c).module, (*c).graph, e);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			if (T11_) goto LA12_;
			T11_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA12_: ;
			if (!T11_) goto LA13_;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = eqeq___59bygf5b7AsTVb9a1lVM66oA((*e).info, (*n).info);
				if (!!(T17_)) goto LA18_;
				pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*n).info, ((NimStringDesc*) NIM_NIL));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_870, NIM_FALSE);
				popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
			}
			goto LA15_;
			LA18_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*e).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_871, NIM_FALSE);
			}
			LA15_: ;
			result = e;
		}
		goto LA9_;
		LA13_: ;
		{
			result = fixupTypeAfterEval__uWNSz7p50zmqqN864XaVBA(c, result, e);
		}
		LA9_: ;
	}
	LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semOperand__vJZwz9bfROKrfrtM50y74CQ_39)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		illFormedAst__aOnJJ9cXkOooTyUuLmnc09bw(n, (*(*c).graph).config);
	}
	LA3_: ;
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, n, (flags | 4096));
	{
		if (!!(((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA7_;
		{
			NIM_BOOL T11_;
			NimStringDesc* T15_;
			NimStringDesc* T16_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*(*result).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T11_)) goto LA12_;
			T11_ = (((*(*result).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0);
			LA12_: ;
			if (!T11_) goto LA13_;
			T15_ = (NimStringDesc*)0;
			T15_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 0);
			T16_ = (NimStringDesc*)0;
			T16_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_677), T15_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_872, NIM_FALSE);
		}
		LA13_: ;
		{
			if (!((IL64(140737496743936) &((NU64)1<<((NU)((*(*result).typ).kind)&63U)))!=0)) goto LA19_;
			result = newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings(result);
		}
		LA19_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		if (!!(((192 & flags) == 0))) goto LA22_;
		asgnRef((void**) (&(*result).typ), newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63), c));
	}
	goto LA5_;
	LA22_: ;
	{
		NimStringDesc* T25_;
		NimStringDesc* T26_;
		T25_ = (NimStringDesc*)0;
		T25_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(result, 4);
		T26_ = (NimStringDesc*)0;
		T26_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_775), T25_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T26_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_873, NIM_FALSE);
		asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semInferredLambda__s5ZNJifOyxLa9bFOCUqHCXg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* original;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T9_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	n_2 = n;
	original = (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	s = original;
	n_2 = replaceTypesInBody__JQMwbj1fgdFwBCg7mhUBRQ(c, pt, n_2, original, NIM_FALSE);
	result = n_2;
	asgnRef((void**) (&(*s).ast), result);
	asgnRef((void**) (&(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_4.sym), s);
	asgnRef((void**) (&(*n_2)._kind_6.sons->data[((NI) 2)]), (*(*c).graph).emptyNode);
	params = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*n_2).typ).n);
	asgnRef((void**) (&(*n_2)._kind_6.sons->data[((NI) 3)]), params);
	asgnRef((void**) (&(*s).typ), (*n_2).typ);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(params);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NimStringDesc* T8_;
					if (!((IL64(3420483916987896064) &((NU64)1<<((NU)((*(*(*params)._kind_6.sons->data[i]).typ).kind)&63U)))!=0)) goto LA6_;
					T8_ = (NimStringDesc*)0;
					T8_ = rawNewString(((*(*(*(*params)._kind_6.sons->data[i])._kind_4.sym).name).s ? (*(*(*(*params)._kind_6.sons->data[i])._kind_4.sym).name).s->Sup.len : 0) + 32);
appendString(T8_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_874));
appendString(T8_, (*(*(*(*params)._kind_6.sons->data[i])._kind_4.sym).name).s);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*params)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T8_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_875, NIM_FALSE);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	T9_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T9_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, s);
	addParams__XjZLpvNqVUTx1J6TXREPBQ_2(c, params, ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
	pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3(c, s);
	addResult__n01jThJgoOr9aRxjZW5y9c7g(c, n_2, (*(*n_2).typ).sons->data[((NI) 0)], ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12));
	T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T10_ = semProcBody__7YxUILpPxooC5qqa89a54dw_5(c, (*n_2)._kind_6.sons->data[((NI) 6)]);
	asgnRef((void**) (&(*(*s).ast)._kind_6.sons->data[((NI) 6)]), hloBody__7YxUILpPxooC5qqa89a54dw_10(c, T10_));
	trackProc__P9bJkIGwY9beKGfhhcBedbpg(c, s, (*(*s).ast)._kind_6.sons->data[((NI) 6)]);
	popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = (((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0);
		if (!(T13_)) goto LA14_;
		T13_ = !(((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA14_: ;
		if (!T13_) goto LA15_;
		asgnRef((void**) (&(*result).typ), makeVarType__45x39aIZGLTdqqo59b4NHvLw(c, (*result).typ, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
	}
	LA15_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__aOG8hV039bfSL2VAm1lrf0Q)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* result;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	tyProc__3cacbJ4la9bDJNibHybQSnA T5_;
	tyProc__L4XfH7VEp8aJssG3EbEBaQ T6_;
	tyProc__7JwrY3AhkVNlleAJXClX9cw T7_;
	result = (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*)0;
	c = newContext__dfWKKRV6rIabJ2ctPOd59aA(graph, module);
	{
		if (!!(((*c).p == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*graph).config, (*module).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_2), TM__rF9caJawfOjYTjsgLVUSGFA_3);
	}
	LA3_: ;
	(*c).semConstExpr = semConstExpr__7YxUILpPxooC5qqa89a54dw;
	(*c).semExpr = semExpr__vJZwz9bfROKrfrtM50y74CQ_3;
	(*c).semTryExpr = tryExpr__vJZwz9bfROKrfrtM50y74CQ_17;
	(*c).semTryConstExpr = tryConstExpr__7YxUILpPxooC5qqa89a54dw_30;
	(*c).computeRequiresInit = computeRequiresInit__p5rbEi9c5JmURA4qGF6bxhg;
	(*c).semOperand = semOperand__vJZwz9bfROKrfrtM50y74CQ_39;
	(*c).semConstBoolExpr = semConstBoolExpr__7YxUILpPxooC5qqa89a54dw_3;
	(*c).semOverloadedCall = semOverloadedCall__pBkKnME6t9c8v6khuDD76Fg;
	nimZeroMem((void*)(&T5_), sizeof(tyProc__3cacbJ4la9bDJNibHybQSnA));
	T5_.ClP_0 = ((TM__rF9caJawfOjYTjsgLVUSGFA_876) (semInferredLambda__s5ZNJifOyxLa9bFOCUqHCXg)); T5_.ClE_0 = NIM_NIL;
	asgnRef((void**) (&(*c).semInferredLambda.ClE_0), T5_.ClE_0);
	(*c).semInferredLambda.ClP_0 = T5_.ClP_0;
	nimZeroMem((void*)(&T6_), sizeof(tyProc__L4XfH7VEp8aJssG3EbEBaQ));
	T6_.ClP_0 = ((TM__rF9caJawfOjYTjsgLVUSGFA_877) (generateInstance__Bbmaz5QjetnTaor7LYngPg)); T6_.ClE_0 = NIM_NIL;
	asgnRef((void**) (&(*c).semGenerateInstance.ClE_0), T6_.ClE_0);
	(*c).semGenerateInstance.ClP_0 = T6_.ClP_0;
	(*c).semTypeNode = semTypeNode__O8zf75mcUwo9cfPQUQRaEug;
	(*c).instTypeBoundOp = instTypeBoundOp__Kdk4BCAjDmsFKO9cO4U4ccw;
	nimZeroMem((void*)(&T7_), sizeof(tyProc__7JwrY3AhkVNlleAJXClX9cw));
	T7_.ClP_0 = ((TM__rF9caJawfOjYTjsgLVUSGFA_878) (hasUnresolvedArgs__iY9a3KG6T9aTt3fJH8J6BrJQ)); T7_.ClE_0 = NIM_NIL;
	asgnRef((void**) (&(*c).hasUnresolvedArgs.ClE_0), T7_.ClE_0);
	(*c).hasUnresolvedArgs.ClP_0 = T7_.ClP_0;
	asgnRef((void**) (&(*c).templInstCounter), new__wSSF51wLRD8g2UFxfG6Hvg());
	pushProcCon__jWGpC0lY8vG9b1MhOYJ9cFiQ_3(c, module);
	pushOwner__AqgO9b89aLwRYAgSHN9aBrlHQ(c, (*c).module);
	asgnRef((void**) (&(*c).importTable), openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c));
	strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).importTable).symbols), module);
	{
		if (!(((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA10_;
		asgnRef((void**) (&(*graph).systemModule), module);
	}
	LA10_: ;
	asgnRef((void**) (&(*c).topLevelScope), openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c));
	result = &c->Sup;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportSystemStmt__Py1GUj7PccyIa3ac40A6MA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*g).systemModule == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			x = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i = i_2;
						x = (*n)._kind_6.sons->data[i];
						{
							NI32 f;
							if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA12_;
							f = checkModuleName__fDy39b69bb9cFVEyPkMJp3GTg((*g).config, x, NIM_FALSE);
							{
								if (!(f == (*(*g).systemModule).info.fileIndex)) goto LA16_;
								result = NIM_TRUE;
								goto BeforeRet_;
							}
							LA16_: ;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 117):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 120):
	{
		{
			NI32 f_2;
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA21_;
			f_2 = checkModuleName__fDy39b69bb9cFVEyPkMJp3GTg((*g).config, (*n)._kind_6.sons->data[((NI) 0)], NIM_FALSE);
			{
				if (!(f_2 == (*(*g).systemModule).info.fileIndex)) goto LA25_;
				result = NIM_TRUE;
				goto BeforeRet_;
			}
			LA25_: ;
		}
		LA21_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyTree__OiccTa3ruRNl9anoSqZh2Sg_7)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA5;
						i = i_2;
						it = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T8_;
							T8_ = (NIM_BOOL)0;
							T8_ = isEmptyTree__OiccTa3ruRNl9anoSqZh2Sg_7(it);
							if (!!(T8_)) goto LA9_;
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA9_: ;
						i_2 += ((NI) 1);
					} LA5: ;
				}
			}
		}
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	{
		result = NIM_TRUE;
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, gatherStmts__9a9a1Ojxj7NR51moAUvzAVIw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					NI32 f;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					f = checkModuleName__fDy39b69bb9cFVEyPkMJp3GTg((*(*c).graph).config, (*n)._kind_6.sons->data[i], NIM_TRUE);
					{
						if (!!((f == ((NI32) -1)))) goto LA7_;
						{
							NIM_BOOL T11_;
							NimStringDesc* T14_;
							NimStringDesc* T15_;
							T11_ = (NIM_BOOL)0;
							T11_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).includedFiles), ((NI) (f)));
							if (!T11_) goto LA12_;
							T14_ = (NimStringDesc*)0;
							T14_ = toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw((*(*c).graph).config, f);
							T15_ = (NimStringDesc*)0;
							T15_ = nsuFormatSingleElem(((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_9), T14_);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_879, NIM_FALSE);
						}
						goto LA9_;
						LA12_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* code;
							code = (*(*c).graph).includeFileCallback((*c).graph, (*c).module, f);
							gatherStmts__9a9a1Ojxj7NR51moAUvzAVIw(c, code, result);
							excl__jENnK9c9bPE73pKmo2vYjpqg_2((&(*c).includedFiles), ((NI) (f)));
						}
						LA9_: ;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA20;
					i_3 = i_4;
					gatherStmts__9a9a1Ojxj7NR51moAUvzAVIw(c, (*n)._kind_6.sons->data[i_3], result);
					i_4 += ((NI) 1);
				} LA20: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	{
		(*n).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 7)) & 31);
		typeSectionLeftSidePass__NRIJDWZtATzMum7OEjYC2g_12(c, n);
		add__P8dDSotTW25BkfbyspojGg(result, n);
	}
	break;
	default:
	{
		add__P8dDSotTW25BkfbyspojGg(result, n);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAllTypeSections__7YxUILpPxooC5qqa89a54dw_66)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	gatherStmts__9a9a1Ojxj7NR51moAUvzAVIw(c, n, result);
	{
		NI iX60gensym3118_;
		NI colontmp_;
		NI i;
		iX60gensym3118_ = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < colontmp_)) goto LA3;
				iX60gensym3118_ = i;
				{
					if (!((*(*result)._kind_6.sons->data[iX60gensym3118_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98))) goto LA6_;
					typeSectionRightSidePass__NRIJDWZtATzMum7OEjYC2g_13(c, (*result)._kind_6.sons->data[iX60gensym3118_]);
				}
				LA6_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	{
		NI iX60gensym3121_;
		NI colontmp__2;
		NI i_2;
		iX60gensym3121_ = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(result);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp__2)) goto LA10;
				iX60gensym3121_ = i_2;
				{
					if (!((*(*result)._kind_6.sons->data[iX60gensym3121_]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98))) goto LA13_;
					typeSectionFinalPass__NRIJDWZtATzMum7OEjYC2g_14(c, (*result)._kind_6.sons->data[iX60gensym3121_]);
				}
				LA13_: ;
				i_2 += ((NI) 1);
			} LA10: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, hloStmt__7YxUILpPxooC5qqa89a54dw_67)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = ((*c).patterns ? (*c).patterns->Sup.len : 0);
		T3_ = (T4_ == ((NI) 0));
		if (T3_) goto LA5_;
		T3_ = !((((*(*(*c).graph).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 23))&31U)))!=0));
		LA5_: ;
		if (!T3_) goto LA6_;
		result = n;
		goto BeforeRet_;
	}
	LA6_: ;
	(*c).hloLoopDetector = ((NI) 0);
	result = hlo__7YxUILpPxooC5qqa89a54dw_11(c, n);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, buildEchoStmt__7YxUILpPxooC5qqa89a54dw_68)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* e;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info);
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_880));
	e = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*(*(*c).graph).systemModule)._kind_3.tab, T1_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!!((e == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA4_;
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(e);
		add__P8dDSotTW25BkfbyspojGg(result, T6_);
	}
	goto LA2_;
	LA4_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_881), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_882, NIM_FALSE);
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = errorNode__g3ODV709caO5lfQfPGeUxSQ_2(c, n);
		add__P8dDSotTW25BkfbyspojGg(result, T8_);
	}
	LA2_: ;
	add__P8dDSotTW25BkfbyspojGg(result, n);
	result = semExpr__vJZwz9bfROKrfrtM50y74CQ_3(c, result, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semStmtAndGenerateGenerics__7YxUILpPxooC5qqa89a54dw_65)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*c).topStmts == ((NI) 0));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isImportSystemStmt__Py1GUj7PccyIa3ac40A6MA((*c).graph, n);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		{
			NIM_BOOL T10_;
			NIM_BOOL T12_;
			T10_ = (NIM_BOOL)0;
			T10_ = !((((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0));
			if (!(T10_)) goto LA11_;
			T12_ = (NIM_BOOL)0;
			T12_ = isEmptyTree__OiccTa3ruRNl9anoSqZh2Sg_7(n);
			T10_ = !(T12_);
			LA11_: ;
			if (!T10_) goto LA13_;
			strTableAdd__tyTgUybFIoow4CX2l5beug((&(*(*c).importTable).symbols), (*(*c).graph).systemModule);
			importAllSymbols__9bonb4OC5BOScb4pv7w7J1Q(c, (*(*c).graph).systemModule);
			(*c).topStmts += ((NI) 1);
		}
		LA13_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		(*c).topStmts += ((NI) 1);
	}
	LA1_: ;
	{
		if (!(((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0)) goto LA18_;
		result = semAllTypeSections__7YxUILpPxooC5qqa89a54dw_66(c, n);
	}
	goto LA16_;
	LA18_: ;
	{
		result = n;
	}
	LA16_: ;
	result = semStmt__vJZwz9bfROKrfrtM50y74CQ_4(c, result, 0);
	result = hloStmt__7YxUILpPxooC5qqa89a54dw_67(c, result);
	{
		NIM_BOOL T23_;
		NIM_BOOL T25_;
		T23_ = (NIM_BOOL)0;
		T23_ = ((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 18));
		if (!(T23_)) goto LA24_;
		T25_ = (NIM_BOOL)0;
		T25_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*result).typ);
		T23_ = !(T25_);
		LA24_: ;
		if (!T23_) goto LA26_;
		result = buildEchoStmt__7YxUILpPxooC5qqa89a54dw_68(c, result);
	}
	LA26_: ;
	{
		if (!((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14))) goto LA30_;
		appendToModule__T4o9clzgbAgGY4ORbfP6LmQ((*c).module, result);
	}
	LA30_: ;
	trackStmt__QaQdy9beybDhOWYNIJD0SGA(c, (*c).module, result, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recoverContext__Zisdl5hRh5Vv9bXMXRnK8QA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	asgnRef((void**) (&(*c).currentScope), (*c).topLevelScope);
	{
		while (1) {
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T3_;
			T3_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T3_ = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
			if (!!(((*T3_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA2;
			popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
		} LA2: ;
	}
	{
		while (1) {
			NIM_BOOL T6_;
			T6_ = (NIM_BOOL)0;
			T6_ = !(((*c).p == ((tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ*) NIM_NIL)));
			if (!(T6_)) goto LA7_;
			T6_ = !(((*(*(*c).p).owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
			LA7_: ;
			if (!T6_) goto LA5;
			asgnRef((void**) (&(*c).p), (*(*c).p).next);
		} LA5: ;
	}
}
static N_INLINE(Exception*, getCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(NIM_BOOL, isObjWithCache)(TNimType* obj, TNimType* subclass, TNimType** cache) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(obj == subclass)) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((*obj).base == subclass)) goto LA7_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA7_: ;
	{
		if (!(cache[(((NI) 0))- 0] == obj)) goto LA11_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		if (!(cache[(((NI) 1))- 0] == obj)) goto LA15_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA15_: ;
	result = isObjSlowPath__H8B7g6iFRPI5Em52KFoD6w(obj, subclass, cache);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__QAJdPOwMq9buTNGNGQO3ImA)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile result;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	c = ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) (context));
	{
		if (!((*(*(*c).graph).config).errorMax <= ((NI) 1))) goto LA3_;
		result = semStmtAndGenerateGenerics__7YxUILpPxooC5qqa89a54dw_65(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		NI oldContextLen;
		NI oldInGenericInst;
		TSafePoint TM__rF9caJawfOjYTjsgLVUSGFA_883;
		oldContextLen = getInfoContextLen__QY5gXnIUBOUa79b5tGece0A((*(*c).graph).config);
		oldInGenericInst = (*c).inGenericInst;
		pushSafePoint(&TM__rF9caJawfOjYTjsgLVUSGFA_883);
		TM__rF9caJawfOjYTjsgLVUSGFA_883.status = _setjmp(TM__rF9caJawfOjYTjsgLVUSGFA_883.context);
		if (TM__rF9caJawfOjYTjsgLVUSGFA_883.status == 0) {
		result = semStmtAndGenerateGenerics__7YxUILpPxooC5qqa89a54dw_65(c, n);
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__IxbcvonC7TQkv166Uvdu1g_))||isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__cDtWY9cE7zf8BAC5QcEZZkQ_))) {
				TM__rF9caJawfOjYTjsgLVUSGFA_883.status = 0;
				recoverContext__Zisdl5hRh5Vv9bXMXRnK8QA(c);
				(*c).inGenericInst = oldInGenericInst;
				setInfoContextLen__JRH1QeGlTzlBOChAZ7bvoQ((*(*c).graph).config, oldContextLen);
				{
					Exception* T10_;
					T10_ = (Exception*)0;
					T10_ = getCurrentException();
					if (!((T10_) && (isObjWithCache((*T10_).Sup.m_type, (&NTI__cDtWY9cE7zf8BAC5QcEZZkQ_), Nim_OfCheck_CACHE885)))) goto LA11_;
					(*c).suggestionsMade = NIM_TRUE;
					result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				}
				goto LA8_;
				LA11_: ;
				{
					result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info);
				}
				LA8_: ;
				popCurrentException();
			}
		}
		if (TM__rF9caJawfOjYTjsgLVUSGFA_883.status != 0) reraiseException();
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reportUnusedModules__Zisdl5hRh5Vv9bXMXRnK8QA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (((*c).unusedImports ? (*c).unusedImports->Sup.len : 0)-1);
		colontmp_ = T2_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA4;
				i = res;
				{
					if (!!((((*(*c).unusedImports->data[i].Field0).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0))&63U)))!=0))) goto LA7_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*c).unusedImports->data[i].Field1, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 29), (*(*(*c).unusedImports->data[i].Field0).name).s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__rF9caJawfOjYTjsgLVUSGFA_885, NIM_FALSE);
				}
				LA7_: ;
				res += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addCodeForGenerics__NRIJDWZtATzMum7OEjYC2g_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI T19_;
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).generics ? (*c).generics->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = (*c).lastGenericIdx;
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				prc = (*(*c).generics->data[i].inst).sym;
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((94208 &((NU32)1<<((NU)((*prc).kind)&31U)))!=0);
					if (!(T7_)) goto LA8_;
					T7_ = ((*prc).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
					LA8_: ;
					if (!T7_) goto LA9_;
					{
						NIM_BOOL T13_;
						NimStringDesc* T17_;
						T13_ = (NIM_BOOL)0;
						T13_ = ((*prc).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						if (T13_) goto LA14_;
						T13_ = ((*(*prc).ast)._kind_6.sons->data[((NI) 6)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						LA14_: ;
						if (!T13_) goto LA15_;
						T17_ = (NimStringDesc*)0;
						T17_ = rawNewString(((*(*prc).name).s ? (*(*prc).name).s->Sup.len : 0) + 12);
appendString(T17_, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_888));
appendString(T17_, (*(*prc).name).s);
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*prc).info, T17_, TM__rF9caJawfOjYTjsgLVUSGFA_889);
					}
					goto LA11_;
					LA15_: ;
					{
						add__P8dDSotTW25BkfbyspojGg(n, (*prc).ast);
					}
					LA11_: ;
				}
				LA9_: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	T19_ = ((*c).generics ? (*c).generics->Sup.len : 0);
	(*c).lastGenericIdx = T19_;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__q2jGmbBjsPumxfsrswciWg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* context, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	c = ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) (context));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 14));
		if (!(T3_)) goto LA4_;
		T3_ = !((*c).suggestionsMade);
		LA4_: ;
		if (!T3_) goto LA5_;
		suggestSentinel__9bcrXlTwB3ELAkoCqH9bihfA(c);
	}
	LA5_: ;
	closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	rawCloseScope__TX9bi5b9bIHR13FiwHwV59a4w_2(c);
	reportUnusedModules__Zisdl5hRh5Vv9bXMXRnK8QA_2(c);
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
	{
		if (!!((n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA9_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__rF9caJawfOjYTjsgLVUSGFA_886), TM__rF9caJawfOjYTjsgLVUSGFA_887);
	}
	LA9_: ;
	addCodeForGenerics__NRIJDWZtATzMum7OEjYC2g_16(c, result);
	{
		if (!!(((*(*c).module).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA13_;
		add__P8dDSotTW25BkfbyspojGg(result, (*(*c).module).ast);
	}
	LA13_: ;
	popOwner__9aY89b9aR25iMJ8fPdM84CvQg_2(c);
	popProcCon__SjrsaPFXVDopDGJmDQUKewsemdata(c);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_semDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__rF9caJawfOjYTjsgLVUSGFA_323_3[3];
static TNimNode* TM__rF9caJawfOjYTjsgLVUSGFA_334_2[2];
static TNimNode* TM__rF9caJawfOjYTjsgLVUSGFA_364_2[2];
static TNimNode* TM__rF9caJawfOjYTjsgLVUSGFA_721_2[2];
static TNimNode TM__rF9caJawfOjYTjsgLVUSGFA_0[13];

/* section: NIM_merge_TYPE_INIT3 */
NTI__LF0eKAnygFo4etNDdpTetg_.size = sizeof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg);
NTI__LF0eKAnygFo4etNDdpTetg_.align = NIM_ALIGNOF(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg);
NTI__LF0eKAnygFo4etNDdpTetg_.kind = 17;
NTI__LF0eKAnygFo4etNDdpTetg_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__rF9caJawfOjYTjsgLVUSGFA_323_3[0] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[1];
TM__rF9caJawfOjYTjsgLVUSGFA_0[1].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[1].offset = offsetof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg, colonstate_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[1].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[1].name = ":state";
TM__rF9caJawfOjYTjsgLVUSGFA_323_3[1] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[2];
TM__rF9caJawfOjYTjsgLVUSGFA_0[2].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[2].offset = offsetof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg, c1);
TM__rF9caJawfOjYTjsgLVUSGFA_0[2].typ = (&NTI__EjEifkTC8tg9afiUW4StSSA_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[2].name = "c1";
TM__rF9caJawfOjYTjsgLVUSGFA_323_3[2] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[3];
TM__rF9caJawfOjYTjsgLVUSGFA_0[3].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[3].offset = offsetof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg, scope2);
TM__rF9caJawfOjYTjsgLVUSGFA_0[3].typ = (&NTI__N89ckikRqMir57209a3tEeqw_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[3].name = "scope2";
TM__rF9caJawfOjYTjsgLVUSGFA_0[0].len = 3; TM__rF9caJawfOjYTjsgLVUSGFA_0[0].kind = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[0].sons = &TM__rF9caJawfOjYTjsgLVUSGFA_323_3[0];
NTI__LF0eKAnygFo4etNDdpTetg_.node = &TM__rF9caJawfOjYTjsgLVUSGFA_0[0];
NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_.size = sizeof(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*);
NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_.align = NIM_ALIGNOF(tyObject_Env_semmagicdotnim_semDynamicBindSym___LF0eKAnygFo4etNDdpTetg*);
NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_.kind = 22;
NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_.base = (&NTI__LF0eKAnygFo4etNDdpTetg_);
NTI__IqGNbqKVyQ9b9an5n9bN8QJsQ_.marker = Marker_tyRef__IqGNbqKVyQ9b9an5n9bN8QJsQ;
NTI__UaUb9bgQbqCS7gyXItZuJNg_.size = sizeof(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg);
NTI__UaUb9bgQbqCS7gyXItZuJNg_.align = NIM_ALIGNOF(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg);
NTI__UaUb9bgQbqCS7gyXItZuJNg_.kind = 17;
NTI__UaUb9bgQbqCS7gyXItZuJNg_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__rF9caJawfOjYTjsgLVUSGFA_334_2[0] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[5];
TM__rF9caJawfOjYTjsgLVUSGFA_0[5].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[5].offset = offsetof(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg, colonstate_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[5].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[5].name = ":state";
TM__rF9caJawfOjYTjsgLVUSGFA_334_2[1] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[6];
TM__rF9caJawfOjYTjsgLVUSGFA_0[6].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[6].offset = offsetof(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg, orig1);
TM__rF9caJawfOjYTjsgLVUSGFA_0[6].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[6].name = "orig1";
TM__rF9caJawfOjYTjsgLVUSGFA_0[4].len = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[4].kind = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[4].sons = &TM__rF9caJawfOjYTjsgLVUSGFA_334_2[0];
NTI__UaUb9bgQbqCS7gyXItZuJNg_.node = &TM__rF9caJawfOjYTjsgLVUSGFA_0[4];
NTI__NaDYkbcAjZXYRP9arR0vzYg_.size = sizeof(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*);
NTI__NaDYkbcAjZXYRP9arR0vzYg_.align = NIM_ALIGNOF(tyObject_Env_semmagicdotnim_turnFinalizerIntoDestructor___UaUb9bgQbqCS7gyXItZuJNg*);
NTI__NaDYkbcAjZXYRP9arR0vzYg_.kind = 22;
NTI__NaDYkbcAjZXYRP9arR0vzYg_.base = (&NTI__UaUb9bgQbqCS7gyXItZuJNg_);
NTI__NaDYkbcAjZXYRP9arR0vzYg_.marker = Marker_tyRef__NaDYkbcAjZXYRP9arR0vzYg;
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.size = sizeof(tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q);
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.align = NIM_ALIGNOF(tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q);
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.kind = 18;
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.base = 0;
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.flags = 2;
TM__rF9caJawfOjYTjsgLVUSGFA_364_2[0] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[8];
TM__rF9caJawfOjYTjsgLVUSGFA_0[8].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[8].offset = offsetof(tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q, Field0);
TM__rF9caJawfOjYTjsgLVUSGFA_0[8].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[8].name = "Field0";
TM__rF9caJawfOjYTjsgLVUSGFA_364_2[1] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[9];
TM__rF9caJawfOjYTjsgLVUSGFA_0[9].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[9].offset = offsetof(tyTuple__K9bYwLtGKmFQYg8TwmqoG3Q, Field1);
TM__rF9caJawfOjYTjsgLVUSGFA_0[9].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[9].name = "Field1";
TM__rF9caJawfOjYTjsgLVUSGFA_0[7].len = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[7].kind = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[7].sons = &TM__rF9caJawfOjYTjsgLVUSGFA_364_2[0];
NTI__K9bYwLtGKmFQYg8TwmqoG3Q_.node = &TM__rF9caJawfOjYTjsgLVUSGFA_0[7];
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.size = sizeof(tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*);
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.align = NIM_ALIGNOF(tySequence__P9bWebqKHkrGHwy9aZW9bw0TA*);
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.kind = 24;
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.base = (&NTI__K9bYwLtGKmFQYg8TwmqoG3Q_);
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.flags = 2;
NTI__P9bWebqKHkrGHwy9aZW9bw0TA_.marker = Marker_tySequence__P9bWebqKHkrGHwy9aZW9bw0TA;
NTI__GnXaFIlVxvDpiKnOUsLlMw_.size = sizeof(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw);
NTI__GnXaFIlVxvDpiKnOUsLlMw_.align = NIM_ALIGNOF(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw);
NTI__GnXaFIlVxvDpiKnOUsLlMw_.kind = 17;
NTI__GnXaFIlVxvDpiKnOUsLlMw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__rF9caJawfOjYTjsgLVUSGFA_721_2[0] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[11];
TM__rF9caJawfOjYTjsgLVUSGFA_0[11].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[11].offset = offsetof(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw, colonstate_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[11].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[11].name = ":state";
TM__rF9caJawfOjYTjsgLVUSGFA_721_2[1] = &TM__rF9caJawfOjYTjsgLVUSGFA_0[12];
TM__rF9caJawfOjYTjsgLVUSGFA_0[12].kind = 1;
TM__rF9caJawfOjYTjsgLVUSGFA_0[12].offset = offsetof(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw, genericType1);
TM__rF9caJawfOjYTjsgLVUSGFA_0[12].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__rF9caJawfOjYTjsgLVUSGFA_0[12].name = "genericType1";
TM__rF9caJawfOjYTjsgLVUSGFA_0[10].len = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[10].kind = 2; TM__rF9caJawfOjYTjsgLVUSGFA_0[10].sons = &TM__rF9caJawfOjYTjsgLVUSGFA_721_2[0];
NTI__GnXaFIlVxvDpiKnOUsLlMw_.node = &TM__rF9caJawfOjYTjsgLVUSGFA_0[10];
NTI__hW0nFkOHm9b8Hn43XRoDtzQ_.size = sizeof(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*);
NTI__hW0nFkOHm9b8Hn43XRoDtzQ_.align = NIM_ALIGNOF(tyObject_Env_semstmtsdotnim_checkCovariantParamsUsages___GnXaFIlVxvDpiKnOUsLlMw*);
NTI__hW0nFkOHm9b8Hn43XRoDtzQ_.kind = 22;
NTI__hW0nFkOHm9b8Hn43XRoDtzQ_.base = (&NTI__GnXaFIlVxvDpiKnOUsLlMw_);
NTI__hW0nFkOHm9b8Hn43XRoDtzQ_.marker = Marker_tyRef__hW0nFkOHm9b8Hn43XRoDtzQ;
}

