/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <glob.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__yByxe8FSFNTgs4tcAkTYag tyTuple__yByxe8FSFNTgs4tcAkTYag;
typedef struct tySequence__1I3cxybVrOXM64KW2dfERQ tySequence__1I3cxybVrOXM64KW2dfERQ;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;
typedef struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw;

/* section: NIM_merge_TYPES */
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw[37];
typedef NU8 tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg;
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
struct tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg {
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a;
tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__tPA3StZ6VsKyoznyrIfFxg_9) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ;
struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA {
tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w {
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA defaultCC;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* dynlib;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* otherPragmas;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
};
typedef NU8 tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ;
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
typedef NimStringDesc* tyArray__sMpvt1sOxOJ3LFGulnbeMQ[4];
typedef NU8 tySet_tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg;
struct tyTuple__yByxe8FSFNTgs4tcAkTYag {
NimStringDesc* Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
NimStringDesc* Field3;
NimStringDesc* Field4;
NimStringDesc* Field5;
NimStringDesc* Field6;
NimStringDesc* Field7;
NimStringDesc* Field8;
NimStringDesc* Field9;
NimStringDesc* Field10;
NimStringDesc* Field11;
NimStringDesc* Field12;
NimStringDesc* Field13;
NimStringDesc* Field14;
NimStringDesc* Field15;
NimStringDesc* Field16;
NimStringDesc* Field17;
NimStringDesc* Field18;
NimStringDesc* Field19;
NimStringDesc* Field20;
tySet_tyEnum_TInfoCCProp__49cn73TjZ7Rt9b8QCAU8tLNg Field21;
};
typedef tyTuple__yByxe8FSFNTgs4tcAkTYag tyArray__sa9aJ6U8e9b7Bj4Yq8itsR8w[11];
struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw {
NI depthLevel;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* parent;
};
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* resultSym;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* selfSym;
NI nestedLoopCounter;
NI nestedBlockCounter;
NI inTryStmt;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* next;
NIM_BOOL mappingExists;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q mapping;
tySequence__1I3cxybVrOXM64KW2dfERQ* caseContext;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field0;
NI Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};
struct tySequence__1I3cxybVrOXM64KW2dfERQ {
  TGenericSeq Sup;
  tyTuple__FyNGItFCBJSXLJ9aJSzlX9aw data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__m5gdSrENJIwAi9aMdDiUT9bg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__KQ6mgDJAAhGjX4CT62UFwg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI* i, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL comesFromPush, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(void, processNote__0LSWh2UqkqDBtNGS0Kh9cNQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichKeyword__sZUQNPhNGEM8MllfcWvRiw)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* id);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w, findStr__ksT2oQUquwtB1u6JxjTCFw)(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg a, NimStringDesc* s, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w default_0);
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__0LSWh2UqkqDBtNGS0Kh9cNQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, processExc__3TCM8u8T9bVrVbU2YOmorCg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__aVxWxXLmf103vwE8uZ9cXRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCustomPragma__wiyGBj4PmPVNmjmIuvK9cHQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA t, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUse__k3cqh606mJPYNzLXdtZjIg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, pragma__m5gdSrENJIwAi9aMdDiUT9bg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL isStatement);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___txCax6HTxTvaDY9bSHIRipg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** b, NI bLen_0);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUse__no49bEWZLCgyYgYqiaocHSg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w, NimStringDesc* pragmaName);
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__k09cbJuHCFNqocyycgSiPqw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, setExternName__k09cbJuHCFNqocyycgSiPqw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* defaultStr);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectStrLit__iTLkBylaQ5j0DcqGsSoybQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* c, NimStringDesc* define);
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__Q09bd79bkpFX5inwl8cmQvPw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__C1MQfgDmfXqO1v69aAZbuYA)(NimStringDesc* strVal, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__k09cbJuHCFNqocyycgSiPqw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__k09cbJuHCFNqocyycgSiPqw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__k09cbJuHCFNqocyycgSiPqw_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__k09cbJuHCFNqocyycgSiPqw_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__GehhaBQhWjS36aXBX9cGo4g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__Nm9cs6Kn6ltGLynV4vNsRgw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPowerOfTwo__1xdTQapFveM9bImKot7h9cdw)(NI x);
N_LIB_PRIVATE N_NIMCALL(void, noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__ePldymDitzRJBrQOoUllvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flag);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__O7VABFZyA8PIDgrKEJ9aAKw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, processMagic__ISl2Z9aoSIz8Q3Jlw20Fjuw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__iGg0RIKceRvsmvq8FUHOEw)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*, getLib__Nj24SwOhKqYFNJIoNsGSTA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*, newLib__rs8ukRH9beqw1tk0hnXjBtg)(tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__jYnZYpCgdCpukBZK9bxcw9bQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* lib);
N_LIB_PRIVATE N_NIMCALL(void, addToLib__xoFj1Tk9cDOsrW8yALZcxCA)(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__C3X1S7JVdavu4gb5a39adyw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, expectDynlibNode__wiyGBj4PmPVNmjmIuvK9cHQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**, X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem)(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__lRfMX9cOvnV9cCzAmWFEHWsA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, registerCompilerProc__9cLrw2jAkfW3f8XFlNBee8g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__6xKxol9c17ygvuKxKHe5vyg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* outerPragma);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TLookupFlag__ObWMY5GMSl1GiMcrKaAhKQ flags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__D9cCpOUBRV9c9af06eLYGN2uA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, processDefine__0LSWh2UqkqDBtNGS0Kh9cNQ_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__znuJizGq3isbcihOOtUY0A)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol, NimStringDesc* value);
N_LIB_PRIVATE N_NIMCALL(void, processUndef__0LSWh2UqkqDBtNGS0Kh9cNQ_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ)(tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__0LSWh2UqkqDBtNGS0Kh9cNQ_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___gEyhbzZ1UcxyenWRLJRXNQ)(NimStringDesc* head, NimStringDesc* tail);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, cstrToNimstr)(NCSTRING str);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, completeCfilePath__VmrjcznbGOrooG3SBIdEFQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* cfile, NIM_BOOL createSubDir);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosextractFilename)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(void, docompile__oYdb3GlpLIy9cryXlGGrAxw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__z7B4FbwzX3Y0L1EA2lLGXw)(NimStringDesc* x, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__INt9bhJYC8JcZL7VjCVQHWQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg* c);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, findFile__Jsd6LfkMRIXL9b0vzcHVYOA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* f, NIM_BOOL suppressStdlib);
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toObjFile__GMjJ0d3khWrmxAqhh9anEsw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, processLink__0LSWh2UqkqDBtNGS0Kh9cNQ_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeFile__bIZEBTIFD5raNKz9aFRkrqw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringDesc* path, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosaddFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__VWI2GZGxWbHzjYJHzOr3dA_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOption__siPDo9a2eQzwubdmcIGchWg_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOption__siPDo9a2eQzwubdmcIGchWg_4)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* option);
N_LIB_PRIVATE N_NIMCALL(void, addLocalCompileOption__9aZ1lkFxjUUC2WDEd4sU9ckQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* option, NimStringDesc* nimfile);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__fr10i3QiqDDNG5EqWBCesA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(void, processPush__tJumk6sIiZ2uaM1X2Ysp1A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI start);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w*, pushOptionEntry__SQasfuhUR9aUpH0EyW9aFezg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__y4eNprw54h2RqpKXqw47Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__0LSWh2UqkqDBtNGS0Kh9cNQ_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ, parseEnum__qIaeVZYC2IcNaPaw4CHbjg)(NimStringDesc* s);
static N_INLINE(NIM_BOOL, isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
static N_INLINE(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, pragmaToOptions__T015FMVm7Ly7T46PlmTKCQpragmas)(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w);
N_LIB_PRIVATE N_NIMCALL(void, onOff__z5rO4uDEbwX8mhNS9cT9cWBQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__0LSWh2UqkqDBtNGS0Kh9cNQ_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA, wordToCallConv__FoLOpmK9aKgNJHHWPzd6rrw)(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw sw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, processPop__0LSWh2UqkqDBtNGS0Kh9cNQ_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__9aY89b9aR25iMJ8fPdM84CvQg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, processPragma__lMBKKtS58KCQFAjFX14tQA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeI__L1Xluv2iZ8cHbWec9bBiiaw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, X5BX5D___lNrbV6XRsw9boDXksMOKVag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s, NI sLen_0, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__tyTgUybFIoow4CX2l5beug)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* n);
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__C3X1S7JVdavu4gb5a39adyw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, processOption__557NRVJHpXqxWeukDYchKw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__0LSWh2UqkqDBtNGS0Kh9cNQ_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsmOrEmit__7on6juYQ5yDeHojpmzlBFg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* con, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_CHAR marker);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringDesc* s, NIM_CHAR sub, NI start, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__2yh9cer0ymNRHlOOg8P7IuA)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, searchInScopes__Drn1sJCJSwUUo03qKJigUw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__aOnJJ9cXkOooTyUuLmnc09bw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__0LSWh2UqkqDBtNGS0Kh9cNQ_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__0LSWh2UqkqDBtNGS0Kh9cNQ_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, getInfoContext__TXxF2CG3kwLqptPWf0kC9aQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI index);
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__hUQzMUBJmHVdQ9cj81jo89cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it);
N_LIB_PRIVATE N_NIMCALL(NI16, pragmaLocks__AMYzMg6pmHjlh0azeAYr7Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pragmaGuard__yHVOFpP1CkeW6rPusEqxjg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
N_LIB_PRIVATE N_NIMCALL(void, registerNimScriptSymbol__9cLrw2jAkfW3f8XFlNBee8g_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__0LSWh2UqkqDBtNGS0Kh9cNQ_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__0LSWh2UqkqDBtNGS0Kh9cNQ_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*, openScope__HbQKk9aDdsJVs9bASTXwa5Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, addDecl__aPXKqZJT9c7r7gT8X3uZAHw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__TX9bi5b9bIHR13FiwHwV59a4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__ISl2Z9aoSIz8Q3Jlw20Fjuw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, mergePragmas__TCm7mXLrAaTqiVWnN4JCgg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__L8Ia04mIjWr0SdD6EvU9aQw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_2, "invalid pragma: ", 16);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_4, "/home/runner/work/nightlies/nightlies/nim/compiler/pragmas.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_3 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 107),
((NI) 12)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_5, "a \'cast\' pragma cannot be pushed", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_6 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 786),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_7, "\'cast\' pragma only allowed in a statement context", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_8 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 788),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_10, "invalid type for raises/tags list", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_11 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 650),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_12, "recursive dependency: ", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_13 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 805),
((NI) 17)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_14, "$1", 2);
extern TNimType NTI__yoNlBGx0D2tRizIdhQuENw_;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_16, "invalid extern name: \'", 22);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_17, "\'. (Forgot to escape \'$\'\?)", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_18 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 155),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_19, "string literal expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_20 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 201),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_21 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 209),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_22, "exportcpp requires `cpp` backend, got ", 38);
extern TNimType NTI__4OBsgZ9cscH2JLUE5Wcz01g_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_23 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 821),
((NI) 22)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_24, "cppdefine", 9);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_25, "`importjs` pragma requires the JavaScript target", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_26 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 843),
((NI) 20)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__tPA3StZ6VsKyoznyrIfFxg_27 = {
0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_28, "`importjs` for routines requires a pattern", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_29 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 848),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_30, "integer literal expected", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_31 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 218),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_32 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 223),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_33, "size may only be 1, 2, 4 or 8", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_34 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 863),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_35, "power of two expected", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_36 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 869),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_37, "\'on\' or \'off\' expected", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_38 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 257),
((NI) 12)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_39, "use {.experimental: \"codeReordering\".} instead; ", 48);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_40, "{.noForward.}", 13);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_41, "{.reorder.}", 11);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_42, " is deprecated", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_43 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 272),
((NI) 9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_44 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 236),
((NI) 14)}
;
extern TNimType NTI__shZhZOdbVC5nnFvcXQAImg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_45 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 245),
((NI) 30)}
;
extern TNimType NTI__arD7Tw6eD6lvOczWZl9buNg_;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_46, ".noreturn with return type not allowed", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_47 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 937),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_48 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 299),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_49 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 309),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_50, "FlowVar", 7);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_51, "annotation to deprecated not supported here", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_52 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 966),
((NI) 22)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_53, "list of key:value pairs expected", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_54 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 713),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_55, "the .deprecated pragma is unreliable for routines", 49);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_56 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 718),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_57, "key:value pair expected", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_58 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 726),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_59, "a type can only borrow `.` for now", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_60 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 694),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_61, "hint", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_62 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1024),
((NI) 15)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_63, "warning", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_64 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1028),
((NI) 15)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_65, "error", 5);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_66 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1041),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_67 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1042),
((NI) 22)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_68, "true", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_69 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 506),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_71, "compile", 7);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_72, "\'.compile\' pragma takes up 2 arguments", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_73 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 525),
((NI) 18)}
;
extern NIM_CONST tyArray__sa9aJ6U8e9b7Bj4Yq8itsR8w CC__78I18QZNZFIv9ah7oETc0jg;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_74, "link", 4);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_75, "passl", 5);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_76, "passc", 5);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_77, "localpassl", 10);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_78, "\'push\' cannot have arguments", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_79 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 445),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_81, "Code reordering experimental pragma only valid at toplevel", 58);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_82 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 396),
((NI) 24)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_83, "unknown experimental feature", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_84 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 400),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_85 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 402),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_86, "calling convention expected", 27);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_87 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 282),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_88 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 284),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_89, "speed", 5);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_90, "size", 4);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_91, "none", 4);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_92, "\'none\', \'speed\' or \'size\' expected", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_93 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 435),
((NI) 26)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_94, "{.pop.} without a corresponding {.push.}", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_95 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 463),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_96, "option expected", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_97 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 441),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_98 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 581),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_99, "empty \'asm\' statement", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_100 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 549),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_101 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 595),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_102, "`{.union.}` is not implemented for js backend.", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_103 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1118),
((NI) 20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_104 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 621),
((NI) 18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_105 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 623),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_106, "tuple expected", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_107 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 628),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_108, "locks pragma takes a list of expressions", 40);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_109 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 668),
((NI) 16)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_110, "unknown", 7);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_111, "invalid string literal for locks pragma (only allowed string is"
" \"unknown\")", 74);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_112 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 682),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_113, "integer must be within 0..1000", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_114 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 686),
((NI) 18)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_115, "bitsize needs to be positive", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_116 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1163),
((NI) 22)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_117, "expression expected", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_118 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1179),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_119, "\'experimental\' pragma only valid as toplevel statement or in a "
"\'push\' environment", 81);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_120 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1184),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_121, "the \'.this\' pragma is deprecated", 32);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_122 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1189),
((NI) 17)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_123, "self", 4);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_124 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1192),
((NI) 17)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_125, "\'this\' pragma is allowed to have zero or one arguments", 54);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_126 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1194),
((NI) 20)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_127, "proposition expected", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_128 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 113),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_129 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 119),
((NI) 14)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_130, "result", 6);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_131, "cannot attach a custom pragma to \'", 34);
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_132, "\'", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_133 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 109),
((NI) 12)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_134, "implicitPragmas", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_135 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1250),
((NI) 25)}
;
STRING_LITERAL(TM__tPA3StZ6VsKyoznyrIfFxg_136, ".dynlib requires .exportc", 25);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__tPA3StZ6VsKyoznyrIfFxg_137 = {((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_4),
((NI) 1256),
((NI) 16)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getPragmaVal__fMcQjyT1dTz2fXfUKJSCCA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procAst, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw name) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	p = (*procAst)._kind_6.sons->data[((NI) 4)];
	{
		if (!((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(p);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					it = (*p)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						NIM_BOOL T12_;
						NIM_BOOL T13_;
						NI T15_;
						T11_ = (NIM_BOOL)0;
						T12_ = (NIM_BOOL)0;
						T13_ = (NIM_BOOL)0;
						T13_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T13_)) goto LA14_;
						T15_ = (NI)0;
						T15_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						T13_ = (T15_ == ((NI) 2));
						LA14_: ;
						T12_ = T13_;
						if (!(T12_)) goto LA16_;
						T12_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
						LA16_: ;
						T11_ = T12_;
						if (!(T11_)) goto LA17_;
						T11_ = ((*(*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident).Sup.id == name);
						LA17_: ;
						if (!T11_) goto LA18_;
						result = (*it)._kind_6.sons->data[((NI) 1)];
						goto BeforeRet_;
					}
					LA18_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg, dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem)(tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w a, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w b) {
	tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	T1_ = (NimStringDesc*)0;
	T2_ = (NimStringDesc*)0;
	T2_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA(n, 4);
	T1_ = rawNewString((T2_ ? T2_->Sup.len : 0) + 16);
appendString(T1_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_2));
appendString(T1_, T2_);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_3, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, processNote__0LSWh2UqkqDBtNGS0Kh9cNQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NI T9_;
		NI T12_;
		tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg nk;
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T17_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T7_)) goto LA8_;
		T9_ = (NI)0;
		T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T7_ = (T9_ == ((NI) 2));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA10_;
		T6_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
		LA10_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA11_;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[((NI) 0)]);
		T5_ = (T12_ == ((NI) 2));
		LA11_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA13_;
		T4_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA13_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA14_;
		T3_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA14_: ;
		if (!T3_) goto LA15_;
		nk = (tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg)0;
		T17_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
		T17_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)])._kind_5.ident);
		switch (T17_) {
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 121):
		{
			tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w xX60gensym128_;
			tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T19_;
			T19_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 52), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 83));
			xX60gensym128_ = findStr__ksT2oQUquwtB1u6JxjTCFw(T19_, (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0));
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xX60gensym128__2;
				if (!!((xX60gensym128_ == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0)))) goto LA22_;
				nk = ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (xX60gensym128_));
				xX60gensym128__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym128__2);
				{
					NIM_BOOL T26_;
					T26_ = (NIM_BOOL)0;
					T26_ = ((*xX60gensym128__2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
					if (!(T26_)) goto LA27_;
					T26_ = !(((*xX60gensym128__2)._kind_1.intVal == IL64(0)));
					LA27_: ;
					if (!T26_) goto LA28_;
					(*(*(*c).graph).config).notes[(NU)((nk- 12))>>3] |=(1U<<((nk- 12)&7U));
				}
				goto LA24_;
				LA28_: ;
				{
					(*(*(*c).graph).config).notes[(NU)((nk- 12))>>3] &= ~(1U<<((nk- 12)&7U));
				}
				LA24_: ;
			}
			goto LA20_;
			LA22_: ;
			{
				invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
			}
			LA20_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 120):
		{
			tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w xX60gensym137_;
			tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T33_;
			T33_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51));
			xX60gensym137_ = findStr__ksT2oQUquwtB1u6JxjTCFw(T33_, (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0));
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xX60gensym137__2;
				if (!!((xX60gensym137_ == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0)))) goto LA36_;
				nk = ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (xX60gensym137_));
				xX60gensym137__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym137__2);
				{
					NIM_BOOL T40_;
					T40_ = (NIM_BOOL)0;
					T40_ = ((*xX60gensym137__2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
					if (!(T40_)) goto LA41_;
					T40_ = !(((*xX60gensym137__2)._kind_1.intVal == IL64(0)));
					LA41_: ;
					if (!T40_) goto LA42_;
					(*(*(*c).graph).config).notes[(NU)((nk- 12))>>3] |=(1U<<((nk- 12)&7U));
				}
				goto LA38_;
				LA42_: ;
				{
					(*(*(*c).graph).config).notes[(NU)((nk- 12))>>3] &= ~(1U<<((nk- 12)&7U));
				}
				LA38_: ;
			}
			goto LA34_;
			LA36_: ;
			{
				invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
			}
			LA34_: ;
		}
		break;
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 122):
		{
			tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w xX60gensym146_;
			tyObject_HSlice__9a7LZzxhxaoaVRy8OcVBd9cg T47_;
			T47_ = dotdot___N3IU9cJ5UjABfbcVFvMuhrQsystem(((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 12), ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51));
			xX60gensym146_ = findStr__ksT2oQUquwtB1u6JxjTCFw(T47_, (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0));
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* xX60gensym146__2;
				if (!!((xX60gensym146_ == ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 0)))) goto LA50_;
				nk = ((tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg) (xX60gensym146_));
				xX60gensym146__2 = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), xX60gensym146__2);
				{
					NIM_BOOL T54_;
					T54_ = (NIM_BOOL)0;
					T54_ = ((*xX60gensym146__2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
					if (!(T54_)) goto LA55_;
					T54_ = !(((*xX60gensym146__2)._kind_1.intVal == IL64(0)));
					LA55_: ;
					if (!T54_) goto LA56_;
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 12))>>3] |=(1U<<((nk- 12)&7U));
				}
				goto LA52_;
				LA56_: ;
				{
					(*(*(*c).graph).config).warningAsErrors[(NU)((nk- 12))>>3] &= ~(1U<<((nk- 12)&7U));
				}
				LA52_: ;
			}
			goto LA48_;
			LA50_: ;
			{
				invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
			}
			LA48_: ;
		}
		break;
		default:
		{
			invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
		}
		break;
		}
	}
	goto LA1_;
	LA15_: ;
	{
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processExc__3TCM8u8T9bVrVbU2YOmorCg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (*c).hasUnresolvedArgs.ClE_0? (*c).hasUnresolvedArgs.ClP_0(c, x, (*c).hasUnresolvedArgs.ClE_0):((TM__tPA3StZ6VsKyoznyrIfFxg_9)((*c).hasUnresolvedArgs.ClP_0))(c, x);
		if (!T3_) goto LA4_;
		asgnRef((void**) (&(*x).typ), makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, x));
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
		T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T7_ = (*c).semTypeNode(c, x, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
		t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T7_, IL64(36275087638268176));
		{
			NIM_BOOL T10_;
			NIM_BOOL T12_;
			T10_ = (NIM_BOOL)0;
			T10_ = !(((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17)));
			if (!(T10_)) goto LA11_;
			T12_ = (NIM_BOOL)0;
			T12_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(t);
			T10_ = !(T12_);
			LA11_: ;
			if (!T10_) goto LA13_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_10), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_11, NIM_FALSE);
		}
		LA13_: ;
		asgnRef((void**) (&(*x).typ), t);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRaisesOrTags__0LSWh2UqkqDBtNGS0Kh9cNQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA10_;
			processExc__3TCM8u8T9bVrVbU2YOmorCg(c, it);
		}
		goto LA8_;
		LA10_: ;
		{
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
				e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA16;
							i = i_2;
							e = (*it)._kind_6.sons->data[i];
							processExc__3TCM8u8T9bVrVbU2YOmorCg(c, e);
							i_2 += ((NI) 1);
						} LA16: ;
					}
				}
			}
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semCustomPragma__wiyGBj4PmPVNmjmIuvK9cHQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callNode;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	callNode = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		tyArray__jlWPjgtbdjE069arIWHC9c9bg T5_;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
		T5_[0] = n;
		callNode = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T5_, 1);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__AB6yfoUgfWM2NtGe9bzkCmw T9_;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA7_;
		nimZeroMem((void*)T9_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
		T9_[0] = (*n)._kind_6.sons->data[((NI) 0)];
		T9_[1] = (*n)._kind_6.sons->data[((NI) 1)];
		callNode = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), T9_, 2);
	}
	goto LA1_;
	LA7_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA11_;
		callNode = n;
	}
	goto LA1_;
	LA11_: ;
	{
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
		result = n;
		goto BeforeRet_;
	}
	LA1_: ;
	r = (*c).semOverloadedCall(c, callNode, n, 262144, 262144);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = (r == 0);
		if (T16_) goto LA17_;
		T16_ = !((((*(*(*r)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))&63U)))!=0));
		LA17_: ;
		if (!T16_) goto LA18_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
		result = n;
		goto BeforeRet_;
	}
	LA18_: ;
	result = r;
	{
		NIM_BOOL T22_;
		NI T24_;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		if (!(T22_)) goto LA23_;
		T24_ = (NI)0;
		T24_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
		T22_ = (T24_ == ((NI) 1));
		LA23_: ;
		if (!T22_) goto LA25_;
		result = (*result)._kind_6.sons->data[((NI) 0)];
	}
	goto LA20_;
	LA25_: ;
	{
		NIM_BOOL T28_;
		NI T30_;
		T28_ = (NIM_BOOL)0;
		T28_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
		if (!(T28_)) goto LA29_;
		T30_ = (NI)0;
		T30_ = len__P89cqdlERShb9alU3iC0yj8wast(r);
		T28_ = (T30_ == ((NI) 2));
		LA29_: ;
		if (!T28_) goto LA31_;
		transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) ((*n).kind)));
	}
	goto LA20_;
	LA31_: ;
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__31wM5Ui9c8jnrQ5QD4oPxOQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(void, setExternName__k09cbJuHCFNqocyycgSiPqw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	{
		if (!eqStrings(extname, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14))) goto LA3_;
		asgnRef((void**) (&(*s).loc.r), rope__yShmEg9cffWxI7s5XzEKBow((*(*s).name).s));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(extname->data, (extname ? extname->Sup.len : 0), 36);
		if (!!(T6_)) goto LA7_;
		asgnRef((void**) (&(*s).loc.r), rope__yShmEg9cffWxI7s5XzEKBow(extname));
	}
	goto LA1_;
	LA7_: ;
	{
		TSafePoint TM__tPA3StZ6VsKyoznyrIfFxg_15;
		NimStringDesc* T10_;
		pushSafePoint(&TM__tPA3StZ6VsKyoznyrIfFxg_15);
		TM__tPA3StZ6VsKyoznyrIfFxg_15.status = _setjmp(TM__tPA3StZ6VsKyoznyrIfFxg_15.context);
		if (TM__tPA3StZ6VsKyoznyrIfFxg_15.status == 0) {
		T10_ = (NimStringDesc*)0;
		T10_ = nsuFormatSingleElem(extname, (*(*s).name).s);
		asgnRef((void**) (&(*s).loc.r), rope__yShmEg9cffWxI7s5XzEKBow(T10_));
		popSafePoint();
		}
		else {
			popSafePoint();
			if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
				NimStringDesc* T13_;
				TM__tPA3StZ6VsKyoznyrIfFxg_15.status = 0;
				T13_ = (NimStringDesc*)0;
				T13_ = rawNewString((extname ? extname->Sup.len : 0) + 48);
appendString(T13_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_16));
appendString(T13_, extname);
appendString(T13_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_17));
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T13_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_18, NIM_FALSE);
				popCurrentException();
			}
		}
		if (TM__tPA3StZ6VsKyoznyrIfFxg_15.status != 0) reraiseException();
	}
	LA1_: ;
	{
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*(*(*c).graph).config).cmd == ((tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw) 7));
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(extname->data, (extname ? extname->Sup.len : 0), 36);
		T16_ = !(T18_);
		LA17_: ;
		if (!T16_) goto LA19_;
		(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 1)) & 15);
	}
	LA19_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternExport__k09cbJuHCFNqocyycgSiPqw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7)) & 63);
}
N_LIB_PRIVATE N_NOINLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), (*n).info, T1_);
	asgnRef((void**) (&(*result)._kind_3.strVal), ((NimStringDesc*) NIM_NIL));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_20, NIM_FALSE);
		result = newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)]));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
		{
			result = (*n)._kind_6.sons->data[((NI) 1)];
		}
		break;
		default:
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_21, NIM_FALSE);
			result = newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA(c, n);
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, expectStrLit__iTLkBylaQ5j0DcqGsSoybQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (NimStringDesc*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, n);
	result = copyString((*T1_)._kind_3.strVal);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* defaultStr) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA3_;
		result = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		result = copyString(defaultStr);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, recordPragma__Q09bd79bkpFX5inwl8cmQvPw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc** args, NI argsLen_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* recorded;
	recorded = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (argsLen_0-1);
		res = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T4_;
				if (!(res <= colontmp_)) goto LA3;
				i = res;
				T4_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T4_ = newStrNode__C1MQfgDmfXqO1v69aAZbuYA(args[i], (*n).info);
				add__P8dDSotTW25BkfbyspojGg(recorded, T4_);
				res += ((NI) 1);
			} LA3: ;
		}
	}
	(*(*c).graph).recordStmt((*c).graph, (*c).module, recorded);
}
N_LIB_PRIVATE N_NIMCALL(void, makeExternImport__k09cbJuHCFNqocyycgSiPqw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCompilerProc__k09cbJuHCFNqocyycgSiPqw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
	(*s).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 7)) & 15);
}
N_LIB_PRIVATE N_NIMCALL(void, processImportCpp__k09cbJuHCFNqocyycgSiPqw_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
		if (!((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 1))) goto LA3_;
		m = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
		(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31)) & 63);
	}
	LA3_: ;
	(*(*(*c).graph).config).globalOptions |= ((NU64)1)<<((((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 35)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, processImportObjC__k09cbJuHCFNqocyycgSiPqw_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* extname, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
	setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, s, extname, info);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 32)) & 63);
	(*s).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
	m = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
	(*m).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 32)) & 63);
}
N_LIB_PRIVATE N_NIMCALL(NI, expectIntLit__GehhaBQhWjS36aXBX9cGo4g)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_30), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_31, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)]));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
		{
			result = ((NI) ((*(*n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
		}
		break;
		default:
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_30), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_32, NIM_FALSE);
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTurnedOn__O7VABFZyA8PIDgrKEJ9aAKw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		x = (*c).semConstBoolExpr(c, (*n)._kind_6.sons->data[((NI) 1)]);
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), x);
		{
			if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA10_;
			result = !(((*x)._kind_1.intVal == IL64(0)));
			goto BeforeRet_;
		}
		LA10_: ;
	}
	LA6_: ;
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_37), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_38, NIM_FALSE);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaNoForward__ePldymDitzRJBrQOoUllvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flag) {
	NimStringDesc* T7_;
	NimStringDesc* T8_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTurnedOn__O7VABFZyA8PIDgrKEJ9aAKw(c, n);
		if (!T3_) goto LA4_;
		(*(*c).module).flags |= ((NU64)1)<<((flag) & 63);
		(*c).features |= ((NU16)1)<<((((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 9)) & 15);
	}
	goto LA1_;
	LA4_: ;
	{
		(*(*c).module).flags &= ~(((NU64)1) << ((flag) & 63));
	}
	LA1_: ;
	T7_ = (NimStringDesc*)0;
	T8_ = (NimStringDesc*)0;
	{
		if (!(flag == ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10))) goto LA11_;
		T8_ = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_40));
	}
	goto LA9_;
	LA11_: ;
	{
		T8_ = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_41));
	}
	LA9_: ;
	T7_ = rawNewString((T8_ ? T8_->Sup.len : 0) + 62);
appendString(T7_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_39));
appendString(T7_, T8_);
appendString(T7_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_42));
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), T7_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_43, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, processMagic__ISl2Z9aoSIz8Q3Jlw20Fjuw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NimStringDesc* v;
{	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_44, NIM_FALSE);
		goto BeforeRet_;
	}
	LA6_: ;
	v = (NimStringDesc*)0;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2))) goto LA10_;
		v = copyString((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
	}
	goto LA8_;
	LA10_: ;
	{
		v = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, n);
	}
	LA8_: ;
	{
		tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m;
		m = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
		{
			tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg v_2;
			NI res;
			v_2 = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 270))) goto LA16;
					v_2 = ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) (res));
					m = v_2;
					{
						NimStringDesc* T19_;
						T19_ = (NimStringDesc*)0;
						T19_ = substr__iGg0RIKceRvsmvq8FUHOEw(reprEnum((NI)m, (&NTI__shZhZOdbVC5nnFvcXQAImg_)), ((NI) 1));
						if (!eqStrings(T19_, v)) goto LA20_;
						(*s).magic = m;
						goto LA13;
					}
					LA20_: ;
					res += ((NI) 1);
				} LA16: ;
			}
		}
	} LA13: ;
	{
		if (!((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0))) goto LA24_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 19), v, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_45, NIM_FALSE);
	}
	LA24_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*, getLib__Nj24SwOhKqYFNJIoNsGSTA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path) {
	tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* result;
	NI T11_;
{	result = (tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*)0;
	{
		tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA** it;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA**)0;
		i = ((NI) 0);
		T2_ = ((*c).libs ? (*c).libs->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				it = &(*c).libs->data[i];
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*(*it)).kind == kind);
					if (!(T7_)) goto LA8_;
					T7_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*(*it)).path, path, NIM_FALSE);
					LA8_: ;
					if (!T7_) goto LA9_;
					result = (*it);
					goto BeforeRet_;
				}
				LA9_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	result = newLib__rs8ukRH9beqw1tk0hnXjBtg(kind);
	asgnRef((void**) (&(*result).path), path);
	asgnRef((void**) (&(*c).libs), (tySequence__arD7Tw6eD6lvOczWZl9buNg*) incrSeqV3((TGenericSeq*)((*c).libs), (&NTI__arD7Tw6eD6lvOczWZl9buNg_)));
	T11_ = (*c).libs->Sup.len++;
	asgnRef((void**) (&(*c).libs->data[T11_]), result);
	{
		if (!((*path).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*path).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA14_;
		(*result).isOverriden = isDynlibOverride__jYnZYpCgdCpukBZK9bxcw9bQ((*(*c).graph).config, (*path)._kind_3.strVal);
	}
	LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, expectDynlibNode__wiyGBj4PmPVNmjmIuvK9cHQ_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_48, NIM_FALSE);
		result = newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		result = (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T11_)) goto LA12_;
			T11_ = ((*(*result)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10));
			LA12_: ;
			if (!T11_) goto LA13_;
			result = (*(*result)._kind_4.sym).ast;
		}
		LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			if (T17_) goto LA18_;
			T17_ = !(((369098752 &((NU64)1<<((NU)((*(*result).typ).kind)&63U)))!=0));
			LA18_: ;
			if (!T17_) goto LA19_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_49, NIM_FALSE);
			result = newEmptyStrNode__ZaI7vJX4CKSjFfkKfQ2vVA(c, n);
		}
		LA19_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**, X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem)(tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** s, NI sLen_0, NI i) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** result;
	result = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDynLib__C3X1S7JVdavu4gb5a39adyw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	{
		NIM_BOOL T3_;
		tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T7_ = expectDynlibNode__wiyGBj4PmPVNmjmIuvK9cHQ_3(c, n);
		lib = getLib__Nj24SwOhKqYFNJIoNsGSTA(c, ((tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ) 1), T7_);
		{
			tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T12_;
			if (!!((*lib).isOverriden)) goto LA10_;
			T12_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
			T12_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
			asgnRef((void**) (&(*(*T12_)).dynlib), lib);
		}
		LA10_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		{
			tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib_2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA16_;
			T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T18_ = expectDynlibNode__wiyGBj4PmPVNmjmIuvK9cHQ_3(c, n);
			lib_2 = getLib__Nj24SwOhKqYFNJIoNsGSTA(c, ((tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ) 1), T18_);
			{
				if (!!((*lib_2).isOverriden)) goto LA21_;
				addToLib__xoFj1Tk9cDOsrW8yALZcxCA(lib_2, sym);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4)) & 15);
			}
			LA21_: ;
		}
		goto LA14_;
		LA16_: ;
		{
			(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5)) & 15);
		}
		LA14_: ;
		{
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
			if (!(T27_)) goto LA28_;
			T27_ = !(((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = !((((*(*sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 42))&63U)))!=0));
			LA29_: ;
			if (!T26_) goto LA30_;
			(*(*sym).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 2);
		}
		LA30_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markCompilerProc__lRfMX9cOvnV9cCzAmWFEHWsA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)));
		if (T3_) goto LA4_;
		T3_ = !(eqStrings((*(*s).name).s, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_50)));
		LA4_: ;
		if (!T3_) goto LA5_;
		makeExternExport__k09cbJuHCFNqocyycgSiPqw(c, s, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14), (*s).info);
	}
	LA5_: ;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 18)) & 63);
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	registerCompilerProc__9cLrw2jAkfW3f8XFlNBee8g((*c).graph, s);
}
N_LIB_PRIVATE N_NIMCALL(void, deprecatedStmt__6xKxol9c17ygvuKxKHe5vyg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* outerPragma) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragma;
{	pragma = (*outerPragma)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*pragma).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*pragma).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22))) goto LA3_;
		(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22)) & 63);
		asgnRef((void**) (&(*(*c).module).constraint), getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, outerPragma));
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!!(((*pragma).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA7_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*pragma).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_53), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_54, NIM_FALSE);
		goto BeforeRet_;
	}
	LA7_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		n = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(pragma);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					n = (*pragma)._kind_6.sons->data[i];
					{
						NIM_BOOL T15_;
						NI T17_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dest;
						tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* src;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* alias;
						T15_ = (NIM_BOOL)0;
						T15_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T15_)) goto LA16_;
						T17_ = (NI)0;
						T17_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
						T15_ = (T17_ == ((NI) 2));
						LA16_: ;
						if (!T15_) goto LA18_;
						dest = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, (*n)._kind_6.sons->data[((NI) 1)], 2);
						{
							NIM_BOOL T22_;
							T22_ = (NIM_BOOL)0;
							T22_ = (dest == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
							if (T22_) goto LA23_;
							T22_ = ((520192 &((NU32)1<<((NU)((*dest).kind)&31U)))!=0);
							LA23_: ;
							if (!T22_) goto LA24_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_55), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_56, NIM_FALSE);
						}
						LA24_: ;
						src = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*n)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
						alias = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 25), src, dest, (*(*n)._kind_6.sons->data[((NI) 0)]).info, (*(*(*c).graph).config).options);
						(*alias).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1)) & 63);
						{
							if (!(((*dest).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 18))&63U)))!=0)) goto LA28_;
							markCompilerProc__lRfMX9cOvnV9cCzAmWFEHWsA(c, alias);
						}
						LA28_: ;
						addInterfaceDecl__aPXKqZJT9c7r7gT8X3uZAHw_3(c, alias);
						asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(dest));
					}
					goto LA13_;
					LA18_: ;
					{
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_57), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_58, NIM_FALSE);
					}
					LA13_: ;
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, typeBorrow__D9cCpOUBRV9c9af06eLYGN2uA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53)))) goto LA10_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_59), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_60, NIM_FALSE);
		}
		LA10_: ;
	}
	LA6_: ;
	(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 32)) & 63);
}
static N_INLINE(NIM_BOOL, isRoutine__Ye2MiAptq3GrXxTQeyXNeAast)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processDefine__0LSWh2UqkqDBtNGS0Kh9cNQ_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		defineSymbol__znuJizGq3isbcihOOtUY0A((*(*(*c).graph).config).symbols, (*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_68));
	}
	goto LA1_;
	LA8_: ;
	{
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processUndef__0LSWh2UqkqDBtNGS0Kh9cNQ_6)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		undefSymbol__7r39cyzHGkKGsFt9bPVES2hQ((*(*(*c).graph).config).symbols, (*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
	}
	goto LA1_;
	LA8_: ;
	{
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[i]));
	switch ((*(*n)._kind_6.sons->data[i]).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		result = (*(*n)._kind_6.sons->data[i])._kind_3.strVal;
	}
	break;
	default:
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_69, NIM_FALSE);
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, docompile__oYdb3GlpLIy9cryXlGGrAxw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, NimStringDesc* src, NimStringDesc* dest, NimStringDesc* customArgs) {
	tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg cf;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T1_;
	tyArray__sMpvt1sOxOJ3LFGulnbeMQ T2_;
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
	nimZeroMem((void*)(&cf), sizeof(tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg));
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	splitFile__z7B4FbwzX3Y0L1EA2lLGXw(src, (&T1_));
	cf.nimname = copyString(T1_.Field1);
	cf.cname = copyString(src);
	cf.obj = copyString(dest);
	cf.flags = 2;
	cf.customArgs = copyString(customArgs);
	addExternalFileToCompile__INt9bhJYC8JcZL7VjCVQHWQ((*(*c).graph).config, (&cf));
	nimZeroMem((void*)T2_, sizeof(tyArray__sMpvt1sOxOJ3LFGulnbeMQ));
	T2_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_71));
	T2_[1] = copyString(src);
	T2_[2] = copyString(dest);
	T2_[3] = copyString(customArgs);
	recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T2_, 4);
}
static N_INLINE(NIM_BOOL, isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__0LSWh2UqkqDBtNGS0Kh9cNQ_7)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		it = (*n)._kind_6.sons->data[((NI) 1)];
	}
	goto LA1_;
	LA6_: ;
	{
		it = n;
	}
	LA1_: ;
	{
		NIM_BOOL T11_;
		NI T13_;
		NimStringDesc* s;
		NimStringDesc* dest;
		NimStringDesc* found;
		NimStringDesc* T16_;
		NimStringDesc* T17_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
		if (!(T11_)) goto LA12_;
		T13_ = (NI)0;
		T13_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T11_ = (T13_ == ((NI) 2));
		LA12_: ;
		if (!T11_) goto LA14_;
		s = getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA(c, it, ((NI) 0));
		dest = getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA(c, it, ((NI) 1));
		T16_ = (NimStringDesc*)0;
		T16_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*c).graph).config, (*n).info.fileIndex);
		T17_ = (NimStringDesc*)0;
		T17_ = nosparentDir(T16_);
		found = slash___gEyhbzZ1UcxyenWRLJRXNQ(T17_, s);
		{
			NimStringDesc* f;
			glob_t fX60gensym135_;
			NI resX60gensym135_;
			int T19_;
			TSafePoint TM__tPA3StZ6VsKyoznyrIfFxg_70;
			f = (NimStringDesc*)0;
			nimZeroMem((void*)(&fX60gensym135_), sizeof(glob_t));
			resX60gensym135_ = (NI)0;
			fX60gensym135_.gl_offs = ((NI) 0);
			fX60gensym135_.gl_pathc = ((NI) 0);
			fX60gensym135_.gl_pathv = ((NCSTRING*) NIM_NIL);
			T19_ = (int)0;
			T19_ = glob(nimToCStringConv(found), ((int) 0), NIM_NIL, (&fX60gensym135_));
			resX60gensym135_ = ((NI) (T19_));
			pushSafePoint(&TM__tPA3StZ6VsKyoznyrIfFxg_70);
			TM__tPA3StZ6VsKyoznyrIfFxg_70.status = _setjmp(TM__tPA3StZ6VsKyoznyrIfFxg_70.context);
			if (TM__tPA3StZ6VsKyoznyrIfFxg_70.status == 0) {
			{
				if (!(resX60gensym135_ == ((NI) 0))) goto LA22_;
				{
					NI iX60gensym135_;
					NI colontmp_;
					NI res;
					iX60gensym135_ = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = (NI)(fX60gensym135_.gl_pathc - ((NI) 1));
					res = ((NI) 0);
					{
						while (1) {
							NimStringDesc* pathX60gensym135_;
							if (!(res <= colontmp_)) goto LA26;
							iX60gensym135_ = res;
							pathX60gensym135_ = cstrToNimstr(fX60gensym135_.gl_pathv[iX60gensym135_]);
							{
								NIM_BOOL T29_;
								NimStringDesc* obj;
								NimStringDesc* T32_;
								NimStringDesc* T33_;
								T29_ = (NIM_BOOL)0;
								T29_ = nosfileExists(pathX60gensym135_);
								if (!T29_) goto LA30_;
								f = pathX60gensym135_;
								T32_ = (NimStringDesc*)0;
								T32_ = nosextractFilename(f);
								T33_ = (NimStringDesc*)0;
								T33_ = nsuFormatSingleElem(dest, T32_);
								obj = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*c).graph).config, T33_, NIM_TRUE);
								docompile__oYdb3GlpLIy9cryXlGGrAxw(c, it, f, obj, ((NimStringDesc*) NIM_NIL));
							}
							LA30_: ;
							res += ((NI) 1);
						} LA26: ;
					}
				}
			}
			LA22_: ;
			popSafePoint();
			}
			else {
				popSafePoint();
			}
			{
				globfree((&fX60gensym135_));
				if (TM__tPA3StZ6VsKyoznyrIfFxg_70.status != 0) nimLeaveFinally();
			}
			if (TM__tPA3StZ6VsKyoznyrIfFxg_70.status != 0) reraiseException();
		}
	}
	goto LA9_;
	LA14_: ;
	{
		NimStringDesc* s_2;
		NimStringDesc* customArgs;
		NimStringDesc* found_2;
		NimStringDesc* T48_;
		NimStringDesc* T49_;
		NimStringDesc* obj_2;
		NimStringDesc* T66_;
		s_2 = ((NimStringDesc*) NIM_NIL);
		customArgs = ((NimStringDesc*) NIM_NIL);
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA39_;
			s_2 = getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA(c, n, ((NI) 1));
			{
				NI T43_;
				T43_ = (NI)0;
				T43_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				if (!(T43_ <= ((NI) 3))) goto LA44_;
				customArgs = getStrLit__1SxQ6biss9cZ9aUKm3c3MbGA(c, n, ((NI) 2));
			}
			goto LA41_;
			LA44_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_72), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_73, NIM_FALSE);
			}
			LA41_: ;
		}
		goto LA37_;
		LA39_: ;
		{
			s_2 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, n);
		}
		LA37_: ;
		T48_ = (NimStringDesc*)0;
		T48_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*c).graph).config, (*n).info.fileIndex);
		T49_ = (NimStringDesc*)0;
		T49_ = nosparentDir(T48_);
		found_2 = slash___gEyhbzZ1UcxyenWRLJRXNQ(T49_, s_2);
		{
			NIM_BOOL T52_;
			T52_ = (NIM_BOOL)0;
			T52_ = nosfileExists(found_2);
			if (!!(T52_)) goto LA53_;
			{
				NIM_BOOL T57_;
				T57_ = (NIM_BOOL)0;
				T57_ = nosisAbsolute(s_2);
				if (!T57_) goto LA58_;
				found_2 = copyString(s_2);
			}
			goto LA55_;
			LA58_: ;
			{
				found_2 = findFile__Jsd6LfkMRIXL9b0vzcHVYOA((*(*c).graph).config, s_2, NIM_FALSE);
				{
					NIM_BOOL T63_;
					T63_ = (NIM_BOOL)0;
					T63_ = isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils(found_2);
					if (!T63_) goto LA64_;
					found_2 = copyString(s_2);
				}
				LA64_: ;
			}
			LA55_: ;
		}
		LA53_: ;
		T66_ = (NimStringDesc*)0;
		T66_ = completeCfilePath__VmrjcznbGOrooG3SBIdEFQ((*(*c).graph).config, found_2, NIM_FALSE);
		obj_2 = toObjFile__GMjJ0d3khWrmxAqhh9anEsw((*(*c).graph).config, T66_);
		docompile__oYdb3GlpLIy9cryXlGGrAxw(c, it, found_2, obj_2, customArgs);
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, relativeFile__bIZEBTIFD5raNKz9aFRkrqw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* ext) {
	NimStringDesc* result;
	NimStringDesc* s;
	NimStringDesc* T8_;
	NimStringDesc* T9_;
	result = (NimStringDesc*)0;
	s = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, n);
	{
		NIM_BOOL T3_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) < (ext ? ext->Sup.len : 0));
		if (!(T3_)) goto LA4_;
		nimZeroMem((void*)(&T5_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile(s, (&T5_));
		T3_ = ((T5_.Field2 ? T5_.Field2->Sup.len : 0) == 0);
		LA4_: ;
		if (!T3_) goto LA6_;
		s = nosaddFileExt(s, ext);
	}
	LA6_: ;
	T8_ = (NimStringDesc*)0;
	T8_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg((*(*c).graph).config, (*n).info.fileIndex);
	T9_ = (NimStringDesc*)0;
	T9_ = nosparentDir(T8_);
	result = slash___gEyhbzZ1UcxyenWRLJRXNQ(T9_, s);
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = nosfileExists(result);
		if (!!(T12_)) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = nosisAbsolute(s);
			if (!T17_) goto LA18_;
			result = copyString(s);
		}
		goto LA15_;
		LA18_: ;
		{
			result = findFile__Jsd6LfkMRIXL9b0vzcHVYOA((*(*c).graph).config, s, NIM_FALSE);
			{
				NIM_BOOL T23_;
				T23_ = (NIM_BOOL)0;
				T23_ = isEmpty__kPpSxL0H5sJ9a6ujvdQ0QVQpathutils(result);
				if (!T23_) goto LA24_;
				result = copyString(s);
			}
			LA24_: ;
		}
		LA15_: ;
	}
	LA13_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processLink__0LSWh2UqkqDBtNGS0Kh9cNQ_8)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NimStringDesc* found;
	tyArray__Re75IspeoxXy2oCZHwcRrA T1_;
	found = relativeFile__bIZEBTIFD5raNKz9aFRkrqw(c, n, CC__78I18QZNZFIv9ah7oETc0jg[((*(*(*c).graph).config).cCompiler)- 1].Field1);
	addExternalFileToLink__VWI2GZGxWbHzjYJHzOr3dA_2((*(*c).graph).config, found);
	nimZeroMem((void*)T1_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
	T1_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_74));
	T1_[1] = copyString(found);
	recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, n, T1_, 2);
}
static N_INLINE(NIM_BOOL, isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*(*c).currentScope).depthLevel <= ((NI) 2));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processExperimental__0LSWh2UqkqDBtNGS0Kh9cNQ_9)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		(*c).features = ((*c).features | 15);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)]));
		switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
		{
			TSafePoint TM__tPA3StZ6VsKyoznyrIfFxg_80;
			tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ feature;
			pushSafePoint(&TM__tPA3StZ6VsKyoznyrIfFxg_80);
			TM__tPA3StZ6VsKyoznyrIfFxg_80.status = _setjmp(TM__tPA3StZ6VsKyoznyrIfFxg_80.context);
			if (TM__tPA3StZ6VsKyoznyrIfFxg_80.status == 0) {
			feature = parseEnum__qIaeVZYC2IcNaPaw4CHbjg((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
			(*c).features |= ((NU16)1)<<((feature) & 15);
			{
				if (!(feature == ((tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ) 9))) goto LA12_;
				{
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
					if (!!(T16_)) goto LA17_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_81), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_82, NIM_FALSE);
				}
				LA17_: ;
				(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63);
			}
			LA12_: ;
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__yoNlBGx0D2tRizIdhQuENw_))) {
					TM__tPA3StZ6VsKyoznyrIfFxg_80.status = 0;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_83), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_84, NIM_FALSE);
					popCurrentException();
				}
			}
			if (TM__tPA3StZ6VsKyoznyrIfFxg_80.status != 0) reraiseException();
		}
		break;
		default:
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_85, NIM_FALSE);
		}
		break;
		}
	}
	LA1_: ;
}
static N_INLINE(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, pragmaToOptions__T015FMVm7Ly7T46PlmTKCQpragmas)(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w) {
	tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg result;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg));
	switch (w) {
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 151):
	{
		result = 3518;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 79):
	{
		result = 2;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 196):
	{
		result = 4;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 152):
	{
		result = 8;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 153):
	{
		result = 16;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 154):
	{
		result = 32;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 156):
	{
		result = 384;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 157):
	{
		result = 128;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 158):
	{
		result = 256;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 160):
	{
		result = 512;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 159):
	{
		result = 1024;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 163):
	{
		result = 2048;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 167):
	{
		result = 8192;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 168):
	{
		result = 16384;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 128):
	{
		result = 4096;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 129):
	{
		result = 131072;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 130):
	{
		result = 524288;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 137):
	{
		result = 1;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 77):
	{
		result = 18874368;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 78):
	{
		result = 16777216;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 286):
	{
		result = 1048576;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 213):
	{
		result = 4194304;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 164):
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 165):
	{
		result = 8388608;
	}
	break;
	case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 166):
	{
		result = 67108864;
	}
	break;
	default:
	{
		result = 0;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, onOff__z5rO4uDEbwX8mhNS9cT9cWBQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg op, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isTurnedOn__O7VABFZyA8PIDgrKEJ9aAKw(c, n);
		if (!T3_) goto LA4_;
		(*resOptions) = ((*resOptions) | op);
	}
	goto LA1_;
	LA4_: ;
	{
		(*resOptions) = ((*resOptions) & ~ op);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA, wordToCallConv__FoLOpmK9aKgNJHHWPzd6rrw)(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw sw) {
	tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA result;
	result = (tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA)0;
	result = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) ((NI)((NI)(((NI) 0) + sw) - ((NI) 138))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCallConv__0LSWh2UqkqDBtNGS0Kh9cNQ_10)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw sw;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T4_ = (T6_ == ((NI) 2));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
		LA7_: ;
		if (!T3_) goto LA8_;
		sw = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident);
		switch (sw) {
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 138) ... ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 148):
		{
			tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T11_;
			T11_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
			T11_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
			(*(*T11_)).defaultCC = wordToCallConv__FoLOpmK9aKgNJHHWPzd6rrw(sw);
		}
		break;
		default:
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_86), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_87, NIM_FALSE);
		}
		break;
		}
	}
	goto LA1_;
	LA8_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_86), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_88, NIM_FALSE);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, tryProcessOption__y4eNprw54h2RqpKXqw47Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA6_: ;
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42))) goto LA9_;
		processNote__0LSWh2UqkqDBtNGS0Kh9cNQ(c, n);
	}
	goto LA1_;
	LA9_: ;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA12_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA12_: ;
	{
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw sw;
		tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg opts;
		sw = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident);
		{
			if (!(sw == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 204))) goto LA17_;
			processExperimental__0LSWh2UqkqDBtNGS0Kh9cNQ_9(c, n);
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA17_: ;
		opts = pragmaToOptions__T015FMVm7Ly7T46PlmTKCQpragmas(sw);
		{
			if (!!((opts == 0))) goto LA21_;
			onOff__z5rO4uDEbwX8mhNS9cT9cWBQ(c, n, opts, resOptions);
		}
		goto LA19_;
		LA21_: ;
		{
			switch (sw) {
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 136):
			{
				processCallConv__0LSWh2UqkqDBtNGS0Kh9cNQ_10(c, n);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 112):
			{
				processDynLib__C3X1S7JVdavu4gb5a39adyw(c, n, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 169):
			{
				{
					if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA29_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
				}
				goto LA27_;
				LA29_: ;
				{
					NimStringDesc* T32_;
					T32_ = (NimStringDesc*)0;
					T32_ = nsuNormalize((*(*(*n)._kind_6.sons->data[((NI) 1)])._kind_5.ident).s);
					if (eqStrings(T32_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_89))) goto LA33_;
					if (eqStrings(T32_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_90))) goto LA34_;
					if (eqStrings(T32_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_91))) goto LA35_;
					goto LA36_;
					LA33_: ;
					{
						(*resOptions) |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31);
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31));
					}
					goto LA37_;
					LA34_: ;
					{
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31));
						(*resOptions) |= ((NU32)1)<<((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31);
					}
					goto LA37_;
					LA35_: ;
					{
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 15)) & 31));
						(*resOptions) &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 16)) & 31));
					}
					goto LA37_;
					LA36_: ;
					{
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_92), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_93, NIM_FALSE);
					}
					LA37_: ;
				}
				LA27_: ;
			}
			break;
			default:
			{
				result = NIM_FALSE;
			}
			break;
			}
		}
		LA19_: ;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processPush__tJumk6sIiZ2uaM1X2Ysp1A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI start) {
	tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* x;
	{
		if (!((*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*(*n)._kind_6.sons->data[(NI)(start - ((NI) 1))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA3_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_78), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_79, NIM_FALSE);
	}
	LA3_: ;
	x = pushOptionEntry__SQasfuhUR9aUpH0EyW9aFezg(c);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				{
					NIM_BOOL T10_;
					T10_ = (NIM_BOOL)0;
					T10_ = tryProcessOption__y4eNprw54h2RqpKXqw47Lw(c, (*n)._kind_6.sons->data[i], (&(*(*(*c).graph).config).options));
					if (!!(T10_)) goto LA11_;
					{
						if (!((*x).otherPragmas == 0)) goto LA15_;
						asgnRef((void**) (&(*x).otherPragmas), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90), (*n).info));
					}
					LA15_: ;
					add__P8dDSotTW25BkfbyspojGg((*x).otherPragmas, (*n)._kind_6.sons->data[i]);
				}
				LA11_: ;
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	{
		if (!!((((*(*c).optionStack->data[((NI) 0)]).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0))) goto LA19_;
		(*(*(*c).graph).config).options &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17)) & 31));
	}
	LA19_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processPop__0LSWh2UqkqDBtNGS0Kh9cNQ_11)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI T3_;
		T3_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
		if (!(T3_ <= ((NI) 1))) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_94), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_95, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		popOptionEntry__9aY89b9aR25iMJ8fPdM84CvQg(c);
	}
	LA1_: ;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processPragma__lMBKKtS58KCQFAjFX14tQA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* userPragma;
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T16_;
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T17_;
	it = (*n)._kind_6.sons->data[i];
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	goto LA1_;
	LA6_: ;
	{
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NI T11_;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T11_ = (NI)0;
		T11_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
		T10_ = !((T11_ == ((NI) 2)));
		if (T10_) goto LA12_;
		T10_ = !(((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)));
		LA12_: ;
		T9_ = T10_;
		if (T9_) goto LA13_;
		T9_ = !(((*(*it)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)));
		LA13_: ;
		if (!T9_) goto LA14_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	goto LA1_;
	LA14_: ;
	LA1_: ;
	userPragma = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18), (*(*it)._kind_6.sons->data[((NI) 1)])._kind_5.ident, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (*it).info, (*(*(*c).graph).config).options);
	T16_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem((NI)(i + ((NI) 1)), ((NI) 1));
	T17_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
	T17_ = X5BX5D___lNrbV6XRsw9boDXksMOKVag((*n)._kind_6.sons->data, ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0), T16_);
	asgnRef((void**) (&(*userPragma).ast), newTreeI__L1Xluv2iZ8cHbWec9bBiiaw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90), (*n).info, T17_->data, (T17_ ? T17_->Sup.len : 0)));
	strTableAdd__tyTgUybFIoow4CX2l5beug((&(*c).userPragmas), userPragma);
}
N_LIB_PRIVATE N_NIMCALL(void, processCodegenDecl__C3X1S7JVdavu4gb5a39adyw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	asgnRef((void**) (&(*sym).constraint), getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, n));
}
N_LIB_PRIVATE N_NIMCALL(void, processOption__557NRVJHpXqxWeukDYchKw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg* resOptions) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = tryProcessOption__y4eNprw54h2RqpKXqw47Lw(c, n, resOptions);
		if (!!(T3_)) goto LA4_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_96), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_97, NIM_FALSE);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, semAsmOrEmit__7on6juYQ5yDeHojpmzlBFg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* con, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_CHAR marker) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw T2_;
		NimStringDesc* str;
		NI a;
		T2_ = (tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw)0;
		{
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89))) goto LA5_;
			T2_ = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89);
		}
		goto LA3_;
		LA5_: ;
		{
			T2_ = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152);
		}
		LA3_: ;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(T2_, (*n).info);
		str = copyString((*(*n)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
		{
			if (!((str ? str->Sup.len : 0) == 0)) goto LA10_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*con).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_99), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_100, NIM_FALSE);
			goto BeforeRet_;
		}
		LA10_: ;
		a = ((NI) 0);
		{
			while (1) {
				NI b;
				NimStringDesc* sub;
				NI c;
				b = nsuFindChar(str, marker, ((NI) (a)), ((NI) 0));
				{
					if (!(b < ((NI) 0))) goto LA16_;
					sub = substr__iGg0RIKceRvsmvq8FUHOEw(str, a);
				}
				goto LA14_;
				LA16_: ;
				{
					sub = substr__2yh9cer0ymNRHlOOg8P7IuA(str, a, (NI)(b - ((NI) 1)));
				}
				LA14_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T23_;
					if (!!(((sub ? sub->Sup.len : 0) == 0))) goto LA21_;
					T23_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T23_ = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), sub);
					add__P8dDSotTW25BkfbyspojGg(result, T23_);
				}
				LA21_: ;
				{
					if (!(b < ((NI) 0))) goto LA26_;
					goto LA12;
				}
				LA26_: ;
				c = nsuFindChar(str, marker, ((NI) ((NI)(b + ((NI) 1)))), ((NI) 0));
				{
					if (!(c < ((NI) 0))) goto LA30_;
					sub = substr__iGg0RIKceRvsmvq8FUHOEw(str, (NI)(b + ((NI) 1)));
				}
				goto LA28_;
				LA30_: ;
				{
					sub = substr__2yh9cer0ymNRHlOOg8P7IuA(str, (NI)(b + ((NI) 1)), (NI)(c - ((NI) 1)));
				}
				LA28_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* e;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T37_;
					if (!!(((sub ? sub->Sup.len : 0) == 0))) goto LA35_;
					T37_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
					T37_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*con).cache, sub);
					e = searchInScopes__Drn1sJCJSwUUo03qKJigUw(con, T37_);
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
						if (!!((e == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA40_;
						(*e).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
						T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T42_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(e);
						add__P8dDSotTW25BkfbyspojGg(result, T42_);
					}
					goto LA38_;
					LA40_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
						T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T44_ = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), sub);
						add__P8dDSotTW25BkfbyspojGg(result, T44_);
					}
					LA38_: ;
				}
				goto LA33_;
				LA35_: ;
				{
					NimStringDesc* T46_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T47_;
					T46_ = (NimStringDesc*)0;
					T46_ = nimCharToStr(marker);
					T47_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T47_ = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), T46_);
					add__P8dDSotTW25BkfbyspojGg(result, T47_);
				}
				LA33_: ;
				{
					if (!(c < ((NI) 0))) goto LA50_;
					goto LA12;
				}
				LA50_: ;
				a = (NI)(c + ((NI) 1));
			}
		} LA12: ;
	}
	break;
	default:
	{
		illFormedAstLocal__aOnJJ9cXkOooTyUuLmnc09bw_2(n, (*(*con).graph).config);
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89), (*n).info);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEmit__0LSWh2UqkqDBtNGS0Kh9cNQ_12)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_98, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n1;
		n1 = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
			NI T13_;
			if (!((*n1).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41))) goto LA11_;
			T13_ = (NI)0;
			T13_ = len__P89cqdlERShb9alU3iC0yj8wast(n1);
			b = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*n1).info, T13_);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n1);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						asgnRef((void**) (&(*b)._kind_6.sons->data[i]), (*c).semExpr(c, (*n1)._kind_6.sons->data[i], 0));
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), b);
		}
		goto LA9_;
		LA11_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, n1));
			switch ((*(*n)._kind_6.sons->data[((NI) 1)]).kind) {
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
			case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
			{
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), semAsmOrEmit__7on6juYQ5yDeHojpmzlBFg(c, n, 96));
			}
			break;
			default:
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_101, NIM_FALSE);
			}
			break;
			}
		}
		LA9_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaUnroll__0LSWh2UqkqDBtNGS0Kh9cNQ_13)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		if (!((*(*c).p).nestedLoopCounter <= ((NI) 0))) goto LA3_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NI T8_;
		NI unrollFactor;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T6_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T6_ = (T8_ == ((NI) 2));
		LA7_: ;
		if (!T6_) goto LA9_;
		unrollFactor = expectIntLit__GehhaBQhWjS36aXBX9cGo4g(c, n);
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem(unrollFactor, ((NI) 32));
			if (!T13_) goto LA14_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (unrollFactor))));
		}
		goto LA11_;
		LA14_: ;
		{
			invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, n);
		}
		LA11_: ;
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLine__0LSWh2UqkqDBtNGS0Kh9cNQ_14)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = (T5_ == ((NI) 2));
		LA4_: ;
		if (!T3_) goto LA6_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semConstExpr(c, (*n)._kind_6.sons->data[((NI) 1)]));
		a = (*n)._kind_6.sons->data[((NI) 1)];
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y;
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA10_;
			x = (*a)._kind_6.sons->data[((NI) 0)];
			y = (*a)._kind_6.sons->data[((NI) 1)];
			{
				if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA14_;
				x = (*x)._kind_6.sons->data[((NI) 1)];
			}
			LA14_: ;
			{
				if (!((*y).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA18_;
				y = (*y)._kind_6.sons->data[((NI) 1)];
			}
			LA18_: ;
			{
				if (!!(((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20)))) goto LA22_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_104, NIM_FALSE);
			}
			goto LA20_;
			LA22_: ;
			{
				if (!!(((*y).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6)))) goto LA25_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_30), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_105, NIM_FALSE);
			}
			goto LA20_;
			LA25_: ;
			{
				(*n).info.fileIndex = fileInfoIdx__3HRSVgYDcnQTolSZGx1zjA((*(*c).graph).config, (*x)._kind_3.strVal);
				(*n).info.line = ((NU16) ((*y)._kind_1.intVal));
			}
			LA20_: ;
		}
		goto LA8_;
		LA10_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_106), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_107, NIM_FALSE);
		}
		LA8_: ;
	}
	goto LA1_;
	LA6_: ;
	{
		(*n).info = getInfoContext__TXxF2CG3kwLqptPWf0kC9aQ((*(*c).graph).config, ((NI) -1));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaLockStmt__hUQzMUBJmHVdQ9cj81jo89cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
		n = (*it)._kind_6.sons->data[((NI) 1)];
		{
			if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA11_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_108), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_109, NIM_FALSE);
		}
		goto LA9_;
		LA11_: ;
		{
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), (*c).semExpr(c, (*n)._kind_6.sons->data[i], 0));
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		LA9_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, pragmaLocks__AMYzMg6pmHjlh0azeAYr7Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it) {
	NI16 result;
	result = (NI16)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
	}
	goto LA1_;
	LA6_: ;
	{
		switch ((*(*it)._kind_6.sons->data[((NI) 1)]).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 21):
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
		{
			{
				if (!eqStrings((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_110))) goto LA12_;
				result = ((NI16) 1001);
			}
			goto LA10_;
			LA12_: ;
			{
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*it)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_111), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_112, NIM_FALSE);
			}
			LA10_: ;
		}
		break;
		default:
		{
			NI x;
			x = expectIntLit__GehhaBQhWjS36aXBX9cGo4g(c, it);
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = (x < ((NI) 0));
				if (T18_) goto LA19_;
				T18_ = (((NI) 1000) < x);
				LA19_: ;
				if (!T18_) goto LA20_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*it)._kind_6.sons->data[((NI) 1)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_113), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_114, NIM_FALSE);
			}
			goto LA16_;
			LA20_: ;
			{
				result = ((NI16) (x));
			}
			LA16_: ;
		}
		break;
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pragmaGuard__yHVOFpP1CkeW6rPusEqxjg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
		goto BeforeRet_;
	}
	LA6_: ;
	n = (*it)._kind_6.sons->data[((NI) 1)];
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA10_;
		result = (*n)._kind_4.sym;
	}
	goto LA8_;
	LA10_: ;
	{
		if (!(kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))) goto LA13_;
		result = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, 0);
		{
			NIM_BOOL T17_;
			NIM_BOOL T18_;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T23_;
			T17_ = (NIM_BOOL)0;
			T18_ = (NIM_BOOL)0;
			T18_ = (result == 0);
			if (T18_) goto LA19_;
			T18_ = !(((768 &((NU32)1<<((NU)((*result).kind)&31U)))!=0));
			LA19_: ;
			T17_ = T18_;
			if (T17_) goto LA20_;
			T17_ = !((((*result).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
			LA20_: ;
			if (!T17_) goto LA21_;
			T23_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T23_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, n, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 0), T23_, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), (*n).info, (*(*(*c).graph).config).options);
		}
		LA21_: ;
	}
	goto LA8_;
	LA13_: ;
	{
		result = qualifiedLookUp__WrQDIfycs0nL9b0mMXbSC9ag(c, n, 2);
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaProposition__0LSWh2UqkqDBtNGS0Kh9cNQ_15)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_127), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_128, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0));
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaEnsures__0LSWh2UqkqDBtNGS0Kh9cNQ_16)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
		if (T3_) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T3_ = !((T5_ == ((NI) 2)));
		LA4_: ;
		if (!T3_) goto LA6_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_127), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_129, NIM_FALSE);
	}
	goto LA1_;
	LA6_: ;
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T9_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* o;
		T9_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		T9_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
		o = getCurrOwner__ETdcFH1xSyhy8lRl3iwf6w(c);
		{
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T18_;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T13_ = ((520192 &((NU32)1<<((NU)((*o).kind)&31U)))!=0);
			if (!(T13_)) goto LA14_;
			T13_ = !(((*o).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA14_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA15_;
			T12_ = !(((*(*o).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA15_: ;
			if (!T12_) goto LA16_;
			T18_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T18_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_130));
			s = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11), T18_, o, (*n).info, 0);
			asgnRef((void**) (&(*s).typ), (*(*o).typ).sons->data[((NI) 0)]);
			(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
			addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, s);
		}
		LA16_: ;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*c).semExpr(c, (*n)._kind_6.sons->data[((NI) 1)], 0));
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, illegalCustomPragma__ISl2Z9aoSIz8Q3Jlw20Fjuw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NimStringDesc* T1_;
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 35);
appendString(T1_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_131));
appendString(T1_, (*(*s).name).s);
appendString(T1_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_132));
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T1_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_133, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, singlePragma__KQ6mgDJAAhGjX4CT62UFwg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI* i, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL comesFromPush, NIM_BOOL isStatement) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* userPragma;
{	result = (NIM_BOOL)0;
	it = (*n)._kind_6.sons->data[(*i)];
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		key = (*it)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA6_: ;
	{
		key = it;
	}
	LA1_: ;
	{
		if (!((*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42))) goto LA11_;
		processNote__0LSWh2UqkqDBtNGS0Kh9cNQ(c, it);
		goto BeforeRet_;
	}
	goto LA9_;
	LA11_: ;
	{
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T23_;
		if (!((*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61))) goto LA14_;
		{
			if (!comesFromPush) goto LA18_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_5), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_6, NIM_FALSE);
		}
		goto LA16_;
		LA18_: ;
		{
			if (!!(isStatement)) goto LA21_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_7), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_8, NIM_FALSE);
		}
		goto LA16_;
		LA21_: ;
		LA16_: ;
		T23_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
		T23_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw((*key)._kind_6.sons->data[((NI) 1)]);
		switch (T23_) {
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170):
		case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175):
		{
			pragmaRaisesOrTags__0LSWh2UqkqDBtNGS0Kh9cNQ_3(c, (*key)._kind_6.sons->data[((NI) 1)]);
		}
		break;
		default:
		{
		}
		break;
		}
		goto BeforeRet_;
	}
	goto LA9_;
	LA14_: ;
	{
		if (!!(((*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53) || (*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56)))) goto LA27_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[(*i)]), semCustomPragma__wiyGBj4PmPVNmjmIuvK9cHQ(c, it));
		goto BeforeRet_;
	}
	goto LA9_;
	LA27_: ;
	LA9_: ;
	ident = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, key, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	userPragma = strTableGet__2ZDXFT8aKmu3vdgfJFQCgQ((*c).userPragmas, ident);
	{
		tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T42_;
		NI T43_;
		if (!!((userPragma == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA31_;
		{
			if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA35_;
			styleCheckUse__k3cqh606mJPYNzLXdtZjIg((*(*c).graph).config, (*key).info, userPragma);
		}
		LA35_: ;
		(*c).instCounter += ((NI) 1);
		{
			NimStringDesc* T41_;
			if (!(((NI) 100) < (*c).instCounter)) goto LA39_;
			T41_ = (NimStringDesc*)0;
			T41_ = rawNewString(((*(*userPragma).name).s ? (*(*userPragma).name).s->Sup.len : 0) + 22);
appendString(T41_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_12));
appendString(T41_, (*(*userPragma).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T41_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__tPA3StZ6VsKyoznyrIfFxg_13, NIM_FALSE);
		}
		LA39_: ;
		pragma__m5gdSrENJIwAi9aMdDiUT9bg(c, sym, (*userPragma).ast, validPragmas, isStatement);
		T42_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem((*i), (*i));
		X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*n)._kind_6.sons), T42_, (*(*userPragma).ast)._kind_6.sons->data, ((*(*userPragma).ast)._kind_6.sons ? (*(*userPragma).ast)._kind_6.sons->Sup.len : 0));
		T43_ = (NI)0;
		T43_ = len__P89cqdlERShb9alU3iC0yj8wast((*userPragma).ast);
		(*i) += (NI)(T43_ - ((NI) 1));
		(*c).instCounter -= ((NI) 1);
	}
	goto LA29_;
	LA31_: ;
	{
		tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw k;
		k = whichKeyword__sZUQNPhNGEM8MllfcWvRiw(ident);
		{
			if (!((validPragmas[(NU)(k)>>3] &(1U<<((NU)(k)&7U)))!=0)) goto LA47_;
			{
				if (!!(((49152 & (*(*(*c).graph).config).globalOptions) == 0))) goto LA51_;
				checkPragmaUse__no49bEWZLCgyYgYqiaocHSg((*(*c).graph).config, (*key).info, k, (*ident).s);
			}
			LA51_: ;
			switch (k) {
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 95):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 96):
			{
				NimStringDesc* T54_;
				T54_ = (NimStringDesc*)0;
				T54_ = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				makeExternExport__k09cbJuHCFNqocyycgSiPqw(c, sym, T54_, (*it).info);
				{
					if (!(k == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 96))) goto LA57_;
					{
						NimStringDesc* T63_;
						if (!!(((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2)))) goto LA61_;
						T63_ = (NimStringDesc*)0;
						T63_ = rawNewString((reprEnum((NI)(*(*(*c).graph).config).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_)) ? reprEnum((NI)(*(*(*c).graph).config).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_))->Sup.len : 0) + 38);
appendString(T63_, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_22));
appendString(T63_, reprEnum((NI)(*(*(*c).graph).config).backend, (&NTI__4OBsgZ9cscH2JLUE5Wcz01g_)));
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T63_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_23, NIM_FALSE);
					}
					goto LA59_;
					LA61_: ;
					{
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 8)) & 63);
					}
					LA59_: ;
				}
				LA57_: ;
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 93):
			{
				NimStringDesc* name;
				tyArray__Re75IspeoxXy2oCZHwcRrA T66_;
				name = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ((*(*c).graph).config, name);
				nimZeroMem((void*)T66_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T66_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_24));
				T66_[1] = copyString(name);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T66_, 2);
				makeExternImport__k09cbJuHCFNqocyycgSiPqw_3(c, sym, name, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 92):
			{
				NimStringDesc* name_2;
				tyArray__Re75IspeoxXy2oCZHwcRrA T68_;
				name_2 = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ((*(*c).graph).config, name_2);
				nimZeroMem((void*)T68_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T68_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_24));
				T68_[1] = copyString(name_2);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T68_, 2);
				processImportCompilerProc__k09cbJuHCFNqocyycgSiPqw_4(c, sym, name_2, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 234):
			{
				NimStringDesc* T70_;
				T70_ = (NimStringDesc*)0;
				T70_ = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, sym, T70_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 208):
			{
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18))) goto LA74_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11)) & 63);
				}
				goto LA72_;
				LA74_: ;
				{
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				LA72_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 90):
			{
				NimStringDesc* T78_;
				T78_ = (NimStringDesc*)0;
				T78_ = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				processImportCpp__k09cbJuHCFNqocyycgSiPqw_5(c, sym, T78_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 94):
			{
				NimStringDesc* name_3;
				{
					if (!!(((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3)))) goto LA82_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_25), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_26, NIM_FALSE);
				}
				LA82_: ;
				name_3 = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31)) & 63);
				{
					NIM_BOOL T86_;
					NIM_BOOL T88_;
					T86_ = (NIM_BOOL)0;
					T86_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
					if (!(T86_)) goto LA87_;
					T88_ = (NIM_BOOL)0;
					T88_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ(name_3, TM__tPA3StZ6VsKyoznyrIfFxg_27);
					T86_ = !(T88_);
					LA87_: ;
					if (!T86_) goto LA89_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_28), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_29, NIM_FALSE);
				}
				LA89_: ;
				setExternName__k09cbJuHCFNqocyycgSiPqw_2(c, sym, name_3, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 91):
			{
				NimStringDesc* T92_;
				T92_ = (NimStringDesc*)0;
				T92_ = getOptionalStr__i2CEDMKXy3Z2RzJtAqKq0g(c, it, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_14));
				processImportObjC__k09cbJuHCFNqocyycgSiPqw_6(c, sym, T92_, (*it).info);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 173):
			{
				NI size;
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA96_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				LA96_: ;
				size = expectIntLit__GehhaBQhWjS36aXBX9cGo4g(c, it);
				switch (size) {
				case ((NI) 1):
				case ((NI) 2):
				case ((NI) 4):
				{
					(*(*sym).typ).size = ((NI64) (size));
					(*(*sym).typ).align = ((NI16) (size));
				}
				break;
				case ((NI) 8):
				{
					(*(*sym).typ).size = IL64(8);
					(*(*sym).typ).align = floatInt64Align__Nm9cs6Kn6ltGLynV4vNsRgw((*(*c).graph).config);
				}
				break;
				default:
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_33), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_34, NIM_FALSE);
				}
				break;
				}
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 101):
			{
				NI alignment;
				alignment = expectIntLit__GehhaBQhWjS36aXBX9cGo4g(c, it);
				{
					NIM_BOOL T104_;
					T104_ = (NIM_BOOL)0;
					T104_ = isPowerOfTwo__1xdTQapFveM9bImKot7h9cdw(alignment);
					if (!(T104_)) goto LA105_;
					T104_ = (((NI) 0) < alignment);
					LA105_: ;
					if (!T104_) goto LA106_;
					(*sym)._kind_4.alignment = (((*sym)._kind_4.alignment >= alignment) ? (*sym)._kind_4.alignment : alignment);
				}
				goto LA102_;
				LA106_: ;
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_35), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_36, NIM_FALSE);
				}
				LA102_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 102):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3)) & 15);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 103):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 212):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA113_;
					{
						NIM_BOOL T117_;
						T117_ = (NIM_BOOL)0;
						T117_ = (k == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 103));
						if (!(T117_)) goto LA118_;
						T117_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
						LA118_: ;
						if (!T117_) goto LA119_;
						invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
					}
					goto LA115_;
					LA119_: ;
					{
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11)) & 63);
					}
					LA115_: ;
				}
				LA113_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 269):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 9)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 83):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 40)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 248):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 84):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 45)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 210):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags = ((*sym).flags | 67108872);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 181):
			{
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 184):
			{
				pragmaNoForward__ePldymDitzRJBrQOoUllvA(c, it, ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10));
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 185):
			{
				pragmaNoForward__ePldymDitzRJBrQOoUllvA(c, it, ((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4));
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 74):
			{
				processMagic__ISl2Z9aoSIz8Q3Jlw20Fjuw(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 189):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!comesFromPush) goto LA134_;
					{
						if (!((12288 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA138_;
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27)) & 63);
					}
					LA138_: ;
				}
				goto LA132_;
				LA134_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27)) & 63);
				}
				LA132_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 214):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 110):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 86):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 28)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 105):
			{
				tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T145_;
				T145_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T145_ = getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, it);
				lib = getLib__Nj24SwOhKqYFNJIoNsGSTA(c, ((tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ) 0), T145_);
				addToLib__xoFj1Tk9cDOsrW8yALZcxCA(lib, sym);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6)) & 63);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 6)) & 15);
				(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3)) & 15);
				{
					if (!((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA148_;
					asgnRef((void**) (&(*sym).loc.r), rope__yShmEg9cffWxI7s5XzEKBow((*(*sym).name).s));
				}
				LA148_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 106):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA153_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 12)) & 63);
					{
						if (!!(((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA157_;
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1)) & 63);
					}
					LA157_: ;
				}
				LA153_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 104):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 13)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 108):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!(((*(*(*c).graph).config).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 4)))) goto LA163_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 16)) & 63);
				}
				LA163_: ;
				{
					if (!!(((*(*sym).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA167_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*(*(*sym).ast)._kind_6.sons->data[((NI) 3)])._kind_6.sons->data[((NI) 0)]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_46), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_47, NIM_FALSE);
				}
				LA167_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 187):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 38)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 109):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 5)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 112):
			{
				processDynLib__C3X1S7JVdavu4gb5a39adyw(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 113):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 114):
			{
				tyArray__Re75IspeoxXy2oCZHwcRrA T173_;
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				cppDefine__3wmoYTSOyQ3GsJJ4H7J3lQ((*(*c).graph).config, (*(*sym).name).s);
				nimZeroMem((void*)T173_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T173_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_24));
				T173_[1] = copyString((*(*sym).name).s);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T173_, 2);
				{
					if (!!((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0))) goto LA176_;
					markCompilerProc__lRfMX9cOvnV9cCzAmWFEHWsA(c, sym);
				}
				LA176_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 161):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 37)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 115):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 19)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 220):
			{
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 23)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 134):
			{
				{
					NIM_BOOL T184_;
					T184_ = (NIM_BOOL)0;
					T184_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T184_)) goto LA185_;
					T184_ = ((521088 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
					LA185_: ;
					if (!T184_) goto LA186_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T192_;
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA190_;
						T192_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T192_ = getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, it);
						(void)(T192_);
					}
					LA190_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22)) & 63);
				}
				goto LA182_;
				LA186_: ;
				{
					NIM_BOOL T194_;
					T194_ = (NIM_BOOL)0;
					T194_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T194_)) goto LA195_;
					T194_ = !(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
					LA195_: ;
					if (!T194_) goto LA196_;
					{
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA200_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_51), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_52, NIM_FALSE);
					}
					LA200_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22)) & 63);
				}
				goto LA182_;
				LA196_: ;
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA203_;
					deprecatedStmt__6xKxol9c17ygvuKxKHe5vyg(c, it);
				}
				goto LA182_;
				LA203_: ;
				{
					(*(*c).module).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22)) & 63);
				}
				LA182_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 135):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA209_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA207_;
				LA209_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0)) & 63);
				}
				LA207_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 194):
			{
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7))) goto LA215_;
					typeBorrow__D9cCpOUBRV9c9af06eLYGN2uA(c, sym, it);
				}
				goto LA213_;
				LA215_: ;
				{
					noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30)) & 63);
				}
				LA213_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 76):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA221_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA219_;
				LA221_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2)) & 63);
				}
				LA219_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 209):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					NIM_BOOL T227_;
					T227_ = (NIM_BOOL)0;
					T227_ = ((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					if (T227_) goto LA228_;
					T227_ = (((*(*sym).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0);
					LA228_: ;
					if (!T227_) goto LA229_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA225_;
				LA229_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3)) & 63);
				}
				LA225_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 183):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA235_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA233_;
				LA235_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63);
				}
				LA233_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 198):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA241_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA239_;
				LA241_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 39)) & 63);
				}
				LA239_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 199):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA247_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA245_;
				LA247_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 6)) & 63);
				}
				LA245_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 75):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26)) & 63);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 19)) & 63);
				{
					if (!!(((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA253_;
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7)) & 63);
					{
						if (!((*(*sym).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA257_;
						(*(*sym).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0);
					}
					LA257_: ;
				}
				LA253_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 107):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA262_;
					{
						if (!!(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)))) goto LA266_;
						(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 26)) & 63);
					}
					LA266_: ;
					{
						if (!!(((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA270_;
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7)) & 63);
					}
					goto LA268_;
					LA270_: ;
					{
						invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
					}
					LA268_: ;
				}
				goto LA260_;
				LA262_: ;
				{
				}
				LA260_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 265):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA277_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA275_;
				LA277_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 23)) & 63);
				}
				LA275_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 121):
			{
				NimStringDesc* s;
				tyArray__Re75IspeoxXy2oCZHwcRrA T281_;
				s = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				nimZeroMem((void*)T281_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T281_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_61));
				T281_[1] = copyString(s);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T281_, 2);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 80), s, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_62, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 120):
			{
				NimStringDesc* s_2;
				tyArray__Re75IspeoxXy2oCZHwcRrA T283_;
				s_2 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				nimZeroMem((void*)T283_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T283_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_63));
				T283_[1] = copyString(s_2);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T283_, 2);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 51), s_2, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_64, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 119):
			{
				{
					NIM_BOOL T287_;
					NIM_BOOL T288_;
					NIM_BOOL T290_;
					T287_ = (NIM_BOOL)0;
					T288_ = (NIM_BOOL)0;
					T288_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T288_)) goto LA289_;
					T290_ = (NIM_BOOL)0;
					T290_ = isRoutine__Ye2MiAptq3GrXxTQeyXNeAast(sym);
					if (T290_) goto LA291_;
					T290_ = ((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
					LA291_: ;
					T288_ = T290_;
					LA289_: ;
					T287_ = T288_;
					if (!(T287_)) goto LA292_;
					T287_ = !(isStatement);
					LA292_: ;
					if (!T287_) goto LA293_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T299_;
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28))) goto LA297_;
						T299_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T299_ = getStrLitNode__wiyGBj4PmPVNmjmIuvK9cHQ_2(c, it);
						(void)(T299_);
					}
					LA297_: ;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24)) & 63);
					(*sym).flags &= ~(((NU64)1) << ((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4)) & 63));
				}
				goto LA285_;
				LA293_: ;
				{
					NimStringDesc* s_3;
					tyArray__Re75IspeoxXy2oCZHwcRrA T301_;
					s_3 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
					nimZeroMem((void*)T301_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
					T301_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_65));
					T301_[1] = copyString(s_3);
					recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T301_, 2);
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 11), s_3, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_66, NIM_FALSE);
				}
				LA285_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 118):
			{
				NimStringDesc* T303_;
				(*(*(*c).graph).config).m.errorOutputs = 3;
				T303_ = (NimStringDesc*)0;
				T303_ = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 11), T303_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__tPA3StZ6VsKyoznyrIfFxg_67, NIM_FALSE);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 126):
			{
				processDefine__0LSWh2UqkqDBtNGS0Kh9cNQ_5(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 127):
			{
				processUndef__0LSWh2UqkqDBtNGS0Kh9cNQ_6(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 132):
			{
				processCompile__0LSWh2UqkqDBtNGS0Kh9cNQ_7(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 131):
			{
				processLink__0LSWh2UqkqDBtNGS0Kh9cNQ_8(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 192):
			{
				NimStringDesc* s_4;
				tyArray__Re75IspeoxXy2oCZHwcRrA T309_;
				s_4 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				addLinkOption__siPDo9a2eQzwubdmcIGchWg_3((*(*c).graph).config, s_4);
				nimZeroMem((void*)T309_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T309_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_75));
				T309_[1] = copyString(s_4);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T309_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 191):
			{
				NimStringDesc* s_5;
				tyArray__Re75IspeoxXy2oCZHwcRrA T311_;
				s_5 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				addCompileOption__siPDo9a2eQzwubdmcIGchWg_4((*(*c).graph).config, s_5);
				nimZeroMem((void*)T311_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T311_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_76));
				T311_[1] = copyString(s_5);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T311_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 193):
			{
				NimStringDesc* s_6;
				NimStringDesc* T313_;
				tyArray__Re75IspeoxXy2oCZHwcRrA T314_;
				s_6 = expectStrLit__iTLkBylaQ5j0DcqGsSoybQ(c, it);
				T313_ = (NimStringDesc*)0;
				T313_ = toFullPathConsiderDirty__fr10i3QiqDDNG5EqWBCesA((*(*c).graph).config, (*sym).info.fileIndex);
				addLocalCompileOption__9aZ1lkFxjUUC2WDEd4sU9ckQ((*(*c).graph).config, s_6, T313_);
				nimZeroMem((void*)T314_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
				T314_[0] = copyString(((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_77));
				T314_[1] = copyString(s_6);
				recordPragma__Q09bd79bkpFX5inwl8cmQvPw(c, it, T314_, 2);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 124):
			{
				processPush__tJumk6sIiZ2uaM1X2Ysp1A(c, n, (NI)((*i) + ((NI) 1)));
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 125):
			{
				processPop__0LSWh2UqkqDBtNGS0Kh9cNQ_11(c, it);
				result = NIM_TRUE;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 188):
			{
				{
					NIM_BOOL T320_;
					T320_ = (NIM_BOOL)0;
					T320_ = !((sym == 0));
					if (!(T320_)) goto LA321_;
					T320_ = ((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18));
					LA321_: ;
					if (!T320_) goto LA322_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 10)) & 63);
				}
				goto LA318_;
				LA322_: ;
				{
					processPragma__lMBKKtS58KCQFAjFX14tQA(c, n, (*i));
					result = NIM_TRUE;
				}
				LA318_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 195):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA328_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33)) & 63);
				}
				LA328_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 190):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA333_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14)) & 63);
				}
				LA333_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 215):
			{
				processCodegenDecl__C3X1S7JVdavu4gb5a39adyw_2(c, it, sym);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 151):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 79):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 196):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 152):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 153):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 154):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 155):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 163):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 167):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 168):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 128):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 169):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 160):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 159):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 136):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 137):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 77):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 156):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 157):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 158):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 164):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 165):
			{
				processOption__557NRVJHpXqxWeukDYchKw(c, it, (&(*(*(*c).graph).config).options));
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 129):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 130):
			{
				{
					if (!((86016 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0)) goto LA340_;
					processOption__557NRVJHpXqxWeukDYchKw(c, it, (&(*sym).options));
				}
				goto LA338_;
				LA340_: ;
				{
					processOption__557NRVJHpXqxWeukDYchKw(c, it, (&(*(*(*c).graph).config).options));
				}
				LA338_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 138) ... ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 148):
			{
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA346_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA344_;
				LA346_: ;
				{
					(*(*sym).typ).callConv = wordToCallConv__FoLOpmK9aKgNJHHWPzd6rrw(k);
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 42)) & 63);
				}
				LA344_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 211):
			{
				pragmaEmit__0LSWh2UqkqDBtNGS0Kh9cNQ_12(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 200):
			{
				pragmaUnroll__0LSWh2UqkqDBtNGS0Kh9cNQ_13(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 201):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 202):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 174):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 98):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA356_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA354_;
				LA356_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 40)) & 63);
				}
				LA354_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 99):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA362_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA360_;
				LA362_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 41)) & 63);
				}
				LA360_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 216):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					NIM_BOOL T368_;
					T368_ = (NIM_BOOL)0;
					T368_ = ((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					if (T368_) goto LA369_;
					T368_ = !(((IL64(562949953486848) &((NU64)1<<((NU)((*(*sym).typ).kind)&63U)))!=0));
					LA369_: ;
					if (!T368_) goto LA370_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA366_;
				LA370_: ;
				{
					(*(*sym).typ).kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49);
				}
				LA366_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 264):
			{
				{
					if (!((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3))) goto LA376_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_102), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_103, NIM_FALSE);
				}
				goto LA374_;
				LA376_: ;
				{
					noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
					{
						if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA381_;
						invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
					}
					goto LA379_;
					LA381_: ;
					{
						(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1)) & 63);
					}
					LA379_: ;
				}
				LA374_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 100):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19))) goto LA387_;
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 21)) & 63);
				}
				goto LA385_;
				LA387_: ;
				{
					if (!!(((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA390_;
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 19)) & 63);
				}
				goto LA385_;
				LA390_: ;
				{
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				LA385_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 286):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					NIM_BOOL T396_;
					T396_ = (NIM_BOOL)0;
					T396_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T396_) goto LA397_;
					T396_ = ((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					LA397_: ;
					if (!T396_) goto LA398_;
					processOption__557NRVJHpXqxWeukDYchKw(c, it, (&(*(*(*c).graph).config).options));
				}
				goto LA394_;
				LA398_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 14)) & 63);
				}
				LA394_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 285):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					NIM_BOOL T404_;
					T404_ = (NIM_BOOL)0;
					T404_ = !(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)));
					if (T404_) goto LA405_;
					T404_ = ((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					LA405_: ;
					if (!T404_) goto LA406_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA402_;
				LA406_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 13)) & 63);
				}
				LA402_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 219):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					NIM_BOOL T412_;
					T412_ = (NIM_BOOL)0;
					T412_ = !(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7)));
					if (T412_) goto LA413_;
					T412_ = ((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
					LA413_: ;
					if (!T412_) goto LA414_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA410_;
				LA414_: ;
				{
					(*(*sym).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 16)) & 63);
				}
				LA410_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 207):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 206):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!(sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA420_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				LA420_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 123):
			{
				pragmaLine__0LSWh2UqkqDBtNGS0Kh9cNQ_14(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 170):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 175):
			{
				pragmaRaisesOrTags__0LSWh2UqkqDBtNGS0Kh9cNQ_3(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 218):
			{
				{
					if (!(sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA427_;
					pragmaLockStmt__hUQzMUBJmHVdQ9cj81jo89cA(c, it);
				}
				goto LA425_;
				LA427_: ;
				{
					if (!((*sym).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA430_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA425_;
				LA430_: ;
				{
					(*(*sym).typ).lockLevel = pragmaLocks__AMYzMg6pmHjlh0azeAYr7Q(c, it);
				}
				LA425_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 288):
			{
				{
					NIM_BOOL T436_;
					T436_ = (NIM_BOOL)0;
					T436_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T436_) goto LA437_;
					T436_ = !(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19)));
					LA437_: ;
					if (!T436_) goto LA438_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA434_;
				LA438_: ;
				{
					(*sym)._kind_4.bitsize = expectIntLit__GehhaBQhWjS36aXBX9cGo4g(c, it);
					{
						if (!((*sym)._kind_4.bitsize <= ((NI) 0))) goto LA443_;
						liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_115), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_116, NIM_FALSE);
					}
					LA443_: ;
				}
				LA434_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 217):
			{
				{
					NIM_BOOL T448_;
					T448_ = (NIM_BOOL)0;
					T448_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T448_) goto LA449_;
					T448_ = !(((525056 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0));
					LA449_: ;
					if (!T448_) goto LA450_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA446_;
				LA450_: ;
				{
					asgnRef((void**) (&(*sym)._kind_4.guard), pragmaGuard__yHVOFpP1CkeW6rPusEqxjg(c, it, (*sym).kind));
				}
				LA446_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 238):
			{
				{
					NIM_BOOL T456_;
					T456_ = (NIM_BOOL)0;
					T456_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
					if (T456_) goto LA457_;
					T456_ = !(((768 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0));
					LA457_: ;
					if (!T456_) goto LA458_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA454_;
				LA458_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 34)) & 63);
				}
				LA454_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 97):
			{
				{
					if (!(sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA464_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA462_;
				LA464_: ;
				{
					registerNimScriptSymbol__9cLrw2jAkfW3f8XFlNBee8g_2((*c).graph, sym);
				}
				LA462_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 203):
			{
				{
					NIM_BOOL T470_;
					NI T472_;
					T470_ = (NIM_BOOL)0;
					T470_ = !(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28)));
					if (T470_) goto LA471_;
					T472_ = (NI)0;
					T472_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T470_ = !((T472_ == ((NI) 2)));
					LA471_: ;
					if (!T470_) goto LA473_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_117), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_118, NIM_FALSE);
				}
				goto LA468_;
				LA473_: ;
				{
					asgnRef((void**) (&(*it)._kind_6.sons->data[((NI) 1)]), (*c).semExpr(c, (*it)._kind_6.sons->data[((NI) 1)], 0));
				}
				LA468_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 204):
			{
				{
					NIM_BOOL T479_;
					T479_ = (NIM_BOOL)0;
					T479_ = isTopLevel__9cOn2KgYDErIsBqHhwhr9b4Qsemdata(c);
					if (!!(T479_)) goto LA480_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_119), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_120, NIM_FALSE);
				}
				LA480_: ;
				processExperimental__0LSWh2UqkqDBtNGS0Kh9cNQ_9(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 257):
			{
				{
					NIM_BOOL T485_;
					NI T487_;
					T485_ = (NIM_BOOL)0;
					T485_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
					if (!(T485_)) goto LA486_;
					T487_ = (NI)0;
					T487_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T485_ = (T487_ == ((NI) 2));
					LA486_: ;
					if (!T485_) goto LA488_;
					asgnRef((void**) (&(*c).selfName), considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*it)._kind_6.sons->data[((NI) 1)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_121), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_122, NIM_FALSE);
				}
				goto LA483_;
				LA488_: ;
				{
					NIM_BOOL T491_;
					NI T493_;
					T491_ = (NIM_BOOL)0;
					T491_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
					if (T491_) goto LA492_;
					T493_ = (NI)0;
					T493_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					T491_ = (T493_ == ((NI) 1));
					LA492_: ;
					if (!T491_) goto LA494_;
					asgnRef((void**) (&(*c).selfName), getIdent__9coBOmdXN09be4rJvXK6fQGQ((*c).cache, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_123)));
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_121), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_124, NIM_FALSE);
				}
				goto LA483_;
				LA494_: ;
				{
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*it).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_125), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_126, NIM_FALSE);
				}
				LA483_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 186):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 116):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 20)) & 63);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 80):
			{
				(*sym).magic = ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 260);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 81):
			{
				(*sym).magic = ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 261);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 82):
			{
				(*sym).magic = ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 262);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 117):
			{
				noVal__0LSWh2UqkqDBtNGS0Kh9cNQ_4(c, it);
				{
					if (!(sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA505_;
					invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
				}
				goto LA503_;
				LA505_: ;
				{
					(*sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
				}
				LA503_: ;
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 221):
			{
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 176):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 178):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 179):
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 180):
			{
				pragmaProposition__0LSWh2UqkqDBtNGS0Kh9cNQ_15(c, it);
			}
			break;
			case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 177):
			{
				pragmaEnsures__0LSWh2UqkqDBtNGS0Kh9cNQ_16(c, it);
			}
			break;
			default:
			{
				invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
			}
			break;
			}
		}
		goto LA45_;
		LA47_: ;
		{
			NIM_BOOL T513_;
			tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T515_;
			T513_ = (NIM_BOOL)0;
			T513_ = comesFromPush;
			if (!(T513_)) goto LA514_;
			T515_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
			T515_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw(ident);
			T513_ = !((T515_ == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 0)));
			LA514_: ;
			if (!T513_) goto LA516_;
		}
		goto LA45_;
		LA516_: ;
		{
			{
				NIM_BOOL T521_;
				T521_ = (NIM_BOOL)0;
				T521_ = (sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
				if (T521_) goto LA522_;
				T521_ = ((619400 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
				LA522_: ;
				if (!T521_) goto LA523_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[(*i)]), semCustomPragma__wiyGBj4PmPVNmjmIuvK9cHQ(c, it));
			}
			goto LA519_;
			LA523_: ;
			{
				if (!!((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA526_;
				illegalCustomPragma__ISl2Z9aoSIz8Q3Jlw20Fjuw_2(c, it, sym);
			}
			goto LA519_;
			LA526_: ;
			{
				invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
			}
			LA519_: ;
		}
		LA45_: ;
	}
	LA29_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pragmaRec__m5gdSrENJIwAi9aMdDiUT9bg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL isStatement) {
	NI i;
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	i = ((NI) 0);
	{
		while (1) {
			NI T7_;
			T7_ = (NI)0;
			T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(i < T7_)) goto LA6;
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = singlePragma__KQ6mgDJAAhGjX4CT62UFwg(c, sym, n, (&i), validPragmas, NIM_FALSE, isStatement);
				if (!T10_) goto LA11_;
				goto LA5;
			}
			LA11_: ;
			i += ((NI) 1);
		} LA6: ;
	} LA5: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, overwriteLineInfo__L8Ia04mIjWr0SdD6EvU9aQw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	(*n).info = info;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				overwriteLineInfo__L8Ia04mIjWr0SdD6EvU9aQw((*n)._kind_6.sons->data[i], info);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, mergePragmas__TCm7mXLrAaTqiVWnN4JCgg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas_2;
	pragmas_2 = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(pragmas);
	overwriteLineInfo__L8Ia04mIjWr0SdD6EvU9aQw(pragmas_2, (*n).info);
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 4)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA3_;
		asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 4)]), pragmas_2);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
			p = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(pragmas_2);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i = i_2;
						p = (*pragmas_2)._kind_6.sons->data[i];
						add__P8dDSotTW25BkfbyspojGg((*n)._kind_6.sons->data[((NI) 4)], p);
						i_2 += ((NI) 1);
					} LA9: ;
				}
			}
		}
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas) {
	{
		NIM_BOOL T3_;
		tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* lib;
		tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** T37_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w** it;
			NI i;
			NI L;
			NI T8_;
			it = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
			i = ((NI) 0);
			T8_ = ((*c).optionStack ? (*c).optionStack->Sup.len : 0);
			L = T8_;
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* o;
					if (!(i < L)) goto LA10;
					it = &(*c).optionStack->data[i];
					o = (*(*it)).otherPragmas;
					{
						NIM_BOOL T13_;
						NI i_2;
						T13_ = (NIM_BOOL)0;
						T13_ = !((o == 0));
						if (!(T13_)) goto LA14_;
						T13_ = !((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0));
						LA14_: ;
						if (!T13_) goto LA15_;
						pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*n).info, ((NimStringDesc*) NIM_NIL));
						i_2 = ((NI) 0);
						{
							while (1) {
								NI T19_;
								T19_ = (NI)0;
								T19_ = len__P89cqdlERShb9alU3iC0yj8wast(o);
								if (!(i_2 < T19_)) goto LA18;
								{
									NIM_BOOL T22_;
									T22_ = (NIM_BOOL)0;
									T22_ = singlePragma__KQ6mgDJAAhGjX4CT62UFwg(c, sym, o, (&i_2), validPragmas, NIM_TRUE, NIM_FALSE);
									if (!T22_) goto LA23_;
									internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_134), TM__tPA3StZ6VsKyoznyrIfFxg_135);
								}
								LA23_: ;
								i_2 += ((NI) 1);
							} LA18: ;
						}
						popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
						{
							NIM_BOOL T27_;
							T27_ = (NIM_BOOL)0;
							T27_ = ((520192 &((NU32)1<<((NU)((*sym).kind)&31U)))!=0);
							if (!(T27_)) goto LA28_;
							T27_ = !(((*sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
							LA28_: ;
							if (!T27_) goto LA29_;
							mergePragmas__TCm7mXLrAaTqiVWnN4JCgg((*sym).ast, o);
						}
						LA29_: ;
					}
					LA15_: ;
					i += ((NI) 1);
				} LA10: ;
			}
		}
		{
			NIM_BOOL T33_;
			T33_ = (NIM_BOOL)0;
			T33_ = (((*sym).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 5))&15U)))!=0);
			if (!(T33_)) goto LA34_;
			T33_ = !((((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 7))&63U)))!=0));
			LA34_: ;
			if (!T33_) goto LA35_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__tPA3StZ6VsKyoznyrIfFxg_136), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__tPA3StZ6VsKyoznyrIfFxg_137, NIM_FALSE);
		}
		LA35_: ;
		T37_ = (tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w**)0;
		T37_ = X5BX5D___a3lCl6rQRUUcb6SyL7fj3wsystem((*c).optionStack->data, ((*c).optionStack ? (*c).optionStack->Sup.len : 0), ((NI) 1));
		lib = (*(*T37_)).dynlib;
		{
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = ((80 & (*sym).loc.flags) == 0);
			if (!(T41_)) goto LA42_;
			T41_ = (((*sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0);
			LA42_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA43_;
			T40_ = !((lib == ((tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*) NIM_NIL)));
			LA43_: ;
			if (!T40_) goto LA44_;
			(*sym).loc.flags |= ((NU16)1)<<((((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 4)) & 15);
			addToLib__xoFj1Tk9cDOsrW8yALZcxCA(lib, sym);
			{
				if (!((*sym).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA48_;
				asgnRef((void**) (&(*sym).loc.r), rope__yShmEg9cffWxI7s5XzEKBow((*(*sym).name).s));
			}
			LA48_: ;
		}
		LA44_: ;
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pragma__m5gdSrENJIwAi9aMdDiUT9bg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw validPragmas, NIM_BOOL isStatement) {
{	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	pragmaRec__m5gdSrENJIwAi9aMdDiUT9bg_2(c, sym, n, validPragmas, isStatement);
	implicitPragmas__3fUSuAmLz4H9aPTbK4rPERw(c, sym, n, validPragmas);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasPragma__oSJ8Ge9caDJrmJG9brFCzlOg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw pragma) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p;
		p = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					p = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						NI T13_;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*p).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T11_)) goto LA12_;
						T13_ = (NI)0;
						T13_ = len__P89cqdlERShb9alU3iC0yj8wast(p);
						T11_ = (((NI) 1) < T13_);
						LA12_: ;
						if (!T11_) goto LA14_;
						key = (*p)._kind_6.sons->data[((NI) 0)];
					}
					goto LA9_;
					LA14_: ;
					{
						key = p;
					}
					LA9_: ;
					{
						NIM_BOOL T19_;
						tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T21_;
						T19_ = (NIM_BOOL)0;
						T19_ = ((*key).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
						if (!(T19_)) goto LA20_;
						T21_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
						T21_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*key)._kind_5.ident);
						T19_ = (T21_ == pragma);
						LA20_: ;
						if (!T19_) goto LA22_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA22_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, pragmaAsm__BMqa01f86BatswrKktaxCw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_CHAR result;
	result = (NIM_CHAR)0;
	result = 0;
	{
		if (!!((n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T10_;
						NIM_BOOL T11_;
						NI T13_;
						tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T17_;
						T10_ = (NIM_BOOL)0;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28));
						if (!(T11_)) goto LA12_;
						T13_ = (NI)0;
						T13_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						T11_ = (T13_ == ((NI) 2));
						LA12_: ;
						T10_ = T11_;
						if (!(T10_)) goto LA14_;
						T10_ = ((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
						LA14_: ;
						if (!T10_) goto LA15_;
						T17_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
						T17_ = whichKeyword__sZUQNPhNGEM8MllfcWvRiw((*(*it)._kind_6.sons->data[((NI) 0)])._kind_5.ident);
						switch (T17_) {
						case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 197):
						{
							{
								if (!((*(*it)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5))) goto LA21_;
								result = ((NIM_CHAR) (((NI) (((NI) ((*(*it)._kind_6.sons->data[((NI) 1)])._kind_1.intVal))))));
							}
							goto LA19_;
							LA21_: ;
							{
								invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
							}
							LA19_: ;
						}
						break;
						default:
						{
							invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
						}
						break;
						}
					}
					goto LA8_;
					LA15_: ;
					{
						invalidPragma__0LSWh2UqkqDBtNGS0Kh9cNQ_2(c, it);
					}
					LA8_: ;
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	LA3_: ;
	return result;
}
