/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ;
typedef struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ tySequence__XUL1TrMU0tgXmaMFCIYgFQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct NimStringDesc NimStringDesc;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q;
typedef struct tySequence__8fytVdU59b5aj319cog2ztLw tySequence__8fytVdU59b5aj319cog2ztLw;
typedef struct tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg;
typedef struct tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyTuple__nsNHL3sm0TZE9bootw2pEXw tyTuple__nsNHL3sm0TZE9bootw2pEXw;
typedef struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA;
typedef struct tyTuple__Fb1Z8PVtzpSjrvQ67oA88w tyTuple__Fb1Z8PVtzpSjrvQ67oA88w;
typedef struct tyTuple__QVkyTCL0msoEdWvhK6TYrw tyTuple__QVkyTCL0msoEdWvhK6TYrw;
typedef struct tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww;
typedef struct tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg;
typedef struct tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q;
typedef struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
struct tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ {
tySequence__XUL1TrMU0tgXmaMFCIYgFQ* data;
NI counter;
NIM_BOOL isSorted;
};
struct tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ sigConflicts;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
struct tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typeInfo;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* constants;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* forwarded;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg generatedSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg typeInfoGenerated;
NI unique;
NIM_BOOL inSystem;
};
struct TGenericSeq {
NI len;
NI reserved;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q {
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procDef;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* globals;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* locals;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* body;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module;
tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* g;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg generatedParamCopies;
NIM_BOOL beforeRetNeeded;
NI unique;
tySequence__8fytVdU59b5aj319cog2ztLw* blocks;
NI extraIndent;
tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* up;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg declaredGlobals;
};
struct tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg {
NI id;
NIM_BOOL isLoop;
};
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__mrugoXXRZUEeG9bEXo9auBKw[2];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__qTjAvTvKF9anytN1At69aJMQ[1];
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__JiWwrsTRC6xqNlGcBthSVA[1];
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg;
typedef NU8 tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA;
struct tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w {
tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg kind;
tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA typ;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* res;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* address;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpLoc;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__wqYjTJU9ab2ZgEFMaQc3vNA[3];
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__wm6rkCVggH4IozhLUEP19bg[8];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__YcHYlgE5mhtkt9a3rnoucVg[7];
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__duFhZXIIlrbrM62cWjNekg[5];
typedef NU8 tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw[21];
typedef tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tyArray__f7nG5LD47BH5K9c6mASit3g[4];
typedef NU8 tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
typedef NU8 tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA;
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef tyArray__Re75IspeoxXy2oCZHwcRrA tyArray__k29ck4gbaHsaWs9bvWKy0w5w[62];
struct tyTuple__nsNHL3sm0TZE9bootw2pEXw {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field1;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA {
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b;
};
struct tyTuple__Fb1Z8PVtzpSjrvQ67oA88w {
NimStringDesc* Field0;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw Field1;
};
typedef NU8 tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
struct tyTuple__QVkyTCL0msoEdWvhK6TYrw {
NimStringDesc* Field0;
tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA Field1;
tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA Field2;
};
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef NimStringDesc* tyArray__nHXaesL0DJZHyVS07ARPRA[1];
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
struct tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg {
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* Field0;
tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* Field1;
};
struct tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww {
NI version;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sources;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* names;
NimStringDesc* mappings;
NimStringDesc* file;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg {
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field0;
NI Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__8fytVdU59b5aj319cog2ztLw {
  TGenericSeq Sup;
  tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__XUL1TrMU0tgXmaMFCIYgFQ {
  TGenericSeq Sup;
  tyTuple__tA7Q8IrfOKH7Mn89cK9cBAIg data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*, newModule__uTAIZZefAFwU7gogglQHZw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__O09bHTFgtn9cJLLJxiNhuKUA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__9apu9bmxB0tG2KjdEWuGfVPg)(NI initialSize, tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*, newGlobals__so1C5JeNzMQaRWt046X3Rw)(void);
static N_NIMCALL(void, Marker_tyRef__Q8XTeJJ39cPFyNvJXj9bmcMQ)(void* p, NI op);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
static N_INLINE(NIM_BOOL, skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*, newInitProc__Q2imPq7jCUQhQkfXP9cf4XA)(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module);
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*, newProc__T4OlZpX8DqYbIlMcOrFsUQ)(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procDef, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
static N_NIMCALL(void, Marker_tySequence__8fytVdU59b5aj319cog2ztLw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__OFWibP8T8afo89apFNGZiwA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, initProcOptions__VgCFSoS8r9a5GkCKlhdBDsQ)(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, genModule__AQaGEWMAoGSH1pqI9bePiww)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__IM4kcMNkkOLJtqdEqSxR8A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, frameCreate__5xQGffjrmjbHfz64yWZ49bw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, indentLine__jQGcsbXjMm82EQo5Ohqg0w)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(void, prepend__IM4kcMNkkOLJtqdEqSxR8A_2)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__yShmEg9cffWxI7s5XzEKBow)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AxDJCYpgPoquRsZtiOnpRw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dU9cenGIcVUltUO1088LhYQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw)(NimStringDesc* s, NIM_BOOL escapeNonAscii);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuEscape)(NimStringDesc* s, NimStringDesc* prefix, NimStringDesc* suffix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeJSString__yJnBaOMN1AufVWf0jGrqcg)(NimStringDesc* s);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx, tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org opt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformStmt__o9bTtoSsaDmuiyVzV15dOyg_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__UhPXgqyDuuU9cKcS8FM883w)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___ShdZ6VrAQkY0nWR9a39b9bGdQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___Z7W1o5nPSc3ExfO5f7j1Gg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, idOrSig__sKAFwdXn9cKHxc9cdaovk69cA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NimStringDesc* currentModule, tyObject_CountTable__tUMxxU9cRgLolsrW9b7IBGsQ* sigCollisions);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TLpRy9aDJ1Ni4vccOIoiMbA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__AASbADdVur9cDEeNbrY1Baw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* moduleLoadedVar, NIM_BOOL* inInitGuard);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___RzB0z3UV9bb4kXUEGyS9crRA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genStmt__AQaGEWMAoGSH1pqI9bePiww_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, gen__Bp5hmw3gImpkyC9cflWESLg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, genSym__Bp5hmw3gImpkyC9cflWESLg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genVarInit__iVEhpHbcyNY9aOzPqLze8xw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleName__VbRtGjpKYj6Wtc1GdNdKhg)(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, validJsName__DirUT0y4T1sHsJo7dddJ2w)(NimStringDesc* name);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, mangle__GxzvEIRbrShQbyJNboTw7A)(NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHex__TwQ1R2wlkmY9ak7KGbc718A)(NI x, NI len);
N_LIB_PRIVATE N_NIMCALL(void, add__yG4AKzsBRS1W4MANDlXQeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__KOisMGxcPhz6CcSmxgwEQQ)(NI64 i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Z1QwTAihBHnxe59cytXnhmw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___mZ66tEveFIQokq3arf8Klw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___57MdwiGSzJJwBASUKz9cDIw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA, mapType__ZlkXBdJTrpToZuRLq31tLQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA, mapType__3fHLBKCveV5k5hDCMQOL2g)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___XZnCV59at0sqX6ShEjlFLgw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YLzwVVtf4fuPYZVeMQOa0Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA)(NimStringDesc* frmt, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CtS8L8cOLTsSuQ10mtHsvw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, createVar__K9ag9aJJIngrApxv9aEbfdhIQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NIM_BOOL indirect);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, putToSeq__iEKLYo8HXYG9auKlJ6tkKKw)(NimStringDesc* s, NIM_BOOL indirect);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___mPpmmd13MIZLTbd1oOdSkw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__TIX0sFuRf3uBpOBltYp7bw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lengthOrd__hjogdnp59cMX1rwmjikBhqw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, elemType__PfgI9ap7WOnsRfFV4znQ27w_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, arrayTypeForElemType__Ef4AI5l7XLzo8SqxARtdiQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Th3qC4WgcAhWPSlLw7vZ9cg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, useMagic__4MoUWv1cpa6oOBwwpQ0wfA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProc__VRfKzQHOMcRGtJXZSJxFtg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* oldProc, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, generateHeader__jZNTi9aEbLMAMESBZ7a9cl7A)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3RPy0XXevrEBMts1Mb9arGw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gqwqalZtiJtCgAF9bY5S6qQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___G9bYX9bu7ufcttiARCDUJ0qg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___W0CV9bE9bNiLgazfFZjoQCBg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ecC7jlB6gBWrt0K9byHohPw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBody__ocxOgPRHWfivNZELIhOv7w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lineDir__l8iC2NnHymiEfpCjUoNB9cg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI line);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___6xseTZmgyslBQb6RMm9b4wA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, optionalLine__VuwqVIjxPGcoTVF06Jgl6w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProcBody__ByRZ0N9c4W9b5ThEZxre89cFg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasFrameInfo__eUoj4FPs7h9bV16Cz4RajiA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hFzCKQOJ8Eao2AJk5HOvxA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___62079cK9bsws1aAJqEmAGo6w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hO1UTpWJhaojnhUyqfmgPQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, frameDestroy__XP5ZeYFuxYow89aSkFgfWeg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uD0SC9bUeWpB9cK7V1aBT9aNQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Uez7zQbKzeDFToq2Yh43bA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___BYiowJAm8zF7RBRISElaLg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JbygmsEkVsyK85BPVFvwbg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___FLXrAGf7HFTHIGh8Xuickg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hmfCuT8fgBmRlPR25L7ZOw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HUHatwko3S0fuszXQAOSQQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__EoO5XDgy69ax76bvbHbf27w)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gGKEcvCOVzpTQoSXzO01Dw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LMnNsJkYlruXHnF5LV9c3pA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___uJ11bTQ8dBBAX88A2cyICw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2D3IUNoEAKKLxuRqVNosPQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__EoO5XDgy69ax76bvbHbf27w_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name);
static N_INLINE(NIM_BOOL, objHasTypeField__RtD7YfxmsbodfSCx5S9bFnAjsgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___o7SGM9buciKf5BOjTvMKA7w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Ht0mWR3LosfEZ8SopJcmEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GweM9byC8cQI9cehUzlYVs5A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Xnze9a4kYSwHurdPnhyNGzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__oMf9cufugVin4CJLwmEes2A)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___W2wbDjPGDCaBwLQM6yLUQg)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_Int128__9a9axPfb75jdWY25AamJewkA onError);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sGaOrvR5YSM9cGUajaqcNOw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GF60428RM29aXV0LYutm9aOA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__EoO5XDgy69ax76bvbHbf27w_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTupleFields__jZNTi9aEbLMAMESBZ7a9cl7A_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ciTj4q9cGhcXiXY9bPemZVvw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HLoe040Vi0LPzmTid9aLGdw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, createObjInitList__lQPYSYugh4oxbm9bTJCSJoA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excludedFieldIDs, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** output);
N_LIB_PRIVATE N_NIMCALL(NI, len__9b0YRltzV3kNSE9aQTsG82wg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tnP9cO5PduJRSEeqtm9bocEg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rec, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excludedFieldIDs, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** output);
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___S6XcU2shl8EfYxL7utXbwg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3GvB8fuMNh8BXF8IoORCxw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsNoCopy__AeBLus9crC8L5HbMOYikwJw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___RhAtD9c9aECDorIc8rDhMF9bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTemp__EG8bDinaW3fVLpok9a4s5cA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, NIM_BOOL defineInLocals);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CSdlEV0i9aXEHNuC1G9aIEbw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4SLS9cx2c8VCFIilepFlOeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, genCopyForParamIfNeeded__AQaGEWMAoGSH1pqI9bePiww_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___amX0pef5rA4JAmWZ6ZB2Nw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xAta147ahLKNrJMPPP5B6g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sshAiIx49ba6saVSAWuyFuA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TmulmJw2SZspd0rz2PYvQw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UFeu00R8dNoyzL8vy54mnQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genConstant__bgFYJWdvtLmrkmlW3jRA4A)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, genProcForSymIfNeeded__9aGDirKbsf9cN1iAWvMcXOKg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, attachProc__C5SA4Y9bPAMaecsSyvetPTg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qYiwFpynEwFeSf3Aa2sS0g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA, classify__x3IKzrz1VNvfZbypScSTXg)(NF x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg)(NF f, NimStringDesc* literalPostfix);
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__AQaGEWMAoGSH1pqI9bePiww_4)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QXMcmOst45ThYFLo9cOKDiQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___KsZXXO4zKP47iruPcSEryQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genMagic__Bp5hmw3gImpkyC9cflWESLg_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genOr__mpXN9cOaEmJkFGz77KKnHeQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TUxzei0sBfo3GESRTg1T5w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdLoc__yob5rpIMovhptJKw0A5vnAjsgen)(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jadqNPnY9aM3oxYK6jarLrA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ikDBM4Dyw9c2kuwAAswRyOw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ht9cduX4yJQKi2Gi685ag5A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genAnd__mpXN9cOaEmJkFGz77KKnHeQ_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Wsnl5zC9cCEBdwJcHgpLf0g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___deWmrKhbFG0MxH9cDr9cnhfQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, arith__3Dxk7XsMQw9b52OHOhMc7Fg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ)(NI64 size);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3RBmOS8xzFTxpuGVryQycg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___apXghcMDCUp9col7jN5spHA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9cNvJ1SVovK9b29bKmwKyiijw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0mbMVYCe5Qwl9aQOKV3sh3w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___03lrwELd9clj29bFkdXAVxkw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___8croAZ6oMdSPXHbIisuppw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TDLJ9ciKDBoW4ouZs855Csg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Mk2KRdMWX4H3L9aBEG2elgQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___pFXgvxsz2L5f27ImZwJwzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___n9aTlv49bCxoRKQNZiWsaW2g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___y3oNivo8px1XzxmB9b2OY5g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Pnqkcr360suaX84kwXMuCA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___FA4ohw0aOufzzLhmw9aUAhA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zrNMM9b9c0YgkZAn9c5r9c1Zeg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SWZi8EY4Pz39bBPSp9cbtZMg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___zzgVDys9a8A9cohe0W08nu1g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___XaBXRInsoVU7DBc2WK8dzg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NdMO5d09brFwLfDc8ciTSqQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___E62TlyqwqpEwqcA0YTjttw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___m4T7v0qnGpOgwmMenKcgwg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SKTmZPSgcdPr3Du3ia9b9czg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ItxAXpnPzfUbYRPsHgKrPw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tkJq8W3gQVDjuu9aT3THC6Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___oyQkqbRkRzo43y6iRevkaA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YuphtPwdJHG6BUJOVa9bX3w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QX9cU2fNK0jJrZNDQKnAycA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ggqZXIgPaS71ubw22cYODw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ec65mR1N7BSL9cmUa3z9czvA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LLnl4aDVJynim7LQvfJKLQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Ob6yLhv7QvbU9bdZj8Nw2kA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qfsHROU9aHSaYGq3tpw1XDg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GHW5yjG8N9c2BQBun6aBJzQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___j9bcJJvtd9bur0VZUQL3ibgA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___32ITt7hKDrhn9bXvKbmnE9bw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ZAOkVi5SmgPcGpCSuSRXVA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___smDIOmjGgf8ZP9bfDyv43bQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1jtIbjhXi2wH1iWPyC9bgAQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LJLp1p5BdxuzRFTT9czwOgA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___NPgb4kECDcV8MICSil6Rjw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___cQHGAtgSLYV7mm9bnVGYGRA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Q4LBu2cVl8IcNTrtxd6B6A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRepr__Bp5hmw3gImpkyC9cflWESLg_4)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* magic, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ctvQ2lU9b9bnVVpNP4GhIo2Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genSwap__AQaGEWMAoGSH1pqI9bePiww_5)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___M36w8F9bFwighD3K39bvtVWw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Wm11wQtuJBQgTy9a39apz0eA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___hPtLHtCXJsGExhBgLd7XoQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4Jn9cZxf8sC0AdAJhMJxbXw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* x, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsTemp__63ZTZNC9c5no8E73V2FDEMA_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HiCTlq0dXhMZvpDtUGWGQA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___aagcnoz4kFWlzsoVgR9b0NQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___YZKT3ZfbnHPsIPSSq9bBi6A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LwxnZ9c6VZqWj0n0sORkrTw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0xZtTB2eXM1dRd9aneL5VPw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genConStrStr__Bp5hmw3gImpkyC9cflWESLg_5)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___amO46kEKgIeOmW50ayV6nA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3lABfXU9aXZsyfylYizY8KA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5JCQx3oDHEcLdsEz6Rx0Rw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dTtf7fil83VcW2Mkkr7scw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___88NG6Rr5xfTcA6hqLfZ2iw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1DWSTPxvqlc4A2xRDmjZDw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___y5Z6ewsHLxj9ctzxTLPCLmw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CHBd5pGE9c8nq4KNqM8K48g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___y2h2X887dhz5sEoD4C8ezQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__KV0xCsBzaN9coqb7PG9au0oQ)(NimStringDesc* s, NimStringDesc* sub);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___dQfg2HrsVY6E7P22Nis1MA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0b2Bm7vpM8YAMKp9cuAwg3g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNew__AQaGEWMAoGSH1pqI9bePiww_6)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1Hh3EN9c4pkzdKB09bo9c9aTBg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AOSgPOjXfsLWEICRXv3U2g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___gN4yb6p4ql6iVJOPAjLEJQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrd__Bp5hmw3gImpkyC9cflWESLg_6)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___WIg2bxfQLkmzIdOv1JkRqw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___jS3RkUqTKs5pFAKfIQWYBA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___GXGZYpSrdrt9cuZh4RoVHyw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__lkqE7dycNUTKyDZxsrACPA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* op);
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* x, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CK0iwKv7s4cZGqPi5rQF6w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___PT2vKgDWcFJy9citUgxhMPg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JM349c89cyw9auxMIJuWihRCA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___oYhFcOWR4tEylepRJJLrlA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___fphSfWWyYSWLARtGIpYB9aw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___As9aDT7fkqstj16MQnIGPhA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___eAZ21NmzzIsugeSSkcxIkQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___D2dSwFjTnRSmeKOoMm6w0Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___pNrDKIPqQx0ZbHwzbw1pbA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___wHvkjtGBH55bmbp0FmDDtA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5hzyGWCNjqgqPj0O7sSnkg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___l1wvVBeU1Nnie8cWddgPCA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___yVZN2jQzbJwg3E9cehLff9cg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___E9br9b8BVYaWzg6CXcn9c6EXw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qPugJ1Nc2L1EdGwEF0AJ0Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HzZyrXo2QFynm1T8X76cCw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___O2nyVw4tGD6MMc6u7I9bH9cA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___IQYZUimFiAV9axFM9c64hKjA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___RCJU8UTq9cE0Jsi59anAbTIQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___S6vmSaSCgC4V2L5H7OWeZg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__AQaGEWMAoGSH1pqI9bePiww_7)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Eqr9cgWCkrZrUG3sg0CawIQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9c1lq60gbfPY9cyjQN4YouTQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genOf__Bp5hmw3gImpkyC9cflWESLg_7)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___1nMXoOe6cENU7004pnh6wQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ALynLzo8zWvno8ZxASdm4A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genDefault__Bp5hmw3gImpkyC9cflWESLg_8)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genReset__AQaGEWMAoGSH1pqI9bePiww_8)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tlkWMVJPsx9aWUbp8FMjQ4w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xPW5KjObCPL2lJmHFoqfjg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genEcho__Bp5hmw3gImpkyC9cflWESLg_9)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__Bp5hmw3gImpkyC9cflWESLg_10)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___aoMj8hrcFi4HlPDZ9a9alpig)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Yj64cHk9ajrzJI39bfpBfOVA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genCall__Bp5hmw3gImpkyC9cflWESLg_11)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genArgs__1PNPBjb9aOT7yB9avaRcGbbQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NI start);
N_LIB_PRIVATE N_NIMCALL(void, genArg__RI5RyHREFNXox9cpkCYH50g)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NI* emitted);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9bY6R9buTsrqJYQAuD39cegOA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___U9b6hkqS6N7XIWr0gy8z9bug)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___2MwhwhkHOiavfXQl9aey8nA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genMove__Bp5hmw3gImpkyC9cflWESLg_12)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__Bp5hmw3gImpkyC9cflWESLg_13)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__wAzSnEu9cCHHjvPQlWBZUeQ)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars);
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__4TT1TPwHmxERu3KEGU1QFw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* pat, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__9aqB67Rnkf1OHu3XOk89bdcg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NI* generated, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__2yh9cer0ymNRHlOOg8P7IuA)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__Bp5hmw3gImpkyC9cflWESLg_14)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL preventInheritance);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JRV6DlpqdegYGLcFjNPv0g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__Bp5hmw3gImpkyC9cflWESLg_15)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__Bp5hmw3gImpkyC9cflWESLg_16)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ryMkoQkM4zAjyp0800DrDQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___iW9bjdQoXkul7L0e76qo8XQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__Bp5hmw3gImpkyC9cflWESLg_17)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___i3z9am8Hzy69bSo575pRdzGw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SkAQPSnCyiRvin57XULW4A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Bym8FwH29aQE8fth9ar38yJQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genConv__Bp5hmw3gImpkyC9cflWESLg_18)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value);
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___QxiH9aM0po7vA19b2s1CjdEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___CbbQqCp6itJgwKVRfTr69ag)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___HWgoOloM1oqcI9aZ9bEkoBhg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genAddr__Bp5hmw3gImpkyC9cflWESLg_19)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___HZ7mfC6lJSSHM4bdhgCYTg)(tyTuple__Fb1Z8PVtzpSjrvQ67oA88w x);
N_LIB_PRIVATE N_NIMCALL(void, genCheckedFieldOp__iKztcH0Tujg1djuGYyE69cQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* addrTyp, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, genFieldDefect__NFvxltQN2CgyfP8SjDTS1g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disc);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Anf1UHjOzz9aHgMOgtnEPZA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___tDrtnFWakp63hyE9cfImgZw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___JwpI2xnYNfR68HstfDi1yQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___paA0sar8RKZqiwEaDfWo2A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genFieldAddr__Bp5hmw3gImpkyC9cflWESLg_20)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(NI, getFieldPosition__DLbHFD2eUjMEos1A21BcJw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f);
N_LIB_PRIVATE N_NIMCALL(void, genFieldAccess__Bp5hmw3gImpkyC9cflWESLg_21)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5TB09c2Iz60T0YagbSbI5RQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayAddr__Bp5hmw3gImpkyC9cflWESLg_22)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genDeref__Bp5hmw3gImpkyC9cflWESLg_23)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genArrayAccess__Bp5hmw3gImpkyC9cflWESLg_24)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UxL9a0Hh7Km0Z0DIk7hp9cBA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, upConv__Bp5hmw3gImpkyC9cflWESLg_25)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genCast__Bp5hmw3gImpkyC9cflWESLg_26)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___FZt89ajG3TKAhfL9aW4s7hcA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___5GaE39bOOeQZy3EFOEIy5QA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___SA9cvbR3uc9cP50nnaEBJctw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__hP2w9bfjeb9a8Gw7OVBCznWw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* magic);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___KweYGQ9bFYg76nmoxpk8ksA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__Bp5hmw3gImpkyC9cflWESLg_27)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___AhY63HjLy2bPe9bslUNBuBQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__Bp5hmw3gImpkyC9cflWESLg_28)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__Bp5hmw3gImpkyC9cflWESLg_29)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3m7YwdrxIvOkmvfnm5JYSA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TEWiK8QWtRTCIQ9av7sW8LA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genIf__Bp5hmw3gImpkyC9cflWESLg_30)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9an6bUHwpxqyL2kgNHX3MEg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___kLwAORKb0c4oFgFTN9aEN8Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* src, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___9a3Y7eeGNXkOCLUktwxzN9ag)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatChar)(NIM_CHAR c, NI count);
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__AQaGEWMAoGSH1pqI9bePiww_9)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg*, X5BX5D___4IYft39cjB6OIbPrsxRl9aAgsystem)(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg* s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Qm29ctdy9c4sqKctTsqiBWIg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___UyNt2Asj9aa2ScoGVo9cCnNw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__AQaGEWMAoGSH1pqI9bePiww_10)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lowerTupleUnpacking__8A4G64HByteFanrMUexmNw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, genCaseJS__Bp5hmw3gImpkyC9cflWESLg_31)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___xXvQyblNYV215UGR9cTka7Q)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___T9caGByKkBhaXSZ6fCJLIdQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___f8NIixSwWrk6SXQ3BFamWw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___TmeCjGna9cPfiHHcfqmKXjw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___LYjQOKn1i9ccw8AFlvPGkCg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__AQaGEWMAoGSH1pqI9bePiww_11)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___THj0xNXkqJf6reD7exsGbA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__AQaGEWMAoGSH1pqI9bePiww_12)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3oFXAbir9c7XcKzu9bpgAM9bA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__AQaGEWMAoGSH1pqI9bePiww_13)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genAsgnAux__FTHts0vUatiTmPKVGzyMKA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, NIM_BOOL noCopyNeeded);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___4sbi76q7ZLqpKbD3pwJ59bQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Q9cOQGrP4lOdbYHXMQ1yZtg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___0AX4Q6cA8nOXUagvzFqt0A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___qQ3g8SwjZoIFAay85NaiEA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___D9cWch2yJRlkSqFCXT3v86A)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___NDGD2HOmz0EkwXFFCD1T6w)(tyTuple__QVkyTCL0msoEdWvhK6TYrw x);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___M0TByFCTj9bbOkDSRpFz3LA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genFastAsgn__AQaGEWMAoGSH1pqI9bePiww_14)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, amp___4cYKitaHx6RQ9azRtQsZp6w)(NimStringDesc* a, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b);
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__AQaGEWMAoGSH1pqI9bePiww_15)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, genTry__Bp5hmw3gImpkyC9cflWESLg_32)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___OikfyLf8HmjI9auYLFoaVqg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___3KVF9aLACI1h11BqZrkzjNg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ial810twbEzfkHaHMFYNCg)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__dZW9czpRSiiVl9cyT6tyk84A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Z7wCJf0WipOQOQ4ZZNBIEw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___Xpm9cGf2grEXdjAQV9arqWBQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sqxyWwlLrfrdyc9b3BINcXQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___ztLQ2Orupb9b9b3KrCvoK9cbQ)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___PI6febxsdTbySkLsIEqHKw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__AQaGEWMAoGSH1pqI9bePiww_16)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___sGRyuC9caCxfdM1i8W4fjgw)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(void, genPragma__AQaGEWMAoGSH1pqI9bePiww_17)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___boICAAvO1zkTlYDOuEaj6g)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, percent___vWWA89aSvs5QwAFN4Jdr2IA)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** args, NI argsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__PZ51a8H3AQu4zYP9cwHpJag)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genHeader__Jh8YZW9c6mmqtRqmZvtYISg)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatVarargs)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuUnindent)(NimStringDesc* s, NI count, NimStringDesc* padding);
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, wholeCode__0JkORKxMs17USnUxSKLA9cw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m);
N_LIB_PRIVATE N_NIMCALL(void, attachProc__9aGDirKbsf9cN1iAWvMcXOKg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, generateMethodDispatchers__7t0GJlNQwZyLt0Kz3RhRdw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, prepareToWriteOutput__ea9bsNo9cwchKzwCi7UjcP7g_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, genSourceMap__AhPdyw9b9bcsUwQskMDve3NA)(NimStringDesc* source, NimStringDesc* outFile, tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg* Result);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__D6Pj9c29aCLEJP9beOWa08HYA)(NimStringDesc* filename, NimStringDesc* content);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___79aIqF5QC8ZRJgu2hlv9bdjw)(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* node);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*, percent___PVcH6RFdp59aTK2rmalT2CA)(tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* o);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRopeIfNotEqual__Wiam9c8x73Mtmbj0r4Ppikg_2)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r, NimStringDesc* filename);

/* section: NIM_merge_DATA */
extern TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
N_LIB_PRIVATE TNimType NTI__qij68Ti2EwJQHH6sSdkSdw_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__tUMxxU9cRgLolsrW9b7IBGsQ_;
N_LIB_PRIVATE TNimType NTI__O09bHTFgtn9cJLLJxiNhuKUA_;
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__nWsHZg3qCUsABoCNYLliag_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__PQrmFm4BXFkFSVOUl1ojSg_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_4, "myProcess", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_6, "/home/runner/work/nightlies/nightlies/nim/compiler/jsgen.nim", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_5 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2653),
((NI) 35)}
;
N_LIB_PRIVATE TNimType NTI__AFoo8FBR6Z1RtIhjuHkU2Q_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__7MnKRybmCNh5j9bDRLMkxLw_;
N_LIB_PRIVATE TNimType NTI__46cd0Xw9aDJ1QWTE8nV4mLg_;
N_LIB_PRIVATE TNimType NTI__8fytVdU59b5aj319cog2ztLw_;
N_LIB_PRIVATE TNimType NTI__OFWibP8T8afo89apFNGZiwA_;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_9, "  ", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_10, "\"", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_11, "\\n", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_12, "\\r", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_13, "\\t", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_14, "\\b", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_15, "\\a", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_16, "\\e", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_17, "\\v", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_18, "\\\\", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_19, "\\\"", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_20, "module ", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_21, "_loaded", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_22, "}\012", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_23, "symbol has no generated name: ", 30);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_24 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1388),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_25, "abstract", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_26, "await", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_27, "boolean", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_28, "break", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_29, "byte", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_30, "case", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_31, "catch", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_32, "char", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_33, "class", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_34, "const", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_35, "continue", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_36, "debugger", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_37, "default", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_38, "delete", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_39, "do", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_40, "double", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_41, "else", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_42, "enum", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_43, "export", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_44, "extends", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_45, "false", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_46, "final", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_47, "finally", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_48, "float", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_49, "for", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_50, "function", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_51, "goto", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_52, "if", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_53, "implements", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_54, "import", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_55, "in", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_56, "instanceof", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_57, "int", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_58, "interface", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_59, "let", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_60, "long", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_61, "native", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_62, "new", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_63, "null", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_64, "package", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_65, "private", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_66, "protected", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_67, "public", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_68, "return", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_69, "short", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_70, "static", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_71, "super", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_72, "switch", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_73, "synchronized", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_74, "this", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_75, "throw", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_76, "throws", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_77, "transient", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_78, "true", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_79, "try", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_80, "typeof", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_81, "var", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_82, "void", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_83, "volatile", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_84, "while", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_85, "with", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_86, "yield", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_87, "HEX", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_88, "_", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_89, "var $2", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_90, "jsgen.nim(213, 32) `false` ", 27);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_91, " = $3;$n", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_92, "0", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_93, "0.0", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_94, "{}", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_95, "Int32Array", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_96, "Int16Array", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_97, "Int8Array", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_98, "Uint32Array", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_99, "Uint16Array", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_100, "Uint8Array", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_101, "Float32Array", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_102, "Float64Array", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_103, "(", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_104, ", ", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_105, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_106 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 302),
((NI) 19)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_107, "_Idx", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_108, " {$n$#$#$#$#$#", 14);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_109, "\012", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_110, "framePtr = F.prev;\012", 19);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_111, "IMLP", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_112, "system module needs: ", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_113 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 308),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_114 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 310),
((NI) 16)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_115, "arrayConstr", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_116, "nimCopy", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_117, "genEnumInfo", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_119, "/home/runner/work/nightlies/nightlies/nim/compiler/jstypes.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_118 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 107),
((NI) 46)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_120, ", \012", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_121, "genObjectFields", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_122 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 42),
((NI) 42)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_123, "genObjectFields; nkOfBranch broken", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_124 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 51),
((NI) 23)}
;
extern NIM_CONST tyObject_Int128__9a9axPfb75jdWY25AamJewkA Max__zlJMNfqX7LwCYj0PF6ncWQ;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_125, "genObjectFields(nkRecCase)", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_126 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 61),
((NI) 25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_127 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 69),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_128, "genTypeInfo(", 12);
extern TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_129 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 155),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_130 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_119),
((NI) 156),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_131, "[", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_132, "]", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_133, "{", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_134, "}", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_135, "createRecordVarAux", 18);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_136 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1646),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_137, "[null, 0]", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_138, "[]", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_139, "createVar: ", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_140 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1733),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_141 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1736),
((NI) 17)}
;
static NIM_CONST tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw TM__BxLwT0mhrtgTPodf1v3xjg_142 = {
0xe0, 0x07, 0x77, 0xfc, 0x61, 0x02, 0x00, 0x00,
0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x01}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_143, " = $3, $2_Idx = $4;$n", 21);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_144, " = [[$3, $4]];$n", 16);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_145, " = [$3, $4];$n", 14);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_146, " = [$3];$n", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_147, "couldn\'t find the owner proc of the closed over param: ", 55);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_148 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1373),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_149 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1413),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_150, "request to generate code for .compileTime proc: ", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_151 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1417),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_152 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1433),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_153, "false", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_154, "true", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_155, "null", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_156, "0", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_157, "makeNimstrLit", 13);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_158, "[]", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_159, "NaN", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_160, "-0.0", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_161, "0.0", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_162, "Infinity", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_163, "-Infinity", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_164, "& 0xff", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_165, "& 0xffff", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_166, ">>> 0", 5);
extern NIM_CONST tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag abstractRange__2fNKM13XwmoacahtEcjlJg;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_167, "+", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_168, "-", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_169, "*", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_170, "/", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_171, "addInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_172, "subInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_173, "mulInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_174, "divInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_175, "modInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_176, "nimMin", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_177, "nimMax", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_178, "negInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_179, "negInt64", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_180, "absInt", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_181, "nimCharToStr", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_182, "nimBoolToStr", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_183, "cstrToNimstr", 12);
N_LIB_PRIVATE NIM_CONST tyArray__k29ck4gbaHsaWs9bvWKy0w5w jsMagics__QXSBsb0PxIS2yQAUDBHd9cQ = {{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_171),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_172),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_173),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_174),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_175),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_171),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_172),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_176),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_176)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_177),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_177)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_178),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_179),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_180),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_181),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_181)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_182),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_182)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183)}
,
{((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183),
((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183)}
,
{((NimStringDesc*) NIM_NIL),
((NimStringDesc*) NIM_NIL)}
}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_184, "nimFloatToString", 16);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_185, "reprAny", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_186, ", null", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_187, "reprInt", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_188, "reprChar", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_189, "reprBool", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_190, "reprFloat", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_191, "reprStr", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_192, "reprEnum", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_193, "reprSet", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_194, "\'repr\' doesn\'t support \'void\' type", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_195 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1932),
((NI) 14)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_196, "reprPointer", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_197, "reprJSONStringify", 17);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_198, "genSwap", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_199 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1122),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_200, "addChar", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_201, "eqStrings", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_202, "cmpStrings", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_203, "($1 == null)", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_204, "$2", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_205, "($1 \? 1:0)", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_206, "genOrd", 6);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_207 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1867),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_208, "($1).length", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_209, "(($1).length-1)", 15);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_210, "chckIndx", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_211, "mnewString", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_212, "SetCard", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_213, "SetCard($1)", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_214, "SetLt", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_215, "SetLe", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_216, "SetEq", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_217, "SetMul", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_218, "SetPlus", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_219, "SetMinus", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_220, "isObj", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_221, "genericReset", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_222 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1613),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_223, "toJSStr", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_224, "rawEcho", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_225, "rawEcho(", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_226, "\'$1\' can only be used in compile-time context", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_227 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2093),
((NI) 14)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_228, "mnewString($1)", 14);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_229, "mnewString(0)", 13);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_230, "nimParseBiggestFloat", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_231 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1579),
((NI) 19)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__BxLwT0mhrtgTPodf1v3xjg_232 = {
0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_233, "wrong importcpp pattern; expected parameter at position ", 56);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_234, " but got only: ", 15);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_235 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1525),
((NI) 15)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_236, "#", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_237, "@", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_238, "cannot invoke with infix syntax", 31);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_239 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1589),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_240, ".", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_241, "setConstr", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_242, "setConstr(", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_243, "ConstSet", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_244 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2185),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_245, "genAddr: 3", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_246 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1292),
((NI) 36)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_247, "[0]", 3);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_248, "genAddr: 2", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_249 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1319),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_250 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1181),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_251 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1193),
((NI) 17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_252 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1197),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_253, "raiseFieldError", 15);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_254, "Field", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_255, "genFieldPosition", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_256 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1133),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_257, "genFieldAddr", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_258 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1143),
((NI) 40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_259 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1147),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_260, "genFieldAccess", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_261 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1171),
((NI) 40)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_262, "expr(nkBracketExpr, ", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_263 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1338),
((NI) 25)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_264, "genAddr for complex nkStmtListExpr", 34);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_265 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1347),
((NI) 23)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_266, "genAddr: ", 9);
extern TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_267 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1348),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_268, "genDeref", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_269 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1457),
((NI) 19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_270 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1261),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_271, "genArrayAccess", 14);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_272 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1263),
((NI) 32)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_273, "0xfe", 4);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_274, "0xfffe", 6);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_275, "0xfffffffe", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_276, "chckRange", 9);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_277, "chckRangeF", 10);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_278, "chckRange64", 11);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_279, "convStrToCStr", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_280 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2250),
((NI) 34)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_281, "convCStrToStr", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_282 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2262),
((NI) 34)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_283, "genBlock", 8);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_284 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 923),
((NI) 42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_285 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 718),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_286, "for statement not eliminated", 28);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_287 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2547),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_288, "Your case statement contains too many branches, consider using "
"if/else instead!", 79);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_289 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 890),
((NI) 22)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_290, "jsgen.genCaseStmt: 2", 20);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_291 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 901),
((NI) 31)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_292, "jsgen.genCaseStmt", 17);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_293 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 915),
((NI) 23)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_294, "genReturnStmt", 13);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_295 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2268),
((NI) 36)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_296, "no loop to break", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_297 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 949),
((NI) 19)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_298, "cstring doesn\'t support `[]=` operator", 38);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_299 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1054),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_300 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1087),
((NI) 23)}
;
N_LIB_PRIVATE TNimType NTI__9aFSCXgaSEq2m81RJRMKDeA_;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_304, "genAsgn", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_305 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 1094),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_306, "var _ = ", 8);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_307, "++excHandler;\012", 14);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_308, "F", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_309, " = framePtr;\012", 13);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_310, "jsgen.nim(810, 20) `orExpr == nil` ", 35);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_311, "genTryStmt", 10);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_312 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 814),
((NI) 23)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_313, "||", 2);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_314, "else ", 5);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_315, "reraiseException", 16);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_316, "else {\012", 7);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_317, "\011reraiseException();\012", 21);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_318, "} finally {\012", 12);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_319, "raiseException", 14);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_320, "reraiseException();\012", 20);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_321, "Closure iterators are not supported by JS backend!", 50);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_322 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2566),
((NI) 17)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_323, "First class iterators not implemented", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_324 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2574),
((NI) 15)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_325, "gen: unknown node type: ", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__BxLwT0mhrtgTPodf1v3xjg_326 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_6),
((NI) 2578),
((NI) 21)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_327, "/* Generated by the Nim Compiler v$1 */\012    var framePtr = null"
";\012    var excHandler = 0;\012    var lastJSError = null;\012  ", 119);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_328, " ", 1);
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_330, "1.4.2", 5);
static NIM_CONST tyArray__nHXaesL0DJZHyVS07ARPRA TM__BxLwT0mhrtgTPodf1v3xjg_329 = {((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_330)}
;
STRING_LITERAL(TM__BxLwT0mhrtgTPodf1v3xjg_331, ".map", 4);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tyRef__O09bHTFgtn9cJLLJxiNhuKUA)(void* p, NI op) {
	tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* a;
	a = (tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*)p;
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).sigConflicts.data, op);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_NIMCALL(void, Marker_tyRef__Q8XTeJJ39cPFyNvJXj9bmcMQ)(void* p, NI op) {
	tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* a;
	NI T1_;
	NI T2_;
	a = (tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*)p;
	nimGCvisit((void*)(*a).typeInfo, op);
	nimGCvisit((void*)(*a).constants, op);
	nimGCvisit((void*)(*a).code, op);
	nimGCvisit((void*)(*a).forwarded, op);
	nimGCvisit((void*)(*a).generatedSyms.head, op);
	nimGCvisit((void*)(*a).generatedSyms.data, op);
	T1_ = (NI)0;
	nimGCvisit((void*)(*a).typeInfoGenerated.head, op);
	nimGCvisit((void*)(*a).typeInfoGenerated.data, op);
	T2_ = (NI)0;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*, newGlobals__so1C5JeNzMQaRWt046X3Rw)(void) {
	tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* result;
	result = (tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*)0;
	result = (tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*) newObj((&NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_), sizeof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag));
	(*result).Sup.m_type = (&NTI__nWsHZg3qCUsABoCNYLliag_);
	if ((*result).forwarded) { nimGCunrefNoCycle((*result).forwarded); (*result).forwarded = NIM_NIL; }
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).generatedSyms));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*result).typeInfoGenerated));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*, newModule__uTAIZZefAFwU7gogglQHZw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* result;
	result = (tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*)0;
	result = (tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*) newObj((&NTI__O09bHTFgtn9cJLLJxiNhuKUA_), sizeof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw));
	(*result).Sup.Sup.m_type = (&NTI__qij68Ti2EwJQHH6sSdkSdw_);
	asgnRef((void**) (&(*result).module), module);
	initCountTable__9apu9bmxB0tG2KjdEWuGfVPg(((NI) 32), (&(*result).sigConflicts));
	{
		tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* T5_;
		if (!((*g).backend == ((RootObj*) NIM_NIL))) goto LA3_;
		T5_ = (tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*)0;
		T5_ = newGlobals__so1C5JeNzMQaRWt046X3Rw();
		asgnRef((void**) (&(*g).backend), &T5_->Sup);
	}
	LA3_: ;
	asgnRef((void**) (&(*result).graph), g);
	asgnRef((void**) (&(*result).config), (*g).config);
	{
		if (!(((*module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA8_;
		(*(*((tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag**) (&((*g).backend))))).inSystem = NIM_TRUE;
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, myOpen__gLZYKlu4ac5hh8GLNkHarg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* result;
	tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* T1_;
	result = (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*)0;
	T1_ = (tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*)0;
	T1_ = newModule__uTAIZZefAFwU7gogglQHZw(graph, s);
	result = &T1_->Sup;
	return result;
}
static N_INLINE(NIM_BOOL, skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((NI) 0) < (*config).errorCounter);
	return result;
}
static N_NIMCALL(void, Marker_tySequence__8fytVdU59b5aj319cog2ztLw)(void* p, NI op) {
	tySequence__8fytVdU59b5aj319cog2ztLw* a;
	NI T1_;
	a = (tySequence__8fytVdU59b5aj319cog2ztLw*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tyRef__OFWibP8T8afo89apFNGZiwA)(void* p, NI op) {
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* a;
	NI T1_;
	NI T2_;
	a = (tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*)p;
	nimGCvisit((void*)(*a).procDef, op);
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).globals, op);
	nimGCvisit((void*)(*a).locals, op);
	nimGCvisit((void*)(*a).body, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).g, op);
	nimGCvisit((void*)(*a).generatedParamCopies.head, op);
	nimGCvisit((void*)(*a).generatedParamCopies.data, op);
	T1_ = (NI)0;
	nimGCvisit((void*)(*a).blocks, op);
	nimGCvisit((void*)(*a).up, op);
	nimGCvisit((void*)(*a).declaredGlobals.head, op);
	nimGCvisit((void*)(*a).declaredGlobals.data, op);
	T2_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*, newProc__T4OlZpX8DqYbIlMcOrFsUQ)(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* procDef, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options) {
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* result;
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* T1_;
	result = (tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*)0;
	T1_ = (tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*)0;
	T1_ = (tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*) newObj((&NTI__OFWibP8T8afo89apFNGZiwA_), sizeof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q));
	if ((*T1_).blocks) { nimGCunrefNoCycle((*T1_).blocks); (*T1_).blocks = NIM_NIL; }
	(*T1_).options = options;
	asgnRef((void**) (&(*T1_).module), module);
	asgnRef((void**) (&(*T1_).procDef), procDef);
	asgnRef((void**) (&(*T1_).g), globals);
	(*T1_).extraIndent = ((NI) (!((procDef == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))));
	result = T1_;
	{
		if (!!((procDef == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA4_;
		asgnRef((void**) (&(*result).prc), (*(*procDef)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
	}
	LA4_: ;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg, initProcOptions__VgCFSoS8r9a5GkCKlhdBDsQ)(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module) {
	tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg result;
	nimZeroMem((void*)(&result), sizeof(tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg));
	result = (*(*module).config).options;
	{
		if (!(*(*((tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag**) (&((*(*module).graph).backend))))).inSystem) goto LA3_;
		result &= ~(((NU32)1) << ((((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17)) & 31));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*, newInitProc__Q2imPq7jCUQhQkfXP9cf4XA)(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* module) {
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* result;
	tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg T1_;
	result = (tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*)0;
	T1_ = initProcOptions__VgCFSoS8r9a5GkCKlhdBDsQ(module);
	result = newProc__T4OlZpX8DqYbIlMcOrFsUQ(globals, module, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, indentLine__jQGcsbXjMm82EQo5Ohqg0w)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p_2;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = r;
	p_2 = p;
	{
		while (1) {
			{
				NI i;
				NI colontmp_;
				NI T4_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				T4_ = ((*p_2).blocks ? (*p_2).blocks->Sup.len : 0);
				colontmp_ = (NI)(T4_ + (*p_2).extraIndent);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
						if (!(i_2 < colontmp_)) goto LA6;
						i = i_2;
						T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T7_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_9));
						prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&result, T7_);
						i_2 += ((NI) 1);
					} LA6: ;
				}
			}
			{
				NIM_BOOL T10_;
				T10_ = (NIM_BOOL)0;
				T10_ = ((*p_2).up == ((tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*) NIM_NIL));
				if (T10_) goto LA11_;
				T10_ = !(((*(*p_2).up).prc == (*(*p_2).prc).owner));
				LA11_: ;
				if (!T10_) goto LA12_;
				goto LA1;
			}
			LA12_: ;
			p_2 = (*p_2).up;
		}
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, frameCreate__5xQGffjrmjbHfz64yWZ49bw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* procname, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filename) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = procname;
	T1_[1] = filename;
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = percent___AxDJCYpgPoquRsZtiOnpRw(T1_, 2);
	result = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T2_);
	nimZeroMem((void*)T3_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = percent___dU9cenGIcVUltUO1088LhYQ(T3_, 0);
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T4_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T5_);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeJSString__yJnBaOMN1AufVWf0jGrqcg)(NimStringDesc* s) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = rawNewString(((NI) ((NI)((s ? s->Sup.len : 0) + (NI)((NI64)((s ? s->Sup.len : 0)) >> (NU64)(((NI) 2)))))));
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_10));
	{
		NIM_CHAR c;
		NI i;
		NI L;
		c = (NIM_CHAR)0;
		i = ((NI) 0);
		L = (s ? s->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA3;
				c = s->data[i];
				switch (((NU8)(c))) {
				case 10:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_11));
				}
				break;
				case 13:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_12));
				}
				break;
				case 9:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_13));
				}
				break;
				case 8:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_14));
				}
				break;
				case 7:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_15));
				}
				break;
				case 27:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_16));
				}
				break;
				case 11:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_17));
				}
				break;
				case 92:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_18));
				}
				break;
				case 34:
				{
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_19));
				}
				break;
				default:
				{
					result = addChar(result, c);
				}
				break;
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
	result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_10));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw)(NimStringDesc* s, NIM_BOOL escapeNonAscii) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* T5_;
		if (!escapeNonAscii) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = nsuEscape(s, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_10));
		result = rope__yShmEg9cffWxI7s5XzEKBow(T5_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T7_;
		T7_ = (NimStringDesc*)0;
		T7_ = escapeJSString__yJnBaOMN1AufVWf0jGrqcg(s);
		result = rope__yShmEg9cffWxI7s5XzEKBow(T7_);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, validJsName__DirUT0y4T1sHsJo7dddJ2w)(NimStringDesc* name) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	switch (hashString(name) & 63) {
	case 0: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_56))) goto LA1_;
break;
	case 1: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_64))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_84))) goto LA1_;
break;
	case 3: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_76))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_80))) goto LA1_;
break;
	case 4: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_53))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_66))) goto LA1_;
break;
	case 7: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_27))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_52))) goto LA1_;
break;
	case 8: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_69))) goto LA1_;
break;
	case 10: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_59))) goto LA1_;
break;
	case 11: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_55))) goto LA1_;
break;
	case 13: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_62))) goto LA1_;
break;
	case 15: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_28))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_74))) goto LA1_;
break;
	case 17: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_73))) goto LA1_;
break;
	case 19: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_49))) goto LA1_;
break;
	case 20: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_37))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_61))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_71))) goto LA1_;
break;
	case 21: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_35))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_41))) goto LA1_;
break;
	case 22: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_86))) goto LA1_;
break;
	case 23: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_38))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_63))) goto LA1_;
break;
	case 24: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_72))) goto LA1_;
break;
	case 25: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_29))) goto LA1_;
break;
	case 26: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_34))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_70))) goto LA1_;
break;
	case 29: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_33))) goto LA1_;
break;
	case 30: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_85))) goto LA1_;
break;
	case 34: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_57))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_65))) goto LA1_;
break;
	case 36: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_39))) goto LA1_;
break;
	case 37: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_67))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_78))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_82))) goto LA1_;
break;
	case 38: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_30))) goto LA1_;
break;
	case 40: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_77))) goto LA1_;
break;
	case 42: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_45))) goto LA1_;
break;
	case 44: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_42))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_54))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_60))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_68))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_81))) goto LA1_;
break;
	case 45: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_51))) goto LA1_;
break;
	case 47: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_36))) goto LA1_;
break;
	case 48: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_50))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_83))) goto LA1_;
break;
	case 49: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_44))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_48))) goto LA1_;
break;
	case 50: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_46))) goto LA1_;
break;
	case 54: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_58))) goto LA1_;
break;
	case 55: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_25))) goto LA1_;
break;
	case 56: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_47))) goto LA1_;
break;
	case 57: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_75))) goto LA1_;
break;
	case 59: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_32))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_79))) goto LA1_;
break;
	case 61: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_26))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_40))) goto LA1_;
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_43))) goto LA1_;
break;
	case 62: 
if (eqStrings(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_31))) goto LA1_;
break;
	}
	goto LA2_;
	LA1_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA3_;
	LA2_: ;
	{
	}
	LA3_: ;
	{
		if (!(((NU8)(name->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(name->data[((NI) 0)])) <= ((NU8)(57)))) goto LA8_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA8_: ;
	{
		NIM_CHAR chr;
		NI i;
		NI L;
		chr = (NIM_CHAR)0;
		i = ((NI) 0);
		L = (name ? name->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA12;
				chr = name->data[i];
				{
					if (!!((((NU8)(chr)) >= ((NU8)(65)) && ((NU8)(chr)) <= ((NU8)(90)) || ((NU8)(chr)) >= ((NU8)(97)) && ((NU8)(chr)) <= ((NU8)(122)) || ((NU8)(chr)) == ((NU8)(95)) || ((NU8)(chr)) == ((NU8)(36)) || ((NU8)(chr)) >= ((NU8)(48)) && ((NU8)(chr)) <= ((NU8)(57))))) goto LA15_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA15_: ;
				i += ((NI) 1);
			} LA12: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, mangleName__VbRtGjpKYj6Wtc1GdNdKhg)(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = (*s).loc.r;
	{
		if (!(result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19));
			if (!(T7_)) goto LA8_;
			T7_ = validJsName__DirUT0y4T1sHsJo7dddJ2w((*(*s).name).s);
			LA8_: ;
			if (!T7_) goto LA9_;
			result = rope__yShmEg9cffWxI7s5XzEKBow((*(*s).name).s);
		}
		goto LA5_;
		LA9_: ;
		{
			NimStringDesc* T14_;
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5))) goto LA12_;
			T14_ = (NimStringDesc*)0;
			T14_ = mangle__GxzvEIRbrShQbyJNboTw7A((*(*s).name).s);
			result = rope__yShmEg9cffWxI7s5XzEKBow(T14_);
		}
		goto LA5_;
		LA12_: ;
		{
			NimStringDesc* x;
			NI i;
			x = rawNewString(((NI) (((*(*s).name).s ? (*(*s).name).s->Sup.len : 0))));
			i = ((NI) 0);
			{
				while (1) {
					NIM_CHAR c;
					if (!(i < ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0))) goto LA17;
					c = (*(*s).name).s->data[i];
					switch (((NU8)(c))) {
					case 65 ... 90:
					case 97 ... 122:
					case 95:
					case 48 ... 57:
					{
						x = addChar(x, c);
					}
					break;
					default:
					{
						NimStringDesc* T20_;
						NimStringDesc* T21_;
						T20_ = (NimStringDesc*)0;
						T21_ = (NimStringDesc*)0;
						T21_ = toHex__TwQ1R2wlkmY9ak7KGbc718A(((NU8)(c)), ((NI) 2));
						T20_ = rawNewString((T21_ ? T21_->Sup.len : 0) + 3);
appendString(T20_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_87));
appendString(T20_, T21_);
						x = resizeString(x, (T20_ ? T20_->Sup.len : 0) + 0);
appendString(x, T20_);
					}
					break;
					}
					i += ((NI) 1);
				} LA17: ;
			}
			result = rope__yShmEg9cffWxI7s5XzEKBow(x);
		}
		LA5_: ;
		{
			if (!!(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19)))) goto LA24_;
			{
				NIM_BOOL T28_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
				T28_ = (NIM_BOOL)0;
				T28_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*m).config);
				if (!T28_) goto LA29_;
				T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T31_ = idOrSig__sKAFwdXn9cKHxc9cdaovk69cA(s, (*(*(*m).module).name).s, (&(*m).sigConflicts));
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T31_);
			}
			goto LA26_;
			LA29_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
				add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_88));
				T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T33_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*s).Sup.id)));
				add__IM4kcMNkkOLJtqdEqSxR8A(&result, T33_);
			}
			LA26_: ;
		}
		LA24_: ;
		asgnRef((void**) (&(*s).loc.r), result);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA, mapType__3fHLBKCveV5k5hDCMQOL2g)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
			T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T4_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T5_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T4_, IL64(36134350135273744));
			if (!((IL64(281475111911424) &((NU64)1<<((NU)((*T5_).kind)&63U)))!=0)) goto LA6_;
			result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8);
		}
		goto LA2_;
		LA6_: ;
		{
			result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50):
	{
		result = mapType__3fHLBKCveV5k5hDCMQOL2g((*t).sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 5);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 3);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 6);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 4);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 1);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
		T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T20_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = mapType__3fHLBKCveV5k5hDCMQOL2g(T20_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T26_;
			if (!!(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA24_;
			T26_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T26_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			result = mapType__3fHLBKCveV5k5hDCMQOL2g(T26_);
		}
		goto LA22_;
		LA24_: ;
		{
			result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
		}
		LA22_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 2);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		result = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 7);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 62):
	{
		{
			if (!NIM_TRUE) goto LA33_;
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_90));
		}
		LA33_: ;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA, mapType__ZlkXBdJTrpToZuRLq31tLQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA result;
	result = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
	result = mapType__3fHLBKCveV5k5hDCMQOL2g(typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, putToSeq__iEKLYo8HXYG9auKlJ6tkKKw)(NimStringDesc* s, NIM_BOOL indirect) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = rope__yShmEg9cffWxI7s5XzEKBow(s);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		if (!indirect) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = result;
		result = percent___mPpmmd13MIZLTbd1oOdSkw(T5_, 1);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, arrayTypeForElemType__Ef4AI5l7XLzo8SqxARtdiQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch ((*typ).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_95));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_96));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_97));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_98));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_99));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_100));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_101));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36):
	{
		result = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_102));
	}
	break;
	default:
	{
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	}
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_103));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_105));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((IL64(1152921504606847232) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, generateHeader__jZNTi9aEbLMAMESBZ7a9cl7A)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
					param = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T7_;
						T7_ = (NIM_BOOL)0;
						T7_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*param).typ);
						if (!T7_) goto LA8_;
						goto LA4;
					}
					LA8_: ;
					{
						if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA12_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
					}
					LA12_: ;
					name = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, param);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, name);
					{
						tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T16_;
						T16_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
						T16_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*param).typ);
						if (!(T16_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA17_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
						add__IM4kcMNkkOLJtqdEqSxR8A(&result, name);
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_107));
					}
					LA17_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, lineDir__l8iC2NnHymiEfpCjUoNB9cg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI line) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	NimStringDesc* T2_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T2_ = (NimStringDesc*)0;
	T2_ = toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(config, info.fileIndex);
	T1_[0] = rope__yShmEg9cffWxI7s5XzEKBow(T2_);
	T1_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (line)));
	result = percent___6xseTZmgyslBQb6RMm9b4wA(T1_, 2);
	return result;
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, optionalLine__VuwqVIjxPGcoTVF06Jgl6w)(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!(p == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		result = amp___Z7W1o5nPSc3ExfO5f7j1Gg(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_109));
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasFrameInfo__eUoj4FPs7h9bV16Cz4RajiA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((655360 & (*p).options) == 655360);
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	if (T3_) goto LA4_;
	T3_ = !((((*(*p).prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, frameDestroy__XP5ZeYFuxYow89aSkFgfWeg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_110));
	result = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProcBody__ByRZ0N9c4W9b5ThEZxre89cFg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		NimStringDesc* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasFrameInfo__eUoj4FPs7h9bV16Cz4RajiA(p);
		if (!T3_) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = rawNewString(((*(*(*prc).owner).name).s ? (*(*(*prc).owner).name).s->Sup.len : 0) + ((*(*prc).name).s ? (*(*prc).name).s->Sup.len : 0) + 1);
appendString(T6_, (*(*(*prc).owner).name).s);
appendChar(T6_, 46);
appendString(T6_, (*(*prc).name).s);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T6_, NIM_TRUE);
		T8_ = (NimStringDesc*)0;
		T8_ = toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA((*(*p).module).config, (*prc).info.fileIndex, ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 4));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T8_, NIM_TRUE);
		result = frameCreate__5xQGffjrmjbHfz64yWZ49bw(p, T7_, T9_);
	}
	goto LA1_;
	LA4_: ;
	{
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	LA1_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		if (!(*p).beforeRetNeeded) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = percent___hFzCKQOJ8Eao2AJk5HOvxA(T15_, 0);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T16_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T17_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*p).body);
		nimZeroMem((void*)T18_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = percent___62079cK9bsws1aAJqEmAGo6w(T18_, 0);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T19_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T20_);
	}
	goto LA11_;
	LA13_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, (*p).body);
	}
	LA11_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T26_;
		if (!((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 4))) goto LA24_;
		nimZeroMem((void*)T26_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T26_[0] = result;
		result = percent___hO1UTpWJhaojnhUyqfmgPQ(T26_, 1);
	}
	LA24_: ;
	{
		NIM_BOOL T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T32_;
		T29_ = (NIM_BOOL)0;
		T29_ = hasFrameInfo__eUoj4FPs7h9bV16Cz4RajiA(p);
		if (!T29_) goto LA30_;
		T32_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T32_ = frameDestroy__XP5ZeYFuxYow89aSkFgfWeg(p);
		add__IM4kcMNkkOLJtqdEqSxR8A(&result, T32_);
	}
	LA30_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genProc__VRfKzQHOMcRGtJXZSJxFtg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* oldProc, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* resultSym;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* returnStmt;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resultAsgn;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* header;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* def;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T70_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T71_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T72_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	resultSym = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	p = newProc__T4OlZpX8DqYbIlMcOrFsUQ((*oldProc).g, (*oldProc).module, (*prc).ast, (*prc).options);
	asgnRef((void**) (&(*p).up), oldProc);
	returnStmt = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	resultAsgn = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	name = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, prc);
	header = generateHeader__jZNTi9aEbLMAMESBZ7a9cl7A(p, (*prc).typ);
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* mname;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*prc).typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = !((((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 11))&63U)))!=0));
		LA4_: ;
		if (!T3_) goto LA5_;
		resultSym = (*(*(*prc).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym;
		mname = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, resultSym);
		{
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym1104_;
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T17_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T20_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			vX60gensym1104_ = resultSym;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T12_ = !(((131080 & (*vX60gensym1104_).flags) == 0));
			if (!(T12_)) goto LA13_;
			T12_ = ((192 & (*vX60gensym1104_).flags) == 0);
			LA13_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA14_;
			T11_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym1104_).kind)&31U)))!=0));
			LA14_: ;
			T10_ = !(T11_);
			if (!(T10_)) goto LA15_;
			T10_ = ((IL64(175921875124224) &((NU64)1<<((NU)((*(*resultSym).typ).kind)&63U)))!=0);
			LA15_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA16_;
			T17_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T17_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*resultSym).typ);
			T9_ = (T17_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
			LA16_: ;
			if (!T9_) goto LA18_;
			nimZeroMem((void*)T20_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T20_[0] = mname;
			T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T21_ = percent___3RPy0XXevrEBMts1Mb9arGw(T20_, 1);
			resultAsgn = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T21_);
			nimZeroMem((void*)T22_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T22_[0] = mname;
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = percent___gqwqalZtiJtCgAF9bY5S6qQ(T22_, 1);
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T23_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&resultAsgn, T24_);
		}
		goto LA7_;
		LA18_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* resVar;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym1108_;
			NIM_BOOL T26_;
			NIM_BOOL T27_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			vX60gensym1108_ = resultSym;
			T26_ = (NIM_BOOL)0;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((131080 & (*vX60gensym1108_).flags) == 0));
			if (!(T27_)) goto LA28_;
			T27_ = ((192 & (*vX60gensym1108_).flags) == 0);
			LA28_: ;
			T26_ = T27_;
			if (!(T26_)) goto LA29_;
			T26_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym1108_).kind)&31U)))!=0));
			LA29_: ;
			resVar = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, (*resultSym).typ, T26_);
			nimZeroMem((void*)T30_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T30_[0] = mname;
			T30_[1] = resVar;
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = percent___G9bYX9bu7ufcttiARCDUJ0qg(T30_, 2);
			resultAsgn = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T31_);
		}
		LA7_: ;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*prc).ast)._kind_6.sons->data[((NI) 7)], (&a));
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T34_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T37_;
			T34_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T34_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*resultSym).typ);
			if (!(T34_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA35_;
			nimZeroMem((void*)T37_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T37_[0] = a.address;
			T37_[1] = a.res;
			returnStmt = percent___W0CV9bE9bNiLgazfFZjoQCBg(T37_, 2);
		}
		goto LA32_;
		LA35_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T39_;
			nimZeroMem((void*)T39_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T39_[0] = a.res;
			returnStmt = percent___ecC7jlB6gBWrt0K9byHohPw(T39_, 1);
		}
		LA32_: ;
	}
	LA5_: ;
	transformedBody = transformBody__ocxOgPRHWfivNZELIhOv7w((*(*oldProc).module).graph, prc, NIM_FALSE);
	{
		if (!(((*prc).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41))&63U)))!=0)) goto LA42_;
		transformedBody = injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ((*(*oldProc).module).graph, prc, transformedBody);
	}
	LA42_: ;
	(*p).extraIndent += ((NI) 1);
	genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, transformedBody);
	(*p).extraIndent -= ((NI) 1);
	{
		NI T48_;
		if (!(((*(*(*p).module).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0)) goto LA46_;
		T48_ = (NI)0;
		T48_ = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs((*prc).info);
		result = lineDir__l8iC2NnHymiEfpCjUoNB9cg((*(*p).module).config, (*prc).info, T48_);
	}
	LA46_: ;
	def = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		NimStringDesc* T53_;
		tyArray__wm6rkCVggH4IozhLUEP19bg T54_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T55_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T57_;
		if (!!(((*prc).constraint == 0))) goto LA51_;
		T53_ = (NimStringDesc*)0;
		T53_ = rawNewString(((*(*prc).constraint)._kind_3.strVal ? (*(*prc).constraint)._kind_3.strVal->Sup.len : 0) + 14);
appendString(T53_, (*(*prc).constraint)._kind_3.strVal);
appendString(T53_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_108));
		nimZeroMem((void*)T54_, sizeof(tyArray__wm6rkCVggH4IozhLUEP19bg));
		nimZeroMem((void*)T55_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T54_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T55_, 0);
		T54_[1] = name;
		T54_[2] = header;
		T54_[3] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w((*p).globals);
		T54_[4] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w((*p).locals);
		T54_[5] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(resultAsgn);
		T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T56_ = genProcBody__ByRZ0N9c4W9b5ThEZxre89cFg(p, prc);
		T54_[6] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(T56_);
		T57_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T57_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, returnStmt);
		T54_[7] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(T57_);
		def = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T53_, T54_, 8);
	}
	goto LA49_;
	LA51_: ;
	{
		tyArray__YcHYlgE5mhtkt9a3rnoucVg T66_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
		{
			NIM_BOOL T61_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* thunkName;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T64_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T65_;
			T61_ = (NIM_BOOL)0;
			T61_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*(*p).module).config);
			if (!T61_) goto LA62_;
			thunkName = name;
			name = amp___Z7W1o5nPSc3ExfO5f7j1Gg(name, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_111));
			nimZeroMem((void*)T64_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T64_[0] = thunkName;
			T64_[1] = name;
			T65_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T65_ = percent___uD0SC9bUeWpB9cK7V1aBT9aNQ(T64_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&result, T65_);
		}
		LA62_: ;
		nimZeroMem((void*)T66_, sizeof(tyArray__YcHYlgE5mhtkt9a3rnoucVg));
		T66_[0] = name;
		T66_[1] = header;
		T66_[2] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w((*p).globals);
		T66_[3] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w((*p).locals);
		T66_[4] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(resultAsgn);
		T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T67_ = genProcBody__ByRZ0N9c4W9b5ThEZxre89cFg(p, prc);
		T66_[5] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(T67_);
		T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T68_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, returnStmt);
		T66_[6] = optionalLine__VuwqVIjxPGcoTVF06Jgl6w(T68_);
		def = percent___Uez7zQbKzeDFToq2Yh43bA(T66_, 7);
	}
	LA49_: ;
	(*p).extraIndent -= ((NI) 1);
	T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T69_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, def);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T69_);
	nimZeroMem((void*)T70_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T71_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T71_ = percent___BYiowJAm8zF7RBRISElaLg(T70_, 0);
	T72_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T72_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T71_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&result, T72_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, useMagic__4MoUWv1cpa6oOBwwpQ0wfA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, NimStringDesc* name) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	{
		if (!((name ? name->Sup.len : 0) == ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	s = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA((*(*p).module).graph, name);
	{
		if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
		{
			NimStringDesc* argX60gensym87_;
			if (!!(((94208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0))) goto LA11_;
			argX60gensym87_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_106);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym87_, TM__BxLwT0mhrtgTPodf1v3xjg_106);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
			T15_ = (NIM_BOOL)0;
			T15_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).g).generatedSyms), (*s).Sup.id);
			if (!!(T15_)) goto LA16_;
			code = genProc__VRfKzQHOMcRGtJXZSJxFtg(p, s);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).constants, code);
		}
		LA16_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		{
			NimStringDesc* T23_;
			if (!!(((*p).prc == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA21_;
			T23_ = (NimStringDesc*)0;
			T23_ = rawNewString((name ? name->Sup.len : 0) + 21);
appendString(T23_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_112));
appendString(T23_, name);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*(*p).prc).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T23_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__BxLwT0mhrtgTPodf1v3xjg_113, NIM_FALSE);
		}
		goto LA19_;
		LA21_: ;
		{
			NimStringDesc* T25_;
			T25_ = (NimStringDesc*)0;
			T25_ = rawNewString((name ? name->Sup.len : 0) + 21);
appendString(T25_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_112));
appendString(T25_, name);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T25_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 1), TM__BxLwT0mhrtgTPodf1v3xjg_114, NIM_FALSE);
		}
		LA19_: ;
	}
	LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__EoO5XDgy69ax76bvbHbf27w)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* n;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T19_;
	NI T20_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T21_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T22_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
	s = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
				NimStringDesc* extName;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T17_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!!(((*(*(*typ).n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA6_;
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*typ).n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_117), TM__BxLwT0mhrtgTPodf1v3xjg_118);
				}
				LA6_: ;
				field = (*(*(*typ).n)._kind_6.sons->data[i])._kind_4.sym;
				{
					if (!(((NI) 0) < i)) goto LA10_;
					add__yG4AKzsBRS1W4MANDlXQeg(&s, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_120));
				}
				LA10_: ;
				{
					if (!((*field).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA14_;
					extName = (*(*field).name).s;
				}
				goto LA12_;
				LA14_: ;
				{
					extName = (*(*field).ast)._kind_3.strVal;
				}
				LA12_: ;
				nimZeroMem((void*)T17_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T17_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*field).position)));
				T17_[1] = name;
				T17_[2] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(extName, NIM_TRUE);
				T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T18_ = percent___gGKEcvCOVzpTQoSXzO01Dw(T17_, 3);
				add__IM4kcMNkkOLJtqdEqSxR8A(&s, T18_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	nimZeroMem((void*)T19_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T19_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T20_ = (NI)0;
	T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*typ).n);
	T19_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T20_)));
	T19_[2] = s;
	n = percent___LMnNsJkYlruXHnF5LV9c3pA(T19_, 3);
	nimZeroMem((void*)T21_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T21_[0] = name;
	T21_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).kind)));
	s = percent___uJ11bTQ8dBBAX88A2cyICw(T21_, 2);
	prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, n);
	nimZeroMem((void*)T22_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T22_[0] = name;
	T22_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T23_ = percent___2D3IUNoEAKKLxuRqVNosPQ(T22_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T23_);
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		if (!!(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA26_;
		nimZeroMem((void*)T28_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T28_[0] = name;
		T28_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*typ).sons->data[((NI) 0)]);
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = percent___HUHatwko3S0fuszXQAOSQQ(T28_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T29_);
	}
	LA26_: ;
}
static N_INLINE(NIM_BOOL, objHasTypeField__RtD7YfxmsbodfSCx5S9bFnAjsgen)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 3))&63U)))!=0);
	if (T1_) goto LA2_;
	T1_ = !(((*t).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rope__oMf9cufugVin4CJLwmEes2A)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = dollar___W2wbDjPGDCaBwLQM6yLUQg(arg);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* u;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	s = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	u = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	field = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T4_ == ((NI) 1))) goto LA5_;
			result = genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g(p, typ, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		goto LA2_;
		LA5_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
			NI T17_;
			s = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						{
							if (!(((NI) 0) < i)) goto LA13_;
							add__yG4AKzsBRS1W4MANDlXQeg(&s, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_120));
						}
						LA13_: ;
						T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T15_ = genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g(p, typ, (*n)._kind_6.sons->data[i]);
						add__IM4kcMNkkOLJtqdEqSxR8A(&s, T15_);
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
			nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T17_ = (NI)0;
			T17_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T16_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T17_)));
			T16_[1] = s;
			result = percent___Ht0mWR3LosfEZ8SopJcmEA(T16_, 2);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T19_;
		field = (*n)._kind_4.sym;
		s = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*field).typ);
		nimZeroMem((void*)T19_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T19_[0] = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, field);
		T19_[1] = s;
		T19_[2] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*(*field).name).s, NIM_TRUE);
		result = percent___GweM9byC8cQI9cehUzlYVs5A(T19_, 3);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		tyArray__duFhZXIIlrbrM62cWjNekg T63_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T64_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA23_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_121), TM__BxLwT0mhrtgTPodf1v3xjg_122);
		}
		LA23_: ;
		field = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		s = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*field).typ);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T60_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T61_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
					if (!(i_4 < colontmp__2)) goto LA27;
					i_3 = i_4;
					b = (*n)._kind_6.sons->data[i_3];
					u = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
					switch ((*b).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					{
						{
							NI T31_;
							T31_ = (NI)0;
							T31_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
							if (!(T31_ < ((NI) 2))) goto LA32_;
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*b).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_123), TM__BxLwT0mhrtgTPodf1v3xjg_124);
						}
						LA32_: ;
						{
							NI j;
							NI colontmp__3;
							NI T35_;
							NI i_5;
							j = (NI)0;
							colontmp__3 = (NI)0;
							T35_ = (NI)0;
							T35_ = len__P89cqdlERShb9alU3iC0yj8wast(b);
							colontmp__3 = (NI)(T35_ - ((NI) 1));
							i_5 = ((NI) 0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA37;
									j = i_5;
									{
										if (!!((u == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA40_;
										add__yG4AKzsBRS1W4MANDlXQeg(&u, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
									}
									LA40_: ;
									{
										tyArray__mrugoXXRZUEeG9bEXo9auBKw T46_;
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T47_;
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T48_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
										if (!((*(*b)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA44_;
										nimZeroMem((void*)T46_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
										T47_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 0)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										T46_[0] = rope__oMf9cufugVin4CJLwmEes2A(T47_);
										T48_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*(*b)._kind_6.sons->data[j])._kind_6.sons->data[((NI) 1)], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										T46_[1] = rope__oMf9cufugVin4CJLwmEes2A(T48_);
										T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T49_ = percent___Xnze9a4kYSwHurdPnhyNGzQ(T46_, 2);
										add__IM4kcMNkkOLJtqdEqSxR8A(&u, T49_);
									}
									goto LA42_;
									LA44_: ;
									{
										tyObject_Int128__9a9axPfb75jdWY25AamJewkA T51_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
										T51_ = getOrdValue__GvVg8kpCh7QA2PDTJnFJlQ((*b)._kind_6.sons->data[j], Max__zlJMNfqX7LwCYj0PF6ncWQ);
										T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T52_ = rope__oMf9cufugVin4CJLwmEes2A(T51_);
										add__IM4kcMNkkOLJtqdEqSxR8A(&u, T52_);
									}
									LA42_: ;
									i_5 += ((NI) 1);
								} LA37: ;
							}
						}
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_Int128__9a9axPfb75jdWY25AamJewkA T54_;
						T54_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*p).module).config, (*field).typ);
						u = rope__oMf9cufugVin4CJLwmEes2A(T54_);
					}
					break;
					default:
					{
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_125), TM__BxLwT0mhrtgTPodf1v3xjg_126);
					}
					break;
					}
					{
						if (!!((result == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA58_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_120));
					}
					LA58_: ;
					nimZeroMem((void*)T60_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T60_[0] = u;
					T61_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T61_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(b);
					T60_[1] = genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g(p, typ, T61_);
					T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T62_ = percent___sGaOrvR5YSM9cGUajaqcNOw(T60_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T62_);
					i_4 += ((NI) 1);
				} LA27: ;
			}
		}
		nimZeroMem((void*)T63_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T63_[0] = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, field);
		T63_[1] = s;
		T64_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*p).module).config, (*field).typ);
		T63_[2] = rope__oMf9cufugVin4CJLwmEes2A(T64_);
		T63_[3] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*(*field).name).s, NIM_TRUE);
		T63_[4] = result;
		result = percent___GF60428RM29aXV0LYutm9aOA(T63_, 5);
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_121), TM__BxLwT0mhrtgTPodf1v3xjg_127);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__EoO5XDgy69ax76bvbHbf27w_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name) {
	tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = objHasTypeField__RtD7YfxmsbodfSCx5S9bFnAjsgen(typ);
		if (!T3_) goto LA4_;
		kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17);
	}
	goto LA1_;
	LA4_: ;
	{
		kind = ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18);
	}
	LA1_: ;
	nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T7_[0] = name;
	T7_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (kind)));
	s = percent___uJ11bTQ8dBBAX88A2cyICw(T7_, 2);
	prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s);
	nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T8_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T8_[1] = genObjectFields__9cYkCneeT9aY9avg49aE6JtN6g(p, typ, (*typ).n);
	T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T9_ = percent___o7SGM9buciKf5BOjTvMKA7w(T8_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T9_);
	nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T10_[0] = name;
	T10_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = percent___2D3IUNoEAKKLxuRqVNosPQ(T10_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T11_);
	{
		NIM_BOOL T14_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T18_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		T14_ = (NIM_BOOL)0;
		T14_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		if (!(T14_)) goto LA15_;
		T14_ = !(((*typ).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA15_: ;
		if (!T14_) goto LA16_;
		nimZeroMem((void*)T18_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T18_[0] = name;
		T19_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T19_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*typ).sons->data[((NI) 0)], IL64(36275087638268176));
		T18_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, T19_);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = percent___HUHatwko3S0fuszXQAOSQQ(T18_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T20_);
	}
	LA16_: ;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTupleFields__jZNTi9aEbLMAMESBZ7a9cl7A_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
	NI T11_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	s = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&s, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_120));
				}
				LA6_: ;
				nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T8_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
				T8_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*typ).sons->data[i]);
				T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T9_ = percent___ciTj4q9cGhcXiXY9bPemZVvw(T8_, 2);
				add__IM4kcMNkkOLJtqdEqSxR8A(&s, T9_);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T11_ = (NI)0;
	T11_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
	T10_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T11_)));
	T10_[1] = s;
	result = percent___Ht0mWR3LosfEZ8SopJcmEA(T10_, 2);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__EoO5XDgy69ax76bvbHbf27w_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T4_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T5_;
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = name;
	T1_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).kind)));
	s = percent___uJ11bTQ8dBBAX88A2cyICw(T1_, 2);
	prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s);
	nimZeroMem((void*)T2_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T2_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T2_[1] = genTupleFields__jZNTi9aEbLMAMESBZ7a9cl7A_3(p, typ);
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___o7SGM9buciKf5BOjTvMKA7w(T2_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T3_);
	nimZeroMem((void*)T4_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T4_[0] = name;
	T4_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*typ).Sup.id)));
	T5_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T5_ = percent___2D3IUNoEAKKLxuRqVNosPQ(T4_, 2);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T5_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T1_;
{	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(105553116276752));
	nimZeroMem((void*)T1_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T1_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*t).Sup.id)));
	result = percent___FLXrAGf7HFTHIGh8Xuickg(T1_, 1);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).g).typeInfoGenerated), (*t).Sup.id);
		if (!T4_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	{
		result = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*t).sons->data[((NI) 0)]);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
		nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T9_[0] = result;
		T9_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*t).kind)));
		s = percent___hmfCuT8fgBmRlPR25L7ZOw(T9_, 2);
		prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s_2;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T11_[0] = result;
		T11_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*t).kind)));
		s_2 = percent___hmfCuT8fgBmRlPR25L7ZOw(T11_, 2);
		prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s_2);
		nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T12_[0] = result;
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		T12_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, T13_);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = percent___HUHatwko3S0fuszXQAOSQQ(T12_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T14_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s_3;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T16_[0] = result;
		T16_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*t).kind)));
		s_3 = percent___hmfCuT8fgBmRlPR25L7ZOw(T16_, 2);
		prepend__IM4kcMNkkOLJtqdEqSxR8A_2(&(*(*p).g).typeInfo, s_3);
		nimZeroMem((void*)T17_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T17_[0] = result;
		T17_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*t).sons->data[((NI) 1)]);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = percent___HUHatwko3S0fuszXQAOSQQ(T17_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).typeInfo, T18_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		genEnumInfo__EoO5XDgy69ax76bvbHbf27w(p, t, result);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		genObjectInfo__EoO5XDgy69ax76bvbHbf27w_2(p, t, result);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		genTupleInfo__EoO5XDgy69ax76bvbHbf27w_3(p, t, result);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T27_;
			if (!!(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA25_;
			T27_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T27_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			result = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, T27_);
		}
		goto LA23_;
		LA25_: ;
		{
			NimStringDesc* T29_;
			T29_ = (NimStringDesc*)0;
			T29_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 13);
appendString(T29_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_128));
appendString(T29_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T29_, 41);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T29_, TM__BxLwT0mhrtgTPodf1v3xjg_129);
		}
		LA23_: ;
	}
	break;
	default:
	{
		NimStringDesc* T31_;
		T31_ = (NimStringDesc*)0;
		T31_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 13);
appendString(T31_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_128));
appendString(T31_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T31_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T31_, TM__BxLwT0mhrtgTPodf1v3xjg_130);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((IL64(-9223372036854775680) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rec, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excludedFieldIDs, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** output) {
{	switch ((*rec).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(rec);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA(p, (*rec)._kind_6.sons->data[i], excludedFieldIDs, output);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA(p, (*rec)._kind_6.sons->data[((NI) 0)], excludedFieldIDs, output);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(rec);
			i_4 = ((NI) 1);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T9_;
					if (!(i_4 < colontmp__2)) goto LA8;
					i_3 = i_4;
					T9_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T9_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*rec)._kind_6.sons->data[i_3]);
					createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA(p, T9_, excludedFieldIDs, output);
					i_4 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*(*rec)._kind_4.sym).typ);
			if (!T13_) goto LA14_;
			goto BeforeRet_;
		}
		LA14_: ;
		{
			NIM_BOOL T18_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
			T18_ = (NIM_BOOL)0;
			T18_ = contains__R6uRTGpl30Ofaw4Ni3vawA(excludedFieldIDs, (*(*rec)._kind_4.sym).Sup.id);
			if (!!(T18_)) goto LA19_;
			{
				NI T23_;
				T23_ = (NI)0;
				T23_ = len__9b0YRltzV3kNSE9aQTsG82wg((*output));
				if (!(((NI) 0) < T23_)) goto LA24_;
				add__yG4AKzsBRS1W4MANDlXQeg(output, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
			}
			LA24_: ;
			nimZeroMem((void*)T26_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T26_[0] = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, (*rec)._kind_4.sym);
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = percent___S6XcU2shl8EfYxL7utXbwg(T26_, 1);
			add__IM4kcMNkkOLJtqdEqSxR8A(output, T27_);
			T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T28_ = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, (*(*rec)._kind_4.sym).typ, NIM_FALSE);
			add__IM4kcMNkkOLJtqdEqSxR8A(output, T28_);
		}
		LA19_: ;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*rec).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_135), TM__BxLwT0mhrtgTPodf1v3xjg_136);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, createObjInitList__lQPYSYugh4oxbm9bTJCSJoA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* excludedFieldIDs, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA** output) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = typ;
	{
		NIM_BOOL T3_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		T3_ = (NIM_BOOL)0;
		T3_ = objHasTypeField__RtD7YfxmsbodfSCx5S9bFnAjsgen(t);
		if (!T3_) goto LA4_;
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__9b0YRltzV3kNSE9aQTsG82wg((*output));
			if (!(((NI) 0) < T8_)) goto LA9_;
			add__yG4AKzsBRS1W4MANDlXQeg(output, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
		}
		LA9_: ;
		nimZeroMem((void*)T11_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T11_[0] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___tnP9cO5PduJRSEeqtm9bocEg(T11_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(output, T12_);
	}
	LA4_: ;
	{
		while (1) {
			if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA14;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36275087638268176));
			createRecordVarAux__yyLC0N4Jogp3ojVKBnvQXA(p, (*t).n, excludedFieldIDs, output);
			t = (*t).sons->data[((NI) 0)];
		} LA14: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, createVar__K9ag9aJJIngrApxv9aEbfdhIQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NIM_BOOL indirect) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350135273744));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_92), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_93), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
		T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T4_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(typ);
		result = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, T4_, indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_94), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_45), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_63), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		NI length;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* e;
		NimStringDesc* jsTyp;
		T9_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*p).module).config, t);
		length = toInt__TIX0sFuRf3uBpOBltYp7bw(T9_);
		e = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(t);
		jsTyp = arrayTypeForElemType__Ef4AI5l7XLzo8SqxARtdiQ(e);
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T14_;
			if (!(((NI) 0) < (jsTyp ? jsTyp->Sup.len : 0))) goto LA12_;
			nimZeroMem((void*)T14_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T14_[0] = rope__yShmEg9cffWxI7s5XzEKBow(jsTyp);
			T14_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (length)));
			result = percent___Th3qC4WgcAhWPSlLw7vZ9cg(T14_, 2);
		}
		goto LA10_;
		LA12_: ;
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T18_;
			if (!(((NI) 32) < length)) goto LA16_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_115));
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
			nimZeroMem((void*)T18_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T18_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (length)));
			T18_[1] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, e, NIM_FALSE);
			T18_[2] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, e);
			result = percent___JbygmsEkVsyK85BPVFvwbg(T18_, 3);
		}
		goto LA10_;
		LA16_: ;
		{
			NI i;
			result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_131));
			i = ((NI) 0);
			{
				while (1) {
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					if (!(i < length)) goto LA21;
					{
						if (!(((NI) 0) < i)) goto LA24_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
					}
					LA24_: ;
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, e, NIM_FALSE);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T26_);
					i += ((NI) 1);
				} LA21: ;
			}
			add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_132));
		}
		LA10_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T31_;
			if (!indirect) goto LA29_;
			nimZeroMem((void*)T31_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T31_[0] = result;
			result = percent___mPpmmd13MIZLTbd1oOdSkw(T31_, 1);
		}
		LA29_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_133));
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T40_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T41_;
					if (!(i_3 < colontmp_)) goto LA35;
					i_2 = i_3;
					{
						if (!(((NI) 0) < i_2)) goto LA38_;
						add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
					}
					LA38_: ;
					nimZeroMem((void*)T40_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T40_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i_2)));
					T40_[1] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, (*t).sons->data[i_2], NIM_FALSE);
					T41_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T41_ = percent___HLoe040Vi0LPzmTid9aLGdw(T40_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&result, T41_);
					i_3 += ((NI) 1);
				} LA35: ;
			}
		}
		add__yG4AKzsBRS1W4MANDlXQeg(&result, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_134));
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T46_;
			if (!indirect) goto LA44_;
			nimZeroMem((void*)T46_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T46_[0] = result;
			result = percent___mPpmmd13MIZLTbd1oOdSkw(T46_, 1);
		}
		LA44_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* initList;
		tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg T48_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T49_;
		initList = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		nimZeroMem((void*)(&T48_), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
		initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&T48_));
		createObjInitList__lQPYSYugh4oxbm9bTJCSJoA(p, t, (&T48_), &initList);
		nimZeroMem((void*)T49_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T49_[0] = initList;
		result = percent___3GvB8fuMNh8BXF8IoORCxw(T49_, 1);
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T54_;
			if (!indirect) goto LA52_;
			nimZeroMem((void*)T54_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T54_[0] = result;
			result = percent___mPpmmd13MIZLTbd1oOdSkw(T54_, 1);
		}
		LA52_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T58_;
			T58_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T58_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, t);
			if (!(T58_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA59_;
			result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_137), indirect);
		}
		goto LA56_;
		LA59_: ;
		{
			result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_63), indirect);
		}
		LA56_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_138), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		result = putToSeq__iEKLYo8HXYG9auKlJ6tkKKw(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_63), indirect);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T69_;
			if (!!(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA67_;
			T69_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T69_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			result = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, T69_, indirect);
		}
		goto LA65_;
		LA67_: ;
		{
			NimStringDesc* T71_;
			T71_ = (NimStringDesc*)0;
			T71_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 11);
appendString(T71_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_139));
appendString(T71_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T71_, TM__BxLwT0mhrtgTPodf1v3xjg_140);
			result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
		}
		LA65_: ;
	}
	break;
	default:
	{
		NimStringDesc* T73_;
		T73_ = (NimStringDesc*)0;
		T73_ = rawNewString((reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 11);
appendString(T73_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_139));
appendString(T73_, reprEnum((NI)(*t).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T73_, TM__BxLwT0mhrtgTPodf1v3xjg_141);
		result = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsNoCopy__AeBLus9crC8L5HbMOYikwJw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T4_;
	tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T5_;
	NIM_BOOL T7_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((TM__BxLwT0mhrtgTPodf1v3xjg_142[(NU)((*y).kind)>>3] &(1U<<((NU)((*y).kind)&7U)))!=0);
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T4_ = (NIM_BOOL)0;
	T5_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
	T5_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*y).typ);
	T4_ = !((T5_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)));
	if (T4_) goto LA6_;
	T7_ = (NIM_BOOL)0;
	T7_ = ((*y).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T7_)) goto LA8_;
	T7_ = ((*(*y)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
	LA8_: ;
	T4_ = T7_;
	LA6_: ;
	T3_ = T4_;
	if (!(T3_)) goto LA9_;
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*y).typ, IL64(36134350135273744));
	T3_ = ((IL64(211104670171142) &((NU64)1<<((NU)((*T10_).kind)&63U)))!=0);
	LA9_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, getTemp__EG8bDinaW3fVLpok9a4s5cA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, NIM_BOOL defineInLocals) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T1_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	(*p).unique += ((NI) 1);
	nimZeroMem((void*)T1_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T1_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).unique)));
	result = percent___CSdlEV0i9aXEHNuC1G9aIEbw(T1_, 1);
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		if (!defineInLocals) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = result;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___TLpRy9aDJ1Ni4vccOIoiMbA(T6_, 1);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T7_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).locals, T8_);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarInit__iVEhpHbcyNY9aOzPqLze8xw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* s;
	NimStringDesc* varCode;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* varName;
	NIM_BOOL useReloadingGuard;
	NIM_BOOL T1_;
	NIM_BOOL useGlobalPragmas;
	NIM_BOOL T3_;
{	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	s = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	varCode = (NimStringDesc*)0;
	varName = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, v);
	T1_ = (NIM_BOOL)0;
	T1_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*(*p).module).config);
	LA2_: ;
	useReloadingGuard = T1_;
	T3_ = (NIM_BOOL)0;
	T3_ = (((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0);
	if (!(T3_)) goto LA4_;
	T3_ = !(((67110912 & (*v).flags) == 0));
	LA4_: ;
	useGlobalPragmas = T3_;
	{
		if (!((*v).constraint == 0)) goto LA7_;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
			if (!useReloadingGuard) goto LA11_;
			nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T13_[0] = varName;
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = percent___TLpRy9aDJ1Ni4vccOIoiMbA(T13_, 1);
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T14_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T15_);
			nimZeroMem((void*)T16_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T16_[0] = varName;
			T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T17_ = percent___Z1QwTAihBHnxe59cytXnhmw(T16_, 1);
			T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T18_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T17_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T18_);
			varCode = dollar___mZ66tEveFIQokq3arf8Klw(varName);
			(*p).extraIndent += ((NI) 1);
		}
		goto LA9_;
		LA11_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T22_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
			if (!useGlobalPragmas) goto LA20_;
			nimZeroMem((void*)T22_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T22_[0] = varName;
			T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T23_ = percent___57MdwiGSzJJwBASUKz9cDIw(T22_, 1);
			T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T24_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T23_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T24_);
			varCode = dollar___mZ66tEveFIQokq3arf8Klw(varName);
			(*p).extraIndent += ((NI) 1);
		}
		goto LA9_;
		LA20_: ;
		{
			varCode = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_89));
		}
		LA9_: ;
	}
	goto LA5_;
	LA7_: ;
	{
		varCode = copyString((*(*v).constraint)._kind_3.strVal);
	}
	LA5_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA29_;
		{
			NIM_BOOL T33_;
			NIM_BOOL T34_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym776_;
			NIM_BOOL T35_;
			NIM_BOOL T36_;
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T41_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
			T33_ = (NIM_BOOL)0;
			T34_ = (NIM_BOOL)0;
			vX60gensym776_ = v;
			T35_ = (NIM_BOOL)0;
			T36_ = (NIM_BOOL)0;
			T36_ = !(((131080 & (*vX60gensym776_).flags) == 0));
			if (!(T36_)) goto LA37_;
			T36_ = ((192 & (*vX60gensym776_).flags) == 0);
			LA37_: ;
			T35_ = T36_;
			if (!(T35_)) goto LA38_;
			T35_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym776_).kind)&31U)))!=0));
			LA38_: ;
			T34_ = !(T35_);
			if (!(T34_)) goto LA39_;
			T34_ = ((IL64(175921875124224) &((NU64)1<<((NU)((*(*v).typ).kind)&63U)))!=0);
			LA39_: ;
			T33_ = T34_;
			if (!(T33_)) goto LA40_;
			T41_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T41_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*v).typ);
			T33_ = (T41_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
			LA40_: ;
			if (!T33_) goto LA42_;
			nimZeroMem((void*)T44_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T44_[0] = varName;
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = percent___XZnCV59at0sqX6ShEjlFLgw(T44_, 1);
			T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T46_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T45_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T46_);
			nimZeroMem((void*)T47_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T47_[0] = varName;
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = percent___YLzwVVtf4fuPYZVeMQOa0Q(T47_, 1);
			T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T49_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T48_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T49_);
		}
		goto LA31_;
		LA42_: ;
		{
			NimStringDesc* T51_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T52_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T53_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym784_;
			NIM_BOOL T54_;
			NIM_BOOL T55_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T58_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
			T51_ = (NimStringDesc*)0;
			T51_ = rawNewString((varCode ? varCode->Sup.len : 0) + 8);
appendString(T51_, varCode);
appendString(T51_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_91));
			nimZeroMem((void*)T52_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			nimZeroMem((void*)T53_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T52_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T53_, 0);
			T52_[1] = varName;
			vX60gensym784_ = v;
			T54_ = (NIM_BOOL)0;
			T55_ = (NIM_BOOL)0;
			T55_ = !(((131080 & (*vX60gensym784_).flags) == 0));
			if (!(T55_)) goto LA56_;
			T55_ = ((192 & (*vX60gensym784_).flags) == 0);
			LA56_: ;
			T54_ = T55_;
			if (!(T54_)) goto LA57_;
			T54_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym784_).kind)&31U)))!=0));
			LA57_: ;
			T52_[2] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, (*v).typ, T54_);
			T58_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T58_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T51_, T52_, 3);
			T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T59_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T58_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T59_);
		}
		LA31_: ;
	}
	goto LA27_;
	LA29_: ;
	{
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T61_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, n, (&a));
		T61_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T61_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*v).typ);
		switch (T61_) {
		case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8):
		case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 4):
		{
			{
				NIM_BOOL T65_;
				T65_ = (NIM_BOOL)0;
				T65_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, n);
				if (!T65_) goto LA66_;
				s = a.res;
			}
			goto LA63_;
			LA66_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T69_;
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
				nimZeroMem((void*)T69_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T69_[0] = a.res;
				T69_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*n).typ);
				s = percent___RhAtD9c9aECDorIc8rDhMF9bw(T69_, 2);
			}
			LA63_: ;
		}
		break;
		case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9):
		{
			NIM_BOOL targetBaseIndex;
			targetBaseIndex = ((131080 & (*v).flags) == 0);
			{
				if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA73_;
				{
					NimStringDesc* T79_;
					tyArray__f7nG5LD47BH5K9c6mASit3g T80_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T81_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T82_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
					if (!targetBaseIndex) goto LA77_;
					T79_ = (NimStringDesc*)0;
					T79_ = rawNewString((varCode ? varCode->Sup.len : 0) + 21);
appendString(T79_, varCode);
appendString(T79_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_143));
					nimZeroMem((void*)T80_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
					nimZeroMem((void*)T81_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T80_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T81_, 0);
					T80_[1] = (*v).loc.r;
					T80_[2] = a.address;
					T80_[3] = a.res;
					T82_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T82_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T79_, T80_, 4);
					T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T83_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T82_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T83_);
				}
				goto LA75_;
				LA77_: ;
				{
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym791_;
						NIM_BOOL T87_;
						NIM_BOOL T88_;
						NimStringDesc* T93_;
						tyArray__f7nG5LD47BH5K9c6mASit3g T94_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T95_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T96_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T97_;
						vX60gensym791_ = v;
						T87_ = (NIM_BOOL)0;
						T88_ = (NIM_BOOL)0;
						T88_ = !(((131080 & (*vX60gensym791_).flags) == 0));
						if (!(T88_)) goto LA89_;
						T88_ = ((192 & (*vX60gensym791_).flags) == 0);
						LA89_: ;
						T87_ = T88_;
						if (!(T87_)) goto LA90_;
						T87_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym791_).kind)&31U)))!=0));
						LA90_: ;
						if (!T87_) goto LA91_;
						T93_ = (NimStringDesc*)0;
						T93_ = rawNewString((varCode ? varCode->Sup.len : 0) + 16);
appendString(T93_, varCode);
appendString(T93_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_144));
						nimZeroMem((void*)T94_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
						nimZeroMem((void*)T95_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T94_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T95_, 0);
						T94_[1] = (*v).loc.r;
						T94_[2] = a.address;
						T94_[3] = a.res;
						T96_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T96_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T93_, T94_, 4);
						T97_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T97_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T96_);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T97_);
					}
					goto LA85_;
					LA91_: ;
					{
						NimStringDesc* T99_;
						tyArray__f7nG5LD47BH5K9c6mASit3g T100_;
						tyArray__qTjAvTvKF9anytN1At69aJMQ T101_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
						T99_ = (NimStringDesc*)0;
						T99_ = rawNewString((varCode ? varCode->Sup.len : 0) + 14);
appendString(T99_, varCode);
appendString(T99_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_145));
						nimZeroMem((void*)T100_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
						nimZeroMem((void*)T101_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T100_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T101_, 0);
						T100_[1] = (*v).loc.r;
						T100_[2] = a.address;
						T100_[3] = a.res;
						T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T102_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T99_, T100_, 4);
						T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T103_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T102_);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T103_);
					}
					LA85_: ;
				}
				LA75_: ;
			}
			goto LA71_;
			LA73_: ;
			{
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T109_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T110_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T111_;
					if (!targetBaseIndex) goto LA107_;
					tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
					nimZeroMem((void*)T109_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T109_[0] = tmp;
					T109_[1] = a.res;
					T109_[2] = (*v).loc.r;
					T110_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T110_ = percent___4SLS9cx2c8VCFIilepFlOeg(T109_, 3);
					T111_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T111_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T110_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T111_);
				}
				goto LA105_;
				LA107_: ;
				{
					NimStringDesc* T113_;
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T114_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T115_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T116_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
					T113_ = (NimStringDesc*)0;
					T113_ = rawNewString((varCode ? varCode->Sup.len : 0) + 8);
appendString(T113_, varCode);
appendString(T113_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_91));
					nimZeroMem((void*)T114_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					nimZeroMem((void*)T115_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T114_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T115_, 0);
					T114_[1] = (*v).loc.r;
					T114_[2] = a.res;
					T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T116_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T113_, T114_, 3);
					T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T117_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T116_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T117_);
				}
				LA105_: ;
			}
			LA71_: ;
			goto BeforeRet_;
		}
		break;
		default:
		{
			s = a.res;
		}
		break;
		}
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym804_;
			NIM_BOOL T121_;
			NIM_BOOL T122_;
			NimStringDesc* T127_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T128_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T129_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T130_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T131_;
			vX60gensym804_ = v;
			T121_ = (NIM_BOOL)0;
			T122_ = (NIM_BOOL)0;
			T122_ = !(((131080 & (*vX60gensym804_).flags) == 0));
			if (!(T122_)) goto LA123_;
			T122_ = ((192 & (*vX60gensym804_).flags) == 0);
			LA123_: ;
			T121_ = T122_;
			if (!(T121_)) goto LA124_;
			T121_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym804_).kind)&31U)))!=0));
			LA124_: ;
			if (!T121_) goto LA125_;
			T127_ = (NimStringDesc*)0;
			T127_ = rawNewString((varCode ? varCode->Sup.len : 0) + 10);
appendString(T127_, varCode);
appendString(T127_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_146));
			nimZeroMem((void*)T128_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			nimZeroMem((void*)T129_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T128_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T129_, 0);
			T128_[1] = (*v).loc.r;
			T128_[2] = s;
			T130_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T130_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T127_, T128_, 3);
			T131_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T131_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T130_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T131_);
		}
		goto LA119_;
		LA125_: ;
		{
			NimStringDesc* T133_;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T134_;
			tyArray__qTjAvTvKF9anytN1At69aJMQ T135_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T136_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T137_;
			T133_ = (NimStringDesc*)0;
			T133_ = rawNewString((varCode ? varCode->Sup.len : 0) + 8);
appendString(T133_, varCode);
appendString(T133_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_91));
			nimZeroMem((void*)T134_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			nimZeroMem((void*)T135_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
			T134_[0] = percent___CtS8L8cOLTsSuQ10mtHsvw(T135_, 0);
			T134_[1] = (*v).loc.r;
			T134_[2] = s;
			T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T136_ = runtimeFormat__9bvKdnhoYI2ta9agQNm3orMA(T133_, T134_, 3);
			T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T137_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T136_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T137_);
		}
		LA119_: ;
	}
	LA27_: ;
	{
		NIM_BOOL T140_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T144_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T145_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T146_;
		T140_ = (NIM_BOOL)0;
		T140_ = useReloadingGuard;
		if (T140_) goto LA141_;
		T140_ = useGlobalPragmas;
		LA141_: ;
		if (!T140_) goto LA142_;
		(*p).extraIndent -= ((NI) 1);
		nimZeroMem((void*)T144_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T145_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T145_ = percent___BYiowJAm8zF7RBRISElaLg(T144_, 0);
		T146_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T146_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T145_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T146_);
	}
	LA142_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCopyForParamIfNeeded__AQaGEWMAoGSH1pqI9bePiww_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* owner;
{	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*p).prc == (*s).owner);
		if (T3_) goto LA4_;
		T3_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, n);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	owner = (*p).up;
	{
		while (1) {
			{
				NimStringDesc* T13_;
				if (!(owner == ((tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*) NIM_NIL))) goto LA11_;
				T13_ = (NimStringDesc*)0;
				T13_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 55);
appendString(T13_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_147));
appendString(T13_, (*(*s).name).s);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T13_, TM__BxLwT0mhrtgTPodf1v3xjg_148);
			}
			LA11_: ;
			{
				if (!((*owner).prc == (*s).owner)) goto LA16_;
				{
					NIM_BOOL T20_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* copy;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T23_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
					T20_ = (NIM_BOOL)0;
					T20_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*owner).generatedParamCopies), (*s).Sup.id);
					if (!!(T20_)) goto LA21_;
					nimZeroMem((void*)T23_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T23_[0] = (*s).loc.r;
					T23_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*s).typ);
					copy = percent___amX0pef5rA4JAmWZ6ZB2Nw(T23_, 2);
					T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T24_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(owner, copy);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*owner).locals, T24_);
				}
				LA21_: ;
				goto BeforeRet_;
			}
			LA16_: ;
			owner = (*owner).up;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstant__bgFYJWdvtLmrkmlW3jRA4A)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* oldBody;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*c).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).g).generatedSyms), (*c).Sup.id);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		oldBody = (*p).body;
		asgnRef((void**) (&(*p).body), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
		genVarInit__iVEhpHbcyNY9aOzPqLze8xw(p, c, (*c).ast);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).constants, (*p).body);
		asgnRef((void**) (&(*p).body), oldBody);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, attachProc__C5SA4Y9bPAMaecsSyvetPTg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* content, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).code, content);
}
N_LIB_PRIVATE N_NIMCALL(void, genProcForSymIfNeeded__9aGDirKbsf9cN1iAWvMcXOKg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	{
		NIM_BOOL T3_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* newp;
		tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* owner;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).g).generatedSyms), (*s).Sup.id);
		if (!!(T3_)) goto LA4_;
		newp = genProc__VRfKzQHOMcRGtJXZSJxFtg(p, s);
		owner = p;
		{
			while (1) {
				NIM_BOOL T8_;
				T8_ = (NIM_BOOL)0;
				T8_ = !((owner == ((tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*) NIM_NIL)));
				if (!(T8_)) goto LA9_;
				T8_ = !(((*owner).prc == (*s).owner));
				LA9_: ;
				if (!T8_) goto LA7;
				owner = (*owner).up;
			} LA7: ;
		}
		{
			if (!!((owner == ((tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*) NIM_NIL)))) goto LA12_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*owner).locals, newp);
		}
		goto LA10_;
		LA12_: ;
		{
			attachProc__C5SA4Y9bPAMaecsSyvetPTg(p, newp, s);
		}
		LA10_: ;
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSym__Bp5hmw3gImpkyC9cflWESLg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	s = (*n)._kind_4.sym;
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21):
	{
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA k;
		{
			NimStringDesc* T6_;
			if (!((*s).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA4_;
			T6_ = (NimStringDesc*)0;
			T6_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 30);
appendString(T6_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_23));
appendString(T6_, (*(*s).name).s);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T6_, TM__BxLwT0mhrtgTPodf1v3xjg_24);
		}
		LA4_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA9_;
			T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				if (!!(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA14_;
				T11_ = (*s).ast;
			}
			goto LA12_;
			LA14_: ;
			{
				T11_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*s).info);
			}
			LA12_: ;
			genVarInit__iVEhpHbcyNY9aOzPqLze8xw(p, s, T11_);
		}
		LA9_: ;
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3))) goto LA19_;
			genCopyForParamIfNeeded__AQaGEWMAoGSH1pqI9bePiww_3(p, n);
		}
		LA19_: ;
		k = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*s).typ);
		{
			if (!(k == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA23_;
			(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
			{
				if (!!(((131080 & (*s).flags) == 0))) goto LA27_;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym664_;
					NIM_BOOL T31_;
					NIM_BOOL T32_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T37_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T38_;
					vX60gensym664_ = s;
					T31_ = (NIM_BOOL)0;
					T32_ = (NIM_BOOL)0;
					T32_ = !(((131080 & (*vX60gensym664_).flags) == 0));
					if (!(T32_)) goto LA33_;
					T32_ = ((192 & (*vX60gensym664_).flags) == 0);
					LA33_: ;
					T31_ = T32_;
					if (!(T31_)) goto LA34_;
					T31_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym664_).kind)&31U)))!=0));
					LA34_: ;
					if (!T31_) goto LA35_;
					nimZeroMem((void*)T37_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T37_[0] = (*s).loc.r;
					unsureAsgnRef((void**) (&(*r).address), percent___xAta147ahLKNrJMPPP5B6g(T37_, 1));
					nimZeroMem((void*)T38_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T38_[0] = (*s).loc.r;
					unsureAsgnRef((void**) (&(*r).res), percent___sshAiIx49ba6saVSAWuyFuA(T38_, 1));
				}
				goto LA29_;
				LA35_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T40_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T41_;
					nimZeroMem((void*)T40_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T40_[0] = (*s).loc.r;
					unsureAsgnRef((void**) (&(*r).address), percent___TmulmJw2SZspd0rz2PYvQw(T40_, 1));
					nimZeroMem((void*)T41_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T41_[0] = (*s).loc.r;
					unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T41_, 1));
				}
				LA29_: ;
			}
			goto LA25_;
			LA27_: ;
			{
				unsureAsgnRef((void**) (&(*r).address), (*s).loc.r);
				unsureAsgnRef((void**) (&(*r).res), amp___Z7W1o5nPSc3ExfO5f7j1Gg((*s).loc.r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_107)));
			}
			LA25_: ;
		}
		goto LA21_;
		LA23_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym667_;
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T50_;
			vX60gensym667_ = s;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T45_ = !(((131080 & (*vX60gensym667_).flags) == 0));
			if (!(T45_)) goto LA46_;
			T45_ = ((192 & (*vX60gensym667_).flags) == 0);
			LA46_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA47_;
			T44_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym667_).kind)&31U)))!=0));
			LA47_: ;
			if (!T44_) goto LA48_;
			nimZeroMem((void*)T50_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T50_[0] = (*s).loc.r;
			unsureAsgnRef((void**) (&(*r).res), percent___TmulmJw2SZspd0rz2PYvQw(T50_, 1));
		}
		goto LA21_;
		LA48_: ;
		{
			unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
		}
		LA21_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
	{
		genConstant__bgFYJWdvtLmrkmlW3jRA4A(p, s);
		{
			NimStringDesc* T57_;
			if (!((*s).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA55_;
			T57_ = (NimStringDesc*)0;
			T57_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 30);
appendString(T57_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_23));
appendString(T57_, (*(*s).name).s);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T57_, TM__BxLwT0mhrtgTPodf1v3xjg_149);
		}
		LA55_: ;
		unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 13):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 16):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T64_;
		{
			NimStringDesc* T63_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0)) goto LA61_;
			T63_ = (NimStringDesc*)0;
			T63_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 48);
appendString(T63_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_150));
appendString(T63_, (*(*s).name).s);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T63_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__BxLwT0mhrtgTPodf1v3xjg_151, NIM_FALSE);
		}
		LA61_: ;
		T64_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T64_ = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, s);
		(void)(T64_);
		unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
		{
			NIM_BOOL T67_;
			NIM_BOOL T68_;
			T67_ = (NIM_BOOL)0;
			T68_ = (NIM_BOOL)0;
			T68_ = (((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0);
			if (T68_) goto LA69_;
			T68_ = !(((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
			LA69_: ;
			T67_ = T68_;
			if (T67_) goto LA70_;
			T67_ = !(((IL64(2147483712) & (*s).flags) == 0));
			LA70_: ;
			if (!T67_) goto LA71_;
		}
		goto LA65_;
		LA71_: ;
		{
			NIM_BOOL T74_;
			T74_ = (NIM_BOOL)0;
			T74_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
			if (!(T74_)) goto LA75_;
			T74_ = ((*(*(*s).ast)._kind_6.sons->data[((NI) 6)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA75_: ;
			if (!T74_) goto LA76_;
		}
		goto LA65_;
		LA76_: ;
		{
			NI T81_;
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 4))&63U)))!=0)) goto LA79_;
			asgnRef((void**) (&(*(*p).g).forwarded), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*(*p).g).forwarded), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
			T81_ = (*(*p).g).forwarded->Sup.len++;
			asgnRef((void**) (&(*(*p).g).forwarded->data[T81_]), s);
		}
		goto LA65_;
		LA79_: ;
		{
			genProcForSymIfNeeded__9aGDirKbsf9cN1iAWvMcXOKg(p, s);
		}
		LA65_: ;
	}
	break;
	default:
	{
		{
			NimStringDesc* T88_;
			if (!((*s).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA86_;
			T88_ = (NimStringDesc*)0;
			T88_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 30);
appendString(T88_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_23));
appendString(T88_, (*(*s).name).s);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T88_, TM__BxLwT0mhrtgTPodf1v3xjg_152);
		}
		LA86_: ;
		unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
	}
	break;
	}
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
}
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__AQaGEWMAoGSH1pqI9bePiww_4)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI line;
{	line = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs((*n).info);
	{
		if (!(line < ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		T7_ = (NIM_BOOL)0;
		T7_ = (((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0);
		if (T7_) goto LA8_;
		T7_ = (((*(*(*p).module).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 12))&31U)))!=0);
		LA8_: ;
		if (!T7_) goto LA9_;
		nimZeroMem((void*)T11_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T11_[0] = lineDir__l8iC2NnHymiEfpCjUoNB9cg((*(*p).module).config, (*n).info, line);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = percent___QXMcmOst45ThYFLo9cOKDiQ(T11_, 1);
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T12_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T13_);
	}
	LA9_: ;
	{
		NIM_BOOL T16_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T19_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		T16_ = (NIM_BOOL)0;
		T16_ = hasFrameInfo__eUoj4FPs7h9bV16Cz4RajiA(p);
		if (!T16_) goto LA17_;
		nimZeroMem((void*)T19_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T19_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (line)));
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = percent___KsZXXO4zKP47iruPcSEryQ(T19_, 1);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T20_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T21_);
	}
	LA17_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isAtom__ORlI8o1EUYdPqjuTcBWx1Aast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) <= (*n).kind);
	if (!(T1_)) goto LA2_;
	T1_ = ((*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
		if (T3_) goto LA4_;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
			c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA10;
						i = i_2;
						c = (*n)._kind_6.sons->data[i];
						{
							NIM_BOOL T13_;
							T13_ = (NIM_BOOL)0;
							T13_ = isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA(p, c);
							if (!!(T13_)) goto LA14_;
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA14_: ;
						i_2 += ((NI) 1);
					} LA10: ;
				}
			}
		}
		result = NIM_TRUE;
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = isAtom__ORlI8o1EUYdPqjuTcBWx1Aast(n);
		if (!T17_) goto LA18_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA18_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, rdLoc__yob5rpIMovhptJKw0A5vnAjsgen)(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* a) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	{
		if (!!(((*a).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)))) goto LA3_;
		result = (*a).res;
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T6_;
		nimZeroMem((void*)T6_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T6_[0] = (*a).address;
		T6_[1] = (*a).res;
		result = percent___jadqNPnY9aM3oxYK6jarLrA(T6_, 2);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOr__mpXN9cOaEmJkFGz77KKnHeQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA(p, a);
		if (!(T3_)) goto LA4_;
		T3_ = isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA(p, b);
		LA4_: ;
		if (!T3_) goto LA5_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, a, (&x));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, b, (&y));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		T7_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
		unsureAsgnRef((void**) (&(*r).res), percent___TUxzei0sBfo3GESRTg1T5w(T7_, 2));
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
		gen__Bp5hmw3gImpkyC9cflWESLg(p, a, (&x));
		nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T9_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		T9_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = percent___ikDBM4Dyw9c2kuwAAswRyOw(T9_, 2);
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T10_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T11_);
		(*p).extraIndent += ((NI) 1);
		gen__Bp5hmw3gImpkyC9cflWESLg(p, b, (&y));
		nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T12_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
		T12_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = percent___ht9cduX4yJQKi2Gi685ag5A(T12_, 2);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T13_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T14_);
		(*p).extraIndent -= ((NI) 1);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_134));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T16_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAnd__mpXN9cOaEmJkFGz77KKnHeQ_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	{
		NIM_BOOL T3_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA(p, a);
		if (!(T3_)) goto LA4_;
		T3_ = isSimpleExpr__63ZTZNC9c5no8E73V2FDEMA(p, b);
		LA4_: ;
		if (!T3_) goto LA5_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, a, (&x));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, b, (&y));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		T7_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
		unsureAsgnRef((void**) (&(*r).res), percent___Wsnl5zC9cCEBdwJcHgpLf0g(T7_, 2));
	}
	goto LA1_;
	LA5_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
		unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
		gen__Bp5hmw3gImpkyC9cflWESLg(p, a, (&x));
		nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T9_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		T9_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = percent___deWmrKhbFG0MxH9cDr9cnhfQ(T9_, 2);
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T10_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T11_);
		(*p).extraIndent += ((NI) 1);
		gen__Bp5hmw3gImpkyC9cflWESLg(p, b, (&y));
		nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T12_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
		T12_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T13_ = percent___ht9cduX4yJQKi2Gi685ag5A(T12_, 2);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T13_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T14_);
		(*p).extraIndent -= ((NI) 1);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_134));
		T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T16_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T15_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T16_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ)(NI64 size) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	switch (size) {
	case ((NI) 1):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_164));
	}
	break;
	case ((NI) 2):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_165));
	}
	break;
	case ((NI) 4):
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_166));
	}
	break;
	default:
	{
		result = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) NIM_NIL));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* op) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyArray__f7nG5LD47BH5K9c6mASit3g T2_;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, abstractRange__2fNKM13XwmoacahtEcjlJg);
	trimmer = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*T1_).size);
	nimZeroMem((void*)T2_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
	T2_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
	T2_[1] = rope__yShmEg9cffWxI7s5XzEKBow(op);
	T2_[2] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
	T2_[3] = trimmer;
	unsureAsgnRef((void**) (&(*r).res), percent___3RBmOS8xzFTxpuGVryQycg(T2_, 4));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* xLoc;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* yLoc;
	NI i;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	xLoc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	yLoc = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	i = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0));
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, jsMagics__QXSBsb0PxIS2yQAUDBHd9cQ[(op)- 46][(i)- 0]);
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(((NI) 2) < T3_)) goto LA4_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
		xLoc = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		yLoc = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
	}
	goto LA1_;
	LA4_: ;
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		xLoc = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
	}
	LA1_: ;
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 46):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
			if (!(i == ((NI) 0))) goto LA10_;
			nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T12_[0] = xLoc;
			T12_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___apXghcMDCUp9col7jN5spHA(T12_, 2));
		}
		goto LA8_;
		LA10_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T14_;
			nimZeroMem((void*)T14_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T14_[0] = xLoc;
			T14_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___9cNvJ1SVovK9b29bKmwKyiijw(T14_, 2));
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 47):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T20_;
			if (!(i == ((NI) 0))) goto LA18_;
			nimZeroMem((void*)T20_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T20_[0] = xLoc;
			T20_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___0mbMVYCe5Qwl9aQOKV3sh3w(T20_, 2));
		}
		goto LA16_;
		LA18_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T22_;
			nimZeroMem((void*)T22_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T22_[0] = xLoc;
			T22_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___03lrwELd9clj29bFkdXAVxkw(T22_, 2));
		}
		LA16_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 48):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T28_;
			if (!(i == ((NI) 0))) goto LA26_;
			nimZeroMem((void*)T28_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T28_[0] = xLoc;
			T28_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___8croAZ6oMdSPXHbIisuppw(T28_, 2));
		}
		goto LA24_;
		LA26_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T30_;
			nimZeroMem((void*)T30_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T30_[0] = xLoc;
			T30_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___TDLJ9ciKDBoW4ouZs855Csg(T30_, 2));
		}
		LA24_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 49):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T36_;
			if (!(i == ((NI) 0))) goto LA34_;
			nimZeroMem((void*)T36_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T36_[0] = xLoc;
			T36_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___Mk2KRdMWX4H3L9aBEG2elgQ(T36_, 2));
		}
		goto LA32_;
		LA34_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T38_;
			nimZeroMem((void*)T38_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T38_[0] = xLoc;
			T38_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___pFXgvxsz2L5f27ImZwJwzQ(T38_, 2));
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 50):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T44_;
			if (!(i == ((NI) 0))) goto LA42_;
			nimZeroMem((void*)T44_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T44_[0] = xLoc;
			T44_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___n9aTlv49bCxoRKQNZiWsaW2g(T44_, 2));
		}
		goto LA40_;
		LA42_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T46_;
			nimZeroMem((void*)T46_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T46_[0] = xLoc;
			T46_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___y3oNivo8px1XzxmB9b2OY5g(T46_, 2));
		}
		LA40_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 51):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T52_;
			if (!(i == ((NI) 0))) goto LA50_;
			nimZeroMem((void*)T52_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T52_[0] = xLoc;
			T52_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___apXghcMDCUp9col7jN5spHA(T52_, 2));
		}
		goto LA48_;
		LA50_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T54_;
			nimZeroMem((void*)T54_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T54_[0] = xLoc;
			T54_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___9cNvJ1SVovK9b29bKmwKyiijw(T54_, 2));
		}
		LA48_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T60_;
			if (!(i == ((NI) 0))) goto LA58_;
			nimZeroMem((void*)T60_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T60_[0] = xLoc;
			T60_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___0mbMVYCe5Qwl9aQOKV3sh3w(T60_, 2));
		}
		goto LA56_;
		LA58_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T62_;
			nimZeroMem((void*)T62_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T62_[0] = xLoc;
			T62_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___03lrwELd9clj29bFkdXAVxkw(T62_, 2));
		}
		LA56_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 53):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T68_;
			if (!(i == ((NI) 0))) goto LA66_;
			nimZeroMem((void*)T68_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T68_[0] = xLoc;
			T68_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___9cNvJ1SVovK9b29bKmwKyiijw(T68_, 2));
		}
		goto LA64_;
		LA66_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T70_;
			nimZeroMem((void*)T70_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T70_[0] = xLoc;
			T70_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___9cNvJ1SVovK9b29bKmwKyiijw(T70_, 2));
		}
		LA64_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 54):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T76_;
			if (!(i == ((NI) 0))) goto LA74_;
			nimZeroMem((void*)T76_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T76_[0] = xLoc;
			T76_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___03lrwELd9clj29bFkdXAVxkw(T76_, 2));
		}
		goto LA72_;
		LA74_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T78_;
			nimZeroMem((void*)T78_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T78_[0] = xLoc;
			T78_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___03lrwELd9clj29bFkdXAVxkw(T78_, 2));
		}
		LA72_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 55):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T84_;
			if (!(i == ((NI) 0))) goto LA82_;
			nimZeroMem((void*)T84_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T84_[0] = xLoc;
			T84_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___TDLJ9ciKDBoW4ouZs855Csg(T84_, 2));
		}
		goto LA80_;
		LA82_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T86_;
			nimZeroMem((void*)T86_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T86_[0] = xLoc;
			T86_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___TDLJ9ciKDBoW4ouZs855Csg(T86_, 2));
		}
		LA80_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 56):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T92_;
			if (!(i == ((NI) 0))) goto LA90_;
			nimZeroMem((void*)T92_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T92_[0] = xLoc;
			T92_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___Pnqkcr360suaX84kwXMuCA(T92_, 2));
		}
		goto LA88_;
		LA90_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T94_;
			nimZeroMem((void*)T94_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T94_[0] = xLoc;
			T94_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___Pnqkcr360suaX84kwXMuCA(T94_, 2));
		}
		LA88_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T100_;
			if (!(i == ((NI) 0))) goto LA98_;
			nimZeroMem((void*)T100_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T100_[0] = xLoc;
			T100_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T100_, 2));
		}
		goto LA96_;
		LA98_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T102_;
			nimZeroMem((void*)T102_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T102_[0] = xLoc;
			T102_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T102_, 2));
		}
		LA96_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 58):
	{
		{
			if (!((*(*(*n)._kind_6.sons->data[((NI) 1)]).typ).size <= IL64(4))) goto LA106_;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T112_;
				if (!(i == ((NI) 0))) goto LA110_;
				nimZeroMem((void*)T112_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T112_[0] = xLoc;
				T112_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___FA4ohw0aOufzzLhmw9aUAhA(T112_, 2));
			}
			goto LA108_;
			LA110_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T114_;
				nimZeroMem((void*)T114_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T114_[0] = xLoc;
				T114_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___FA4ohw0aOufzzLhmw9aUAhA(T114_, 2));
			}
			LA108_: ;
		}
		goto LA104_;
		LA106_: ;
		{
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T120_;
				if (!(i == ((NI) 0))) goto LA118_;
				nimZeroMem((void*)T120_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T120_[0] = xLoc;
				T120_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___zrNMM9b9c0YgkZAn9c5r9c1Zeg(T120_, 2));
			}
			goto LA116_;
			LA118_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T122_;
				nimZeroMem((void*)T122_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T122_[0] = xLoc;
				T122_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___zrNMM9b9c0YgkZAn9c5r9c1Zeg(T122_, 2));
			}
			LA116_: ;
		}
		LA104_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 59):
	{
		{
			if (!((*(*(*n)._kind_6.sons->data[((NI) 1)]).typ).size <= IL64(4))) goto LA126_;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T132_;
				if (!(i == ((NI) 0))) goto LA130_;
				nimZeroMem((void*)T132_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T132_[0] = xLoc;
				T132_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___SWZi8EY4Pz39bBPSp9cbtZMg(T132_, 2));
			}
			goto LA128_;
			LA130_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T134_;
				nimZeroMem((void*)T134_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T134_[0] = xLoc;
				T134_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___SWZi8EY4Pz39bBPSp9cbtZMg(T134_, 2));
			}
			LA128_: ;
		}
		goto LA124_;
		LA126_: ;
		{
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T140_;
				if (!(i == ((NI) 0))) goto LA138_;
				nimZeroMem((void*)T140_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T140_[0] = xLoc;
				T140_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___zzgVDys9a8A9cohe0W08nu1g(T140_, 2));
			}
			goto LA136_;
			LA138_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T142_;
				nimZeroMem((void*)T142_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T142_[0] = xLoc;
				T142_[1] = yLoc;
				unsureAsgnRef((void**) (&(*r).res), percent___zzgVDys9a8A9cohe0W08nu1g(T142_, 2));
			}
			LA136_: ;
		}
		LA124_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 60):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T148_;
			if (!(i == ((NI) 0))) goto LA146_;
			nimZeroMem((void*)T148_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T148_[0] = xLoc;
			T148_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___XaBXRInsoVU7DBc2WK8dzg(T148_, 2));
		}
		goto LA144_;
		LA146_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T150_;
			nimZeroMem((void*)T150_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T150_[0] = xLoc;
			T150_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___XaBXRInsoVU7DBc2WK8dzg(T150_, 2));
		}
		LA144_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 61):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T156_;
			if (!(i == ((NI) 0))) goto LA154_;
			nimZeroMem((void*)T156_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T156_[0] = xLoc;
			T156_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___NdMO5d09brFwLfDc8ciTSqQ(T156_, 2));
		}
		goto LA152_;
		LA154_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T158_;
			nimZeroMem((void*)T158_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T158_[0] = xLoc;
			T158_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___NdMO5d09brFwLfDc8ciTSqQ(T158_, 2));
		}
		LA152_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 62):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T164_;
			if (!(i == ((NI) 0))) goto LA162_;
			nimZeroMem((void*)T164_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T164_[0] = xLoc;
			T164_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___E62TlyqwqpEwqcA0YTjttw(T164_, 2));
		}
		goto LA160_;
		LA162_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T166_;
			nimZeroMem((void*)T166_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T166_[0] = xLoc;
			T166_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___E62TlyqwqpEwqcA0YTjttw(T166_, 2));
		}
		LA160_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 63):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T172_;
			if (!(i == ((NI) 0))) goto LA170_;
			nimZeroMem((void*)T172_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T172_[0] = xLoc;
			T172_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___m4T7v0qnGpOgwmMenKcgwg(T172_, 2));
		}
		goto LA168_;
		LA170_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T174_;
			nimZeroMem((void*)T174_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T174_[0] = xLoc;
			T174_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___m4T7v0qnGpOgwmMenKcgwg(T174_, 2));
		}
		LA168_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 64):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T180_;
			if (!(i == ((NI) 0))) goto LA178_;
			nimZeroMem((void*)T180_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T180_[0] = xLoc;
			T180_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___SKTmZPSgcdPr3Du3ia9b9czg(T180_, 2));
		}
		goto LA176_;
		LA178_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T182_;
			nimZeroMem((void*)T182_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T182_[0] = xLoc;
			T182_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___SKTmZPSgcdPr3Du3ia9b9czg(T182_, 2));
		}
		LA176_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 65):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T188_;
			if (!(i == ((NI) 0))) goto LA186_;
			nimZeroMem((void*)T188_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T188_[0] = xLoc;
			T188_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T188_, 2));
		}
		goto LA184_;
		LA186_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T190_;
			nimZeroMem((void*)T190_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T190_[0] = xLoc;
			T190_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T190_, 2));
		}
		LA184_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T196_;
			if (!(i == ((NI) 0))) goto LA194_;
			nimZeroMem((void*)T196_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T196_[0] = xLoc;
			T196_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T196_, 2));
		}
		goto LA192_;
		LA194_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T198_;
			nimZeroMem((void*)T198_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T198_[0] = xLoc;
			T198_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T198_, 2));
		}
		LA192_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 67):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T204_;
			if (!(i == ((NI) 0))) goto LA202_;
			nimZeroMem((void*)T204_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T204_[0] = xLoc;
			T204_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T204_, 2));
		}
		goto LA200_;
		LA202_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T206_;
			nimZeroMem((void*)T206_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T206_[0] = xLoc;
			T206_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T206_, 2));
		}
		LA200_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 68):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T212_;
			if (!(i == ((NI) 0))) goto LA210_;
			nimZeroMem((void*)T212_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T212_[0] = xLoc;
			T212_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T212_, 2));
		}
		goto LA208_;
		LA210_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T214_;
			nimZeroMem((void*)T214_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T214_[0] = xLoc;
			T214_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___CtS8L8cOLTsSuQ10mtHsvw(T214_, 2));
		}
		LA208_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 69):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T220_;
			if (!(i == ((NI) 0))) goto LA218_;
			nimZeroMem((void*)T220_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T220_[0] = xLoc;
			T220_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ItxAXpnPzfUbYRPsHgKrPw(T220_, 2));
		}
		goto LA216_;
		LA218_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T222_;
			nimZeroMem((void*)T222_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T222_[0] = xLoc;
			T222_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ItxAXpnPzfUbYRPsHgKrPw(T222_, 2));
		}
		LA216_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 70):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T228_;
			if (!(i == ((NI) 0))) goto LA226_;
			nimZeroMem((void*)T228_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T228_[0] = xLoc;
			T228_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T228_, 2));
		}
		goto LA224_;
		LA226_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T230_;
			nimZeroMem((void*)T230_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T230_[0] = xLoc;
			T230_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T230_, 2));
		}
		LA224_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 71):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T236_;
			if (!(i == ((NI) 0))) goto LA234_;
			nimZeroMem((void*)T236_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T236_[0] = xLoc;
			T236_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T236_, 2));
		}
		goto LA232_;
		LA234_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T238_;
			nimZeroMem((void*)T238_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T238_[0] = xLoc;
			T238_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T238_, 2));
		}
		LA232_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 72):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T244_;
			if (!(i == ((NI) 0))) goto LA242_;
			nimZeroMem((void*)T244_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T244_[0] = xLoc;
			T244_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T244_, 2));
		}
		goto LA240_;
		LA242_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T246_;
			nimZeroMem((void*)T246_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T246_[0] = xLoc;
			T246_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T246_, 2));
		}
		LA240_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 73):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T252_;
			if (!(i == ((NI) 0))) goto LA250_;
			nimZeroMem((void*)T252_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T252_[0] = xLoc;
			T252_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T252_, 2));
		}
		goto LA248_;
		LA250_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T254_;
			nimZeroMem((void*)T254_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T254_[0] = xLoc;
			T254_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T254_, 2));
		}
		LA248_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 74):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T260_;
			if (!(i == ((NI) 0))) goto LA258_;
			nimZeroMem((void*)T260_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T260_[0] = xLoc;
			T260_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T260_, 2));
		}
		goto LA256_;
		LA258_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T262_;
			nimZeroMem((void*)T262_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T262_[0] = xLoc;
			T262_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T262_, 2));
		}
		LA256_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 75):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T268_;
			if (!(i == ((NI) 0))) goto LA266_;
			nimZeroMem((void*)T268_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T268_[0] = xLoc;
			T268_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T268_, 2));
		}
		goto LA264_;
		LA266_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T270_;
			nimZeroMem((void*)T270_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T270_[0] = xLoc;
			T270_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T270_, 2));
		}
		LA264_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 76):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T276_;
			if (!(i == ((NI) 0))) goto LA274_;
			nimZeroMem((void*)T276_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T276_[0] = xLoc;
			T276_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T276_, 2));
		}
		goto LA272_;
		LA274_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T278_;
			nimZeroMem((void*)T278_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T278_[0] = xLoc;
			T278_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T278_, 2));
		}
		LA272_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 77):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T284_;
			if (!(i == ((NI) 0))) goto LA282_;
			nimZeroMem((void*)T284_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T284_[0] = xLoc;
			T284_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T284_, 2));
		}
		goto LA280_;
		LA282_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T286_;
			nimZeroMem((void*)T286_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T286_[0] = xLoc;
			T286_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T286_, 2));
		}
		LA280_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 78):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T292_;
			if (!(i == ((NI) 0))) goto LA290_;
			nimZeroMem((void*)T292_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T292_[0] = xLoc;
			T292_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T292_, 2));
		}
		goto LA288_;
		LA290_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T294_;
			nimZeroMem((void*)T294_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T294_[0] = xLoc;
			T294_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T294_, 2));
		}
		LA288_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 79):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T300_;
			if (!(i == ((NI) 0))) goto LA298_;
			nimZeroMem((void*)T300_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T300_[0] = xLoc;
			T300_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T300_, 2));
		}
		goto LA296_;
		LA298_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T302_;
			nimZeroMem((void*)T302_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T302_[0] = xLoc;
			T302_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T302_, 2));
		}
		LA296_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 80):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T308_;
			if (!(i == ((NI) 0))) goto LA306_;
			nimZeroMem((void*)T308_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T308_[0] = xLoc;
			T308_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T308_, 2));
		}
		goto LA304_;
		LA306_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T310_;
			nimZeroMem((void*)T310_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T310_[0] = xLoc;
			T310_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T310_, 2));
		}
		LA304_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 81):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T316_;
			if (!(i == ((NI) 0))) goto LA314_;
			nimZeroMem((void*)T316_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T316_[0] = xLoc;
			T316_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T316_, 2));
		}
		goto LA312_;
		LA314_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T318_;
			nimZeroMem((void*)T318_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T318_[0] = xLoc;
			T318_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T318_, 2));
		}
		LA312_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 82):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T324_;
			if (!(i == ((NI) 0))) goto LA322_;
			nimZeroMem((void*)T324_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T324_[0] = xLoc;
			T324_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T324_, 2));
		}
		goto LA320_;
		LA322_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T326_;
			nimZeroMem((void*)T326_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T326_[0] = xLoc;
			T326_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T326_, 2));
		}
		LA320_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 83):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T332_;
			if (!(i == ((NI) 0))) goto LA330_;
			nimZeroMem((void*)T332_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T332_[0] = xLoc;
			T332_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T332_, 2));
		}
		goto LA328_;
		LA330_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T334_;
			nimZeroMem((void*)T334_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T334_[0] = xLoc;
			T334_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T334_, 2));
		}
		LA328_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 84):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T340_;
			if (!(i == ((NI) 0))) goto LA338_;
			nimZeroMem((void*)T340_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T340_[0] = xLoc;
			T340_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T340_, 2));
		}
		goto LA336_;
		LA338_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T342_;
			nimZeroMem((void*)T342_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T342_[0] = xLoc;
			T342_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T342_, 2));
		}
		LA336_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 85):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T348_;
			if (!(i == ((NI) 0))) goto LA346_;
			nimZeroMem((void*)T348_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T348_[0] = xLoc;
			T348_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T348_, 2));
		}
		goto LA344_;
		LA346_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T350_;
			nimZeroMem((void*)T350_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T350_[0] = xLoc;
			T350_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T350_, 2));
		}
		LA344_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 86):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T356_;
			if (!(i == ((NI) 0))) goto LA354_;
			nimZeroMem((void*)T356_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T356_[0] = xLoc;
			T356_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T356_, 2));
		}
		goto LA352_;
		LA354_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T358_;
			nimZeroMem((void*)T358_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T358_[0] = xLoc;
			T358_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T358_, 2));
		}
		LA352_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 87):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T364_;
			if (!(i == ((NI) 0))) goto LA362_;
			nimZeroMem((void*)T364_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T364_[0] = xLoc;
			T364_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T364_, 2));
		}
		goto LA360_;
		LA362_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T366_;
			nimZeroMem((void*)T366_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T366_[0] = xLoc;
			T366_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T366_, 2));
		}
		LA360_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 88):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T372_;
			if (!(i == ((NI) 0))) goto LA370_;
			nimZeroMem((void*)T372_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T372_[0] = xLoc;
			T372_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T372_, 2));
		}
		goto LA368_;
		LA370_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T374_;
			nimZeroMem((void*)T374_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T374_[0] = xLoc;
			T374_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___oyQkqbRkRzo43y6iRevkaA(T374_, 2));
		}
		LA368_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 89):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T380_;
			if (!(i == ((NI) 0))) goto LA378_;
			nimZeroMem((void*)T380_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T380_[0] = xLoc;
			T380_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T380_, 2));
		}
		goto LA376_;
		LA378_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T382_;
			nimZeroMem((void*)T382_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T382_[0] = xLoc;
			T382_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___YuphtPwdJHG6BUJOVa9bX3w(T382_, 2));
		}
		LA376_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 90):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T388_;
			if (!(i == ((NI) 0))) goto LA386_;
			nimZeroMem((void*)T388_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T388_[0] = xLoc;
			T388_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___QX9cU2fNK0jJrZNDQKnAycA(T388_, 2));
		}
		goto LA384_;
		LA386_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T390_;
			nimZeroMem((void*)T390_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T390_[0] = xLoc;
			T390_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___QX9cU2fNK0jJrZNDQKnAycA(T390_, 2));
		}
		LA384_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 91):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T396_;
			if (!(i == ((NI) 0))) goto LA394_;
			nimZeroMem((void*)T396_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T396_[0] = xLoc;
			T396_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T396_, 2));
		}
		goto LA392_;
		LA394_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T398_;
			nimZeroMem((void*)T398_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T398_[0] = xLoc;
			T398_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T398_, 2));
		}
		LA392_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 92):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T404_;
			if (!(i == ((NI) 0))) goto LA402_;
			nimZeroMem((void*)T404_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T404_[0] = xLoc;
			T404_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T404_, 2));
		}
		goto LA400_;
		LA402_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T406_;
			nimZeroMem((void*)T406_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T406_[0] = xLoc;
			T406_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___tkJq8W3gQVDjuu9aT3THC6Q(T406_, 2));
		}
		LA400_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T412_;
			if (!(i == ((NI) 0))) goto LA410_;
			nimZeroMem((void*)T412_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T412_[0] = xLoc;
			T412_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ggqZXIgPaS71ubw22cYODw(T412_, 2));
		}
		goto LA408_;
		LA410_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T414_;
			nimZeroMem((void*)T414_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T414_[0] = xLoc;
			T414_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ec65mR1N7BSL9cmUa3z9czvA(T414_, 2));
		}
		LA408_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 94):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T420_;
			if (!(i == ((NI) 0))) goto LA418_;
			nimZeroMem((void*)T420_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T420_[0] = xLoc;
			T420_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___LLnl4aDVJynim7LQvfJKLQ(T420_, 2));
		}
		goto LA416_;
		LA418_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T422_;
			nimZeroMem((void*)T422_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T422_[0] = xLoc;
			T422_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ec65mR1N7BSL9cmUa3z9czvA(T422_, 2));
		}
		LA416_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 95):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T428_;
			if (!(i == ((NI) 0))) goto LA426_;
			nimZeroMem((void*)T428_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T428_[0] = xLoc;
			T428_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___Ob6yLhv7QvbU9bdZj8Nw2kA(T428_, 2));
		}
		goto LA424_;
		LA426_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T430_;
			nimZeroMem((void*)T430_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T430_[0] = xLoc;
			T430_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___qfsHROU9aHSaYGq3tpw1XDg(T430_, 2));
		}
		LA424_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T436_;
			if (!(i == ((NI) 0))) goto LA434_;
			nimZeroMem((void*)T436_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T436_[0] = xLoc;
			T436_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___GHW5yjG8N9c2BQBun6aBJzQ(T436_, 2));
		}
		goto LA432_;
		LA434_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T438_;
			nimZeroMem((void*)T438_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T438_[0] = xLoc;
			T438_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___GHW5yjG8N9c2BQBun6aBJzQ(T438_, 2));
		}
		LA432_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 97):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T444_;
			if (!(i == ((NI) 0))) goto LA442_;
			nimZeroMem((void*)T444_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T444_[0] = xLoc;
			T444_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___j9bcJJvtd9bur0VZUQL3ibgA(T444_, 2));
		}
		goto LA440_;
		LA442_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T446_;
			nimZeroMem((void*)T446_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T446_[0] = xLoc;
			T446_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___j9bcJJvtd9bur0VZUQL3ibgA(T446_, 2));
		}
		LA440_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 98):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T452_;
			if (!(i == ((NI) 0))) goto LA450_;
			nimZeroMem((void*)T452_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T452_[0] = xLoc;
			T452_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___32ITt7hKDrhn9bXvKbmnE9bw(T452_, 2));
		}
		goto LA448_;
		LA450_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T454_;
			nimZeroMem((void*)T454_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T454_[0] = xLoc;
			T454_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___32ITt7hKDrhn9bXvKbmnE9bw(T454_, 2));
		}
		LA448_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 99):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T460_;
			if (!(i == ((NI) 0))) goto LA458_;
			nimZeroMem((void*)T460_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T460_[0] = xLoc;
			T460_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___j9bcJJvtd9bur0VZUQL3ibgA(T460_, 2));
		}
		goto LA456_;
		LA458_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T462_;
			nimZeroMem((void*)T462_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T462_[0] = xLoc;
			T462_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___j9bcJJvtd9bur0VZUQL3ibgA(T462_, 2));
		}
		LA456_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 100):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T468_;
			if (!(i == ((NI) 0))) goto LA466_;
			nimZeroMem((void*)T468_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T468_[0] = xLoc;
			T468_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ec65mR1N7BSL9cmUa3z9czvA(T468_, 2));
		}
		goto LA464_;
		LA466_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T470_;
			nimZeroMem((void*)T470_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T470_[0] = xLoc;
			T470_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ec65mR1N7BSL9cmUa3z9czvA(T470_, 2));
		}
		LA464_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 101):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T476_;
			if (!(i == ((NI) 0))) goto LA474_;
			nimZeroMem((void*)T476_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T476_[0] = xLoc;
			T476_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ZAOkVi5SmgPcGpCSuSRXVA(T476_, 2));
		}
		goto LA472_;
		LA474_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T478_;
			nimZeroMem((void*)T478_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T478_[0] = xLoc;
			T478_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___ZAOkVi5SmgPcGpCSuSRXVA(T478_, 2));
		}
		LA472_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 102):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T484_;
			if (!(i == ((NI) 0))) goto LA482_;
			nimZeroMem((void*)T484_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T484_[0] = xLoc;
			T484_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___smDIOmjGgf8ZP9bfDyv43bQ(T484_, 2));
		}
		goto LA480_;
		LA482_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T486_;
			nimZeroMem((void*)T486_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T486_[0] = xLoc;
			T486_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___smDIOmjGgf8ZP9bfDyv43bQ(T486_, 2));
		}
		LA480_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 103):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T492_;
			if (!(i == ((NI) 0))) goto LA490_;
			nimZeroMem((void*)T492_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T492_[0] = xLoc;
			T492_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___1jtIbjhXi2wH1iWPyC9bgAQ(T492_, 2));
		}
		goto LA488_;
		LA490_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T494_;
			nimZeroMem((void*)T494_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T494_[0] = xLoc;
			T494_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___1jtIbjhXi2wH1iWPyC9bgAQ(T494_, 2));
		}
		LA488_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 104):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T500_;
			if (!(i == ((NI) 0))) goto LA498_;
			nimZeroMem((void*)T500_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T500_[0] = xLoc;
			T500_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___1jtIbjhXi2wH1iWPyC9bgAQ(T500_, 2));
		}
		goto LA496_;
		LA498_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T502_;
			nimZeroMem((void*)T502_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T502_[0] = xLoc;
			T502_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___1jtIbjhXi2wH1iWPyC9bgAQ(T502_, 2));
		}
		LA496_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 105):
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T504_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_184));
		nimZeroMem((void*)T504_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T504_[0] = xLoc;
		T504_[1] = yLoc;
		unsureAsgnRef((void**) (&(*r).res), percent___LJLp1p5BdxuzRFTT9czwOgA(T504_, 2));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 106):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T510_;
			if (!(i == ((NI) 0))) goto LA508_;
			nimZeroMem((void*)T510_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T510_[0] = xLoc;
			T510_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___NPgb4kECDcV8MICSil6Rjw(T510_, 2));
		}
		goto LA506_;
		LA508_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T512_;
			nimZeroMem((void*)T512_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T512_[0] = xLoc;
			T512_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___NPgb4kECDcV8MICSil6Rjw(T512_, 2));
		}
		LA506_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 152):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 153):
	{
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T518_;
			if (!(i == ((NI) 0))) goto LA516_;
			nimZeroMem((void*)T518_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T518_[0] = xLoc;
			T518_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___QXMcmOst45ThYFLo9cOKDiQ(T518_, 2));
		}
		goto LA514_;
		LA516_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T520_;
			nimZeroMem((void*)T520_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T520_[0] = xLoc;
			T520_[1] = yLoc;
			unsureAsgnRef((void**) (&(*r).res), percent___QXMcmOst45ThYFLo9cOKDiQ(T520_, 2));
		}
		LA514_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, arith__3Dxk7XsMQw9b52OHOhMc7Fg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op) {
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 65):
	{
		binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_167));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66):
	{
		binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_168));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 67):
	{
		binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_169));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 68):
	{
		binaryUintExpr__gKhTOXYvuBrwxbtvs5b9c1Q(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_170));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 49):
	{
		arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2(p, n, r, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 50):
	{
		arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2(p, n, r, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T9_;
		nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
		trimmer = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*T8_).size);
		nimZeroMem((void*)T9_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T9_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
		T9_[1] = trimmer;
		T9_[2] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
		unsureAsgnRef((void**) (&(*r).res), percent___cQHGAtgSLYV7mm9bnVGYGRA(T9_, 3));
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 101):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 102):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 103):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 104):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 105):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 106):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 108):
	{
		arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2(p, n, r, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 87):
	{
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T14_;
			T14_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T14_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			if (!!((T14_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)))) goto LA15_;
			arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2(p, n, r, op);
		}
		goto LA12_;
		LA15_: ;
		{
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x_2;
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y_2;
			tyArray__f7nG5LD47BH5K9c6mASit3g T18_;
			nimZeroMem((void*)(&x_2), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			nimZeroMem((void*)(&y_2), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_2));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y_2));
			nimZeroMem((void*)T18_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T18_[0] = x_2.address;
			T18_[1] = y_2.address;
			T18_[2] = x_2.res;
			T18_[3] = y_2.res;
			unsureAsgnRef((void**) (&(*r).res), percent___Q4LBu2cVl8IcNTrtxd6B6A(T18_, 4));
		}
		LA12_: ;
	}
	break;
	default:
	{
		arithAux__3Dxk7XsMQw9b52OHOhMc7Fg_2(p, n, r, op);
	}
	break;
	}
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* magic, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* typ) {
	NimStringDesc* T1_;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, magic);
	T1_ = (NimStringDesc*)0;
	T1_ = rawNewString((magic ? magic->Sup.len : 0) + 1);
appendString(T1_, magic);
appendString(T1_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_103));
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, T1_);
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	{
		if (!eqStrings(magic, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_185))) goto LA4_;
		{
			if (!(a.address == 0)) goto LA8_;
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
			add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_186));
		}
		goto LA6_;
		LA8_: ;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T11_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
			nimZeroMem((void*)T11_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T11_[0] = a.address;
			T11_[1] = a.res;
			T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T12_ = percent___ctvQ2lU9b9bnVVpNP4GhIo2Q(T11_, 2);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T12_);
		}
		LA6_: ;
	}
	goto LA2_;
	LA4_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
	}
	LA2_: ;
	{
		if (!!((typ == 0))) goto LA16_;
		add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, typ);
	}
	LA16_: ;
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_105));
}
N_LIB_PRIVATE N_NIMCALL(void, genRepr__Bp5hmw3gImpkyC9cflWESLg_4)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_187), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_188), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_189), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_190), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_191), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_192), T7_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_193), T9_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_194), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__BxLwT0mhrtgTPodf1v3xjg_195, NIM_FALSE);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_196), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_197), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	break;
	default:
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		genReprAux__VVJu9bCqc9ae8WmH3h7jRteQ(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_185), T14_);
	}
	break;
	}
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genSwap__AQaGEWMAoGSH1pqI9bePiww_5)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w b;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T16_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&b), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&b));
	tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_FALSE);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T4_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
		T4_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T4_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, T3_);
		if (!(T4_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA5_;
		tmp2 = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_FALSE);
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = !((a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)));
			if (T9_) goto LA10_;
			T9_ = !((b.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)));
			LA10_: ;
			if (!T9_) goto LA11_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_198), TM__BxLwT0mhrtgTPodf1v3xjg_199);
		}
		LA11_: ;
		nimZeroMem((void*)T13_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T13_[0] = tmp;
		T13_[1] = a.address;
		T13_[2] = b.address;
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = percent___M36w8F9bFwighD3K39bvtVWw(T13_, 3);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T14_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T15_);
		tmp = tmp2;
	}
	LA5_: ;
	nimZeroMem((void*)T16_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T16_[0] = tmp;
	T16_[1] = a.res;
	T16_[2] = b.res;
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T17_ = percent___Wm11wQtuJBQgTy9a39apz0eA(T16_, 3);
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T17_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T18_);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, needsTemp__63ZTZNC9c5no8E73V2FDEMA_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32) || (*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
		c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					c = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, c);
						if (!T11_) goto LA12_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA12_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* x, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b;
	a = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen(x);
	b = a;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, n);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NIM_BOOL T10_;
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T11_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
			T8_ = (NIM_BOOL)0;
			T8_ = !(((*x).tmpLoc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			T10_ = (NIM_BOOL)0;
			T11_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T11_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*n).typ);
			T10_ = (T11_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
			if (T10_) goto LA12_;
			T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47));
			LA12_: ;
			T8_ = T10_;
			LA9_: ;
			if (!T8_) goto LA13_;
			nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T15_[0] = (*x).tmpLoc;
			b = percent___HiCTlq0dXhMZvpDtUGWGQA(T15_, 1);
			unsureAsgnRef((void**) (&(*Result).Field0), a);
			unsureAsgnRef((void**) (&(*Result).Field1), b);
		}
		goto LA6_;
		LA13_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T17_;
			tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
			b = tmp;
			nimZeroMem((void*)T17_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T17_[0] = tmp;
			T17_[1] = a;
			a = percent___aagcnoz4kFWlzsoVgR9b0NQ(T17_, 2);
			unsureAsgnRef((void**) (&(*Result).Field0), a);
			unsureAsgnRef((void**) (&(*Result).Field1), b);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		unsureAsgnRef((void**) (&(*Result).Field0), a);
		unsureAsgnRef((void**) (&(*Result).Field1), b);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConStrStr__Bp5hmw3gImpkyC9cflWESLg_5)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	NI T25_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
		if (!((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = a.res;
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___amO46kEKgIeOmW50ayV6nA(T6_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T7_);
	}
	goto LA1_;
	LA4_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T9_[0] = a.res;
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = percent___3lABfXU9aXZsyfylYizY8KA(T9_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T10_);
	}
	LA1_: ;
	{
		NI i;
		NI colontmp_;
		NI T12_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T12_ - ((NI) 1));
		i_2 = ((NI) 2);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA14;
				i = i_2;
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[i], (&a));
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T20_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
					T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T17_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[i]).typ, IL64(36134350144710928));
					if (!((*T17_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA18_;
					nimZeroMem((void*)T20_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T20_[0] = a.res;
					T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T21_ = percent___5JCQx3oDHEcLdsEz6Rx0Rw(T20_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T21_);
				}
				goto LA15_;
				LA18_: ;
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T23_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
					nimZeroMem((void*)T23_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T23_[0] = a.res;
					T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T24_ = percent___dTtf7fil83VcW2Mkkr7scw(T23_, 1);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T24_);
				}
				LA15_: ;
				i_2 += ((NI) 1);
			} LA14: ;
		}
	}
	T25_ = (NI)0;
	T25_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[(NI)(T25_ - ((NI) 1))], (&a));
	{
		NI T28_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T29_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		T28_ = (NI)0;
		T28_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T29_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T29_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[(NI)(T28_ - ((NI) 1))]).typ, IL64(36134350144710928));
		if (!((*T29_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA30_;
		nimZeroMem((void*)T32_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T32_[0] = a.res;
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = percent___88NG6Rr5xfTcA6hqLfZ2iw(T32_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T33_);
	}
	goto LA26_;
	LA30_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T35_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T36_;
		nimZeroMem((void*)T35_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T35_[0] = a.res;
		T36_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T36_ = percent___1DWSTPxvqlc4A2xRDmjZDw(T35_, 1);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T36_);
	}
	LA26_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNew__AQaGEWMAoGSH1pqI9bePiww_6)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
	t = (*T1_).sons->data[((NI) 0)];
	{
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T4_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T4_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T4_ = mapType__3fHLBKCveV5k5hDCMQOL2g(t);
		if (!(T4_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8))) goto LA5_;
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
		T7_[1] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, t, NIM_FALSE);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T7_, 2);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T8_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T9_);
	}
	goto LA2_;
	LA5_: ;
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
		if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA11_;
		nimZeroMem((void*)T13_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T13_[0] = a.address;
		T13_[1] = a.res;
		T13_[2] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, t, NIM_FALSE);
		T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T14_ = percent___AOSgPOjXfsLWEICRXv3U2g(T13_, 3);
		T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T15_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T14_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T15_);
	}
	goto LA2_;
	LA11_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
		nimZeroMem((void*)T17_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T17_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
		T17_[1] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, t, NIM_FALSE);
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = percent___gN4yb6p4ql6iVJOPAjLEJQ(T17_, 2);
		T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T19_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T18_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T19_);
	}
	LA2_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrd__Bp5hmw3gImpkyC9cflWESLg_6)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087633066256));
	switch ((*T1_).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym841_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym841_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym841_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym841_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T6_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw _;
			T6_ = (NIM_BOOL)0;
			T6_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_205), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T6_) goto LA7_;
			nimZeroMem((void*)(&_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&_));
			aX60gensym841_ = _.Field0;
			tmpX60gensym841_ = _.Field1;
		}
		LA7_: ;
		nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T9_[0] = aX60gensym841_;
		T9_[1] = tmpX60gensym841_;
		unsureAsgnRef((void**) (&(*r).res), percent___WIg2bxfQLkmzIdOv1JkRqw(T9_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_206), TM__BxLwT0mhrtgTPodf1v3xjg_207);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* x, tyTuple__nsNHL3sm0TZE9bootw2pEXw* Result) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b;
	a = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen(x);
	b = a;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, n);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NIM_BOOL T10_;
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T11_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__2;
			T8_ = (NIM_BOOL)0;
			T8_ = !(((*x).tmpLoc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			T10_ = (NIM_BOOL)0;
			T11_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T11_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*n).typ);
			T10_ = (T11_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
			if (T10_) goto LA12_;
			T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47));
			LA12_: ;
			T8_ = T10_;
			LA9_: ;
			if (!T8_) goto LA13_;
			nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T15_[0] = (*x).tmpLoc;
			b = percent___HiCTlq0dXhMZvpDtUGWGQA(T15_, 1);
			colontmp_ = a;
			colontmp__2 = b;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp_);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__2);
		}
		goto LA6_;
		LA13_: ;
		{
			NIM_BOOL T17_;
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w address;
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w index;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA first;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw T21_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* m1;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp1;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* n1;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__3;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T45_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__4;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T46_;
			T17_ = (NIM_BOOL)0;
			T17_ = !(((*x).tmpLoc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)));
			if (!(T17_)) goto LA18_;
			T17_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
			LA18_: ;
			if (!T17_) goto LA19_;
			nimZeroMem((void*)(&address), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			nimZeroMem((void*)(&index), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			nimZeroMem((void*)(&first), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&address));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&index));
			nimZeroMem((void*)(&T21_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 0)], (&address), (&T21_));
			m1 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			m1 = T21_.Field0;
			tmp1 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			tmp1 = T21_.Field1;
			typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
			{
				if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16))) goto LA24_;
				first = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*p).module).config, (*typ).sons->data[((NI) 0)]);
			}
			LA24_: ;
			{
				if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA28_;
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_210));
				{
					NIM_BOOL T32_;
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T35_;
					T32_ = (NIM_BOOL)0;
					T32_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(first, IL64(0));
					if (!T32_) goto LA33_;
					nimZeroMem((void*)T35_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T35_[0] = index.res;
					T35_[1] = tmp1;
					index.res = percent___CK0iwKv7s4cZGqPi5rQF6w(T35_, 2);
				}
				goto LA30_;
				LA33_: ;
				{
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T37_;
					nimZeroMem((void*)T37_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T37_[0] = index.res;
					T37_[1] = rope__oMf9cufugVin4CJLwmEes2A(first);
					T37_[2] = tmp1;
					index.res = percent___PT2vKgDWcFJy9citUgxhMPg(T37_, 3);
				}
				LA30_: ;
			}
			goto LA26_;
			LA28_: ;
			{
				NIM_BOOL T39_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T42_;
				T39_ = (NIM_BOOL)0;
				T39_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(first, IL64(0));
				if (!!(T39_)) goto LA40_;
				nimZeroMem((void*)T42_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T42_[0] = index.res;
				T42_[1] = rope__oMf9cufugVin4CJLwmEes2A(first);
				index.res = percent___JM349c89cyw9auxMIJuWihRCA(T42_, 2);
			}
			goto LA26_;
			LA40_: ;
			{
			}
			LA26_: ;
			nimZeroMem((void*)(&T44_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&index), (&T44_));
			n1 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			n1 = T44_.Field0;
			tmp2 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			tmp2 = T44_.Field1;
			nimZeroMem((void*)T45_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T45_[0] = m1;
			T45_[1] = n1;
			colontmp__3 = percent___jadqNPnY9aM3oxYK6jarLrA(T45_, 2);
			nimZeroMem((void*)T46_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T46_[0] = tmp1;
			T46_[1] = tmp2;
			colontmp__4 = percent___jadqNPnY9aM3oxYK6jarLrA(T46_, 2);
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__3);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__4);
		}
		goto LA6_;
		LA19_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__5;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__6;
			colontmp__5 = a;
			colontmp__6 = b;
			unsureAsgnRef((void**) (&(*Result).Field0), colontmp__5);
			unsureAsgnRef((void**) (&(*Result).Field1), colontmp__6);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__7;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* colontmp__8;
		colontmp__7 = a;
		colontmp__8 = b;
		unsureAsgnRef((void**) (&(*Result).Field0), colontmp__7);
		unsureAsgnRef((void**) (&(*Result).Field1), colontmp__8);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryUintExpr__lkqE7dycNUTKyDZxsrACPA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* op) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyTuple__nsNHL3sm0TZE9bootw2pEXw T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__duFhZXIIlrbrM62cWjNekg T3_;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, abstractRange__2fNKM13XwmoacahtEcjlJg);
	trimmer = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*T1_).size);
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
	maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&x), (&T2_));
	a = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	a = T2_.Field0;
	tmp = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	tmp = T2_.Field1;
	nimZeroMem((void*)T3_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
	T3_[0] = a;
	T3_[1] = rope__yShmEg9cffWxI7s5XzEKBow(op);
	T3_[2] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
	T3_[3] = trimmer;
	T3_[4] = tmp;
	unsureAsgnRef((void**) (&(*r).res), percent___oYhFcOWR4tEylepRJJLrlA(T3_, 5));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__AQaGEWMAoGSH1pqI9bePiww_7)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T4_;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
	t = (*T1_).sons->data[((NI) 0)];
	nimZeroMem((void*)T2_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
	T2_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
	T2_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
	T2_[2] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, t, NIM_FALSE);
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = percent___Eqr9cgWCkrZrUG3sg0CawIQ(T2_, 3);
	T4_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T4_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T3_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T4_);
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__Bp5hmw3gImpkyC9cflWESLg_7)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 2)]).typ, IL64(36275087639357712));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T5_;
		if (!(((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2))&63U)))!=0)) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T5_[0] = x.res;
		T5_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		unsureAsgnRef((void**) (&(*r).res), percent___1nMXoOe6cENU7004pnh6wQ(T5_, 2));
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T7_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_220));
		nimZeroMem((void*)T7_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T7_[0] = x.res;
		T7_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, t);
		unsureAsgnRef((void**) (&(*r).res), percent___ALynLzo8zWvno8ZxASdm4A(T7_, 2));
	}
	LA1_: ;
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genDefault__Bp5hmw3gImpkyC9cflWESLg_8)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	unsureAsgnRef((void**) (&(*r).res), createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, (*n).typ, NIM_FALSE));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genReset__AQaGEWMAoGSH1pqI9bePiww_8)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
	nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_221));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!(x.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T5_[0] = x.address;
		T5_[1] = x.res;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___tlkWMVJPsx9aWUbp8FMjQ4w(T5_, 2);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T6_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T7_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyTuple__nsNHL3sm0TZE9bootw2pEXw T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)(&T9_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
		maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&x), (&T9_));
		a = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		a = T9_.Field0;
		tmp = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		tmp = T9_.Field1;
		nimZeroMem((void*)T10_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T10_[0] = a;
		T10_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
		T10_[2] = tmp;
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = percent___xPW5KjObCPL2lJmHFoqfjg(T10_, 3);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T11_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T12_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__Bp5hmw3gImpkyC9cflWESLg_10)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, n, (&a));
	{
		if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA3_;
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.address);
		add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
	}
	goto LA1_;
	LA3_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEcho__Bp5hmw3gImpkyC9cflWESLg_9)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	n_2 = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[((NI) 1)]);
	{
		NimStringDesc* argX60gensym738_;
		if (!!(((*n_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41)))) goto LA3_;
		argX60gensym738_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_222);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym738_, TM__BxLwT0mhrtgTPodf1v3xjg_222);
	}
	LA3_: ;
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_223));
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_224));
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_225));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA7;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					it = (*n_2)._kind_6.sons->data[i];
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*it).typ);
						if (!T11_) goto LA12_;
						goto LA8;
					}
					LA12_: ;
					{
						if (!(((NI) 0) < i)) goto LA16_;
						add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
					}
					LA16_: ;
					genArgNoParam__Bp5hmw3gImpkyC9cflWESLg_10(p, it, r);
				} LA8: ;
				i_2 += ((NI) 1);
			} LA7: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_105));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genArg__RI5RyHREFNXox9cpkCYH50g)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NI* emitted) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, n, (&a));
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T4_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		T3_ = (NIM_BOOL)0;
		T4_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T4_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*param).typ, IL64(36275087632017680));
		T3_ = ((IL64(281475110928384) &((NU64)1<<((NU)((*T4_).kind)&63U)))!=0);
		if (!(T3_)) goto LA5_;
		T3_ = (a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
		LA5_: ;
		if (!T3_) goto LA6_;
		nimZeroMem((void*)T8_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T8_[0] = a.address;
		T8_[1] = a.res;
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = percent___jadqNPnY9aM3oxYK6jarLrA(T8_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T9_);
	}
	goto LA1_;
	LA6_: ;
	{
		if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA11_;
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.address);
		add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
		{
			if (!!((emitted == ((NI*) NIM_NIL)))) goto LA15_;
			(*emitted) += ((NI) 1);
		}
		LA15_: ;
	}
	goto LA1_;
	LA11_: ;
	{
		NIM_BOOL T18_;
		NIM_BOOL T19_;
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T25_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
		T18_ = (NIM_BOOL)0;
		T19_ = (NIM_BOOL)0;
		T19_ = ((IL64(175921875124224) &((NU64)1<<((NU)((*(*n).typ).kind)&63U)))!=0);
		if (!(T19_)) goto LA20_;
		T19_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		LA20_: ;
		T18_ = T19_;
		if (!(T18_)) goto LA21_;
		T22_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T22_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*param).typ);
		T18_ = (T22_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
		LA21_: ;
		if (!T18_) goto LA23_;
		tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
		nimZeroMem((void*)T25_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T25_[0] = tmp;
		T25_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
		T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T26_ = percent___9bY6R9buTsrqJYQAuD39cegOA(T25_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T26_);
		{
			if (!!((emitted == ((NI*) NIM_NIL)))) goto LA29_;
			(*emitted) += ((NI) 1);
		}
		LA29_: ;
	}
	goto LA1_;
	LA23_: ;
	{
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArgs__1PNPBjb9aOT7yB9avaRcGbbQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NI start) {
	NIM_BOOL hasArgs;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	NI emitted;
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_103));
	hasArgs = NIM_FALSE;
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	emitted = (NI)(start - ((NI) 1));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = start;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* paramType;
					it = (*n)._kind_6.sons->data[i];
					paramType = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					{
						NI T7_;
						T7_ = (NI)0;
						T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
						if (!(i < T7_)) goto LA8_;
						paramType = (*(*typ).n)._kind_6.sons->data[i];
						{
							NIM_BOOL T12_;
							T12_ = (NIM_BOOL)0;
							T12_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*paramType).typ);
							if (!T12_) goto LA13_;
							goto LA4;
						}
						LA13_: ;
					}
					LA8_: ;
					{
						if (!hasArgs) goto LA17_;
						add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
					}
					LA17_: ;
					{
						if (!(paramType == 0)) goto LA21_;
						genArgNoParam__Bp5hmw3gImpkyC9cflWESLg_10(p, it, r);
					}
					goto LA19_;
					LA21_: ;
					{
						genArg__RI5RyHREFNXox9cpkCYH50g(p, it, (*paramType)._kind_4.sym, r, (&emitted));
					}
					LA19_: ;
					emitted += ((NI) 1);
					hasArgs = NIM_TRUE;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_105));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__Bp5hmw3gImpkyC9cflWESLg_11)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	genArgs__1PNPBjb9aOT7yB9avaRcGbbQ(p, n, r, ((NI) 1));
	{
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA t;
		if (!!(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA3_;
		t = mapType__3fHLBKCveV5k5hDCMQOL2g((*n).typ);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
			if (!(t == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA7_;
			tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
			nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T9_[0] = tmp;
			T9_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
			unsureAsgnRef((void**) (&(*r).address), percent___U9b6hkqS6N7XIWr0gy8z9bug(T9_, 2));
			nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T10_[0] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T10_, 1));
			unsureAsgnRef((void**) (&(*r).tmpLoc), tmp);
			(*r).typ = t;
		}
		LA7_: ;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMove__Bp5hmw3gImpkyC9cflWESLg_12)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T1_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T2_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T3_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
	unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
	nimZeroMem((void*)T1_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T1_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
	T1_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
	T2_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T2_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T1_, 2);
	T3_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T3_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T2_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T3_);
	genReset__AQaGEWMAoGSH1pqI9bePiww_8(p, n);
}
N_LIB_PRIVATE N_NIMCALL(void, genMagic__Bp5hmw3gImpkyC9cflWESLg_3)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* line;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* filen;
	tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg op;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	line = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	filen = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	op = (*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic;
	switch (op) {
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 110):
	{
		genOr__mpXN9cOaEmJkFGz77KKnHeQ(p, (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 2)], r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 109):
	{
		genAnd__mpXN9cOaEmJkFGz77KKnHeQ_2(p, (*n)._kind_6.sons->data[((NI) 1)], (*n)._kind_6.sons->data[((NI) 2)], r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 46) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107):
	{
		arith__3Dxk7XsMQw9b52OHOhMc7Fg(p, n, r, op);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 135):
	{
		genRepr__Bp5hmw3gImpkyC9cflWESLg_4(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 142):
	{
		genSwap__AQaGEWMAoGSH1pqI9bePiww_5(p, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 131):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym878_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym878_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym878_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym878_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym878_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym878_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T7_;
		nimZeroMem((void*)(&xX60gensym878_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym878_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_200));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym878_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym878_));
		aX60gensym878_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym878_));
		tmpX60gensym878_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym878_));
		bX60gensym878_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym878_));
		tmp2X60gensym878_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym878_));
		nimZeroMem((void*)T7_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T7_[0] = aX60gensym878_;
		T7_[1] = bX60gensym878_;
		T7_[2] = tmpX60gensym878_;
		T7_[3] = tmp2X60gensym878_;
		unsureAsgnRef((void**) (&(*r).res), percent___hPtLHtCXJsGExhBgLd7XoQ(T7_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 132):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w lhs;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w rhs;
		nimZeroMem((void*)(&lhs), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&rhs), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&lhs));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&rhs));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T11_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T14_;
			T11_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T11_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
			if (!((*T11_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29))) goto LA12_;
			nimZeroMem((void*)T14_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T14_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&lhs));
			T14_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&rhs));
			unsureAsgnRef((void**) (&(*r).res), percent___4Jn9cZxf8sC0AdAJhMJxbXw(T14_, 2));
		}
		goto LA9_;
		LA12_: ;
		{
			tyTuple__nsNHL3sm0TZE9bootw2pEXw T16_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a_2;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T17_;
			nimZeroMem((void*)(&T16_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&lhs), (&T16_));
			a_2 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			a_2 = T16_.Field0;
			tmp = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			tmp = T16_.Field1;
			nimZeroMem((void*)T17_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T17_[0] = a_2;
			T17_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&rhs));
			T17_[2] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___YZKT3ZfbnHPsIPSSq9bBi6A(T17_, 3));
		}
		LA9_: ;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 133):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y;
		nimZeroMem((void*)(&x), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&y), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y));
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T21_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* c;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T25_;
			T21_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T21_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*(*n)._kind_6.sons->data[((NI) 2)]).typ);
			if (!(T21_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA22_;
			nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T24_[0] = y.address;
			T24_[1] = y.res;
			c = percent___Xnze9a4kYSwHurdPnhyNGzQ(T24_, 2);
			nimZeroMem((void*)T25_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T25_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
			T25_[1] = c;
			unsureAsgnRef((void**) (&(*r).res), percent___LwxnZ9c6VZqWj0n0sORkrTw(T25_, 2));
		}
		goto LA19_;
		LA22_: ;
		{
			NIM_BOOL T27_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T30_;
			T27_ = (NIM_BOOL)0;
			T27_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, (*n)._kind_6.sons->data[((NI) 2)]);
			if (!T27_) goto LA28_;
			nimZeroMem((void*)T30_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T30_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
			T30_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
			unsureAsgnRef((void**) (&(*r).res), percent___LwxnZ9c6VZqWj0n0sORkrTw(T30_, 2));
		}
		goto LA19_;
		LA28_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* c_2;
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T32_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T35_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
			c_2 = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_FALSE);
			nimZeroMem((void*)T32_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T32_[0] = c_2;
			T32_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y));
			T32_[2] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*(*n)._kind_6.sons->data[((NI) 2)]).typ);
			T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T33_ = percent___0xZtTB2eXM1dRd9aneL5VPw(T32_, 3);
			T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T34_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T33_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T34_);
			nimZeroMem((void*)T35_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T35_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x));
			T35_[1] = c_2;
			unsureAsgnRef((void**) (&(*r).res), percent___LwxnZ9c6VZqWj0n0sORkrTw(T35_, 2));
		}
		LA19_: ;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 125):
	{
		genConStrStr__Bp5hmw3gImpkyC9cflWESLg_5(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 116):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym893_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym893_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym893_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym893_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym893_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym893_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T38_;
		nimZeroMem((void*)(&xX60gensym893_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym893_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_201));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym893_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym893_));
		aX60gensym893_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym893_));
		tmpX60gensym893_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym893_));
		bX60gensym893_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym893_));
		tmp2X60gensym893_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym893_));
		nimZeroMem((void*)T38_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T38_[0] = aX60gensym893_;
		T38_[1] = bX60gensym893_;
		T38_[2] = tmpX60gensym893_;
		T38_[3] = tmp2X60gensym893_;
		unsureAsgnRef((void**) (&(*r).res), percent___y5Z6ewsHLxj9ctzxTLPCLmw(T38_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 117):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym898_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym898_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym898_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym898_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym898_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym898_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T40_;
		nimZeroMem((void*)(&xX60gensym898_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym898_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_202));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym898_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym898_));
		aX60gensym898_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym898_));
		tmpX60gensym898_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym898_));
		bX60gensym898_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym898_));
		tmp2X60gensym898_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym898_));
		nimZeroMem((void*)T40_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T40_[0] = aX60gensym898_;
		T40_[1] = bX60gensym898_;
		T40_[2] = tmpX60gensym898_;
		T40_[3] = tmp2X60gensym898_;
		unsureAsgnRef((void**) (&(*r).res), percent___CHBd5pGE9c8nq4KNqM8K48g(T40_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 118):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym903_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym903_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym903_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym903_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym903_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym903_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T42_;
		nimZeroMem((void*)(&xX60gensym903_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym903_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_202));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym903_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym903_));
		aX60gensym903_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym903_));
		tmpX60gensym903_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym903_));
		bX60gensym903_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym903_));
		tmp2X60gensym903_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym903_));
		nimZeroMem((void*)T42_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T42_[0] = aX60gensym903_;
		T42_[1] = bX60gensym903_;
		T42_[2] = tmpX60gensym903_;
		T42_[3] = tmp2X60gensym903_;
		unsureAsgnRef((void**) (&(*r).res), percent___y2h2X887dhz5sEoD4C8ezQ(T42_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 143):
	{
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T46_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym910_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym910_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T54_;
			T46_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T46_ = mapType__3fHLBKCveV5k5hDCMQOL2g((*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			if (!!((T46_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)))) goto LA47_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
			aX60gensym910_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
			tmpX60gensym910_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
			{
				NIM_BOOL T51_;
				tyTuple__nsNHL3sm0TZE9bootw2pEXw _;
				T51_ = (NIM_BOOL)0;
				T51_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_203), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
				if (!T51_) goto LA52_;
				nimZeroMem((void*)(&_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
				maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&_));
				aX60gensym910_ = _.Field0;
				tmpX60gensym910_ = _.Field1;
			}
			LA52_: ;
			nimZeroMem((void*)T54_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T54_[0] = aX60gensym910_;
			T54_[1] = tmpX60gensym910_;
			unsureAsgnRef((void**) (&(*r).res), percent___dQfg2HrsVY6E7P22Nis1MA(T54_, 2));
			(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
		}
		goto LA44_;
		LA47_: ;
		{
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x_2;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T56_;
			nimZeroMem((void*)(&x_2), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_2));
			nimZeroMem((void*)T56_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T56_[0] = x_2.address;
			T56_[1] = x_2.res;
			unsureAsgnRef((void**) (&(*r).res), percent___0b2Bm7vpM8YAMKp9cuAwg3g(T56_, 2));
		}
		LA44_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 108):
	{
		genRepr__Bp5hmw3gImpkyC9cflWESLg_4(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 32):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 33):
	{
		genNew__AQaGEWMAoGSH1pqI9bePiww_6(p, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 43):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 144):
	{
		{
			NIM_BOOL T63_;
			T63_ = (NIM_BOOL)0;
			T63_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, (*n)._kind_6.sons->data[((NI) 1)]);
			if (!T63_) goto LA64_;
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		}
		goto LA61_;
		LA64_: ;
		{
			tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x_3;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T67_;
			nimZeroMem((void*)(&x_3), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_3));
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
			nimZeroMem((void*)T67_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T67_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x_3));
			T67_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*n).typ);
			unsureAsgnRef((void**) (&(*r).res), percent___RhAtD9c9aECDorIc8rDhMF9bw(T67_, 2));
		}
		LA61_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 150):
	{
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 31):
	{
		genOrd__Bp5hmw3gImpkyC9cflWESLg_6(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 37):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 39):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 36):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 38):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym919_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym919_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T76_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym919_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym919_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T73_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __2;
			T73_ = (NIM_BOOL)0;
			T73_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_208), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T73_) goto LA74_;
			nimZeroMem((void*)(&__2), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__2));
			aX60gensym919_ = __2.Field0;
			tmpX60gensym919_ = __2.Field1;
		}
		LA74_: ;
		nimZeroMem((void*)T76_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T76_[0] = aX60gensym919_;
		T76_[1] = tmpX60gensym919_;
		unsureAsgnRef((void**) (&(*r).res), percent___jS3RkUqTKs5pFAKfIQWYBA(T76_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 9):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym923_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym923_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T83_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym923_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym923_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T80_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __3;
			T80_ = (NIM_BOOL)0;
			T80_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_209), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T80_) goto LA81_;
			nimZeroMem((void*)(&__3), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__3));
			aX60gensym923_ = __3.Field0;
			tmpX60gensym923_ = __3.Field1;
		}
		LA81_: ;
		nimZeroMem((void*)T83_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T83_[0] = aX60gensym923_;
		T83_[1] = tmpX60gensym923_;
		unsureAsgnRef((void**) (&(*r).res), percent___GXGZYpSrdrt9cuZh4RoVHyw(T83_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 29):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T87_;
			T87_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T87_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
			if (!((IL64(34084860461056) &((NU64)1<<((NU)((*T87_).kind)&63U)))!=0)) goto LA88_;
			binaryUintExpr__lkqE7dycNUTKyDZxsrACPA(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_167));
		}
		goto LA85_;
		LA88_: ;
		{
			{
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym935_;
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym935_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym935_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym935_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym935_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym935_;
				tyArray__f7nG5LD47BH5K9c6mASit3g T95_;
				if (!!((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0))) goto LA93_;
				nimZeroMem((void*)(&xX60gensym935_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				nimZeroMem((void*)(&yX60gensym935_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym935_));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym935_));
				aX60gensym935_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym935_));
				tmpX60gensym935_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym935_));
				bX60gensym935_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym935_));
				tmp2X60gensym935_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym935_));
				nimZeroMem((void*)T95_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T95_[0] = aX60gensym935_;
				T95_[1] = bX60gensym935_;
				T95_[2] = tmpX60gensym935_;
				T95_[3] = tmp2X60gensym935_;
				unsureAsgnRef((void**) (&(*r).res), percent___fphSfWWyYSWLARtGIpYB9aw(T95_, 4));
				(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
			}
			goto LA91_;
			LA93_: ;
			{
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym940_;
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym940_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym940_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym940_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym940_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym940_;
				tyTuple__nsNHL3sm0TZE9bootw2pEXw __4;
				tyArray__f7nG5LD47BH5K9c6mASit3g T97_;
				nimZeroMem((void*)(&xX60gensym940_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				nimZeroMem((void*)(&yX60gensym940_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_171));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym940_));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym940_));
				aX60gensym940_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym940_));
				tmpX60gensym940_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym940_));
				bX60gensym940_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym940_));
				tmp2X60gensym940_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym940_));
				nimZeroMem((void*)(&__4), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
				maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym940_), (&__4));
				aX60gensym940_ = __4.Field0;
				tmpX60gensym940_ = __4.Field1;
				nimZeroMem((void*)T97_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T97_[0] = aX60gensym940_;
				T97_[1] = bX60gensym940_;
				T97_[2] = tmpX60gensym940_;
				T97_[3] = tmp2X60gensym940_;
				unsureAsgnRef((void**) (&(*r).res), percent___As9aDT7fkqstj16MQnIGPhA(T97_, 4));
				(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
			}
			LA91_: ;
		}
		LA85_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 30):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T101_;
			T101_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T101_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350136322320));
			if (!((IL64(34084860461056) &((NU64)1<<((NU)((*T101_).kind)&63U)))!=0)) goto LA102_;
			binaryUintExpr__lkqE7dycNUTKyDZxsrACPA(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_168));
		}
		goto LA99_;
		LA102_: ;
		{
			{
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym947_;
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym947_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym947_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym947_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym947_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym947_;
				tyArray__f7nG5LD47BH5K9c6mASit3g T109_;
				if (!!((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 5))&31U)))!=0))) goto LA107_;
				nimZeroMem((void*)(&xX60gensym947_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				nimZeroMem((void*)(&yX60gensym947_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym947_));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym947_));
				aX60gensym947_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym947_));
				tmpX60gensym947_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym947_));
				bX60gensym947_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym947_));
				tmp2X60gensym947_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym947_));
				nimZeroMem((void*)T109_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T109_[0] = aX60gensym947_;
				T109_[1] = bX60gensym947_;
				T109_[2] = tmpX60gensym947_;
				T109_[3] = tmp2X60gensym947_;
				unsureAsgnRef((void**) (&(*r).res), percent___eAZ21NmzzIsugeSSkcxIkQ(T109_, 4));
				(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
			}
			goto LA105_;
			LA107_: ;
			{
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym952_;
				tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym952_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym952_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym952_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym952_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym952_;
				tyTuple__nsNHL3sm0TZE9bootw2pEXw __5;
				tyArray__f7nG5LD47BH5K9c6mASit3g T111_;
				nimZeroMem((void*)(&xX60gensym952_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				nimZeroMem((void*)(&yX60gensym952_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_172));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym952_));
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym952_));
				aX60gensym952_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym952_));
				tmpX60gensym952_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym952_));
				bX60gensym952_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym952_));
				tmp2X60gensym952_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym952_));
				nimZeroMem((void*)(&__5), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
				maybeMakeTempAssignable__B84yKwsFUmIBPjvzzD9aZnw_2(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym952_), (&__5));
				aX60gensym952_ = __5.Field0;
				tmpX60gensym952_ = __5.Field1;
				nimZeroMem((void*)T111_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T111_[0] = aX60gensym952_;
				T111_[1] = bX60gensym952_;
				T111_[2] = tmpX60gensym952_;
				T111_[3] = tmp2X60gensym952_;
				unsureAsgnRef((void**) (&(*r).res), percent___D2dSwFjTnRSmeKOoMm6w0Q(T111_, 4));
				(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
			}
			LA105_: ;
		}
		LA99_: ;
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 137):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym956_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym956_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym956_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym956_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym956_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym956_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T113_;
		nimZeroMem((void*)(&xX60gensym956_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym956_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_211));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym956_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym956_));
		aX60gensym956_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym956_));
		tmpX60gensym956_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym956_));
		bX60gensym956_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym956_));
		tmp2X60gensym956_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym956_));
		nimZeroMem((void*)T113_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T113_[0] = aX60gensym956_;
		T113_[1] = bX60gensym956_;
		T113_[2] = tmpX60gensym956_;
		T113_[3] = tmp2X60gensym956_;
		unsureAsgnRef((void**) (&(*r).res), percent___pNrDKIPqQx0ZbHwzbw1pbA(T113_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 138):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x_4;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y_2;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T115_;
		tyTuple__nsNHL3sm0TZE9bootw2pEXw T116_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* a_3;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp_2;
		tyTuple__nsNHL3sm0TZE9bootw2pEXw T117_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* b;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2;
		tyArray__duFhZXIIlrbrM62cWjNekg T118_;
		nimZeroMem((void*)(&x_4), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&y_2), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_4));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y_2));
		T115_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T115_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36275087632017680));
		t = (*T115_).sons->data[((NI) 0)];
		nimZeroMem((void*)(&T116_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
		maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_4), (&T116_));
		a_3 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		a_3 = T116_.Field0;
		tmp_2 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		tmp_2 = T116_.Field1;
		nimZeroMem((void*)(&T117_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
		maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 2)], (&y_2), (&T117_));
		b = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		b = T117_.Field0;
		tmp2 = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		tmp2 = T117_.Field1;
		nimZeroMem((void*)T118_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
		T118_[0] = a_3;
		T118_[1] = b;
		T118_[2] = createVar__K9ag9aJJIngrApxv9aEbfdhIQ(p, t, NIM_FALSE);
		T118_[3] = tmp_2;
		T118_[4] = tmp2;
		unsureAsgnRef((void**) (&(*r).res), percent___wHvkjtGBH55bmbp0FmDDtA(T118_, 5));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 42):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym967_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym967_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T125_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_212));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym967_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym967_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T122_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __6;
			T122_ = (NIM_BOOL)0;
			T122_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_213), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T122_) goto LA123_;
			nimZeroMem((void*)(&__6), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__6));
			aX60gensym967_ = __6.Field0;
			tmpX60gensym967_ = __6.Field1;
		}
		LA123_: ;
		nimZeroMem((void*)T125_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T125_[0] = aX60gensym967_;
		T125_[1] = tmpX60gensym967_;
		unsureAsgnRef((void**) (&(*r).res), percent___5hzyGWCNjqgqPj0O7sSnkg(T125_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 121):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym971_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym971_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym971_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym971_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym971_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym971_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T127_;
		nimZeroMem((void*)(&xX60gensym971_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym971_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_214));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym971_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym971_));
		aX60gensym971_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym971_));
		tmpX60gensym971_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym971_));
		bX60gensym971_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym971_));
		tmp2X60gensym971_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym971_));
		nimZeroMem((void*)T127_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T127_[0] = aX60gensym971_;
		T127_[1] = bX60gensym971_;
		T127_[2] = tmpX60gensym971_;
		T127_[3] = tmp2X60gensym971_;
		unsureAsgnRef((void**) (&(*r).res), percent___l1wvVBeU1Nnie8cWddgPCA(T127_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 120):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym976_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym976_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym976_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym976_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym976_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym976_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T129_;
		nimZeroMem((void*)(&xX60gensym976_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym976_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_215));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym976_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym976_));
		aX60gensym976_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym976_));
		tmpX60gensym976_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym976_));
		bX60gensym976_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym976_));
		tmp2X60gensym976_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym976_));
		nimZeroMem((void*)T129_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T129_[0] = aX60gensym976_;
		T129_[1] = bX60gensym976_;
		T129_[2] = tmpX60gensym976_;
		T129_[3] = tmp2X60gensym976_;
		unsureAsgnRef((void**) (&(*r).res), percent___yVZN2jQzbJwg3E9cehLff9cg(T129_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 119):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym981_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym981_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym981_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym981_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym981_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym981_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T131_;
		nimZeroMem((void*)(&xX60gensym981_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym981_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_216));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym981_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym981_));
		aX60gensym981_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym981_));
		tmpX60gensym981_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym981_));
		bX60gensym981_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym981_));
		tmp2X60gensym981_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym981_));
		nimZeroMem((void*)T131_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T131_[0] = aX60gensym981_;
		T131_[1] = bX60gensym981_;
		T131_[2] = tmpX60gensym981_;
		T131_[3] = tmp2X60gensym981_;
		unsureAsgnRef((void**) (&(*r).res), percent___E9br9b8BVYaWzg6CXcn9c6EXw(T131_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 122):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym986_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym986_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym986_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym986_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym986_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym986_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T133_;
		nimZeroMem((void*)(&xX60gensym986_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym986_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_217));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym986_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym986_));
		aX60gensym986_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym986_));
		tmpX60gensym986_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym986_));
		bX60gensym986_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym986_));
		tmp2X60gensym986_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym986_));
		nimZeroMem((void*)T133_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T133_[0] = aX60gensym986_;
		T133_[1] = bX60gensym986_;
		T133_[2] = tmpX60gensym986_;
		T133_[3] = tmp2X60gensym986_;
		unsureAsgnRef((void**) (&(*r).res), percent___qPugJ1Nc2L1EdGwEF0AJ0Q(T133_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 123):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym991_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym991_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym991_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym991_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym991_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym991_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T135_;
		nimZeroMem((void*)(&xX60gensym991_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym991_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_218));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym991_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym991_));
		aX60gensym991_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym991_));
		tmpX60gensym991_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym991_));
		bX60gensym991_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym991_));
		tmp2X60gensym991_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym991_));
		nimZeroMem((void*)T135_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T135_[0] = aX60gensym991_;
		T135_[1] = bX60gensym991_;
		T135_[2] = tmpX60gensym991_;
		T135_[3] = tmp2X60gensym991_;
		unsureAsgnRef((void**) (&(*r).res), percent___HzZyrXo2QFynm1T8X76cCw(T135_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 124):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym996_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym996_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym996_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym996_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym996_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym996_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T137_;
		nimZeroMem((void*)(&xX60gensym996_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym996_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_219));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym996_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym996_));
		aX60gensym996_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym996_));
		tmpX60gensym996_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym996_));
		bX60gensym996_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym996_));
		tmp2X60gensym996_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym996_));
		nimZeroMem((void*)T137_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T137_[0] = aX60gensym996_;
		T137_[1] = bX60gensym996_;
		T137_[2] = tmpX60gensym996_;
		T137_[3] = tmp2X60gensym996_;
		unsureAsgnRef((void**) (&(*r).res), percent___O2nyVw4tGD6MMc6u7I9bH9cA(T137_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 40):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym1001_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym1001_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1001_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1001_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym1001_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym1001_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T139_;
		nimZeroMem((void*)(&xX60gensym1001_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym1001_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym1001_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym1001_));
		aX60gensym1001_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1001_));
		tmpX60gensym1001_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1001_));
		bX60gensym1001_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1001_));
		tmp2X60gensym1001_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1001_));
		nimZeroMem((void*)T139_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T139_[0] = aX60gensym1001_;
		T139_[1] = bX60gensym1001_;
		T139_[2] = tmpX60gensym1001_;
		T139_[3] = tmp2X60gensym1001_;
		unsureAsgnRef((void**) (&(*r).res), percent___IQYZUimFiAV9axFM9c64hKjA(T139_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 41):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym1006_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym1006_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1006_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1006_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym1006_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym1006_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T141_;
		nimZeroMem((void*)(&xX60gensym1006_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym1006_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym1006_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym1006_));
		aX60gensym1006_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1006_));
		tmpX60gensym1006_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1006_));
		bX60gensym1006_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1006_));
		tmp2X60gensym1006_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1006_));
		nimZeroMem((void*)T141_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T141_[0] = aX60gensym1006_;
		T141_[1] = bX60gensym1006_;
		T141_[2] = tmpX60gensym1006_;
		T141_[3] = tmp2X60gensym1006_;
		unsureAsgnRef((void**) (&(*r).res), percent___RCJU8UTq9cE0Jsi59anAbTIQ(T141_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 134):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w xX60gensym1011_;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w yX60gensym1011_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1011_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1011_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* bX60gensym1011_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp2X60gensym1011_;
		tyArray__f7nG5LD47BH5K9c6mASit3g T143_;
		nimZeroMem((void*)(&xX60gensym1011_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&yX60gensym1011_), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&xX60gensym1011_));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&yX60gensym1011_));
		aX60gensym1011_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1011_));
		tmpX60gensym1011_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&xX60gensym1011_));
		bX60gensym1011_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1011_));
		tmp2X60gensym1011_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&yX60gensym1011_));
		nimZeroMem((void*)T143_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
		T143_[0] = aX60gensym1011_;
		T143_[1] = bX60gensym1011_;
		T143_[2] = tmpX60gensym1011_;
		T143_[3] = tmp2X60gensym1011_;
		unsureAsgnRef((void**) (&(*r).res), percent___S6vmSaSCgC4V2L5H7OWeZg(T143_, 4));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 34):
	{
		genNewSeq__AQaGEWMAoGSH1pqI9bePiww_7(p, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 35):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1016_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1016_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T151_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) NIM_NIL));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym1016_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym1016_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T148_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __7;
			T148_ = (NIM_BOOL)0;
			T148_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_138), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T148_) goto LA149_;
			nimZeroMem((void*)(&__7), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__7));
			aX60gensym1016_ = __7.Field0;
			tmpX60gensym1016_ = __7.Field1;
		}
		LA149_: ;
		nimZeroMem((void*)T151_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T151_[0] = aX60gensym1016_;
		T151_[1] = tmpX60gensym1016_;
		unsureAsgnRef((void**) (&(*r).res), percent___9c1lq60gbfPY9cyjQN4YouTQ(T151_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 15):
	{
		genOf__Bp5hmw3gImpkyC9cflWESLg_7(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 151):
	{
		genDefault__Bp5hmw3gImpkyC9cflWESLg_8(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 155):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 149):
	{
		genReset__AQaGEWMAoGSH1pqI9bePiww_8(p, n);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 20):
	{
		genEcho__Bp5hmw3gImpkyC9cflWESLg_9(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 208) ... ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 255):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 22):
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 23):
	{
		NimStringDesc* T157_;
		T157_ = (NimStringDesc*)0;
		T157_ = nsuFormatSingleElem(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_226), (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T157_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__BxLwT0mhrtgTPodf1v3xjg_227, NIM_FALSE);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 145):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1024_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1024_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T164_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_211));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym1024_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym1024_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T161_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __8;
			T161_ = (NIM_BOOL)0;
			T161_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_228), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T161_) goto LA162_;
			nimZeroMem((void*)(&__8), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__8));
			aX60gensym1024_ = __8.Field0;
			tmpX60gensym1024_ = __8.Field1;
		}
		LA162_: ;
		nimZeroMem((void*)T164_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T164_[0] = aX60gensym1024_;
		T164_[1] = tmpX60gensym1024_;
		unsureAsgnRef((void**) (&(*r).res), percent___aoMj8hrcFi4HlPDZ9a9alpig(T164_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 146):
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* aX60gensym1028_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym1028_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T171_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_211));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		aX60gensym1028_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		tmpX60gensym1028_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
		{
			NIM_BOOL T168_;
			tyTuple__nsNHL3sm0TZE9bootw2pEXw __9;
			T168_ = (NIM_BOOL)0;
			T168_ = contains__KV0xCsBzaN9coqb7PG9au0oQ(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_229), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_204));
			if (!T168_) goto LA169_;
			nimZeroMem((void*)(&__9), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
			maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*n)._kind_6.sons->data[((NI) 1)], (&(*r)), (&__9));
			aX60gensym1028_ = __9.Field0;
			tmpX60gensym1028_ = __9.Field1;
		}
		LA169_: ;
		nimZeroMem((void*)T171_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T171_[0] = aX60gensym1028_;
		T171_[1] = tmpX60gensym1028_;
		unsureAsgnRef((void**) (&(*r).res), percent___Yj64cHk9ajrzJI39bfpBfOVA(T171_, 2));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 127):
	{
		genProcForSymIfNeeded__9aGDirKbsf9cN1iAWvMcXOKg(p, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
		genCall__Bp5hmw3gImpkyC9cflWESLg_11(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 147):
	{
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_230));
		genCall__Bp5hmw3gImpkyC9cflWESLg_11(p, n, r);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126):
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w x_5;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w y_3;
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w z;
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T175_;
		nimZeroMem((void*)(&x_5), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&y_3), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		nimZeroMem((void*)(&z), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&x_5));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&y_3));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 3)], (&z));
		nimZeroMem((void*)T175_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T175_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&x_5));
		T175_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&y_3));
		T175_[2] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&z));
		unsureAsgnRef((void**) (&(*r).res), percent___2MwhwhkHOiavfXQl9aey8nA(T175_, 3));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 148):
	{
		genMove__Bp5hmw3gImpkyC9cflWESLg_12(p, n, r);
	}
	break;
	default:
	{
		genCall__Bp5hmw3gImpkyC9cflWESLg_11(p, n, r);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__9aqB67Rnkf1OHu3XOk89bdcg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI i, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, NI* generated, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* paramType;
{	{
		NI T3_;
		NimStringDesc* T6_;
		NimStringDesc* T7_;
		NI T8_;
		NimStringDesc* T9_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!(T3_ <= i)) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T7_ = (NimStringDesc*)0;
		T7_ = nimIntToStr(i);
		T8_ = (NI)0;
		T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T9_ = (NimStringDesc*)0;
		T9_ = nimIntToStr((NI)(T8_ - ((NI) 1)));
		T6_ = rawNewString((T7_ ? T7_->Sup.len : 0) + (T9_ ? T9_->Sup.len : 0) + 71);
appendString(T6_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_233));
appendString(T6_, T7_);
appendString(T6_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_234));
appendString(T6_, T9_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__BxLwT0mhrtgTPodf1v3xjg_235, NIM_FALSE);
	}
	LA4_: ;
	it = (*n)._kind_6.sons->data[i];
	paramType = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__5mJADrRYkP3r9auuiuDZN9cQast(typ);
		if (!(i < T12_)) goto LA13_;
		paramType = (*(*typ).n)._kind_6.sons->data[i];
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = isCompileTimeOnly__F9ciDIanrWYqbJ4rgLlNAAg_3types((*paramType).typ);
			if (!T17_) goto LA18_;
			goto BeforeRet_;
		}
		LA18_: ;
	}
	LA13_: ;
	{
		if (!(paramType == 0)) goto LA22_;
		genArgNoParam__Bp5hmw3gImpkyC9cflWESLg_10(p, it, r);
	}
	goto LA20_;
	LA22_: ;
	{
		genArg__RI5RyHREFNXox9cpkCYH50g(p, it, (*paramType)._kind_4.sym, r, ((NI*) NIM_NIL));
	}
	LA20_: ;
	(*generated) += ((NI) 1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__4TT1TPwHmxERu3KEGU1QFw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NimStringDesc* pat, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	NI i;
	NI j;
	i = ((NI) 0);
	j = ((NI) 1);
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	{
		while (1) {
			if (!(i < (pat ? pat->Sup.len : 0))) goto LA2;
			switch (((NU8)(pat->data[i]))) {
			case 64:
			{
				NI generated;
				generated = ((NI) 0);
				{
					NI k;
					NI colontmp_;
					NI i_2;
					k = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					i_2 = j;
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA6;
							k = i_2;
							{
								if (!(((NI) 0) < generated)) goto LA9_;
								add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
							}
							LA9_: ;
							genOtherArg__9aqB67Rnkf1OHu3XOk89bdcg(p, n, k, typ, (&generated), r);
							i_2 += ((NI) 1);
						} LA6: ;
					}
				}
				i += ((NI) 1);
			}
			break;
			case 35:
			{
				NI generated_2;
				generated_2 = ((NI) 0);
				genOtherArg__9aqB67Rnkf1OHu3XOk89bdcg(p, n, j, typ, (&generated_2), r);
				j += ((NI) 1);
				i += ((NI) 1);
			}
			break;
			case 31:
			{
				add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_236));
				i += ((NI) 1);
			}
			break;
			case 29:
			{
				add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_237));
				i += ((NI) 1);
			}
			break;
			default:
			{
				NI start;
				start = i;
				{
					while (1) {
						if (!(i < (pat ? pat->Sup.len : 0))) goto LA16;
						{
							if (!!((((NU8)(pat->data[i])) == ((NU8)(64)) || ((NU8)(pat->data[i])) == ((NU8)(35)) || ((NU8)(pat->data[i])) == ((NU8)(31)) || ((NU8)(pat->data[i])) == ((NU8)(29))))) goto LA19_;
							i += ((NI) 1);
						}
						goto LA17_;
						LA19_: ;
						{
							goto LA15;
						}
						LA17_: ;
					} LA16: ;
				} LA15: ;
				{
					NimStringDesc* T26_;
					if (!(start <= (NI)(i - ((NI) 1)))) goto LA24_;
					T26_ = (NimStringDesc*)0;
					T26_ = substr__2yh9cer0ymNRHlOOg8P7IuA(pat, start, (NI)(i - ((NI) 1)));
					add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, T26_);
				}
				LA24_: ;
			}
			break;
			}
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__Bp5hmw3gImpkyC9cflWESLg_13)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w op;
{	f = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	{
		if (!((*f).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA3_;
		asgnRef((void**) (&(*f).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, f));
	}
	LA3_: ;
	{
		NimStringDesc* pat;
		if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0)) goto LA7_;
		pat = (*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).loc.r).data;
		{
			NimStringDesc* argX60gensym723_;
			if (!!((((NI) 0) < (pat ? pat->Sup.len : 0)))) goto LA11_;
			argX60gensym723_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_231);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym723_, TM__BxLwT0mhrtgTPodf1v3xjg_231);
		}
		LA11_: ;
		{
			NIM_BOOL T15_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
			T15_ = (NIM_BOOL)0;
			T15_ = contains__wAzSnEu9cCHHjvPQlWBZUeQ(pat, TM__BxLwT0mhrtgTPodf1v3xjg_232);
			if (!T15_) goto LA16_;
			typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
			genPatternCall__4TT1TPwHmxERu3KEGU1QFw(p, n, pat, typ, r);
			goto BeforeRet_;
		}
		LA16_: ;
	}
	LA7_: ;
	{
		NI T20_;
		T20_ = (NI)0;
		T20_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		if (!!((T20_ == ((NI) 1)))) goto LA21_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T31_;
			if (!((*r).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA25_;
			{
				if (!((*r).address == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA29_;
				liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_238), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__BxLwT0mhrtgTPodf1v3xjg_239, NIM_FALSE);
			}
			LA29_: ;
			nimZeroMem((void*)T31_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T31_[0] = (*r).address;
			T31_[1] = (*r).res;
			unsureAsgnRef((void**) (&(*r).res), percent___jadqNPnY9aM3oxYK6jarLrA(T31_, 2));
			unsureAsgnRef((void**) (&(*r).address), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
			(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
		}
		LA25_: ;
		add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_240));
	}
	LA21_: ;
	nimZeroMem((void*)(&op), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&op));
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, op.res);
	genArgs__1PNPBjb9aOT7yB9avaRcGbbQ(p, n, r, ((NI) 2));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__Bp5hmw3gImpkyC9cflWESLg_14)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&b), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_241));
	unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_242)));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
				}
				LA6_: ;
				it = (*n)._kind_6.sons->data[i];
				{
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA10_;
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 0)], (&a));
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 1)], (&b));
					nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T12_[0] = a.res;
					T12_[1] = b.res;
					T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T13_ = percent___Xnze9a4kYSwHurdPnhyNGzQ(T12_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T13_);
				}
				goto LA8_;
				LA10_: ;
				{
					gen__Bp5hmw3gImpkyC9cflWESLg(p, it, (&a));
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_105));
	{
		NIM_BOOL T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		T17_ = (NIM_BOOL)0;
		T17_ = isDeepConstExpr__sjm2oD6Aq9cG39aPE7CTvtmA(n, NIM_FALSE);
		if (!T17_) goto LA18_;
		(*(*p).g).unique += ((NI) 1);
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_243));
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*(*p).g).unique)));
		tmp = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T20_, T21_);
		nimZeroMem((void*)T22_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T22_[0] = tmp;
		T22_[1] = (*r).res;
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = percent___JRV6DlpqdegYGLcFjNPv0g(T22_, 2);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).constants, T23_);
		unsureAsgnRef((void**) (&(*r).res), tmp);
	}
	LA18_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__Bp5hmw3gImpkyC9cflWESLg_15)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_131)));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
				}
				LA6_: ;
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[i], (&a));
				{
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
					if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA10_;
					nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T12_[0] = a.address;
					T12_[1] = a.res;
					T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T13_ = percent___Xnze9a4kYSwHurdPnhyNGzQ(T12_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T13_);
				}
				goto LA8_;
				LA10_: ;
				{
					{
						NIM_BOOL T17_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T20_;
						T17_ = (NIM_BOOL)0;
						T17_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, (*n)._kind_6.sons->data[i]);
						if (!!(T17_)) goto LA18_;
						typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[i]).typ, IL64(36134350135273744));
						useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
						nimZeroMem((void*)T20_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T20_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
						T20_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, typ);
						a.res = percent___RhAtD9c9aECDorIc8rDhMF9bw(T20_, 2);
					}
					LA18_: ;
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, a.res);
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_132));
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__Bp5hmw3gImpkyC9cflWESLg_16)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_133)));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 0) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
				}
				LA6_: ;
				it = (*n)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA10_;
					it = (*it)._kind_6.sons->data[((NI) 1)];
				}
				LA10_: ;
				gen__Bp5hmw3gImpkyC9cflWESLg(p, it, (&a));
				typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*it).typ, IL64(36134350135273744));
				{
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T16_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
					if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA14_;
					nimZeroMem((void*)T16_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T16_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
					T16_[1] = a.address;
					T16_[2] = a.res;
					T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T17_ = percent___ryMkoQkM4zAjyp0800DrDQ(T16_, 3);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T17_);
				}
				goto LA12_;
				LA14_: ;
				{
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					{
						NIM_BOOL T21_;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T24_;
						T21_ = (NIM_BOOL)0;
						T21_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, it);
						if (!!(T21_)) goto LA22_;
						useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
						nimZeroMem((void*)T24_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T24_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
						T24_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, typ);
						a.res = percent___RhAtD9c9aECDorIc8rDhMF9bw(T24_, 2);
					}
					LA22_: ;
					nimZeroMem((void*)T25_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T25_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (i)));
					T25_[1] = a.res;
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = percent___iW9bjdQoXkul7L0e76qo8XQ(T25_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*r).res, T26_);
				}
				LA12_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*r).res, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_134));
}
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__Bp5hmw3gImpkyC9cflWESLg_17)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* initList;
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg fieldIDs;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T31_;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	initList = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	nimZeroMem((void*)(&fieldIDs), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&fieldIDs));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(((NI) 1) < i)) goto LA6_;
					add__yG4AKzsBRS1W4MANDlXQeg(&initList, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_104));
				}
				LA6_: ;
				it = (*n)._kind_6.sons->data[i];
				{
					NimStringDesc* argX60gensym1055_;
					if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34)))) goto LA10_;
					argX60gensym1055_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_244);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym1055_, TM__BxLwT0mhrtgTPodf1v3xjg_244);
				}
				LA10_: ;
				val = (*it)._kind_6.sons->data[((NI) 1)];
				gen__Bp5hmw3gImpkyC9cflWESLg(p, val, (&a));
				f = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
				{
					if (!((*f).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA14_;
					asgnRef((void**) (&(*f).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, f));
				}
				LA14_: ;
				incl__jENnK9c9bPE73pKmo2vYjpqg((&fieldIDs), (*f).Sup.id);
				typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*val).typ, IL64(36134350135273744));
				{
					tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T20_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
					if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA18_;
					nimZeroMem((void*)T20_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
					T20_[0] = (*f).loc.r;
					T20_[1] = a.address;
					T20_[2] = a.res;
					T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T21_ = percent___i3z9am8Hzy69bSo575pRdzGw(T20_, 3);
					add__IM4kcMNkkOLJtqdEqSxR8A(&initList, T21_);
				}
				goto LA16_;
				LA18_: ;
				{
					tyArray__mrugoXXRZUEeG9bEXo9auBKw T29_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
					{
						NIM_BOOL T25_;
						tyArray__mrugoXXRZUEeG9bEXo9auBKw T28_;
						T25_ = (NIM_BOOL)0;
						T25_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, val);
						if (!!(T25_)) goto LA26_;
						useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
						nimZeroMem((void*)T28_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
						T28_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
						T28_[1] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, typ);
						a.res = percent___RhAtD9c9aECDorIc8rDhMF9bw(T28_, 2);
					}
					LA26_: ;
					nimZeroMem((void*)T29_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
					T29_[0] = (*f).loc.r;
					T29_[1] = a.res;
					T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T30_ = percent___SkAQPSnCyiRvin57XULW4A(T29_, 2);
					add__IM4kcMNkkOLJtqdEqSxR8A(&initList, T30_);
				}
				LA16_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087638309136));
	createObjInitList__lQPYSYugh4oxbm9bTJCSJoA(p, t, (&fieldIDs), &initList);
	nimZeroMem((void*)T31_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T31_[0] = initList;
	unsureAsgnRef((void**) (&(*r).res), percent___Bym8FwH29aQE8fth9ar38yJQ(T31_, 1));
}
static N_INLINE(NIM_BOOL, contains__NUcXcdcbrUs0l4XrxCmsRgsystem)(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA s, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA, dotdot___Lid9a4g9biXDC8SKbcluO70gsystem)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag b) {
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genConv__Bp5hmw3gImpkyC9cflWESLg_18)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src;
	NIM_BOOL toInt;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T5_;
	NIM_BOOL fromInt;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T6_;
	NIM_BOOL toUint;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T7_;
	NIM_BOOL fromUint;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T8_;
{	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
	src = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
	{
		if (!((*dest).kind == (*src).kind)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	toInt = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T5_, (*dest).kind);
	T6_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	fromInt = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T6_, (*src).kind);
	T7_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	toUint = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T7_, (*dest).kind);
	T8_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	fromUint = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T8_, (*src).kind);
	{
		NIM_BOOL T11_;
		NIM_BOOL T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T17_;
		T11_ = (NIM_BOOL)0;
		T11_ = toUint;
		if (!(T11_)) goto LA12_;
		T13_ = (NIM_BOOL)0;
		T13_ = fromInt;
		if (T13_) goto LA14_;
		T13_ = fromUint;
		LA14_: ;
		T11_ = T13_;
		LA12_: ;
		if (!T11_) goto LA15_;
		trimmer = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*dest).size);
		nimZeroMem((void*)T17_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T17_[0] = (*r).res;
		T17_[1] = trimmer;
		unsureAsgnRef((void**) (&(*r).res), percent___QxiH9aM0po7vA19b2s1CjdEA(T17_, 2));
	}
	goto LA9_;
	LA15_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
		if (!((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1))) goto LA19_;
		nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T21_[0] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___CbbQqCp6itJgwKVRfTr69ag(T21_, 1));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	goto LA9_;
	LA19_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T25_;
		if (!toInt) goto LA23_;
		nimZeroMem((void*)T25_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T25_[0] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___HWgoOloM1oqcI9aZ9bEkoBhg(T25_, 1));
	}
	goto LA9_;
	LA23_: ;
	{
	}
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCheckedFieldOp__iKztcH0Tujg1djuGYyE69cQ)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* addrTyp, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* accessExpr;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* checkExpr;
	NIM_BOOL negCheck;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* disc;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w setx;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w obj;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T26_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
	NimStringDesc* msg;
	tyArray__duFhZXIIlrbrM62cWjNekg T29_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
	{
		NimStringDesc* argX60gensym571_;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46)))) goto LA3_;
		argX60gensym571_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_250);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym571_, TM__BxLwT0mhrtgTPodf1v3xjg_250);
	}
	LA3_: ;
	accessExpr = (*n)._kind_6.sons->data[((NI) 0)];
	checkExpr = (*n)._kind_6.sons->data[((NI) 1)];
	negCheck = ((*(*(*checkExpr)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 96));
	{
		NI T9_;
		if (!negCheck) goto LA7_;
		T9_ = (NI)0;
		T9_ = len__P89cqdlERShb9alU3iC0yj8wast(checkExpr);
		checkExpr = (*checkExpr)._kind_6.sons->data[(NI)(T9_ - ((NI) 1))];
	}
	LA7_: ;
	field = (*(*accessExpr)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	{
		NimStringDesc* argX60gensym581_;
		if (!!(((*field).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19)))) goto LA12_;
		argX60gensym581_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_251);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym581_, TM__BxLwT0mhrtgTPodf1v3xjg_251);
	}
	LA12_: ;
	{
		if (!((*field).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA16_;
		asgnRef((void**) (&(*field).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, field));
	}
	LA16_: ;
	disc = (*(*checkExpr)._kind_6.sons->data[((NI) 2)])._kind_4.sym;
	{
		NimStringDesc* argX60gensym585_;
		if (!!(((*disc).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19)))) goto LA20_;
		argX60gensym585_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_252);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym585_, TM__BxLwT0mhrtgTPodf1v3xjg_252);
	}
	LA20_: ;
	{
		if (!((*disc).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA24_;
		asgnRef((void**) (&(*disc).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, disc));
	}
	LA24_: ;
	nimZeroMem((void*)(&setx), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*checkExpr)._kind_6.sons->data[((NI) 1)], (&setx));
	nimZeroMem((void*)(&obj), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*accessExpr)._kind_6.sons->data[((NI) 0)], (&obj));
	tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
	nimZeroMem((void*)T26_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T26_[0] = tmp;
	T26_[1] = obj.res;
	T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T27_ = percent___JRV6DlpqdegYGLcFjNPv0g(T26_, 2);
	T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T28_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T27_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T28_);
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_253));
	useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_157));
	msg = genFieldDefect__NFvxltQN2CgyfP8SjDTS1g(field, disc);
	nimZeroMem((void*)T29_, sizeof(tyArray__duFhZXIIlrbrM62cWjNekg));
	T29_[0] = setx.res;
	T29_[1] = tmp;
	T29_[2] = (*disc).loc.r;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T34_;
		if (!negCheck) goto LA32_;
		nimZeroMem((void*)T34_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T29_[3] = percent___tDrtnFWakp63hyE9cfImgZw(T34_, 0);
	}
	goto LA30_;
	LA32_: ;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T36_;
		nimZeroMem((void*)T36_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T29_[3] = percent___JwpI2xnYNfR68HstfDi1yQ(T36_, 0);
	}
	LA30_: ;
	T29_[4] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(msg, NIM_TRUE);
	T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T37_ = percent___Anf1UHjOzz9aHgMOgtnEPZA(T29_, 5);
	T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T38_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T37_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T38_);
	{
		NIM_BOOL T41_;
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T43_;
		NimStringDesc* T46_;
		T41_ = (NIM_BOOL)0;
		T41_ = !((addrTyp == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T41_)) goto LA42_;
		T43_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T43_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, addrTyp);
		T41_ = (T43_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
		LA42_: ;
		if (!T41_) goto LA44_;
		(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
		T46_ = (NimStringDesc*)0;
		T46_ = dollar___mZ66tEveFIQokq3arf8Klw((*field).loc.r);
		unsureAsgnRef((void**) (&(*r).res), makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T46_, NIM_TRUE));
		unsureAsgnRef((void**) (&(*r).address), tmp);
	}
	goto LA39_;
	LA44_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T48_;
		(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
		nimZeroMem((void*)T48_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T48_[0] = tmp;
		T48_[1] = (*field).loc.r;
		unsureAsgnRef((void**) (&(*r).res), percent___paA0sar8RKZqiwEaDfWo2A(T48_, 2));
	}
	LA39_: ;
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(NI, getFieldPosition__DLbHFD2eUjMEos1A21BcJw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f) {
	NI result;
	result = (NI)0;
	switch ((*f).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		result = ((NI) ((*f)._kind_1.intVal));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = (*(*f)._kind_4.sym).position;
	}
	break;
	default:
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*f).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_255), TM__BxLwT0mhrtgTPodf1v3xjg_256);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldAddr__Bp5hmw3gImpkyC9cflWESLg_20)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		b = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		b = n;
	}
	LA1_: ;
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*b)._kind_6.sons->data[((NI) 0)], (&a));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		NimStringDesc* T11_;
		NI T12_;
		NimStringDesc* T13_;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*b)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
		if (!((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA9_;
		T11_ = (NimStringDesc*)0;
		T12_ = (NI)0;
		T12_ = getFieldPosition__DLbHFD2eUjMEos1A21BcJw(p, (*b)._kind_6.sons->data[((NI) 1)]);
		T13_ = (NimStringDesc*)0;
		T13_ = nimIntToStr(T12_);
		T11_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 5);
appendString(T11_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_254));
appendString(T11_, T13_);
		unsureAsgnRef((void**) (&(*r).res), makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T11_, NIM_TRUE));
	}
	goto LA6_;
	LA9_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
		NimStringDesc* T23_;
		{
			if (!!(((*(*b)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA17_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*b)._kind_6.sons->data[((NI) 1)]).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_257), TM__BxLwT0mhrtgTPodf1v3xjg_258);
		}
		LA17_: ;
		f = (*(*b)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		{
			if (!((*f).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA21_;
			asgnRef((void**) (&(*f).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, f));
		}
		LA21_: ;
		T23_ = (NimStringDesc*)0;
		T23_ = dollar___mZ66tEveFIQokq3arf8Klw((*f).loc.r);
		unsureAsgnRef((void**) (&(*r).res), makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T23_, NIM_TRUE));
	}
	LA6_: ;
	{
		NimStringDesc* argX60gensym554_;
		if (!!(!((a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))))) goto LA26_;
		argX60gensym554_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_259);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym554_, TM__BxLwT0mhrtgTPodf1v3xjg_259);
	}
	LA26_: ;
	unsureAsgnRef((void**) (&(*r).address), a.res);
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldAccess__Bp5hmw3gImpkyC9cflWESLg_21)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* otyp;
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	(*r).typ = mapType__3fHLBKCveV5k5hDCMQOL2g((*n).typ);
	otyp = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T5_;
		NI T6_;
		if (!((*otyp).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T5_[0] = (*r).res;
		T6_ = (NI)0;
		T6_ = getFieldPosition__DLbHFD2eUjMEos1A21BcJw(p, (*n)._kind_6.sons->data[((NI) 1)]);
		T5_[1] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (T6_)));
		unsureAsgnRef((void**) (&(*r).res), percent___5TB09c2Iz60T0YagbSbI5RQ(T5_, 2));
		{
			if (!((*r).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA9_;
			{
				NIM_BOOL T13_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym559_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T16_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T17_;
				T13_ = (NIM_BOOL)0;
				T13_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, (*n)._kind_6.sons->data[((NI) 0)]);
				if (!T13_) goto LA14_;
				tmpX60gensym559_ = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
				nimZeroMem((void*)T16_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T16_[0] = tmpX60gensym559_;
				T16_[1] = (*r).res;
				unsureAsgnRef((void**) (&(*r).address), percent___U9b6hkqS6N7XIWr0gy8z9bug(T16_, 2));
				nimZeroMem((void*)T17_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T17_[0] = tmpX60gensym559_;
				unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T17_, 1));
				unsureAsgnRef((void**) (&(*r).tmpLoc), tmpX60gensym559_);
			}
			goto LA11_;
			LA14_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T19_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T20_;
				nimZeroMem((void*)T19_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T19_[0] = (*r).res;
				unsureAsgnRef((void**) (&(*r).address), percent___TmulmJw2SZspd0rz2PYvQw(T19_, 1));
				nimZeroMem((void*)T20_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T20_[0] = (*r).res;
				unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T20_, 1));
			}
			LA11_: ;
		}
		LA9_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T30_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA24_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_260), TM__BxLwT0mhrtgTPodf1v3xjg_261);
		}
		LA24_: ;
		f = (*(*n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
		{
			if (!((*f).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA28_;
			asgnRef((void**) (&(*f).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, f));
		}
		LA28_: ;
		nimZeroMem((void*)T30_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T30_[0] = (*r).res;
		T30_[1] = (*f).loc.r;
		unsureAsgnRef((void**) (&(*r).res), percent___paA0sar8RKZqiwEaDfWo2A(T30_, 2));
		{
			if (!((*r).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA33_;
			{
				NIM_BOOL T37_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpX60gensym568_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T40_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T41_;
				T37_ = (NIM_BOOL)0;
				T37_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, (*n)._kind_6.sons->data[((NI) 1)]);
				if (!T37_) goto LA38_;
				tmpX60gensym568_ = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
				nimZeroMem((void*)T40_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T40_[0] = tmpX60gensym568_;
				T40_[1] = (*r).res;
				unsureAsgnRef((void**) (&(*r).address), percent___U9b6hkqS6N7XIWr0gy8z9bug(T40_, 2));
				nimZeroMem((void*)T41_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T41_[0] = tmpX60gensym568_;
				unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T41_, 1));
				unsureAsgnRef((void**) (&(*r).tmpLoc), tmpX60gensym568_);
			}
			goto LA35_;
			LA38_: ;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T43_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T44_;
				nimZeroMem((void*)T43_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T43_[0] = (*r).res;
				unsureAsgnRef((void**) (&(*r).address), percent___TmulmJw2SZspd0rz2PYvQw(T43_, 1));
				nimZeroMem((void*)T44_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T44_[0] = (*r).res;
				unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T44_, 1));
			}
			LA35_: ;
		}
		LA33_: ;
	}
	LA1_: ;
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayAddr__Bp5hmw3gImpkyC9cflWESLg_22)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w b;
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA first;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
	tyTuple__nsNHL3sm0TZE9bootw2pEXw T6_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&b), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&first), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
	(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64))) goto LA3_;
		m = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		m = n;
	}
	LA1_: ;
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*m)._kind_6.sons->data[((NI) 0)], (&a));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*m)._kind_6.sons->data[((NI) 1)], (&b));
	nimZeroMem((void*)(&T6_), sizeof(tyTuple__nsNHL3sm0TZE9bootw2pEXw));
	maybeMakeTemp__B84yKwsFUmIBPjvzzD9aZnw(p, (*m)._kind_6.sons->data[((NI) 0)], (&a), (&T6_));
	x = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	x = T6_.Field0;
	tmp = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	tmp = T6_.Field1;
	unsureAsgnRef((void**) (&(*r).address), x);
	typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*m)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
	{
		if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16))) goto LA9_;
		first = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*p).module).config, (*typ).sons->data[((NI) 0)]);
	}
	LA9_: ;
	{
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 4))&31U)))!=0)) goto LA13_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_210));
		{
			NIM_BOOL T17_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T20_;
			T17_ = (NIM_BOOL)0;
			T17_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(first, IL64(0));
			if (!T17_) goto LA18_;
			nimZeroMem((void*)T20_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T20_[0] = b.res;
			T20_[1] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___CK0iwKv7s4cZGqPi5rQF6w(T20_, 2));
		}
		goto LA15_;
		LA18_: ;
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T22_;
			nimZeroMem((void*)T22_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T22_[0] = b.res;
			T22_[1] = rope__oMf9cufugVin4CJLwmEes2A(first);
			T22_[2] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___PT2vKgDWcFJy9citUgxhMPg(T22_, 3));
		}
		LA15_: ;
	}
	goto LA11_;
	LA13_: ;
	{
		NIM_BOOL T24_;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T27_;
		T24_ = (NIM_BOOL)0;
		T24_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(first, IL64(0));
		if (!!(T24_)) goto LA25_;
		nimZeroMem((void*)T27_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T27_[0] = b.res;
		T27_[1] = rope__oMf9cufugVin4CJLwmEes2A(first);
		unsureAsgnRef((void**) (&(*r).res), percent___JM349c89cyw9auxMIJuWihRCA(T27_, 2));
	}
	goto LA11_;
	LA25_: ;
	{
		unsureAsgnRef((void**) (&(*r).res), b.res);
	}
	LA11_: ;
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, genAddr__Bp5hmw3gImpkyC9cflWESLg_19)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	switch ((*(*n)._kind_6.sons->data[((NI) 0)]).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((*s).loc.r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA4_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_245), TM__BxLwT0mhrtgTPodf1v3xjg_246);
		}
		LA4_: ;
		switch ((*s).kind) {
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3):
		{
			unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
			unsureAsgnRef((void**) (&(*r).address), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
			(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
		}
		break;
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
		case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11):
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA jsType;
			(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
			jsType = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*n).typ);
			{
				if (!(jsType == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8))) goto LA10_;
				(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* vX60gensym617_;
					NIM_BOOL T14_;
					NIM_BOOL T15_;
					vX60gensym617_ = s;
					T14_ = (NIM_BOOL)0;
					T15_ = (NIM_BOOL)0;
					T15_ = !(((131080 & (*vX60gensym617_).flags) == 0));
					if (!(T15_)) goto LA16_;
					T15_ = ((192 & (*vX60gensym617_).flags) == 0);
					LA16_: ;
					T14_ = T15_;
					if (!(T14_)) goto LA17_;
					T14_ = !(((128544 &((NU32)1<<((NU)((*vX60gensym617_).kind)&31U)))!=0));
					LA17_: ;
					if (!T14_) goto LA18_;
					unsureAsgnRef((void**) (&(*r).res), amp___Z7W1o5nPSc3ExfO5f7j1Gg((*s).loc.r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_247)));
				}
				goto LA12_;
				LA18_: ;
				{
					unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
				}
				LA12_: ;
				unsureAsgnRef((void**) (&(*r).address), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
			}
			goto LA8_;
			LA10_: ;
			{
				NIM_BOOL T22_;
				T22_ = (NIM_BOOL)0;
				T22_ = !(((131080 & (*s).flags) == 0));
				if (T22_) goto LA23_;
				T22_ = (jsType == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9));
				LA23_: ;
				if (!T22_) goto LA24_;
				(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
				unsureAsgnRef((void**) (&(*r).address), (*s).loc.r);
				unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_92)));
			}
			goto LA8_;
			LA24_: ;
			{
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
			}
			LA8_: ;
		}
		break;
		default:
		{
			tyTuple__Fb1Z8PVtzpSjrvQ67oA88w T28_;
			NimStringDesc* T29_;
			nimZeroMem((void*)(&T28_), sizeof(tyTuple__Fb1Z8PVtzpSjrvQ67oA88w));
			T28_.Field0 = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_248));
			T28_.Field1 = (*s).kind;
			T29_ = (NimStringDesc*)0;
			T29_ = dollar___HZ7mfC6lJSSHM4bdhgCYTg(T28_);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T29_, TM__BxLwT0mhrtgTPodf1v3xjg_249);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		genCheckedFieldOp__iKztcH0Tujg1djuGYyE69cQ(p, (*n)._kind_6.sons->data[((NI) 0)], (*n).typ, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T34_;
			T34_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T34_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*n).typ);
			if (!(T34_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA35_;
			genFieldAddr__Bp5hmw3gImpkyC9cflWESLg_20(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		}
		goto LA32_;
		LA35_: ;
		{
			genFieldAccess__Bp5hmw3gImpkyC9cflWESLg_21(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		}
		LA32_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
		{
			if (!((IL64(281475111911424) &((NU64)1<<((NU)((*ty).kind)&63U)))!=0)) goto LA41_;
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		}
		goto LA39_;
		LA41_: ;
		{
			tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kindOfIndexedExpr;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T44_;
			T44_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T44_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
			kindOfIndexedExpr = (*T44_).kind;
			switch (kindOfIndexedExpr) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
			{
				genArrayAddr__Bp5hmw3gImpkyC9cflWESLg_22(p, (*n)._kind_6.sons->data[((NI) 0)], r);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
			{
				genFieldAddr__Bp5hmw3gImpkyC9cflWESLg_20(p, (*n)._kind_6.sons->data[((NI) 0)], r);
			}
			break;
			default:
			{
				NimStringDesc* T48_;
				T48_ = (NimStringDesc*)0;
				T48_ = rawNewString((reprEnum((NI)kindOfIndexedExpr, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)kindOfIndexedExpr, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 21);
appendString(T48_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_262));
appendString(T48_, reprEnum((NI)kindOfIndexedExpr, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T48_, 41);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, T48_, TM__BxLwT0mhrtgTPodf1v3xjg_263);
			}
			break;
			}
		}
		LA39_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		{
			NI T55_;
			T55_ = (NI)0;
			T55_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T55_ == ((NI) 1))) goto LA56_;
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		}
		goto LA53_;
		LA56_: ;
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_264), TM__BxLwT0mhrtgTPodf1v3xjg_265);
		}
		LA53_: ;
	}
	break;
	default:
	{
		NimStringDesc* T60_;
		T60_ = (NimStringDesc*)0;
		T60_ = rawNewString((reprEnum((NI)(*(*n)._kind_6.sons->data[((NI) 0)]).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*(*n)._kind_6.sons->data[((NI) 0)]).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 9);
appendString(T60_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_266));
appendString(T60_, reprEnum((NI)(*(*n)._kind_6.sons->data[((NI) 0)]).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*(*n)._kind_6.sons->data[((NI) 0)]).info, T60_, TM__BxLwT0mhrtgTPodf1v3xjg_267);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genDeref__Bp5hmw3gImpkyC9cflWESLg_23)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
	tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA t;
	it = (*n)._kind_6.sons->data[((NI) 0)];
	t = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*it).typ);
	{
		if (!(t == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8))) goto LA3_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, it, r);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
		nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, it, (&a));
		(*r).kind = a.kind;
		(*r).typ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*n).typ);
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T10_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T11_;
			if (!((*r).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA8_;
			tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
			nimZeroMem((void*)T10_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T10_[0] = tmp;
			T10_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
			unsureAsgnRef((void**) (&(*r).address), percent___U9b6hkqS6N7XIWr0gy8z9bug(T10_, 2));
			nimZeroMem((void*)T11_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T11_[0] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T11_, 1));
			unsureAsgnRef((void**) (&(*r).tmpLoc), tmp);
		}
		goto LA6_;
		LA8_: ;
		{
			if (!(a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA13_;
			{
				if (!!((a.tmpLoc == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA17_;
				unsureAsgnRef((void**) (&(*r).tmpLoc), a.tmpLoc);
			}
			LA17_: ;
			unsureAsgnRef((void**) (&(*r).res), rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a)));
		}
		goto LA6_;
		LA13_: ;
		{
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_268), TM__BxLwT0mhrtgTPodf1v3xjg_269);
		}
		LA6_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayAccess__Bp5hmw3gImpkyC9cflWESLg_24)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ty;
	ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		if (!((IL64(175921866735616) &((NU64)1<<((NU)((*ty).kind)&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(ty);
		ty = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T5_, IL64(36134350144710928));
	}
	LA3_: ;
	switch ((*ty).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		genArrayAddr__Bp5hmw3gImpkyC9cflWESLg_22(p, n, r);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		genFieldAddr__Bp5hmw3gImpkyC9cflWESLg_20(p, n, r);
	}
	break;
	default:
	{
		NimStringDesc* T9_;
		T9_ = (NimStringDesc*)0;
		T9_ = rawNewString((reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 21);
appendString(T9_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_262));
appendString(T9_, reprEnum((NI)(*ty).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
appendChar(T9_, 41);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T9_, TM__BxLwT0mhrtgTPodf1v3xjg_270);
	}
	break;
	}
	(*r).typ = mapType__3fHLBKCveV5k5hDCMQOL2g((*n).typ);
	{
		if (!((*r).res == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA12_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_271), TM__BxLwT0mhrtgTPodf1v3xjg_272);
	}
	LA12_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T18_;
		if (!((*ty).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29))) goto LA16_;
		nimZeroMem((void*)T18_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T18_[0] = (*r).address;
		T18_[1] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___UxL9a0Hh7Km0Z0DIk7hp9cBA(T18_, 2));
	}
	goto LA14_;
	LA16_: ;
	{
		if (!((*r).typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA20_;
		{
			NIM_BOOL T24_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T27_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T28_;
			T24_ = (NIM_BOOL)0;
			T24_ = needsTemp__63ZTZNC9c5no8E73V2FDEMA_2(p, (*n)._kind_6.sons->data[((NI) 0)]);
			if (!T24_) goto LA25_;
			tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
			nimZeroMem((void*)T27_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T27_[0] = tmp;
			T27_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
			unsureAsgnRef((void**) (&(*r).address), percent___U9b6hkqS6N7XIWr0gy8z9bug(T27_, 2));
			nimZeroMem((void*)T28_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T28_[0] = tmp;
			unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T28_, 1));
			unsureAsgnRef((void**) (&(*r).tmpLoc), tmp);
		}
		goto LA22_;
		LA25_: ;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* x;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T30_;
			tyArray__JiWwrsTRC6xqNlGcBthSVA T31_;
			x = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*r)));
			nimZeroMem((void*)T30_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T30_[0] = x;
			unsureAsgnRef((void**) (&(*r).address), percent___TmulmJw2SZspd0rz2PYvQw(T30_, 1));
			nimZeroMem((void*)T31_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T31_[0] = x;
			unsureAsgnRef((void**) (&(*r).res), percent___UFeu00R8dNoyzL8vy54mnQ(T31_, 1));
		}
		LA22_: ;
	}
	goto LA14_;
	LA20_: ;
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T33_;
		nimZeroMem((void*)T33_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T33_[0] = (*r).address;
		T33_[1] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___jadqNPnY9aM3oxYK6jarLrA(T33_, 2));
	}
	LA14_: ;
	(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, upConv__Bp5hmw3gImpkyC9cflWESLg_25)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
}
N_LIB_PRIVATE N_NIMCALL(void, genCast__Bp5hmw3gImpkyC9cflWESLg_26)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src;
	NIM_BOOL toInt;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T5_;
	NIM_BOOL toUint;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T6_;
	NIM_BOOL fromInt;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T7_;
	NIM_BOOL fromUint;
	tyObject_HSlice__HjDAjiFsTWGmlZ9cd8nEusA T8_;
{	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
	src = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
	{
		if (!((*dest).kind == (*src).kind)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	toInt = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T5_, (*dest).kind);
	T6_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	toUint = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T6_, (*dest).kind);
	T7_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	fromInt = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T7_, (*src).kind);
	T8_ = dotdot___Lid9a4g9biXDC8SKbcluO70gsystem(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	fromUint = contains__NUcXcdcbrUs0l4XrxCmsRgsystem(T8_, (*src).kind);
	{
		NIM_BOOL T11_;
		NIM_BOOL T13_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T17_;
		T11_ = (NIM_BOOL)0;
		T11_ = toUint;
		if (!(T11_)) goto LA12_;
		T13_ = (NIM_BOOL)0;
		T13_ = fromInt;
		if (T13_) goto LA14_;
		T13_ = fromUint;
		LA14_: ;
		T11_ = T13_;
		LA12_: ;
		if (!T11_) goto LA15_;
		trimmer = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*dest).size);
		nimZeroMem((void*)T17_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T17_[0] = (*r).res;
		T17_[1] = trimmer;
		unsureAsgnRef((void**) (&(*r).res), percent___QxiH9aM0po7vA19b2s1CjdEA(T17_, 2));
	}
	goto LA9_;
	LA15_: ;
	{
		if (!toInt) goto LA19_;
		{
			if (!fromInt) goto LA23_;
			goto BeforeRet_;
		}
		goto LA21_;
		LA23_: ;
		{
			if (!fromUint) goto LA26_;
			{
				NIM_BOOL T30_;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T34_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*src).size == IL64(4));
				if (!(T30_)) goto LA31_;
				T30_ = ((*dest).size == IL64(4));
				LA31_: ;
				if (!T30_) goto LA32_;
				nimZeroMem((void*)T34_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T34_[0] = (*r).res;
				unsureAsgnRef((void**) (&(*r).res), percent___FZt89ajG3TKAhfL9aW4s7hcA(T34_, 1));
			}
			goto LA28_;
			LA32_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* trimmer_2;
				NimStringDesc* minuend;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T40_;
				trimmer_2 = unsignedTrimmerJS__Z9b4MKfBgROPw39c1OtIrpwQ((*dest).size);
				switch ((*dest).size) {
				case ((NI) 1):
				{
					minuend = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_273));
				}
				break;
				case ((NI) 2):
				{
					minuend = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_274));
				}
				break;
				case ((NI) 4):
				{
					minuend = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_275));
				}
				break;
				default:
				{
					minuend = ((NimStringDesc*) NIM_NIL);
				}
				break;
				}
				nimZeroMem((void*)T40_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T40_[0] = rope__yShmEg9cffWxI7s5XzEKBow(minuend);
				T40_[1] = (*r).res;
				T40_[2] = trimmer_2;
				unsureAsgnRef((void**) (&(*r).res), percent___5GaE39bOOeQZy3EFOEIy5QA(T40_, 3));
			}
			LA28_: ;
		}
		goto LA21_;
		LA26_: ;
		LA21_: ;
	}
	goto LA9_;
	LA19_: ;
	{
		NIM_BOOL T42_;
		NIM_BOOL T43_;
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T45_;
		tyArray__qTjAvTvKF9anytN1At69aJMQ T49_;
		T42_ = (NIM_BOOL)0;
		T43_ = (NIM_BOOL)0;
		T43_ = ((*src).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
		if (!(T43_)) goto LA44_;
		T45_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T45_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, src);
		T43_ = (T45_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8));
		LA44_: ;
		T42_ = T43_;
		if (!(T42_)) goto LA46_;
		T42_ = ((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
		LA46_: ;
		if (!T42_) goto LA47_;
		unsureAsgnRef((void**) (&(*r).address), (*r).res);
		nimZeroMem((void*)T49_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		unsureAsgnRef((void**) (&(*r).res), percent___SA9cvbR3uc9cP50nnaEBJctw(T49_, 0));
		(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
	}
	goto LA9_;
	LA47_: ;
	{
		NIM_BOOL T51_;
		NIM_BOOL T52_;
		tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T54_;
		T51_ = (NIM_BOOL)0;
		T52_ = (NIM_BOOL)0;
		T52_ = ((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
		if (!(T52_)) goto LA53_;
		T54_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
		T54_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, dest);
		T52_ = (T54_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8));
		LA53_: ;
		T51_ = T52_;
		if (!(T51_)) goto LA55_;
		T51_ = ((*src).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
		LA55_: ;
		if (!T51_) goto LA56_;
		unsureAsgnRef((void**) (&(*r).res), (*r).address);
		(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8);
	}
	goto LA9_;
	LA56_: ;
	LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__hP2w9bfjeb9a8Gw7OVBCznWw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r, NimStringDesc* magic) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w b;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&b), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 3))&31U)))!=0));
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
		T5_ = ((IL64(34084860461056) &((NU64)1<<((NU)((*T6_).kind)&63U)))!=0);
		if (!(T5_)) goto LA7_;
		T5_ = !((((*(*(*p).module).config).legacyFeatures &((NU8)1<<((NU)(((tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA) 1))&7U)))!=0));
		LA7_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA8_;
	}
	goto LA1_;
	LA8_: ;
	{
		tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T11_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], (&a));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 2)], (&b));
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_276));
		nimZeroMem((void*)T11_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
		T11_[0] = (*r).res;
		T11_[1] = a.res;
		T11_[2] = b.res;
		unsureAsgnRef((void**) (&(*r).res), percent___KweYGQ9bFYg76nmoxpk8ksA(T11_, 3));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__Bp5hmw3gImpkyC9cflWESLg_27)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72))) goto LA3_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], r);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		{
			if (!((*r).res == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_279), TM__BxLwT0mhrtgTPodf1v3xjg_280);
		}
		LA8_: ;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_223));
		nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T10_[0] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___AhY63HjLy2bPe9bslUNBuBQ(T10_, 1));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__Bp5hmw3gImpkyC9cflWESLg_28)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	{
		if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71))) goto LA3_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)], r);
	}
	goto LA1_;
	LA3_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
		{
			if (!((*r).res == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA8_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_281), TM__BxLwT0mhrtgTPodf1v3xjg_282);
		}
		LA8_: ;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_183));
		nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T10_[0] = (*r).res;
		unsureAsgnRef((void**) (&(*r).res), percent___NPgb4kECDcV8MICSil6Rjw(T10_, 1));
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__Bp5hmw3gImpkyC9cflWESLg_29)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	NI idx;
	NI T1_;
	NI labl;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
	(*p).unique += ((NI) 1);
	T1_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	idx = T1_;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA4_;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA8_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_283), TM__BxLwT0mhrtgTPodf1v3xjg_284);
		}
		LA8_: ;
		sym = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		(*sym).loc.k = ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 10);
		(*sym).position = (NI)(idx + ((NI) 1));
	}
	LA4_: ;
	labl = (*p).unique;
	nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T10_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (labl)));
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = percent___3m7YwdrxIvOkmvfnm5JYSA(T10_, 1);
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T11_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T12_);
	asgnRef((void**) (&(*p).blocks), (tySequence__8fytVdU59b5aj319cog2ztLw*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__8fytVdU59b5aj319cog2ztLw_), ((NI) ((NI)(idx + ((NI) 1))))));
	(*p).blocks->data[idx].id = ((NI64)-((*p).unique));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 1)], r);
	asgnRef((void**) (&(*p).blocks), (tySequence__8fytVdU59b5aj319cog2ztLw*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__8fytVdU59b5aj319cog2ztLw_), ((NI) (idx))));
	nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T13_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) (labl)));
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = percent___TEWiK8QWtRTCIQ9av7sW8LA(T13_, 1);
	T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T15_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T14_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T15_);
}
N_LIB_PRIVATE N_NIMCALL(void, moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* src, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* dest) {
	{
		if (!!(((*src).kind == ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 0)))) goto LA3_;
		{
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T9_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
			if (!!(((*dest).kind == ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 0)))) goto LA7_;
			nimZeroMem((void*)T9_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T9_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen(dest);
			T9_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*src)));
			T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T10_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T9_, 2);
			T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T11_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T10_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T11_);
		}
		goto LA5_;
		LA7_: ;
		{
			tyArray__JiWwrsTRC6xqNlGcBthSVA T13_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T15_;
			nimZeroMem((void*)T13_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
			T13_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&(*src)));
			T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T14_ = percent___9a3Y7eeGNXkOCLUktwxzN9ag(T13_, 1);
			T15_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T15_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T14_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T15_);
		}
		LA5_: ;
		(*src).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 0);
		unsureAsgnRef((void**) (&(*src).res), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__Bp5hmw3gImpkyC9cflWESLg_30)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w cond;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w stmt;
	NI toClose;
	NimStringDesc* T31_;
	NimStringDesc* T32_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
	nimZeroMem((void*)(&cond), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&stmt), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	toClose = ((NI) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!!(T3_)) goto LA4_;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
		unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
	}
	LA4_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T28_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
				if (!(i_2 < colontmp_)) goto LA8;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				{
					NI T11_;
					tyArray__JiWwrsTRC6xqNlGcBthSVA T21_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
					T11_ = (NI)0;
					T11_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					if (!!((T11_ == ((NI) 1)))) goto LA12_;
					{
						tyArray__qTjAvTvKF9anytN1At69aJMQ T18_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						if (!(((NI) 0) < i)) goto LA16_;
						nimZeroMem((void*)T18_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
						T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T19_ = percent___9an6bUHwpxqyL2kgNHX3MEg(T18_, 0);
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T19_);
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T20_);
						toClose += ((NI) 1);
					}
					LA16_: ;
					(*p).extraIndent += ((NI) 1);
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 0)], (&cond));
					(*p).extraIndent -= ((NI) 1);
					nimZeroMem((void*)T21_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T21_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&cond));
					T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T22_ = percent___kLwAORKb0c4oFgFTN9aEN8Q(T21_, 1);
					T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T23_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T22_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T23_);
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 1)], (&stmt));
				}
				goto LA9_;
				LA12_: ;
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T25_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
					nimZeroMem((void*)T25_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T26_ = percent___9an6bUHwpxqyL2kgNHX3MEg(T25_, 0);
					T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T27_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T26_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T27_);
					(*p).extraIndent += ((NI) 1);
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 0)], (&stmt));
					(*p).extraIndent -= ((NI) 1);
				}
				LA9_: ;
				moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&stmt), (&(*r)));
				nimZeroMem((void*)T28_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T29_ = percent___BYiowJAm8zF7RBRISElaLg(T28_, 0);
				T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T30_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T29_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T30_);
				i_2 += ((NI) 1);
			} LA8: ;
		}
	}
	T31_ = (NimStringDesc*)0;
	T32_ = (NimStringDesc*)0;
	T32_ = nsuRepeatChar(125, ((NI) (toClose)));
	T31_ = rawNewString((T32_ ? T32_->Sup.len : 0) + 1);
appendString(T31_, T32_);
appendString(T31_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_109));
	T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T33_ = rope__yShmEg9cffWxI7s5XzEKBow(T31_);
	T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T34_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T33_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T34_);
}
static N_INLINE(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg*, X5BX5D___4IYft39cjB6OIbPrsxRl9aAgsystem)(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg* s, NI sLen_0, NI i) {
	tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg* result;
	result = (tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg*)0;
	result = (&s[(NI)(sLen_0 - i)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__AQaGEWMAoGSH1pqI9bePiww_9)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w cond;
	NI T6_;
	tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg* T7_;
	tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg* T8_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* labl;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T9_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	tyArray__mrugoXXRZUEeG9bEXo9auBKw T12_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T13_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T14_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T15_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T16_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
	NI T18_;
	nimZeroMem((void*)(&cond), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	{
		NIM_BOOL T3_;
		NimStringDesc* argX60gensym345_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!!(T3_)) goto LA4_;
		argX60gensym345_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_285);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym345_, TM__BxLwT0mhrtgTPodf1v3xjg_285);
	}
	LA4_: ;
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	(*p).unique += ((NI) 1);
	T6_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	asgnRef((void**) (&(*p).blocks), (tySequence__8fytVdU59b5aj319cog2ztLw*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__8fytVdU59b5aj319cog2ztLw_), ((NI) ((NI)(T6_ + ((NI) 1))))));
	T7_ = (tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg*)0;
	T7_ = X5BX5D___4IYft39cjB6OIbPrsxRl9aAgsystem((*p).blocks->data, ((*p).blocks ? (*p).blocks->Sup.len : 0), ((NI) 1));
	(*T7_).id = ((NI64)-((*p).unique));
	T8_ = (tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg*)0;
	T8_ = X5BX5D___4IYft39cjB6OIbPrsxRl9aAgsystem((*p).blocks->data, ((*p).blocks ? (*p).blocks->Sup.len : 0), ((NI) 1));
	(*T8_).isLoop = NIM_TRUE;
	labl = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).unique)));
	nimZeroMem((void*)T9_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T9_[0] = labl;
	T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T10_ = percent___Qm29ctdy9c4sqKctTsqiBWIg(T9_, 1);
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T10_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T11_);
	(*p).extraIndent += ((NI) 1);
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&cond));
	(*p).extraIndent -= ((NI) 1);
	nimZeroMem((void*)T12_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
	T12_[0] = cond.res;
	T12_[1] = labl;
	T13_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T13_ = percent___UyNt2Asj9aa2ScoGVo9cCnNw(T12_, 2);
	T14_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T14_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T13_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T14_);
	(*p).extraIndent += ((NI) 1);
	genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, (*n)._kind_6.sons->data[((NI) 1)]);
	(*p).extraIndent -= ((NI) 1);
	nimZeroMem((void*)T15_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T15_[0] = labl;
	T16_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T16_ = percent___BYiowJAm8zF7RBRISElaLg(T15_, 1);
	T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T17_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T16_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T17_);
	T18_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
	asgnRef((void**) (&(*p).blocks), (tySequence__8fytVdU59b5aj319cog2ztLw*) setLengthSeqV2(&((*p).blocks)->Sup, (&NTI__8fytVdU59b5aj319cog2ztLw_), ((NI) ((NI)(T18_ - ((NI) 1))))));
}
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__AQaGEWMAoGSH1pqI9bePiww_10)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				a = (*n)._kind_6.sons->data[i];
				{
					if (!!(((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA6_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* unpacked;
						if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA10_;
						unpacked = lowerTupleUnpacking__8A4G64HByteFanrMUexmNw_2((*(*p).module).graph, a, (*p).prc);
						genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, unpacked);
					}
					goto LA8_;
					LA10_: ;
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
						v = (*(*a)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						{
							NIM_BOOL T15_;
							T15_ = (NIM_BOOL)0;
							T15_ = !((((*v).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0));
							if (!(T15_)) goto LA16_;
							T15_ = !((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 6))&63U)))!=0));
							LA16_: ;
							if (!T15_) goto LA17_;
							genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, a);
							{
								if (!!((((*v).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0))) goto LA21_;
								genVarInit__iVEhpHbcyNY9aOzPqLze8xw(p, v, (*a)._kind_6.sons->data[((NI) 2)]);
							}
							goto LA19_;
							LA21_: ;
							{
								{
									if (!((*v).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA26_;
									asgnRef((void**) (&(*v).ast), (*a)._kind_6.sons->data[((NI) 2)]);
								}
								LA26_: ;
							}
							LA19_: ;
						}
						LA17_: ;
					}
					LA8_: ;
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseJS__Bp5hmw3gImpkyC9cflWESLg_31)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w cond;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w stmt;
	NI totalRange;
	NIM_BOOL stringSwitch;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T65_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T66_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T67_;
	nimZeroMem((void*)(&cond), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&stmt), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	totalRange = ((NI) 0);
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&cond));
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087632017680));
	stringSwitch = ((*T1_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28));
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		if (!stringSwitch) goto LA4_;
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_223));
		nimZeroMem((void*)T6_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T6_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&cond));
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = percent___xXvQyblNYV215UGR9cTka7Q(T6_, 1);
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T7_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T8_);
	}
	goto LA2_;
	LA4_: ;
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T10_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
		nimZeroMem((void*)T10_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T10_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&cond));
		T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T11_ = percent___T9caGByKkBhaXSZ6fCJLIdQ(T10_, 1);
		T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T12_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T11_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T12_);
	}
	LA2_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!!(T15_)) goto LA16_;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
		unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
	}
	LA16_: ;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA20;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				switch ((*it).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T53_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T54_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T55_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T56_;
					{
						NI j;
						NI colontmp__2;
						NI T23_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T23_ = (NI)0;
						T23_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						colontmp__2 = (NI)(T23_ - ((NI) 1));
						i_3 = ((NI) 0);
						{
							while (1) {
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
								if (!(i_3 < colontmp__2)) goto LA25;
								j = i_3;
								e = (*it)._kind_6.sons->data[j];
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
									if (!((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA28_;
									v = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2((*e)._kind_6.sons->data[((NI) 0)]);
									totalRange += ((NI) ((NI64)((*(*e)._kind_6.sons->data[((NI) 1)])._kind_1.intVal - (*v)._kind_1.intVal)));
									{
										if (!(((NI) 65535) < totalRange)) goto LA32_;
										liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_288), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__BxLwT0mhrtgTPodf1v3xjg_289, NIM_FALSE);
									}
									LA32_: ;
									{
										while (1) {
											tyArray__JiWwrsTRC6xqNlGcBthSVA T36_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T37_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T38_;
											if (!((*v)._kind_1.intVal <= (*(*e)._kind_6.sons->data[((NI) 1)])._kind_1.intVal)) goto LA35;
											gen__Bp5hmw3gImpkyC9cflWESLg(p, v, (&cond));
											nimZeroMem((void*)T36_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
											T36_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&cond));
											T37_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T37_ = percent___f8NIixSwWrk6SXQ3BFamWw(T36_, 1);
											T38_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T38_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T37_);
											add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T38_);
											(*v)._kind_1.intVal += ((NI) 1);
										} LA35: ;
									}
								}
								goto LA26_;
								LA28_: ;
								{
									{
										if (!stringSwitch) goto LA42_;
										switch ((*e).kind) {
										case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
										{
											tyArray__JiWwrsTRC6xqNlGcBthSVA T45_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
											tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
											nimZeroMem((void*)T45_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
											T45_[0] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*e)._kind_3.strVal, NIM_FALSE);
											T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T46_ = percent___f8NIixSwWrk6SXQ3BFamWw(T45_, 1);
											T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
											T47_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T46_);
											add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T47_);
										}
										break;
										default:
										{
											internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*e).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_290), TM__BxLwT0mhrtgTPodf1v3xjg_291);
										}
										break;
										}
									}
									goto LA40_;
									LA42_: ;
									{
										tyArray__JiWwrsTRC6xqNlGcBthSVA T50_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T51_;
										tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T52_;
										gen__Bp5hmw3gImpkyC9cflWESLg(p, e, (&cond));
										nimZeroMem((void*)T50_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
										T50_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&cond));
										T51_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T51_ = percent___f8NIixSwWrk6SXQ3BFamWw(T50_, 1);
										T52_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
										T52_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T51_);
										add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T52_);
									}
									LA40_: ;
								}
								LA26_: ;
								i_3 += ((NI) 1);
							} LA25: ;
						}
					}
					(*p).extraIndent += ((NI) 1);
					T53_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T53_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(it);
					gen__Bp5hmw3gImpkyC9cflWESLg(p, T53_, (&stmt));
					moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&stmt), (&(*r)));
					nimZeroMem((void*)T54_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T55_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T55_ = percent___TmeCjGna9cPfiHHcfqmKXjw(T54_, 0);
					T56_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T56_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T55_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T56_);
					(*p).extraIndent -= ((NI) 1);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T58_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T59_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T60_;
					tyArray__qTjAvTvKF9anytN1At69aJMQ T61_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
					nimZeroMem((void*)T58_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T59_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T59_ = percent___LYjQOKn1i9ccw8AFlvPGkCg(T58_, 0);
					T60_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T60_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T59_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T60_);
					(*p).extraIndent += ((NI) 1);
					gen__Bp5hmw3gImpkyC9cflWESLg(p, (*it)._kind_6.sons->data[((NI) 0)], (&stmt));
					moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&stmt), (&(*r)));
					nimZeroMem((void*)T61_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T62_ = percent___TmeCjGna9cPfiHHcfqmKXjw(T61_, 0);
					T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T63_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T62_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T63_);
					(*p).extraIndent -= ((NI) 1);
				}
				break;
				default:
				{
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*it).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_292), TM__BxLwT0mhrtgTPodf1v3xjg_293);
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA20: ;
		}
	}
	nimZeroMem((void*)T65_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T66_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T66_ = percent___BYiowJAm8zF7RBRISElaLg(T65_, 0);
	T67_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T67_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T66_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T67_);
}
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__AQaGEWMAoGSH1pqI9bePiww_11)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyArray__qTjAvTvKF9anytN1At69aJMQ T10_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T11_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T12_;
	{
		if (!((*p).procDef == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_294), TM__BxLwT0mhrtgTPodf1v3xjg_295);
	}
	LA3_: ;
	(*p).beforeRetNeeded = NIM_TRUE;
	{
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA7_;
		genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, (*n)._kind_6.sons->data[((NI) 0)]);
	}
	goto LA5_;
	LA7_: ;
	{
		genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	}
	LA5_: ;
	nimZeroMem((void*)T10_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T11_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T11_ = percent___THj0xNXkqJf6reD7exsGbA(T10_, 0);
	T12_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T12_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T11_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T12_);
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__AQaGEWMAoGSH1pqI9bePiww_12)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI idx;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T17_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T19_;
	idx = (NI)0;
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		sym = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		idx = (NI)((*sym).position - ((NI) 1));
	}
	goto LA1_;
	LA3_: ;
	{
		NI T6_;
		T6_ = ((*p).blocks ? (*p).blocks->Sup.len : 0);
		idx = (NI)(T6_ - ((NI) 1));
		{
			while (1) {
				NIM_BOOL T9_;
				T9_ = (NIM_BOOL)0;
				T9_ = (((NI) 0) <= idx);
				if (!(T9_)) goto LA10_;
				T9_ = !((*p).blocks->data[idx].isLoop);
				LA10_: ;
				if (!T9_) goto LA8;
				idx -= ((NI) 1);
			} LA8: ;
		}
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = (idx < ((NI) 0));
			if (T13_) goto LA14_;
			T13_ = !((*p).blocks->data[idx].isLoop);
			LA14_: ;
			if (!T13_) goto LA15_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_296), TM__BxLwT0mhrtgTPodf1v3xjg_297);
		}
		LA15_: ;
	}
	LA1_: ;
	(*p).blocks->data[idx].id = ((*p).blocks->data[idx].id > 0? ((*p).blocks->data[idx].id) : -((*p).blocks->data[idx].id));
	nimZeroMem((void*)T17_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T17_[0] = rope__KOisMGxcPhz6CcSmxgwEQQ(((NI64) ((*p).blocks->data[idx].id)));
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = percent___3oFXAbir9c7XcKzu9bpgAM9bA(T17_, 1);
	T19_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T19_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T18_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T19_);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgnAux__FTHts0vUatiTmPKVGzyMKA)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* y, NIM_BOOL noCopyNeeded) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w b;
	tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA xtyp;
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	nimZeroMem((void*)(&b), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	xtyp = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*x).typ);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
		T4_ = (((NI) 2) <= T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T8_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T8_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*x)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		T3_ = ((*T8_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29));
		LA7_: ;
		if (!T3_) goto LA9_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*x).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_298), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__BxLwT0mhrtgTPodf1v3xjg_299, NIM_FALSE);
	}
	LA9_: ;
	gen__Bp5hmw3gImpkyC9cflWESLg(p, x, (&a));
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, y);
	gen__Bp5hmw3gImpkyC9cflWESLg(p, y, (&b));
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T13_;
		T13_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T13_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*x).typ, IL64(36134350135273744));
		if (!((285212672 &((NU64)1<<((NU)((*T13_).kind)&63U)))!=0)) goto LA14_;
		xtyp = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 4);
	}
	LA14_: ;
	switch (xtyp) {
	case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 4):
	{
		{
			NIM_BOOL T19_;
			NIM_BOOL T20_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T25_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T26_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
			T19_ = (NIM_BOOL)0;
			T20_ = (NIM_BOOL)0;
			T20_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, y);
			if (!(T20_)) goto LA21_;
			T20_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, x);
			LA21_: ;
			T19_ = T20_;
			if (T19_) goto LA22_;
			T19_ = noCopyNeeded;
			LA22_: ;
			if (!T19_) goto LA23_;
			nimZeroMem((void*)T25_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T25_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
			T25_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&b));
			T26_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T26_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T25_, 2);
			T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T27_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T26_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T27_);
		}
		goto LA17_;
		LA23_: ;
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T29_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
			nimZeroMem((void*)T29_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T29_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
			T29_[1] = b.res;
			T29_[2] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*y).typ);
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = percent___4sbi76q7ZLqpKbD3pwJ59bQ(T29_, 3);
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T30_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T31_);
		}
		LA17_: ;
	}
	break;
	case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 8):
	{
		{
			NIM_BOOL T35_;
			NIM_BOOL T36_;
			NIM_BOOL T38_;
			tyArray__mrugoXXRZUEeG9bEXo9auBKw T43_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T44_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T45_;
			T35_ = (NIM_BOOL)0;
			T36_ = (NIM_BOOL)0;
			T36_ = ((8388608 &((NU64)1<<((NU)((*(*x).typ).kind)&63U)))!=0);
			if (T36_) goto LA37_;
			T38_ = (NIM_BOOL)0;
			T38_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, y);
			if (!(T38_)) goto LA39_;
			T38_ = needsNoCopy__AeBLus9crC8L5HbMOYikwJw(p, x);
			LA39_: ;
			T36_ = T38_;
			LA37_: ;
			T35_ = T36_;
			if (T35_) goto LA40_;
			T35_ = noCopyNeeded;
			LA40_: ;
			if (!T35_) goto LA41_;
			nimZeroMem((void*)T43_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
			T43_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
			T43_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&b));
			T44_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T44_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T43_, 2);
			T45_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T45_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T44_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T45_);
		}
		goto LA33_;
		LA41_: ;
		{
			tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T47_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T48_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T49_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_116));
			nimZeroMem((void*)T47_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
			T47_[0] = a.res;
			T47_[1] = b.res;
			T47_[2] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*y).typ);
			T48_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T48_ = percent___Q9cOQGrP4lOdbYHXMQ1yZtg(T47_, 3);
			T49_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T49_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T48_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T49_);
		}
		LA33_: ;
	}
	break;
	case ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9):
	{
		{
			NIM_BOOL T53_;
			T53_ = (NIM_BOOL)0;
			T53_ = !((a.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)));
			if (T53_) goto LA54_;
			T53_ = !((b.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9)));
			LA54_: ;
			if (!T53_) goto LA55_;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmp;
				tyArray__f7nG5LD47BH5K9c6mASit3g T61_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T62_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T63_;
				if (!((*y).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27))) goto LA59_;
				tmp = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_FALSE);
				nimZeroMem((void*)T61_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
				T61_[0] = tmp;
				T61_[1] = a.address;
				T61_[2] = a.res;
				T61_[3] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&b));
				T62_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T62_ = percent___0AX4Q6cA8nOXUagvzFqt0A(T61_, 4);
				T63_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T63_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T62_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T63_);
			}
			goto LA57_;
			LA59_: ;
			{
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T67_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T68_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T69_;
				if (!(b.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA65_;
				nimZeroMem((void*)T67_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T67_[0] = a.res;
				T67_[1] = b.address;
				T67_[2] = b.res;
				T68_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T68_ = percent___qQ3g8SwjZoIFAay85NaiEA(T67_, 3);
				T69_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T69_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T68_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T69_);
			}
			goto LA57_;
			LA65_: ;
			{
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T77_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T78_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T79_;
				if (!(b.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0))) goto LA71_;
				{
					NimStringDesc* argX60gensym511_;
					if (!!((b.address == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA75_;
					argX60gensym511_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__BxLwT0mhrtgTPodf1v3xjg_300);
					internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym511_, TM__BxLwT0mhrtgTPodf1v3xjg_300);
				}
				LA75_: ;
				nimZeroMem((void*)T77_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T77_[0] = a.address;
				T77_[1] = b.res;
				T78_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T78_ = percent___D9cWch2yJRlkSqFCXT3v86A(T77_, 2);
				T79_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T79_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T78_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T79_);
			}
			goto LA57_;
			LA71_: ;
			{
				NIM_BOOL T81_;
				tyArray__wqYjTJU9ab2ZgEFMaQc3vNA T85_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T87_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T88_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T89_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T90_;
				tyArray__mrugoXXRZUEeG9bEXo9auBKw T91_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T93_;
				T81_ = (NIM_BOOL)0;
				T81_ = ((*(*x).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23));
				if (!(T81_)) goto LA82_;
				T81_ = ((*(*y).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
				LA82_: ;
				if (!T81_) goto LA83_;
				nimZeroMem((void*)T85_, sizeof(tyArray__wqYjTJU9ab2ZgEFMaQc3vNA));
				T85_[0] = a.res;
				T85_[1] = b.address;
				T85_[2] = b.res;
				T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T86_ = percent___qQ3g8SwjZoIFAay85NaiEA(T85_, 3);
				T87_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T87_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T86_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T87_);
				nimZeroMem((void*)T88_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T88_[0] = a.address;
				T88_[1] = b.res;
				T89_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T89_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T88_, 2);
				T90_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T90_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T89_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T90_);
				nimZeroMem((void*)T91_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
				T91_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
				T91_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&b));
				T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T92_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T91_, 2);
				T93_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T93_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T92_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T93_);
			}
			goto LA57_;
			LA83_: ;
			{
				tyTuple__QVkyTCL0msoEdWvhK6TYrw T95_;
				NimStringDesc* T96_;
				nimZeroMem((void*)(&T95_), sizeof(tyTuple__QVkyTCL0msoEdWvhK6TYrw));
				T95_.Field0 = copyString(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_304));
				T95_.Field1 = b.typ;
				T95_.Field2 = a.typ;
				T96_ = (NimStringDesc*)0;
				T96_ = dollar___NDGD2HOmz0EkwXFFCD1T6w(T95_);
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*x).info, T96_, TM__BxLwT0mhrtgTPodf1v3xjg_305);
			}
			LA57_: ;
		}
		goto LA51_;
		LA55_: ;
		{
			tyArray__f7nG5LD47BH5K9c6mASit3g T98_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T99_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T100_;
			nimZeroMem((void*)T98_, sizeof(tyArray__f7nG5LD47BH5K9c6mASit3g));
			T98_[0] = a.address;
			T98_[1] = b.address;
			T98_[2] = a.res;
			T98_[3] = b.res;
			T99_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T99_ = percent___M0TByFCTj9bbOkDSRpFz3LA(T98_, 4);
			T100_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T100_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T99_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T100_);
		}
		LA51_: ;
	}
	break;
	default:
	{
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T102_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T104_;
		nimZeroMem((void*)T102_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T102_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
		T102_[1] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&b));
		T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T103_ = percent___1Hh3EN9c4pkzdKB09bo9c9aTBg(T102_, 2);
		T104_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T104_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T103_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T104_);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__AQaGEWMAoGSH1pqI9bePiww_13)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	genAsgnAux__FTHts0vUatiTmPKVGzyMKA(p, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, genFastAsgn__AQaGEWMAoGSH1pqI9bePiww_14)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL noCopy;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
	noCopy = ((285212672 &((NU64)1<<((NU)((*T1_).kind)&63U)))!=0);
	genAsgnAux__FTHts0vUatiTmPKVGzyMKA(p, (*n)._kind_6.sons->data[((NI) 0)], (*n)._kind_6.sons->data[((NI) 1)], noCopy);
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__AQaGEWMAoGSH1pqI9bePiww_15)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T1_;
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	T1_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T1_);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				it = (*n)._kind_6.sons->data[i];
				switch ((*it).kind) {
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
				{
					add__yG4AKzsBRS1W4MANDlXQeg(&(*p).body, (*it)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
					v = (*it)._kind_4.sym;
					{
						if (!NIM_FALSE) goto LA9_;
					}
					goto LA7_;
					LA9_: ;
					{
						tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w r;
						tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
						nimZeroMem((void*)(&r), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
						gen__Bp5hmw3gImpkyC9cflWESLg(p, it, (&r));
						{
							if (!((*(*it).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26))) goto LA14_;
							r.res = r.address;
							r.address = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
							r.typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
						}
						goto LA12_;
						LA14_: ;
						{
							tyArray__mrugoXXRZUEeG9bEXo9auBKw T19_;
							if (!(r.typ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA17_;
							nimZeroMem((void*)T19_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
							T19_[0] = r.address;
							T19_[1] = r.res;
							r.res = percent___jadqNPnY9aM3oxYK6jarLrA(T19_, 2);
							r.address = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
							r.typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
						}
						goto LA12_;
						LA17_: ;
						LA12_: ;
						T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
						T20_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&r));
						add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T20_);
					}
					LA7_: ;
				}
				break;
				default:
				{
					tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w r_2;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
					nimZeroMem((void*)(&r_2), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
					gen__Bp5hmw3gImpkyC9cflWESLg(p, it, (&r_2));
					T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T22_ = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&r_2));
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T22_);
				}
				break;
				}
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	add__yG4AKzsBRS1W4MANDlXQeg(&(*p).body, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_109));
}
N_LIB_PRIVATE N_NIMCALL(void, genTry__Bp5hmw3gImpkyC9cflWESLg_32)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	NI i;
	NIM_BOOL catchBranchesExist;
	NIM_BOOL T6_;
	NI T7_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* tmpFramePtr;
	tyArray__qTjAvTvKF9anytN1At69aJMQ T19_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
	NIM_BOOL generalCatchBranchExists;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T124_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T125_;
	tyArray__JiWwrsTRC6xqNlGcBthSVA T126_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T127_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T128_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T136_;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T137_;
	genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		if (!!(T3_)) goto LA4_;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 2);
		unsureAsgnRef((void**) (&(*r).res), getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE));
	}
	LA4_: ;
	(*p).unique += ((NI) 1);
	i = ((NI) 1);
	T6_ = (NIM_BOOL)0;
	T7_ = (NI)0;
	T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	T6_ = (((NI) 1) < T7_);
	if (!(T6_)) goto LA8_;
	T6_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
	LA8_: ;
	catchBranchesExist = T6_;
	{
		if (!catchBranchesExist) goto LA11_;
		add__yG4AKzsBRS1W4MANDlXQeg(&(*p).body, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_307));
	}
	LA11_: ;
	tmpFramePtr = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_308));
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T17_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
		if (!!((((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0))) goto LA15_;
		tmpFramePtr = getTemp__EG8bDinaW3fVLpok9a4s5cA(p, NIM_TRUE);
		T17_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T17_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(tmpFramePtr, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_309));
		T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T18_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T17_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T18_);
	}
	LA15_: ;
	nimZeroMem((void*)T19_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
	T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T20_ = percent___OikfyLf8HmjI9auYLFoaVqg(T19_, 0);
	T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T21_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T20_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T21_);
	nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
	moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&a), (&(*r)));
	generalCatchBranchExists = NIM_FALSE;
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T26_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T27_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T28_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
		if (!catchBranchesExist) goto LA24_;
		nimZeroMem((void*)T26_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T27_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T27_ = percent___3KVF9aLACI1h11BqZrkzjNg(T26_, 0);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T27_);
		nimZeroMem((void*)T28_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T28_[0] = tmpFramePtr;
		T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T29_ = percent___ial810twbEzfkHaHMFYNCg(T28_, 1);
		T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T30_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T29_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T30_);
	}
	LA24_: ;
	{
		while (1) {
			NIM_BOOL T33_;
			NI T34_;
			T33_ = (NIM_BOOL)0;
			T34_ = (NI)0;
			T34_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T33_ = (i < T34_);
			if (!(T33_)) goto LA35_;
			T33_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87));
			LA35_: ;
			if (!T33_) goto LA32;
			{
				NI T38_;
				T38_ = (NI)0;
				T38_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i]);
				if (!(T38_ == ((NI) 1))) goto LA39_;
				generalCatchBranchExists = NIM_TRUE;
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T45_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T46_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T47_;
					if (!(((NI) 1) < i)) goto LA43_;
					nimZeroMem((void*)T45_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T46_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T46_ = percent___9an6bUHwpxqyL2kgNHX3MEg(T45_, 0);
					T47_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T47_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T46_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T47_);
				}
				LA43_: ;
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], (&a));
				moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&a), (&(*r)));
				{
					tyArray__qTjAvTvKF9anytN1At69aJMQ T52_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T53_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T54_;
					if (!(((NI) 1) < i)) goto LA50_;
					nimZeroMem((void*)T52_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
					T53_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T53_ = percent___BYiowJAm8zF7RBRISElaLg(T52_, 0);
					T54_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T54_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T53_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T54_);
				}
				LA50_: ;
			}
			goto LA36_;
			LA39_: ;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* orExpr;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* excAlias;
				tyArray__JiWwrsTRC6xqNlGcBthSVA T93_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T94_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T95_;
				NI T103_;
				tyArray__qTjAvTvKF9anytN1At69aJMQ T104_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T105_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T106_;
				orExpr = ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL);
				excAlias = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_220));
				{
					NI j;
					NI colontmp_;
					NI T57_;
					NI i_2;
					j = (NI)0;
					colontmp_ = (NI)0;
					T57_ = (NI)0;
					T57_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i]);
					colontmp_ = (NI)(T57_ - ((NI) 1));
					i_2 = ((NI) 0);
					{
						while (1) {
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* throwObj;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
							if (!(i_2 < colontmp_)) goto LA59;
							j = i_2;
							throwObj = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							it = (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[j];
							{
								NIM_BOOL T62_;
								T62_ = (NIM_BOOL)0;
								T62_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw(it);
								if (!T62_) goto LA63_;
								throwObj = (*it)._kind_6.sons->data[((NI) 1)];
								excAlias = (*it)._kind_6.sons->data[((NI) 2)];
								{
									if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA67_;
									failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_310));
								}
								LA67_: ;
							}
							goto LA60_;
							LA63_: ;
							{
								if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4))) goto LA70_;
								throwObj = it;
							}
							goto LA60_;
							LA70_: ;
							{
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_311), TM__BxLwT0mhrtgTPodf1v3xjg_312);
							}
							LA60_: ;
							{
								if (!!((orExpr == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA75_;
								add__yG4AKzsBRS1W4MANDlXQeg(&orExpr, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_313));
							}
							LA75_: ;
							{
								NIM_BOOL T79_;
								tyArray__JiWwrsTRC6xqNlGcBthSVA T82_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T83_;
								T79_ = (NIM_BOOL)0;
								T79_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A((*throwObj).typ, (*(*p).module).config);
								if (!T79_) goto LA80_;
								nimZeroMem((void*)T82_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
								T82_[0] = (*(*(*throwObj).typ).sym).loc.r;
								T83_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T83_ = percent___Z7wCJf0WipOQOQ4ZZNBIEw(T82_, 1);
								add__IM4kcMNkkOLJtqdEqSxR8A(&orExpr, T83_);
							}
							goto LA77_;
							LA80_: ;
							{
								tyArray__JiWwrsTRC6xqNlGcBthSVA T85_;
								tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T86_;
								nimZeroMem((void*)T85_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
								T85_[0] = genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*throwObj).typ);
								T86_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
								T86_ = percent___Xpm9cGf2grEXdjAQV9arqWBQ(T85_, 1);
								add__IM4kcMNkkOLJtqdEqSxR8A(&orExpr, T86_);
							}
							LA77_: ;
							i_2 += ((NI) 1);
						} LA59: ;
					}
				}
				{
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T91_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
					if (!(((NI) 1) < i)) goto LA89_;
					T91_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T91_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_314));
					T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T92_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T91_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T92_);
				}
				LA89_: ;
				nimZeroMem((void*)T93_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T93_[0] = orExpr;
				T94_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T94_ = percent___sqxyWwlLrfrdyc9b3BINcXQ(T93_, 1);
				T95_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T95_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T94_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T95_);
				{
					tyArray__JiWwrsTRC6xqNlGcBthSVA T100_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T101_;
					tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T102_;
					if (!!((excAlias == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA98_;
					asgnRef((void**) (&(*(*excAlias)._kind_4.sym).loc.r), mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, (*excAlias)._kind_4.sym));
					nimZeroMem((void*)T100_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
					T100_[0] = (*(*excAlias)._kind_4.sym).loc.r;
					T101_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T101_ = percent___ztLQ2Orupb9b9b3KrCvoK9cbQ(T100_, 1);
					T102_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
					T102_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T101_);
					add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T102_);
				}
				LA98_: ;
				T103_ = (NI)0;
				T103_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i]);
				gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[(NI)(T103_ - ((NI) 1))], (&a));
				moveInto__rA59a0Z9bTX9aiKkWlHk0Akiw(p, (&a), (&(*r)));
				nimZeroMem((void*)T104_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
				T105_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T105_ = percent___BYiowJAm8zF7RBRISElaLg(T104_, 0);
				T106_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T106_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T105_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T106_);
			}
			LA36_: ;
			i += ((NI) 1);
		} LA32: ;
	}
	{
		tyArray__qTjAvTvKF9anytN1At69aJMQ T121_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T122_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T123_;
		if (!catchBranchesExist) goto LA109_;
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T115_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T116_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T117_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T118_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T119_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T120_;
			if (!!(generalCatchBranchExists)) goto LA113_;
			useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_315));
			T115_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T115_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_316));
			T116_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T116_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T115_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T116_);
			T117_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T117_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_317));
			T118_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T118_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T117_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T118_);
			T119_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T119_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_22));
			T120_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T120_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T119_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T120_);
		}
		LA113_: ;
		nimZeroMem((void*)T121_, sizeof(tyArray__qTjAvTvKF9anytN1At69aJMQ));
		T122_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T122_ = percent___PI6febxsdTbySkLsIEqHKw(T121_, 0);
		T123_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T123_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T122_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T123_);
	}
	LA109_: ;
	T124_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T124_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_318));
	T125_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T125_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T124_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T125_);
	nimZeroMem((void*)T126_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
	T126_[0] = tmpFramePtr;
	T127_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T127_ = percent___ial810twbEzfkHaHMFYNCg(T126_, 1);
	T128_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T128_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T127_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T128_);
	{
		NIM_BOOL T131_;
		NI T132_;
		T131_ = (NIM_BOOL)0;
		T132_ = (NI)0;
		T132_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T131_ = (i < T132_);
		if (!(T131_)) goto LA133_;
		T131_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107));
		LA133_: ;
		if (!T131_) goto LA134_;
		genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
	}
	LA134_: ;
	T136_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T136_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_22));
	T137_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T137_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T136_);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T137_);
}
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__AQaGEWMAoGSH1pqI9bePiww_16)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w a;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		tyArray__mrugoXXRZUEeG9bEXo9auBKw T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA3_;
		nimZeroMem((void*)(&a), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], (&a));
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36275087638309136));
		genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_319));
		nimZeroMem((void*)T5_, sizeof(tyArray__mrugoXXRZUEeG9bEXo9auBKw));
		T5_[0] = rdLoc__yob5rpIMovhptJKw0A5vnAjsgen((&a));
		T5_[1] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*(*(*typ).sym).name).s, NIM_TRUE);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___sGRyuC9caCxfdM1i8W4fjgw(T5_, 2);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T6_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T7_);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T10_;
		genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
		useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_315));
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_320));
		T10_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T10_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T9_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T10_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPragma__AQaGEWMAoGSH1pqI9bePiww_17)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** it;
		tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
		NI i;
		NI L;
		NI T2_;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
		colontmp_ = (*n)._kind_6.sons;
		i = ((NI) 0);
		T2_ = (colontmp_ ? colontmp_->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T5_;
				if (!(i < L)) goto LA4;
				it = &colontmp_->data[i];
				T5_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
				T5_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw((*it));
				switch (T5_) {
				case ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 211):
				{
					genAsmOrEmitStmt__AQaGEWMAoGSH1pqI9bePiww_15(p, (*(*it))._kind_6.sons->data[((NI) 1)]);
				}
				break;
				default:
				{
				}
				break;
				}
				i += ((NI) 1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, gen__Bp5hmw3gImpkyC9cflWESLg)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w* r) {
	(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 0);
	{
		if (!!(((*r).kind == ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 3)))) goto LA3_;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 0);
	}
	LA3_: ;
	unsureAsgnRef((void**) (&(*r).res), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		genSym__Bp5hmw3gImpkyC9cflWESLg_2(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		{
			if (!((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1))) goto LA9_;
			{
				if (!((*n)._kind_1.intVal == IL64(0))) goto LA13_;
				unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_153)));
			}
			goto LA11_;
			LA13_: ;
			{
				unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_154)));
			}
			LA11_: ;
		}
		goto LA7_;
		LA9_: ;
		{
			unsureAsgnRef((void**) (&(*r).res), rope__KOisMGxcPhz6CcSmxgwEQQ((*n)._kind_1.intVal));
		}
		LA7_: ;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			if (!T20_) goto LA21_;
		}
		goto LA18_;
		LA21_: ;
		{
			tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA T24_;
			T24_ = (tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA)0;
			T24_ = mapType__ZlkXBdJTrpToZuRLq31tLQ(p, (*n).typ);
			if (!(T24_ == ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9))) goto LA25_;
			(*r).typ = ((tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA) 9);
			unsureAsgnRef((void**) (&(*r).address), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_155)));
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_156)));
			(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
		}
		goto LA18_;
		LA25_: ;
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_155)));
			(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
		}
		LA18_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T31_;
			T31_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T31_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
			if (!((*T31_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28))) goto LA32_;
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T38_;
				if (!!((((*n)._kind_3.strVal ? (*n)._kind_3.strVal->Sup.len : 0) == ((NI) 0)))) goto LA36_;
				useMagic__4MoUWv1cpa6oOBwwpQ0wfA(p, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_157));
				nimZeroMem((void*)T38_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T38_[0] = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*n)._kind_3.strVal, NIM_TRUE);
				unsureAsgnRef((void**) (&(*r).res), percent___qYiwFpynEwFeSf3Aa2sS0g(T38_, 1));
			}
			goto LA34_;
			LA36_: ;
			{
				unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_158)));
			}
			LA34_: ;
		}
		goto LA29_;
		LA32_: ;
		{
			unsureAsgnRef((void**) (&(*r).res), makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw((*n)._kind_3.strVal, NIM_FALSE));
		}
		LA29_: ;
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 18):
	{
		NF f;
		tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA T42_;
		f = (*n)._kind_2.floatVal;
		T42_ = (tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA)0;
		T42_ = classify__x3IKzrz1VNvfZbypScSTXg(f);
		switch (T42_) {
		case ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 4):
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_159)));
		}
		break;
		case ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 3):
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_160)));
		}
		break;
		case ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 2):
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_161)));
		}
		break;
		case ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 5):
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_162)));
		}
		break;
		case ((tyEnum_FloatClass__pPga1yW9b8J9cwNnm9b1aPRnA) 6):
		{
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_163)));
		}
		break;
		default:
		{
			NimStringDesc* T49_;
			T49_ = (NimStringDesc*)0;
			T49_ = toStrMaxPrecision__ayHojnbqAtgkZF8TXMNMzg(f, ((NimStringDesc*) NIM_NIL));
			unsureAsgnRef((void**) (&(*r).res), rope__yShmEg9cffWxI7s5XzEKBow(T49_));
		}
		break;
		}
		(*r).kind = ((tyEnum_TResKind__EoayJcDa8SxU1YPfjU8L9bg) 1);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		{
			NIM_BOOL T53_;
			T53_ = (NIM_BOOL)0;
			T53_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
			if (!T53_) goto LA54_;
			genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
		}
		LA54_: ;
		{
			NIM_BOOL T58_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T58_)) goto LA59_;
			T58_ = !(((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
			LA59_: ;
			if (!T58_) goto LA60_;
			genMagic__Bp5hmw3gImpkyC9cflWESLg_3(p, n, r);
		}
		goto LA56_;
		LA60_: ;
		{
			NIM_BOOL T63_;
			NIM_BOOL T64_;
			NI T67_;
			T63_ = (NIM_BOOL)0;
			T64_ = (NIM_BOOL)0;
			T64_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T64_)) goto LA65_;
			T64_ = (((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
			LA65_: ;
			T63_ = T64_;
			if (!(T63_)) goto LA66_;
			T67_ = (NI)0;
			T67_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T63_ = (((NI) 1) <= T67_);
			LA66_: ;
			if (!T63_) goto LA68_;
			genInfixCall__Bp5hmw3gImpkyC9cflWESLg_13(p, n, r);
		}
		goto LA56_;
		LA68_: ;
		{
			genCall__Bp5hmw3gImpkyC9cflWESLg_11(p, n, r);
		}
		LA56_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	{
		genSetConstr__Bp5hmw3gImpkyC9cflWESLg_14(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		genArrayConstr__Bp5hmw3gImpkyC9cflWESLg_15(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	{
		genTupleConstr__Bp5hmw3gImpkyC9cflWESLg_16(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	{
		genObjConstr__Bp5hmw3gImpkyC9cflWESLg_17(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		genConv__Bp5hmw3gImpkyC9cflWESLg_18(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		genAddr__Bp5hmw3gImpkyC9cflWESLg_19(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		genDeref__Bp5hmw3gImpkyC9cflWESLg_23(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		genArrayAccess__Bp5hmw3gImpkyC9cflWESLg_24(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		genFieldAccess__Bp5hmw3gImpkyC9cflWESLg_21(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		genCheckedFieldOp__iKztcH0Tujg1djuGYyE69cQ(p, n, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	{
		upConv__Bp5hmw3gImpkyC9cflWESLg_25(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61):
	{
		genCast__Bp5hmw3gImpkyC9cflWESLg_26(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	{
		genRangeChck__hP2w9bfjeb9a8Gw7OVBCznWw(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_277));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	{
		genRangeChck__hP2w9bfjeb9a8Gw7OVBCznWw(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_278));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	{
		genRangeChck__hP2w9bfjeb9a8Gw7OVBCznWw(p, n, r, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_276));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71):
	{
		convStrToCStr__Bp5hmw3gImpkyC9cflWESLg_27(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72):
	{
		convCStrToStr__Bp5hmw3gImpkyC9cflWESLg_28(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T92_;
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		T92_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T92_ = mangleName__VbRtGjpKYj6Wtc1GdNdKhg((*p).module, s);
		(void)(T92_);
		unsureAsgnRef((void**) (&(*r).res), (*s).loc.r);
		{
			NIM_BOOL T95_;
			T95_ = (NIM_BOOL)0;
			T95_ = (((*s).loc.flags &((NU16)1<<((NU)(((tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA) 3))&15U)))!=0);
			if (T95_) goto LA96_;
			T95_ = !(((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
			LA96_: ;
			if (!T95_) goto LA97_;
		}
		goto LA93_;
		LA97_: ;
		{
			NIM_BOOL T100_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T103_;
			T100_ = (NIM_BOOL)0;
			T100_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*(*p).g).generatedSyms), (*s).Sup.id);
			if (!!(T100_)) goto LA101_;
			T103_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T103_ = genProc__VRfKzQHOMcRGtJXZSJxFtg(p, s);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).locals, T103_);
		}
		goto LA93_;
		LA101_: ;
		LA93_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4):
	{
		unsureAsgnRef((void**) (&(*r).res), genTypeInfo__jZNTi9aEbLMAMESBZ7a9cl7A_2(p, (*n).typ));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
	{
		NIM_BOOL isExpr;
		NIM_BOOL T106_;
		T106_ = (NIM_BOOL)0;
		T106_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast((*n).typ);
		isExpr = !(T106_);
		{
			NI i;
			NI colontmp_;
			NI T108_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T108_ = (NI)0;
			T108_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp_ = (NI)(T108_ - isExpr);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA110;
					i = i_2;
					genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, (*n)._kind_6.sons->data[i]);
					i_2 += ((NI) 1);
				} LA110: ;
			}
		}
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T115_;
			if (!isExpr) goto LA113_;
			T115_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T115_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
			gen__Bp5hmw3gImpkyC9cflWESLg(p, T115_, r);
		}
		LA113_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		genBlock__Bp5hmw3gImpkyC9cflWESLg_29(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48):
	{
		genIf__Bp5hmw3gImpkyC9cflWESLg_30(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 93):
	{
		gen__Bp5hmw3gImpkyC9cflWESLg(p, (*(*n)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[((NI) 0)], r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		genWhileStmt__AQaGEWMAoGSH1pqI9bePiww_9(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		genVarStmt__AQaGEWMAoGSH1pqI9bePiww_10(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_286), TM__BxLwT0mhrtgTPodf1v3xjg_287);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		genCaseJS__Bp5hmw3gImpkyC9cflWESLg_31(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		genReturnStmt__AQaGEWMAoGSH1pqI9bePiww_11(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		genBreakStmt__AQaGEWMAoGSH1pqI9bePiww_12(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	{
		genAsgn__AQaGEWMAoGSH1pqI9bePiww_13(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74):
	{
		genFastAsgn__AQaGEWMAoGSH1pqI9bePiww_14(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA131_;
			genLineDir__AQaGEWMAoGSH1pqI9bePiww_4(p, n);
			gen__Bp5hmw3gImpkyC9cflWESLg(p, (*n)._kind_6.sons->data[((NI) 0)], r);
			unsureAsgnRef((void**) (&(*r).res), amp___4cYKitaHx6RQ9azRtQsZp6w(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_306), (*r).res));
		}
		LA131_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 89):
	{
		genAsmOrEmitStmt__AQaGEWMAoGSH1pqI9bePiww_15(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 154):
	{
		genTry__Bp5hmw3gImpkyC9cflWESLg_32(p, n, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 108):
	{
		genRaiseStmt__AQaGEWMAoGSH1pqI9bePiww_16(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 121):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 117):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 119):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 120):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		{
			if (!((*(*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA140_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_321), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__BxLwT0mhrtgTPodf1v3xjg_322, NIM_FALSE);
		}
		LA140_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90):
	{
		genPragma__AQaGEWMAoGSH1pqI9bePiww_17(p, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
		s_2 = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			if (!((262272 & (*s_2).flags) == 128)) goto LA146_;
			genSym__Bp5hmw3gImpkyC9cflWESLg_2(p, (*n)._kind_6.sons->data[((NI) 0)], r);
			unsureAsgnRef((void**) (&(*r).res), ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL));
		}
		LA146_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 156):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 157):
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*p).module).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_323), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 2), TM__BxLwT0mhrtgTPodf1v3xjg_324, NIM_FALSE);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 91):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T150_;
		T150_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T150_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
		gen__Bp5hmw3gImpkyC9cflWESLg(p, T150_, r);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
	}
	break;
	default:
	{
		NimStringDesc* T153_;
		T153_ = (NimStringDesc*)0;
		T153_ = rawNewString((reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)) ? reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_))->Sup.len : 0) + 24);
appendString(T153_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_325));
appendString(T153_, reprEnum((NI)(*n).kind, (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*p).module).config, (*n).info, T153_, TM__BxLwT0mhrtgTPodf1v3xjg_326);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, genStmt__AQaGEWMAoGSH1pqI9bePiww_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w r;
	nimZeroMem((void*)(&r), sizeof(tyObject_TCompRes__ZngkNoeBYb0CyBmkEOJi5w));
	gen__Bp5hmw3gImpkyC9cflWESLg(p, n, (&r));
	{
		tyArray__JiWwrsTRC6xqNlGcBthSVA T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T7_;
		if (!!((r.res == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL)))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T5_[0] = r.res;
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = percent___boICAAvO1zkTlYDOuEaj6g(T5_, 1);
		T7_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T7_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T6_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T7_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__AASbADdVur9cDEeNbrY1Baw)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* moduleLoadedVar, NIM_BOOL* inInitGuard) {
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115))) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						child = (*n)._kind_6.sons->data[i];
						addHcrInitGuards__AASbADdVur9cDEeNbrY1Baw(p, child, moduleLoadedVar, inInitGuard);
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL stmtShouldExecute;
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100));
		if (T10_) goto LA11_;
		T10_ = (((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 20))&31U)))!=0);
		LA11_: ;
		stmtShouldExecute = T10_;
		{
			if (!(*inInitGuard)) goto LA14_;
			{
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
				if (!stmtShouldExecute) goto LA18_;
				(*p).extraIndent -= ((NI) 1);
				T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T20_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_22));
				T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T21_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T20_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T21_);
				(*inInitGuard) = NIM_FALSE;
			}
			LA18_: ;
		}
		goto LA12_;
		LA14_: ;
		{
			{
				tyArray__JiWwrsTRC6xqNlGcBthSVA T27_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T28_;
				tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T29_;
				if (!!(stmtShouldExecute)) goto LA25_;
				nimZeroMem((void*)T27_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
				T27_[0] = moduleLoadedVar;
				T28_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T28_ = percent___RzB0z3UV9bb4kXUEGyS9crRA(T27_, 1);
				T29_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
				T29_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T28_);
				add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T29_);
				(*p).extraIndent += ((NI) 1);
				(*inInitGuard) = NIM_TRUE;
			}
			LA25_: ;
		}
		LA12_: ;
		genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genModule__AQaGEWMAoGSH1pqI9bePiww)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedN;
	{
		NimStringDesc* T5_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T6_;
		NimStringDesc* T7_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T8_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T9_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0)) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = rawNewString(((*(*(*(*p).module).module).name).s ? (*(*(*(*p).module).module).name).s->Sup.len : 0) + 7);
appendString(T5_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_20));
appendString(T5_, (*(*(*(*p).module).module).name).s);
		T6_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T6_ = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T5_, NIM_TRUE);
		T7_ = (NimStringDesc*)0;
		T7_ = toFilenameOption__hCtp6lwFVPBOAIlYyXBiuA((*(*p).module).config, (*(*(*p).module).module).info.fileIndex, ((tyEnum_FilenameOption__PR85MOw9bZL5JFJQSb26org) 4));
		T8_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T8_ = makeJSString__C2w9bj3qP5A9cVnAUrvoI9aqw(T7_, NIM_TRUE);
		T9_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T9_ = frameCreate__5xQGffjrmjbHfz64yWZ49bw(p, T6_, T8_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T9_);
	}
	LA3_: ;
	transformedN = transformStmt__o9bTtoSsaDmuiyVzV15dOyg_2((*(*p).module).graph, (*(*p).module).module, n);
	{
		if (!(((*(*(*p).module).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41))&63U)))!=0)) goto LA12_;
		transformedN = injectDestructorCalls__vFi0WDJke19caFCX1tc1FkQ((*(*p).module).graph, (*(*p).module).module, transformedN);
	}
	LA12_: ;
	{
		NIM_BOOL T16_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* moduleSym;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* moduleLoadedVar;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T20_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T21_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T23_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T24_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T25_;
		NIM_BOOL inGuardedBlock;
		tyArray__JiWwrsTRC6xqNlGcBthSVA T32_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T33_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T34_;
		T16_ = (NIM_BOOL)0;
		T16_ = hcrOn__UhPXgqyDuuU9cKcS8FM883w((*(*p).module).config);
		if (!(T16_)) goto LA17_;
		T16_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
		LA17_: ;
		if (!T16_) goto LA18_;
		moduleSym = (*(*p).module).module;
		T20_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T20_ = rope__yShmEg9cffWxI7s5XzEKBow((*(*moduleSym).name).s);
		T21_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T21_ = amp___Z7W1o5nPSc3ExfO5f7j1Gg(T20_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_21));
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = idOrSig__sKAFwdXn9cKHxc9cdaovk69cA(moduleSym, (*(*moduleSym).name).s, (&(*(*p).module).sigConflicts));
		moduleLoadedVar = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T21_, T22_);
		nimZeroMem((void*)T23_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T23_[0] = moduleLoadedVar;
		T24_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T24_ = percent___TLpRy9aDJ1Ni4vccOIoiMbA(T23_, 1);
		T25_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T25_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T24_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T25_);
		inGuardedBlock = NIM_FALSE;
		addHcrInitGuards__AASbADdVur9cDEeNbrY1Baw(p, transformedN, moduleLoadedVar, (&inGuardedBlock));
		{
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T30_;
			tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T31_;
			if (!inGuardedBlock) goto LA28_;
			(*p).extraIndent -= ((NI) 1);
			T30_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T30_ = rope__yShmEg9cffWxI7s5XzEKBow(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_22));
			T31_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
			T31_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T30_);
			add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T31_);
		}
		LA28_: ;
		nimZeroMem((void*)T32_, sizeof(tyArray__JiWwrsTRC6xqNlGcBthSVA));
		T32_[0] = moduleLoadedVar;
		T33_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T33_ = percent___vWWA89aSvs5QwAFN4Jdr2IA(T32_, 1);
		T34_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T34_ = indentLine__jQGcsbXjMm82EQo5Ohqg0w(p, T33_);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T34_);
	}
	goto LA14_;
	LA18_: ;
	{
		genStmt__AQaGEWMAoGSH1pqI9bePiww_2(p, transformedN);
	}
	LA14_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T40_;
		if (!(((*p).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 17))&31U)))!=0)) goto LA38_;
		T40_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T40_ = frameDestroy__XP5ZeYFuxYow89aSkFgfWeg(p);
		add__IM4kcMNkkOLJtqdEqSxR8A(&(*p).body, T40_);
	}
	LA38_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myProcess__PZ51a8H3AQu4zYP9cwHpJag)(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m;
	tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals;
	tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	m = ((tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*) (b));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses((*m).config, n);
		if (!T3_) goto LA4_;
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		if (!((*m).module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA8_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*m).config, (*n).info, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_4), TM__BxLwT0mhrtgTPodf1v3xjg_5);
	}
	LA8_: ;
	globals = (*((tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag**) (&((*(*m).graph).backend))));
	p = newInitProc__Q2imPq7jCUQhQkfXP9cf4XA(globals, m);
	(*p).unique = (*globals).unique;
	genModule__AQaGEWMAoGSH1pqI9bePiww(p, n);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).code, (*p).locals);
	add__IM4kcMNkkOLJtqdEqSxR8A(&(*(*p).g).code, (*p).body);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, genHeader__Jh8YZW9c6mmqtRqmZvtYISg)(void) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = nsuUnindent(((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_327), ((NI) IL64(9223372036854775807)), ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_328));
	T2_ = (NimStringDesc*)0;
	T2_ = nsuFormatVarargs(T1_, TM__BxLwT0mhrtgTPodf1v3xjg_329, 1);
	result = rope__yShmEg9cffWxI7s5XzEKBow(T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, attachProc__9aGDirKbsf9cN1iAWvMcXOKg_2)(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* newp;
	newp = genProc__VRfKzQHOMcRGtJXZSJxFtg(p, s);
	attachProc__C5SA4Y9bPAMaecsSyvetPTg(p, newp, s);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*, wholeCode__0JkORKxMs17USnUxSKLA9cw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m) {
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* result;
	tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag* globals;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* disp;
	tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T18_;
	result = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	globals = (*((tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag**) (&((*graph).backend))));
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** prc;
		NI i;
		NI L;
		NI T2_;
		prc = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		T2_ = ((*globals).forwarded ? (*globals).forwarded->Sup.len : 0);
		L = T2_;
		{
			while (1) {
				if (!(i < L)) goto LA4;
				prc = &(*globals).forwarded->data[i];
				{
					NIM_BOOL T7_;
					tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p;
					T7_ = (NIM_BOOL)0;
					T7_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*globals).generatedSyms), (*(*prc)).Sup.id);
					if (!!(T7_)) goto LA8_;
					p = newInitProc__Q2imPq7jCUQhQkfXP9cf4XA(globals, m);
					attachProc__9aGDirKbsf9cN1iAWvMcXOKg_2(p, (*prc));
				}
				LA8_: ;
				i += ((NI) 1);
			} LA4: ;
		}
	}
	disp = generateMethodDispatchers__7t0GJlNQwZyLt0Kz3RhRdw(graph);
	{
		NI i_2;
		NI colontmp_;
		NI i_3;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(disp);
		i_3 = ((NI) 0);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc_2;
				if (!(i_3 < colontmp_)) goto LA12;
				i_2 = i_3;
				prc_2 = (*(*disp)._kind_6.sons->data[i_2])._kind_4.sym;
				{
					NIM_BOOL T15_;
					tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q* p_2;
					T15_ = (NIM_BOOL)0;
					T15_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*globals).generatedSyms), (*prc_2).Sup.id);
					if (!!(T15_)) goto LA16_;
					p_2 = newInitProc__Q2imPq7jCUQhQkfXP9cf4XA(globals, m);
					attachProc__9aGDirKbsf9cN1iAWvMcXOKg_2(p_2, prc_2);
				}
				LA16_: ;
				i_3 += ((NI) 1);
			} LA12: ;
		}
	}
	T18_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
	T18_ = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ((*globals).typeInfo, (*globals).constants);
	result = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T18_, (*globals).code);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, myClose__yQE5q7IZnoaww0fGINiRdA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw* m;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = myProcess__PZ51a8H3AQu4zYP9cwHpJag(b, n);
	m = ((tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*) (b));
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** destructorCall;
			NI i;
			NI L;
			NI T6_;
			destructorCall = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			i = ((NI) 0);
			T6_ = ((*graph).globalDestructors ? (*graph).globalDestructors->Sup.len : 0);
			L = T6_;
			{
				while (1) {
					if (!(i < L)) goto LA8;
					destructorCall = &(*graph).globalDestructors->data[i];
					add__P8dDSotTW25BkfbyspojGg(n, (*destructorCall));
					i += ((NI) 1);
				} LA8: ;
			}
		}
	}
	LA3_: ;
	{
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0)) goto LA11_;
		(*(*((tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag**) (&((*graph).backend))))).inSystem = NIM_FALSE;
	}
	LA11_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = skipCodegen__nwSFZweO0MiC1cK59cLXWvgpasses((*m).config, n);
		if (!T15_) goto LA16_;
		result = n;
		goto BeforeRet_;
	}
	LA16_: ;
	{
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* code;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T22_;
		tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* T23_;
		NimStringDesc* outFile;
		NIM_BOOL T32_;
		if (!(((*(*m).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 14))&63U)))!=0)) goto LA20_;
		T22_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T22_ = genHeader__Jh8YZW9c6mmqtRqmZvtYISg();
		T23_ = (tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*)0;
		T23_ = wholeCode__0JkORKxMs17USnUxSKLA9cw(graph, m);
		code = amp___ShdZ6VrAQkY0nWR9a39b9bGdQ(T22_, T23_);
		outFile = prepareToWriteOutput__ea9bsNo9cwchKzwCi7UjcP7g_2((*m).config);
		{
			tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww* map;
			tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg _;
			NimStringDesc* T28_;
			NimStringDesc* T29_;
			tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q* T30_;
			NimStringDesc* T31_;
			if (!(((*(*m).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 49))&63U)))!=0)) goto LA26_;
			map = (tyObject_SourceMapcolonObjectType___m1S8ZVbfoQLk0xvz8tc6ww*)0;
			nimZeroMem((void*)(&_), sizeof(tyTuple__wb7Ftwo1Ba9cOF5RERh5YIg));
			T28_ = (NimStringDesc*)0;
			T28_ = dollar___mZ66tEveFIQokq3arf8Klw(code);
			genSourceMap__AhPdyw9b9bcsUwQskMDve3NA(T28_, outFile, (&_));
			code = _.Field0;
			map = _.Field1;
			T29_ = (NimStringDesc*)0;
			T29_ = rawNewString((outFile ? outFile->Sup.len : 0) + 4);
appendString(T29_, outFile);
appendString(T29_, ((NimStringDesc*) &TM__BxLwT0mhrtgTPodf1v3xjg_331));
			T30_ = (tyObject_JsonNodeObj__df9bshXB7C9cTiWPIOtX3j1Q*)0;
			T30_ = percent___PVcH6RFdp59aTK2rmalT2CA(map);
			T31_ = (NimStringDesc*)0;
			T31_ = dollar___79aIqF5QC8ZRJgu2hlv9bdjw(T30_);
			writeFile__D6Pj9c29aCLEJP9beOWa08HYA(T29_, T31_);
		}
		LA26_: ;
		T32_ = (NIM_BOOL)0;
		T32_ = writeRopeIfNotEqual__Wiam9c8x73Mtmbj0r4Ppikg_2(code, outFile);
		(void)(T32_);
	}
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_jsgenDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__BxLwT0mhrtgTPodf1v3xjg_2_4[4];
static TNimNode* TM__BxLwT0mhrtgTPodf1v3xjg_3_8[8];
static TNimNode* TM__BxLwT0mhrtgTPodf1v3xjg_7_15[15];
static TNimNode* TM__BxLwT0mhrtgTPodf1v3xjg_8_2[2];
static TNimNode* TM__BxLwT0mhrtgTPodf1v3xjg_301_10[10];
NI TM__BxLwT0mhrtgTPodf1v3xjg_303;
static char* NIM_CONST TM__BxLwT0mhrtgTPodf1v3xjg_302[10] = {
"etyNone", 
"etyNull", 
"etyProc", 
"etyBool", 
"etySeq", 
"etyInt", 
"etyFloat", 
"etyString", 
"etyObject", 
"etyBaseIndex"};
static TNimNode TM__BxLwT0mhrtgTPodf1v3xjg_0[44];

/* section: NIM_merge_TYPE_INIT3 */
NTI__qij68Ti2EwJQHH6sSdkSdw_.size = sizeof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw);
NTI__qij68Ti2EwJQHH6sSdkSdw_.align = NIM_ALIGNOF(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw);
NTI__qij68Ti2EwJQHH6sSdkSdw_.kind = 17;
NTI__qij68Ti2EwJQHH6sSdkSdw_.base = (&NTI__Hb6rFM0ecvtlLf2kv9aU75w_);
TM__BxLwT0mhrtgTPodf1v3xjg_2_4[0] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[1];
TM__BxLwT0mhrtgTPodf1v3xjg_0[1].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[1].offset = offsetof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw, module);
TM__BxLwT0mhrtgTPodf1v3xjg_0[1].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[1].name = "module";
TM__BxLwT0mhrtgTPodf1v3xjg_2_4[1] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[2];
TM__BxLwT0mhrtgTPodf1v3xjg_0[2].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[2].offset = offsetof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw, graph);
TM__BxLwT0mhrtgTPodf1v3xjg_0[2].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[2].name = "graph";
TM__BxLwT0mhrtgTPodf1v3xjg_2_4[2] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[3];
TM__BxLwT0mhrtgTPodf1v3xjg_0[3].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[3].offset = offsetof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw, config);
TM__BxLwT0mhrtgTPodf1v3xjg_0[3].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[3].name = "config";
TM__BxLwT0mhrtgTPodf1v3xjg_2_4[3] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[4];
TM__BxLwT0mhrtgTPodf1v3xjg_0[4].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[4].offset = offsetof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw, sigConflicts);
TM__BxLwT0mhrtgTPodf1v3xjg_0[4].typ = (&NTI__tUMxxU9cRgLolsrW9b7IBGsQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[4].name = "sigConflicts";
TM__BxLwT0mhrtgTPodf1v3xjg_0[0].len = 4; TM__BxLwT0mhrtgTPodf1v3xjg_0[0].kind = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[0].sons = &TM__BxLwT0mhrtgTPodf1v3xjg_2_4[0];
NTI__qij68Ti2EwJQHH6sSdkSdw_.node = &TM__BxLwT0mhrtgTPodf1v3xjg_0[0];
NTI__O09bHTFgtn9cJLLJxiNhuKUA_.size = sizeof(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*);
NTI__O09bHTFgtn9cJLLJxiNhuKUA_.align = NIM_ALIGNOF(tyObject_TJSGen__qij68Ti2EwJQHH6sSdkSdw*);
NTI__O09bHTFgtn9cJLLJxiNhuKUA_.kind = 22;
NTI__O09bHTFgtn9cJLLJxiNhuKUA_.base = (&NTI__qij68Ti2EwJQHH6sSdkSdw_);
NTI__O09bHTFgtn9cJLLJxiNhuKUA_.marker = Marker_tyRef__O09bHTFgtn9cJLLJxiNhuKUA;
NTI__nWsHZg3qCUsABoCNYLliag_.size = sizeof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag);
NTI__nWsHZg3qCUsABoCNYLliag_.align = NIM_ALIGNOF(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag);
NTI__nWsHZg3qCUsABoCNYLliag_.kind = 17;
NTI__nWsHZg3qCUsABoCNYLliag_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[0] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[6];
TM__BxLwT0mhrtgTPodf1v3xjg_0[6].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[6].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, typeInfo);
TM__BxLwT0mhrtgTPodf1v3xjg_0[6].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[6].name = "typeInfo";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[1] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[7];
TM__BxLwT0mhrtgTPodf1v3xjg_0[7].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[7].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, constants);
TM__BxLwT0mhrtgTPodf1v3xjg_0[7].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[7].name = "constants";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[2] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[8];
TM__BxLwT0mhrtgTPodf1v3xjg_0[8].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[8].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, code);
TM__BxLwT0mhrtgTPodf1v3xjg_0[8].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[8].name = "code";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[3] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[9];
TM__BxLwT0mhrtgTPodf1v3xjg_0[9].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[9].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, forwarded);
TM__BxLwT0mhrtgTPodf1v3xjg_0[9].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[9].name = "forwarded";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[4] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[10];
TM__BxLwT0mhrtgTPodf1v3xjg_0[10].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[10].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, generatedSyms);
TM__BxLwT0mhrtgTPodf1v3xjg_0[10].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[10].name = "generatedSyms";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[5] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[11];
TM__BxLwT0mhrtgTPodf1v3xjg_0[11].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[11].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, typeInfoGenerated);
TM__BxLwT0mhrtgTPodf1v3xjg_0[11].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[11].name = "typeInfoGenerated";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[6] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[12];
TM__BxLwT0mhrtgTPodf1v3xjg_0[12].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[12].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, unique);
TM__BxLwT0mhrtgTPodf1v3xjg_0[12].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[12].name = "unique";
TM__BxLwT0mhrtgTPodf1v3xjg_3_8[7] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[13];
TM__BxLwT0mhrtgTPodf1v3xjg_0[13].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[13].offset = offsetof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag, inSystem);
TM__BxLwT0mhrtgTPodf1v3xjg_0[13].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[13].name = "inSystem";
TM__BxLwT0mhrtgTPodf1v3xjg_0[5].len = 8; TM__BxLwT0mhrtgTPodf1v3xjg_0[5].kind = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[5].sons = &TM__BxLwT0mhrtgTPodf1v3xjg_3_8[0];
NTI__nWsHZg3qCUsABoCNYLliag_.node = &TM__BxLwT0mhrtgTPodf1v3xjg_0[5];
NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_.size = sizeof(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*);
NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_.align = NIM_ALIGNOF(tyObject_PGlobalscolonObjectType___nWsHZg3qCUsABoCNYLliag*);
NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_.kind = 22;
NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_.base = (&NTI__nWsHZg3qCUsABoCNYLliag_);
NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_.marker = Marker_tyRef__Q8XTeJJ39cPFyNvJXj9bmcMQ;
NTI__AFoo8FBR6Z1RtIhjuHkU2Q_.size = sizeof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q);
NTI__AFoo8FBR6Z1RtIhjuHkU2Q_.align = NIM_ALIGNOF(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q);
NTI__AFoo8FBR6Z1RtIhjuHkU2Q_.kind = 18;
NTI__AFoo8FBR6Z1RtIhjuHkU2Q_.base = 0;
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[0] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[15];
TM__BxLwT0mhrtgTPodf1v3xjg_0[15].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[15].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, procDef);
TM__BxLwT0mhrtgTPodf1v3xjg_0[15].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[15].name = "procDef";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[1] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[16];
TM__BxLwT0mhrtgTPodf1v3xjg_0[16].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[16].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, prc);
TM__BxLwT0mhrtgTPodf1v3xjg_0[16].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[16].name = "prc";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[2] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[17];
TM__BxLwT0mhrtgTPodf1v3xjg_0[17].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[17].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, globals);
TM__BxLwT0mhrtgTPodf1v3xjg_0[17].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[17].name = "globals";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[3] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[18];
TM__BxLwT0mhrtgTPodf1v3xjg_0[18].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[18].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, locals);
TM__BxLwT0mhrtgTPodf1v3xjg_0[18].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[18].name = "locals";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[4] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[19];
TM__BxLwT0mhrtgTPodf1v3xjg_0[19].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[19].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, body);
TM__BxLwT0mhrtgTPodf1v3xjg_0[19].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[19].name = "body";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[5] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[20];
TM__BxLwT0mhrtgTPodf1v3xjg_0[20].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[20].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, options);
TM__BxLwT0mhrtgTPodf1v3xjg_0[20].typ = (&NTI__7MnKRybmCNh5j9bDRLMkxLw_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[20].name = "options";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[6] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[21];
TM__BxLwT0mhrtgTPodf1v3xjg_0[21].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[21].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, module);
TM__BxLwT0mhrtgTPodf1v3xjg_0[21].typ = (&NTI__O09bHTFgtn9cJLLJxiNhuKUA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[21].name = "module";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[7] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[22];
TM__BxLwT0mhrtgTPodf1v3xjg_0[22].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[22].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, g);
TM__BxLwT0mhrtgTPodf1v3xjg_0[22].typ = (&NTI__Q8XTeJJ39cPFyNvJXj9bmcMQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[22].name = "g";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[8] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[23];
TM__BxLwT0mhrtgTPodf1v3xjg_0[23].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[23].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, generatedParamCopies);
TM__BxLwT0mhrtgTPodf1v3xjg_0[23].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[23].name = "generatedParamCopies";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[9] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[24];
TM__BxLwT0mhrtgTPodf1v3xjg_0[24].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[24].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, beforeRetNeeded);
TM__BxLwT0mhrtgTPodf1v3xjg_0[24].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[24].name = "beforeRetNeeded";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[10] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[25];
TM__BxLwT0mhrtgTPodf1v3xjg_0[25].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[25].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, unique);
TM__BxLwT0mhrtgTPodf1v3xjg_0[25].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[25].name = "unique";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[11] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[26];
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.size = sizeof(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg);
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.align = NIM_ALIGNOF(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg);
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.kind = 18;
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.base = 0;
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.flags = 3;
TM__BxLwT0mhrtgTPodf1v3xjg_8_2[0] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[28];
TM__BxLwT0mhrtgTPodf1v3xjg_0[28].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[28].offset = offsetof(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg, id);
TM__BxLwT0mhrtgTPodf1v3xjg_0[28].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[28].name = "id";
TM__BxLwT0mhrtgTPodf1v3xjg_8_2[1] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[29];
TM__BxLwT0mhrtgTPodf1v3xjg_0[29].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[29].offset = offsetof(tyObject_TBlock__46cd0Xw9aDJ1QWTE8nV4mLg, isLoop);
TM__BxLwT0mhrtgTPodf1v3xjg_0[29].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[29].name = "isLoop";
TM__BxLwT0mhrtgTPodf1v3xjg_0[27].len = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[27].kind = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[27].sons = &TM__BxLwT0mhrtgTPodf1v3xjg_8_2[0];
NTI__46cd0Xw9aDJ1QWTE8nV4mLg_.node = &TM__BxLwT0mhrtgTPodf1v3xjg_0[27];
NTI__8fytVdU59b5aj319cog2ztLw_.size = sizeof(tySequence__8fytVdU59b5aj319cog2ztLw*);
NTI__8fytVdU59b5aj319cog2ztLw_.align = NIM_ALIGNOF(tySequence__8fytVdU59b5aj319cog2ztLw*);
NTI__8fytVdU59b5aj319cog2ztLw_.kind = 24;
NTI__8fytVdU59b5aj319cog2ztLw_.base = (&NTI__46cd0Xw9aDJ1QWTE8nV4mLg_);
NTI__8fytVdU59b5aj319cog2ztLw_.flags = 2;
NTI__8fytVdU59b5aj319cog2ztLw_.marker = Marker_tySequence__8fytVdU59b5aj319cog2ztLw;
TM__BxLwT0mhrtgTPodf1v3xjg_0[26].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[26].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, blocks);
TM__BxLwT0mhrtgTPodf1v3xjg_0[26].typ = (&NTI__8fytVdU59b5aj319cog2ztLw_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[26].name = "blocks";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[12] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[30];
TM__BxLwT0mhrtgTPodf1v3xjg_0[30].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[30].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, extraIndent);
TM__BxLwT0mhrtgTPodf1v3xjg_0[30].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[30].name = "extraIndent";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[13] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[31];
TM__BxLwT0mhrtgTPodf1v3xjg_0[31].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[31].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, up);
TM__BxLwT0mhrtgTPodf1v3xjg_0[31].typ = (&NTI__OFWibP8T8afo89apFNGZiwA_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[31].name = "up";
TM__BxLwT0mhrtgTPodf1v3xjg_7_15[14] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[32];
TM__BxLwT0mhrtgTPodf1v3xjg_0[32].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[32].offset = offsetof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q, declaredGlobals);
TM__BxLwT0mhrtgTPodf1v3xjg_0[32].typ = (&NTI__PQrmFm4BXFkFSVOUl1ojSg_);
TM__BxLwT0mhrtgTPodf1v3xjg_0[32].name = "declaredGlobals";
TM__BxLwT0mhrtgTPodf1v3xjg_0[14].len = 15; TM__BxLwT0mhrtgTPodf1v3xjg_0[14].kind = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[14].sons = &TM__BxLwT0mhrtgTPodf1v3xjg_7_15[0];
NTI__AFoo8FBR6Z1RtIhjuHkU2Q_.node = &TM__BxLwT0mhrtgTPodf1v3xjg_0[14];
NTI__OFWibP8T8afo89apFNGZiwA_.size = sizeof(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*);
NTI__OFWibP8T8afo89apFNGZiwA_.align = NIM_ALIGNOF(tyObject_TProc__AFoo8FBR6Z1RtIhjuHkU2Q*);
NTI__OFWibP8T8afo89apFNGZiwA_.kind = 22;
NTI__OFWibP8T8afo89apFNGZiwA_.base = (&NTI__AFoo8FBR6Z1RtIhjuHkU2Q_);
NTI__OFWibP8T8afo89apFNGZiwA_.marker = Marker_tyRef__OFWibP8T8afo89apFNGZiwA;
NTI__9aFSCXgaSEq2m81RJRMKDeA_.size = sizeof(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA);
NTI__9aFSCXgaSEq2m81RJRMKDeA_.align = NIM_ALIGNOF(tyEnum_TJSTypeKind__9aFSCXgaSEq2m81RJRMKDeA);
NTI__9aFSCXgaSEq2m81RJRMKDeA_.kind = 14;
NTI__9aFSCXgaSEq2m81RJRMKDeA_.base = 0;
NTI__9aFSCXgaSEq2m81RJRMKDeA_.flags = 3;
for (TM__BxLwT0mhrtgTPodf1v3xjg_303 = 0; TM__BxLwT0mhrtgTPodf1v3xjg_303 < 10; TM__BxLwT0mhrtgTPodf1v3xjg_303++) {
TM__BxLwT0mhrtgTPodf1v3xjg_0[TM__BxLwT0mhrtgTPodf1v3xjg_303+33].kind = 1;
TM__BxLwT0mhrtgTPodf1v3xjg_0[TM__BxLwT0mhrtgTPodf1v3xjg_303+33].offset = TM__BxLwT0mhrtgTPodf1v3xjg_303;
TM__BxLwT0mhrtgTPodf1v3xjg_0[TM__BxLwT0mhrtgTPodf1v3xjg_303+33].name = TM__BxLwT0mhrtgTPodf1v3xjg_302[TM__BxLwT0mhrtgTPodf1v3xjg_303];
TM__BxLwT0mhrtgTPodf1v3xjg_301_10[TM__BxLwT0mhrtgTPodf1v3xjg_303] = &TM__BxLwT0mhrtgTPodf1v3xjg_0[TM__BxLwT0mhrtgTPodf1v3xjg_303+33];
}
TM__BxLwT0mhrtgTPodf1v3xjg_0[43].len = 10; TM__BxLwT0mhrtgTPodf1v3xjg_0[43].kind = 2; TM__BxLwT0mhrtgTPodf1v3xjg_0[43].sons = &TM__BxLwT0mhrtgTPodf1v3xjg_301_10[0];
NTI__9aFSCXgaSEq2m81RJRMKDeA_.node = &TM__BxLwT0mhrtgTPodf1v3xjg_0[43];
}

