/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw;
typedef struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA;
typedef struct tySequence__K8W16aeLg4OWxniQxtguMw tySequence__K8W16aeLg4OWxniQxtguMw;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
struct tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* transCon;
NI inlining;
NI nestedProcs;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* contSyms;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* breakSyms;
NIM_BOOL deferDetected;
NIM_BOOL tooEarly;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA {
NI counter;
tySequence__K8W16aeLg4OWxniQxtguMw* data;
};
struct tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw {
tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA mapping;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forStmt;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* forLoopBody;
NI yieldStmts;
tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* next;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg;
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
struct tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw {
  RootObj Sup;
NI colonstate_;
tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c1;
};
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs, void* ClE_0);
void* ClE_0;
} tyProc__5qqAV51RjFgqAF4yOP2S7Q;
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__2w3VcOiOmEqxgfH4AylIpg_23) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__2w3VcOiOmEqxgfH4AylIpg_24) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__2w3VcOiOmEqxgfH4AylIpg_25) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__2w3VcOiOmEqxgfH4AylIpg_26) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__2w3VcOiOmEqxgfH4AylIpg_27) (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs);
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__K8W16aeLg4OWxniQxtguMw {
  TGenericSeq Sup;
  tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*, openTransf__3DaoTzFM8siFEsr9areRAsg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__CFQvJAfmRh5qxjY9bLo9c7Fg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__TGWT2zXHjsFJka0TXFMVzw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftLambdas__dmTb5DSkbT8504NMz3NOoA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, NIM_BOOL* tooEarly);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, processTransf__vQ6WkB89cnNhnYNYOnfVCDw)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, pushTransCon__Q7kqtvaYdgT06r9a1oTEwOg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*, newTransCon__gHBjh7dKE1v5tJDPFQImxA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, initIdNodeTable__n26YHulDKiMl1PNSd3sg9cA)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transform__x9bzuCn2mNRReiUBcSXmpNQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSym__x9bzuCn2mNRReiUBcSXmpNQ_2)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSymAux__x9bzuCn2mNRReiUBcSXmpNQ_3)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBody__ocxOgPRHWfivNZELIhOv7w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftIterSym__8CYqf1nXlpBtnWvyO6vrCw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeClosure__fa9aZDXQ04CAodm0trAX6LA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, idNodeTableGet__6wztwviRk10SZ9cTP17EzEQ)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformArrayAccess__x9bzuCn2mNRReiUBcSXmpNQ_4)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__6JdTBPckyxXesjJbA5eHMwtransf)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformFor__x9bzuCn2mNRReiUBcSXmpNQ_5)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newLabel__V1Tz56SxbDGtHGL321qFFA)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__T00TWsJvsUcixkQXPnIphAtransf)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI sons);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformLoopBody__x9bzuCn2mNRReiUBcSXmpNQ_6)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasContinue__9bK4fFwGtTysodwQljFbYHQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftForLoop__d1skGaYPbh4srEm2IRKTwg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, addVar__qOCBdprWtK4hxer73SEdQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleIteratorVar__9chmxIhIr2aUJbMPEmPAqZg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter);
N_LIB_PRIVATE N_NIMCALL(void, rec__geiVtgUG9aFR6CzPR9bf9ccIw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NI* dangerousYields);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg, putArgInto__9aRkwnDgD2oEx3liL5Jf75A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal);
N_LIB_PRIVATE N_NIMCALL(void, idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA* t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTemp__8R75N1yxpZ5H5DEY9c3VDOQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVarForClosureIter__JA4vA9a9b64Ti9cPXENYI6L5g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* detail);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, popTransCon__uND2ekcuj27zfq5DWCAPjg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformCase__x9bzuCn2mNRReiUBcSXmpNQ_8)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI sons);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformWhile__x9bzuCn2mNRReiUBcSXmpNQ_9)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBlock__x9bzuCn2mNRReiUBcSXmpNQ_10)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreak__x9bzuCn2mNRReiUBcSXmpNQ_11)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformCall__x9bzuCn2mNRReiUBcSXmpNQ_12)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, flattenTree__4jym4pu5X8jJvM0PYQomDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* root);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getMergeOp__EuK0aY8I1jCqHxmYwogXtg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, flattenTreeAux__cz5kqNnGwAu9cFHQaWrJE9cw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg, getMagic__4W1ZJaFiusqlhViRx9cbM9bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, evalOp__naTMtRq9avUKkKDwI0csDMg)(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformAddrDeref__oB0ZJYmKjtxbUq9azE9as4GQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw a, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toVar__ltkZL9cdOU06qIwP1L9aFqcw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, methodCall__8CKh3oS3FPdX9cqBY8VV6MQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformConv__x9bzuCn2mNRReiUBcSXmpNQ_13)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrdinalType__6euCPZwUsyXzP1vAm4IthA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL allowEnumWithHoles);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lastOrd__hjogdnp59cMX1rwmjikBhqw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, takeType__0FGAKd3dm9aUGX9cs9aj1kraA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* arg);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, generateThunk__XhGS8C5uskyoYzXjsKDuiw)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformConstSection__fVJbvRdbXsZk6wrZ9cHGJCg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformVarSection__fVJbvRdbXsZk6wrZ9cHGJCg_2)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVar__SdYC3nz0w1cFDftpjGBhxQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, copySym__lIu8wX6Beq6dBJgESOFFjg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
static N_INLINE(NIM_BOOL, importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformYield__x9bzuCn2mNRReiUBcSXmpNQ_14)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_NIMCALL(void, Marker_tyRef__7lgNfGoBjgvsM5K1jkApkg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTupleAccess__9bplMpBXm4y9buiuIhASVmzA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tup, NI i);
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, asgnTo__MJeJEZTxLrk1GPzHVc547Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs, void* ClE_0);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, introduceNewLocalVars__x9bzuCn2mNRReiUBcSXmpNQ_15)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformAsgn__x9bzuCn2mNRReiUBcSXmpNQ_16)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformExceptBranch__x9bzuCn2mNRReiUBcSXmpNQ_17)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__dZW9czpRSiiVl9cyT6tyk84A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callCodegenProc__6cD4vACMYqPEkcqC9cypTrw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg1, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg2, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg3, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* optionalArgs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toRef__IIQZtbSxQZOu2WmBJ9bnpCg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getConstExpr__A7gcXCy5E3uGBy5F37NoHA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
static N_INLINE(NIM_BOOL, dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst);
N_LIB_PRIVATE N_NIMCALL(void, liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, flattenStmts__N9aNOI5jUJs7HuqSqY7VqPw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___txCax6HTxTvaDY9bSHIRipg)(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ** s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** b, NI bLen_0);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, X5BX5D___5Y2wMdX1Q5sV9abRFAviD9aw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s, NI sLen_0, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftLocalsIfRequested__LPFQUSXwjhtGHYhcDkDrbA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformClosureIterator__pOvzY9bL6Z9bAquTmdZOUhVg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);

/* section: NIM_merge_DATA */
extern TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
N_LIB_PRIVATE TNimType NTI__m7cKlfKYTeFRQpBypUYc2A_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__VDvyAvJlyyy8i9bxzTgZE9cw_;
extern TNimType NTI__UWAp0mDjKLG1NEwUafSRhA_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
N_LIB_PRIVATE TNimType NTI__TGWT2zXHjsFJka0TXFMVzw_;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_4, "wrong AST for borrowed symbol", 29);
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_6, "/home/runner/work/nightlies/nightlies/nim/compiler/transf.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_5 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 129),
((NI) 37)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_7, "transformFor", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_8 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 615),
((NI) 39)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_9, ":tmp", 4);
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_10, "popTransCon", 11);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_11 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 81),
((NI) 39)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_12, "closure to closure created", 26);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_13 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 456),
((NI) 17)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_14, "(", 1);
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_15, ", ", 2);
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_16, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_17 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 178),
((NI) 22)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_18, "transformVarSection: not nkVarTuple", 35);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_19 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 196),
((NI) 21)}
;
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__k9ckC7egSTPlxMaCeJlF9aLw_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
N_LIB_PRIVATE TNimType NTI__7lgNfGoBjgvsM5K1jkApkg_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_21 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 355),
((NI) 21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__2w3VcOiOmEqxgfH4AylIpg_22 = {((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_6),
((NI) 360),
((NI) 21)}
;
STRING_LITERAL(TM__2w3VcOiOmEqxgfH4AylIpg_28, "getCurrentException", 19);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_NIMCALL(void, Marker_tyRef__CFQvJAfmRh5qxjY9bLo9c7Fg)(void* p, NI op) {
	tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* a;
	a = (tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*)p;
	nimGCvisit((void*)(*a).mapping.data, op);
	nimGCvisit((void*)(*a).owner, op);
	nimGCvisit((void*)(*a).forStmt, op);
	nimGCvisit((void*)(*a).forLoopBody, op);
	nimGCvisit((void*)(*a).next, op);
}
static N_NIMCALL(void, Marker_tyRef__TGWT2zXHjsFJka0TXFMVzw)(void* p, NI op) {
	tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* a;
	a = (tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*)p;
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).transCon, op);
	nimGCvisit((void*)(*a).contSyms, op);
	nimGCvisit((void*)(*a).breakSyms, op);
	nimGCvisit((void*)(*a).graph, op);
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*, openTransf__3DaoTzFM8siFEsr9areRAsg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, NimStringDesc* filename) {
	tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* result;
	result = (tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*)0;
	result = (tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*) newObj((&NTI__TGWT2zXHjsFJka0TXFMVzw_), sizeof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A));
	(*result).Sup.Sup.m_type = (&NTI__m7cKlfKYTeFRQpBypUYc2A_);
	if ((*result).contSyms) { nimGCunrefNoCycle((*result).contSyms); (*result).contSyms = NIM_NIL; }
	if ((*result).breakSyms) { nimGCunrefNoCycle((*result).breakSyms); (*result).breakSyms = NIM_NIL; }
	asgnRef((void**) (&(*result).module), module);
	asgnRef((void**) (&(*result).graph), g);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushTransCon__Q7kqtvaYdgT06r9a1oTEwOg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* t) {
	asgnRef((void**) (&(*t).next), (*c).transCon);
	asgnRef((void**) (&(*c).transCon), t);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*, newTransCon__gHBjh7dKE1v5tJDPFQImxA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* result;
	result = (tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*)0;
	result = (tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*) newObj((&NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_), sizeof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw));
	initIdNodeTable__n26YHulDKiMl1PNSd3sg9cA((&(*result).mapping));
	asgnRef((void**) (&(*result).owner), owner);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!!(((*c).transCon == ((tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*) NIM_NIL)))) goto LA3_;
		result = (*(*c).transCon).owner;
	}
	goto LA1_;
	LA3_: ;
	{
		result = (*c).module;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSymAux__x9bzuCn2mNRReiUBcSXmpNQ_3)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
	tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* tc;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
			if (!((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA9_;
			T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T11_ = transformBody__ocxOgPRHWfivNZELIhOv7w((*c).graph, s, NIM_TRUE);
			(void)(T11_);
		}
		LA9_: ;
		{
			if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA14_;
			{
				if (!(*c).tooEarly) goto LA18_;
				result = n;
				goto BeforeRet_;
			}
			goto LA16_;
			LA18_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T21_;
				T21_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T21_ = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
				result = liftIterSym__8CYqf1nXlpBtnWvyO6vrCw_2((*c).graph, n, T21_);
				goto BeforeRet_;
			}
			LA16_: ;
		}
		goto LA12_;
		LA14_: ;
		{
			NIM_BOOL T23_;
			T23_ = (NIM_BOOL)0;
			T23_ = ((94208 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			if (!(T23_)) goto LA24_;
			T23_ = !((*c).tooEarly);
			LA24_: ;
			if (!T23_) goto LA25_;
			result = makeClosure__fa9aZDXQ04CAodm0trAX6LA((*c).graph, s, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), (*n).info);
			goto BeforeRet_;
		}
		goto LA12_;
		LA25_: ;
		LA12_: ;
	}
	LA5_: ;
	b = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	tc = (*c).transCon;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 30))&63U)))!=0);
		if (!(T29_)) goto LA30_;
		T29_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		LA30_: ;
		if (!T29_) goto LA31_;
		b = (*(*s).ast)._kind_6.sons->data[((NI) 6)];
		{
			if (!!(((*b).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA35_;
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_4), TM__2w3VcOiOmEqxgfH4AylIpg_5);
		}
		LA35_: ;
		b = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*b)._kind_4.sym, (*n).info);
	}
	goto LA27_;
	LA31_: ;
	{
		if (!(((NI) 0) < (*c).inlining)) goto LA38_;
		b = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig((*n)._kind_4.sym, (*n).info);
	}
	goto LA27_;
	LA38_: ;
	{
		b = n;
	}
	LA27_: ;
	{
		while (1) {
			tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T43_;
			if (!!((tc == ((tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*) NIM_NIL)))) goto LA42;
			T43_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
			T43_ = &(*b)._kind_4.sym->Sup;
			result = idNodeTableGet__6wztwviRk10SZ9cTP17EzEQ((*tc).mapping, T43_);
			{
				if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA46_;
				{
					if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA50_;
					result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(result);
					(*result).info = (*n).info;
				}
				LA50_: ;
				goto BeforeRet_;
			}
			LA46_: ;
			tc = (*tc).next;
		} LA42: ;
	}
	result = b;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSym__x9bzuCn2mNRReiUBcSXmpNQ_2)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = transformSymAux__x9bzuCn2mNRReiUBcSXmpNQ_3(c, n);
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__6JdTBPckyxXesjJbA5eHMwtransf)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3(a);
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformArrayAccess__x9bzuCn2mNRReiUBcSXmpNQ_4)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = n;
	}
	goto LA1_;
	LA5_: ;
	{
		result = newTransNode__6JdTBPckyxXesjJbA5eHMwtransf(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T11_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[i]);
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, T11_));
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newLabel__V1Tz56SxbDGtHGL321qFFA)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 22), ((tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*) NIM_NIL), T1_, (*n).info, 0);
	asgnRef((void**) (&(*result).name), getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_9)));
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__T00TWsJvsUcixkQXPnIphAtransf)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI sons) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = newNodeI__vokyXY9cZDshCSxFKChhG9bg(kind, info);
	if ((*x)._kind_6.sons) { nimGCunrefNoCycle((*x)._kind_6.sons); (*x)._kind_6.sons = NIM_NIL; }
	(*x)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (sons)));
	result = x;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasContinue__9bK4fFwGtTysodwQljFbYHQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111):
	{
		result = NIM_TRUE;
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA6;
					i = i_2;
					{
						NIM_BOOL T9_;
						T9_ = (NIM_BOOL)0;
						T9_ = hasContinue__9bK4fFwGtTysodwQljFbYHQ((*n)._kind_6.sons->data[i]);
						if (!T9_) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA6: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, pop__sJkHMuFHoY5Elz2ZDxz78Asystem)(tySequence__DfgJFJEYoj4YBAHLZPl5lQ** s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	NI L;
	NI T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = ((*s) ? (*s)->Sup.len : 0);
	L = (NI)(T1_ - ((NI) 1));
	result = (*s)->data[L];
	unsureAsgnRef((void**) (&(*s)), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*s))->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) (L))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformLoopBody__x9bzuCn2mNRReiUBcSXmpNQ_6)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
		NI T6_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasContinue__9bK4fFwGtTysodwQljFbYHQ(n);
		if (!T3_) goto LA4_;
		labl = newLabel__V1Tz56SxbDGtHGL321qFFA(c, n);
		asgnRef((void**) (&(*c).contSyms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).contSyms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
		T6_ = (*c).contSyms->Sup.len++;
		asgnRef((void**) (&(*c).contSyms->data[T6_]), labl);
		result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112), (*n).info, ((NI) 2));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, n));
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).contSyms));
		(void)(T7_);
	}
	goto LA1_;
	LA4_: ;
	{
		result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rec__geiVtgUG9aFR6CzPR9bf9ccIw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NI* dangerousYields) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T5_)) goto LA6_;
			T5_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).owner == owner);
			LA6_: ;
			if (!T5_) goto LA7_;
		}
		goto LA3_;
		LA7_: ;
		{
			(*dangerousYields) += ((NI) 1);
		}
		LA3_: ;
	}
	break;
	default:
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* c;
			c = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA14;
						i = i_2;
						c = (*n)._kind_6.sons->data[i];
						rec__geiVtgUG9aFR6CzPR9bf9ccIw(c, owner, dangerousYields);
						i_2 += ((NI) 1);
					} LA14: ;
				}
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleIteratorVar__9chmxIhIr2aUJbMPEmPAqZg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter) {
	NIM_BOOL result;
	NI dangerousYields;
	result = (NIM_BOOL)0;
	dangerousYields = ((NI) 0);
	rec__geiVtgUG9aFR6CzPR9bf9ccIw((*(*iter).ast)._kind_6.sons->data[((NI) 6)], iter, (&dangerousYields));
	result = (dangerousYields == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg, putArgInto__9aRkwnDgD2oEx3liL5Jf75A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal) {
	tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg result;
{	result = (tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg)0;
	{
		if (!((*formal).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA3_;
		result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
		T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(formal, IL64(36134350135273744));
		if (!((*T7_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*T7_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA8_;
		switch ((*arg).kind) {
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126):
		{
			result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 4);
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
		{
			result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 2);
			goto BeforeRet_;
		}
		break;
		default:
		{
			result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0);
			goto BeforeRet_;
		}
		break;
		}
	}
	LA8_: ;
	switch ((*arg).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		result = putArgInto__9aRkwnDgD2oEx3liL5Jf75A((*arg)._kind_6.sons->data[((NI) 0)], formal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(arg);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					{
						tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg T21_;
						T21_ = (tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg)0;
						T21_ = putArgInto__9aRkwnDgD2oEx3liL5Jf75A((*arg)._kind_6.sons->data[i], formal);
						if (!!((T21_ == ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0)))) goto LA22_;
						result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 1);
						goto BeforeRet_;
					}
					LA22_: ;
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
		result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(arg);
			i_4 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
					if (!(i_4 < colontmp__2)) goto LA27;
					i_3 = i_4;
					{
						if (!((*(*arg)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA30_;
						a = (*(*arg)._kind_6.sons->data[i_3])._kind_6.sons->data[((NI) 1)];
					}
					goto LA28_;
					LA30_: ;
					{
						a = (*arg)._kind_6.sons->data[((NI) 0)];
					}
					LA28_: ;
					{
						tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg T35_;
						T35_ = (tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg)0;
						T35_ = putArgInto__9aRkwnDgD2oEx3liL5Jf75A(a, formal);
						if (!!((T35_ == ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0)))) goto LA36_;
						result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 1);
						goto BeforeRet_;
					}
					LA36_: ;
					i_4 += ((NI) 1);
				} LA27: ;
			}
		}
		result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0);
	}
	break;
	default:
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T41_;
			T41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T41_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(formal, IL64(36134350135273744));
			if (!((*T41_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23) || (*T41_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47))) goto LA42_;
			result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 3);
		}
		goto LA39_;
		LA42_: ;
		{
			result = ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 1);
		}
		LA39_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTemp__8R75N1yxpZ5H5DEY9c3VDOQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* r;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_9));
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
	r = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5), T1_, T2_, info, 0);
	asgnRef((void**) (&(*r).typ), typ);
	(*r).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
	owner = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
	{
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T6_)) goto LA7_;
		T6_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA7_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA8_;
		T5_ = !((*c).tooEarly);
		LA8_: ;
		if (!T5_) goto LA9_;
		result = freshVarForClosureIter__JA4vA9a9b64Ti9cPXENYI6L5g((*c).graph, r, owner);
	}
	goto LA3_;
	LA9_: ;
	{
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(r);
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(kind, (*ri).info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), le);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), ri);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popTransCon__uND2ekcuj27zfq5DWCAPjg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c) {
	{
		if (!((*c).transCon == ((tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*) NIM_NIL))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_10), TM__2w3VcOiOmEqxgfH4AylIpg_11);
	}
	LA3_: ;
	asgnRef((void**) (&(*c).transCon), (*(*c).transCon).next);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformFor__x9bzuCn2mNRReiUBcSXmpNQ_5)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	NI T5_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
	NI T10_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* stmtList;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
	NI T26_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T27_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
	tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* newC;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T49_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T88_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94)))) goto LA3_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*n).info, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_7), TM__2w3VcOiOmEqxgfH4AylIpg_8);
	}
	LA3_: ;
	T5_ = (NI)0;
	T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	call = (*n)._kind_6.sons->data[(NI)(T5_ - ((NI) 2))];
	labl = newLabel__V1Tz56SxbDGtHGL321qFFA(c, n);
	result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112), (*n).info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl));
	{
		if (!((*call).typ == 0)) goto LA8_;
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		goto BeforeRet_;
	}
	LA8_: ;
	asgnRef((void**) (&(*c).breakSyms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).breakSyms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T10_ = (*c).breakSyms->Sup.len++;
	asgnRef((void**) (&(*c).breakSyms->data[T10_]), labl);
	{
		NIM_BOOL T13_;
		NIM_BOOL T14_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
		NI T20_;
		NI T21_;
		NI T22_;
		NI T23_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T24_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T25_;
		T13_ = (NIM_BOOL)0;
		T14_ = (NIM_BOOL)0;
		T14_ = !(((*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*call).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)));
		if (T14_) goto LA15_;
		T14_ = !(((*(*call)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)));
		LA15_: ;
		T13_ = T14_;
		if (T13_) goto LA16_;
		T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T17_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*call)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		T13_ = ((*T17_).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA16_: ;
		if (!T13_) goto LA18_;
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), n);
		T20_ = (NI)0;
		T20_ = len__P89cqdlERShb9alU3iC0yj8wast((*result)._kind_6.sons->data[((NI) 1)]);
		T21_ = (NI)0;
		T21_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*(*result)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[(NI)(T20_ - ((NI) 1))]), transformLoopBody__x9bzuCn2mNRReiUBcSXmpNQ_6(c, (*n)._kind_6.sons->data[(NI)(T21_ - ((NI) 1))]));
		T22_ = (NI)0;
		T22_ = len__P89cqdlERShb9alU3iC0yj8wast((*result)._kind_6.sons->data[((NI) 1)]);
		T23_ = (NI)0;
		T23_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*(*result)._kind_6.sons->data[((NI) 1)])._kind_6.sons->data[(NI)(T22_ - ((NI) 2))]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[(NI)(T23_ - ((NI) 2))]));
		T24_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T24_ = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), liftForLoop__d1skGaYPbh4srEm2IRKTwg((*c).graph, (*result)._kind_6.sons->data[((NI) 1)], T24_));
		T25_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T25_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).breakSyms));
		(void)(T25_);
		goto BeforeRet_;
	}
	LA18_: ;
	stmtList = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info, ((NI) 0));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), stmtList);
	T26_ = (NI)0;
	T26_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
	loopBody = transformLoopBody__x9bzuCn2mNRReiUBcSXmpNQ_6(c, (*n)._kind_6.sons->data[(NI)(T26_ - ((NI) 1))]);
	T27_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T27_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).breakSyms));
	(void)(T27_);
	iter = (*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	v = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
	{
		NI i;
		NI colontmp_;
		NI T29_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T29_ = (NI)0;
		T29_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		colontmp_ = (NI)(T29_ - ((NI) 2));
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA31;
				i = i_2;
				{
					if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA34_;
					{
						NI j;
						NI colontmp__2;
						NI T37_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T37_ = (NI)0;
						T37_ = len__P89cqdlERShb9alU3iC0yj8wast((*n)._kind_6.sons->data[i]);
						colontmp__2 = (NI)(T37_ - ((NI) 1));
						i_3 = ((NI) 0);
						{
							while (1) {
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T40_;
								if (!(i_3 < colontmp__2)) goto LA39;
								j = i_3;
								T40_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
								T40_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*n)._kind_6.sons->data[i])._kind_6.sons->data[j]);
								addVar__qOCBdprWtK4hxer73SEdQA(v, T40_);
								i_3 += ((NI) 1);
							} LA39: ;
						}
					}
				}
				goto LA32_;
				LA34_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T48_;
					{
						NIM_BOOL T44_;
						T44_ = (NIM_BOOL)0;
						T44_ = ((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
						if (!(T44_)) goto LA45_;
						T44_ = isSimpleIteratorVar__9chmxIhIr2aUJbMPEmPAqZg(iter);
						LA45_: ;
						if (!T44_) goto LA46_;
						(*(*(*n)._kind_6.sons->data[i])._kind_4.sym).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 40)) & 63);
					}
					LA46_: ;
					T48_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T48_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[i]);
					addVar__qOCBdprWtK4hxer73SEdQA(v, T48_);
				}
				LA32_: ;
				i_2 += ((NI) 1);
			} LA31: ;
		}
	}
	add__P8dDSotTW25BkfbyspojGg(stmtList, v);
	T49_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T49_ = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
	newC = newTransCon__gHBjh7dKE1v5tJDPFQImxA(T49_);
	asgnRef((void**) (&(*newC).forStmt), n);
	asgnRef((void**) (&(*newC).forLoopBody), loopBody);
	{
		if (!!(((*iter).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)))) goto LA52_;
		goto BeforeRet_;
	}
	LA52_: ;
	pushTransCon__Q7kqtvaYdgT06r9a1oTEwOg(c, newC);
	{
		NI i_4;
		NI colontmp__3;
		NI i_5;
		i_4 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(call);
		i_5 = ((NI) 1);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formal;
				tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg pa;
				if (!(i_5 < colontmp__3)) goto LA56;
				i_4 = i_5;
				arg = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*call)._kind_6.sons->data[i_4]);
				ff = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*iter).typ, IL64(36134350135273744));
				{
					NI T59_;
					T59_ = (NI)0;
					T59_ = len__P89cqdlERShb9alU3iC0yj8wast((*ff).n);
					if (!(T59_ <= i_4)) goto LA60_;
					goto BeforeRet_;
				}
				LA60_: ;
				formal = (*(*(*ff).n)._kind_6.sons->data[i_4])._kind_4.sym;
				pa = putArgInto__9aRkwnDgD2oEx3liL5Jf75A(arg, (*formal).typ);
				switch (pa) {
				case ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 0):
				{
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T63_;
					T63_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T63_ = &formal->Sup;
					idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*newC).mapping), T63_, arg);
				}
				break;
				case ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 1):
				case ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 2):
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* temp;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T81_;
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T82_;
					t = (*formal).typ;
					{
						if (!(pa == ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 2))) goto LA67_;
						t = (*arg).typ;
					}
					goto LA65_;
					LA67_: ;
					{
						NIM_BOOL T70_;
						NIM_BOOL T71_;
						T70_ = (NIM_BOOL)0;
						T71_ = (NIM_BOOL)0;
						T71_ = !(((*formal).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
						if (!(T71_)) goto LA72_;
						T71_ = !(((*(*(*formal).ast).typ).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						LA72_: ;
						T70_ = T71_;
						if (!(T70_)) goto LA73_;
						T70_ = ((*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
						LA73_: ;
						if (!T70_) goto LA74_;
						t = (*(*formal).ast).typ;
					}
					goto LA65_;
					LA74_: ;
					{
						NIM_BOOL T77_;
						T77_ = (NIM_BOOL)0;
						T77_ = ((*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
						if (!(T77_)) goto LA78_;
						T77_ = !(((*(*arg).typ).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 0))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						LA78_: ;
						if (!T77_) goto LA79_;
						t = (*arg).typ;
					}
					goto LA65_;
					LA79_: ;
					LA65_: ;
					temp = newTemp__8R75N1yxpZ5H5DEY9c3VDOQ(c, t, (*formal).info);
					addVar__qOCBdprWtK4hxer73SEdQA(v, temp);
					T81_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T81_ = newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA(c, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), temp, arg);
					add__P8dDSotTW25BkfbyspojGg(stmtList, T81_);
					T82_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T82_ = &formal->Sup;
					idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*newC).mapping), T82_, temp);
				}
				break;
				case ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 3):
				{
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T84_;
					T84_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T84_ = &formal->Sup;
					idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*newC).mapping), T84_, arg);
				}
				break;
				case ((tyEnum_TPutArgInto__TtDZDXmcFHiTkscZ5Y1ugg) 4):
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* temp_2;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T86_;
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T87_;
					temp_2 = newTemp__8R75N1yxpZ5H5DEY9c3VDOQ(c, (*arg).typ, (*formal).info);
					addVar__qOCBdprWtK4hxer73SEdQA(v, temp_2);
					T86_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T86_ = newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA(c, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), temp_2, arg);
					add__P8dDSotTW25BkfbyspojGg(stmtList, T86_);
					T87_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T87_ = &formal->Sup;
					idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*newC).mapping), T87_, temp_2);
				}
				break;
				}
				i_5 += ((NI) 1);
			} LA56: ;
		}
	}
	body = transformBody__ocxOgPRHWfivNZELIhOv7w((*c).graph, iter, NIM_TRUE);
	pushInfoContext__uDLK9aoAOWwwFTev4NOwF7Q((*(*c).graph).config, (*n).info, ((NimStringDesc*) NIM_NIL));
	(*c).inlining += ((NI) 1);
	T88_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T88_ = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, body);
	add__P8dDSotTW25BkfbyspojGg(stmtList, T88_);
	(*c).inlining -= ((NI) 1);
	popInfoContext__O9arH9bYenXLOr27ZSmcQnEw_3((*(*c).graph).config);
	popTransCon__uND2ekcuj27zfq5DWCAPjg(c);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newTransNode__6JdTBPckyxXesjJbA5eHMwtransf(n);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[i]));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI sons) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	x = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(kind, (*n).info, (*n).typ);
	if ((*x)._kind_6.sons) { nimGCunrefNoCycle((*x)._kind_6.sons); (*x)._kind_6.sons = NIM_NIL; }
	(*x)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (sons)));
	asgnRef((void**) (&(*x).typ), (*n).typ);
	result = x;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformCase__x9bzuCn2mNRReiUBcSXmpNQ_8)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ifs;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97), n, ((NI) 0));
	ifs = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
		it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					it = (*n)._kind_6.sons->data[i];
					e = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, it);
					switch ((*it).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86):
					{
						{
							tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
							if (!(ifs == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA8_;
							{
								if (!!(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA12_;
								kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 48);
							}
							goto LA10_;
							LA12_: ;
							{
								kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92);
							}
							LA10_: ;
							ifs = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(kind, (*it).info, ((NI) 0));
							asgnRef((void**) (&(*ifs).typ), (*n).typ);
						}
						LA8_: ;
						add__P8dDSotTW25BkfbyspojGg(ifs, e);
					}
					break;
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						{
							if (!(ifs == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA18_;
							add__P8dDSotTW25BkfbyspojGg(result, e);
						}
						goto LA16_;
						LA18_: ;
						{
							add__P8dDSotTW25BkfbyspojGg(ifs, e);
						}
						LA16_: ;
					}
					break;
					default:
					{
						add__P8dDSotTW25BkfbyspojGg(result, e);
					}
					break;
					}
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch;
		if (!!((ifs == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA24_;
		elseBranch = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), (*n).info, ((NI) 1));
		asgnRef((void**) (&(*elseBranch)._kind_6.sons->data[((NI) 0)]), ifs);
		add__P8dDSotTW25BkfbyspojGg(result, elseBranch);
	}
	goto LA22_;
	LA24_: ;
	{
		NIM_BOOL T27_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T30_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elseBranch_2;
		T27_ = (NIM_BOOL)0;
		T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T28_ = lastSon__UPSW0jLTX5qJL51YMUAHgw(result);
		T27_ = !(((*T28_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88)));
		if (!(T27_)) goto LA29_;
		T30_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T30_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350144710928));
		T27_ = !(((*T30_).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) && (*T30_).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35) || (*T30_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2) || (*T30_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14) || (*T30_).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) && (*T30_).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44)));
		LA29_: ;
		if (!T27_) goto LA31_;
		elseBranch_2 = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88), (*n).info, ((NI) 1));
		asgnRef((void**) (&(*elseBranch_2)._kind_6.sons->data[((NI) 0)]), newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23), (*n).info, ((NI) 0)));
		add__P8dDSotTW25BkfbyspojGg(result, elseBranch_2);
	}
	goto LA22_;
	LA31_: ;
	LA22_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformWhile__x9bzuCn2mNRReiUBcSXmpNQ_9)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(((NI) 0) < (*c).inlining)) goto LA3_;
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
		NI T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
		NI T11_;
		NI T12_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
		labl = newLabel__V1Tz56SxbDGtHGL321qFFA(c, n);
		asgnRef((void**) (&(*c).breakSyms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).breakSyms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
		T6_ = (*c).breakSyms->Sup.len++;
		asgnRef((void**) (&(*c).breakSyms->data[T6_]), labl);
		result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112), (*n).info, ((NI) 2));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl));
		body = newTransNode__6JdTBPckyxXesjJbA5eHMwtransf(n);
		{
			NI i;
			NI colontmp_;
			NI T8_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp_ = (NI)(T8_ - ((NI) 1));
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					asgnRef((void**) (&(*body)._kind_6.sons->data[i]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		T11_ = (NI)0;
		T11_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
		T12_ = (NI)0;
		T12_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		asgnRef((void**) (&(*body)._kind_6.sons->data[(NI)(T11_ - ((NI) 1))]), transformLoopBody__x9bzuCn2mNRReiUBcSXmpNQ_6(c, (*n)._kind_6.sons->data[(NI)(T12_ - ((NI) 1))]));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), body);
		T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T13_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).breakSyms));
		(void)(T13_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBlock__x9bzuCn2mNRReiUBcSXmpNQ_10)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
	NI T13_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T14_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	labl = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!(((NI) 0) < (*c).inlining)) goto LA3_;
		labl = newLabel__V1Tz56SxbDGtHGL321qFFA(c, (*n)._kind_6.sons->data[((NI) 0)]);
		T5_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T5_ = &(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym->Sup;
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl);
		idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*(*c).transCon).mapping), T5_, T6_);
	}
	goto LA1_;
	LA3_: ;
	{
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA10_;
			labl = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		goto LA8_;
		LA10_: ;
		{
			labl = newLabel__V1Tz56SxbDGtHGL321qFFA(c, n);
		}
		LA8_: ;
	}
	LA1_: ;
	asgnRef((void**) (&(*c).breakSyms), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) incrSeqV3((TGenericSeq*)((*c).breakSyms), (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_)));
	T13_ = (*c).breakSyms->Sup.len++;
	asgnRef((void**) (&(*c).breakSyms->data[T13_]), labl);
	result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	T14_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T14_ = pop__sJkHMuFHoY5Elz2ZDxz78Asystem((&(*c).breakSyms));
	(void)(T14_);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBreak__x9bzuCn2mNRReiUBcSXmpNQ_11)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		if (!(T3_)) goto LA4_;
		T5_ = ((*c).breakSyms ? (*c).breakSyms->Sup.len : 0);
		T3_ = (((NI) 0) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		T8_ = (((*c).breakSyms ? (*c).breakSyms->Sup.len : 0)-1);
		labl = (*c).breakSyms->data[T8_];
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl));
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getMergeOp__EuK0aY8I1jCqHxmYwogXtg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T4_)) goto LA5_;
			T4_ = ((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 125));
			LA5_: ;
			if (!T4_) goto LA6_;
			result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		}
		LA6_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, flattenTreeAux__cz5kqNnGwAu9cFHQaWrJE9cw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* d, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op2;
	op2 = getMergeOp__EuK0aY8I1jCqHxmYwogXtg(a);
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NIM_BOOL T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((op2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*op2).Sup.id == (*op).Sup.id);
		if (T5_) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = !(((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
		if (!(T7_)) goto LA8_;
		T7_ = ((*op2).magic == (*op).magic);
		LA8_: ;
		T5_ = T7_;
		LA6_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA9_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
			i_2 = ((NI) 1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					flattenTreeAux__cz5kqNnGwAu9cFHQaWrJE9cw(d, (*a)._kind_6.sons->data[i], op);
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	goto LA1_;
	LA9_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
		T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T15_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(a);
		add__P8dDSotTW25BkfbyspojGg(d, T15_);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, flattenTree__4jym4pu5X8jJvM0PYQomDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* root) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	op = getMergeOp__EuK0aY8I1jCqHxmYwogXtg(root);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!!((op == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		result = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(root);
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*root)._kind_6.sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, T5_);
		flattenTreeAux__cz5kqNnGwAu9cFHQaWrJE9cw(result, root, op);
	}
	goto LA1_;
	LA3_: ;
	{
		result = root;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformAddrDeref__oB0ZJYmKjtxbUq9azE9as4GQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw a, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw b) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 2));
		if (T3_) goto LA4_;
		T3_ = (((*(*c).module).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 31))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	n_2 = result;
	switch ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
		m = (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*m).kind == a);
			if (T10_) goto LA11_;
			T10_ = ((*m).kind == b);
			LA11_: ;
			if (!T10_) goto LA12_;
			asgnRef((void**) (&(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]), (*m)._kind_6.sons->data[((NI) 0)]);
			result = (*n_2)._kind_6.sons->data[((NI) 0)];
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
				T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T16_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36275087632017680));
				if (!!(((*T16_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)))) goto LA17_;
				asgnRef((void**) (&(*result).typ), (*n_2).typ);
			}
			goto LA14_;
			LA17_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
				T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T20_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36134350135273744));
				if (!((*T20_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23))) goto LA21_;
				T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T23_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36134350135273744));
				asgnRef((void**) (&(*result).typ), toVar__ltkZL9cdOU06qIwP1L9aFqcw((*result).typ, (*T23_).kind));
			}
			goto LA14_;
			LA21_: ;
			LA14_: ;
		}
		LA12_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m_2;
		m_2 = (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = ((*m_2).kind == a);
			if (T27_) goto LA28_;
			T27_ = ((*m_2).kind == b);
			LA28_: ;
			if (!T27_) goto LA29_;
			asgnRef((void**) (&(*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]), (*m_2)._kind_6.sons->data[((NI) 0)]);
			result = (*n_2)._kind_6.sons->data[((NI) 0)];
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
				T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T33_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36275087632017680));
				if (!!(((*T33_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)))) goto LA34_;
				asgnRef((void**) (&(*result).typ), (*n_2).typ);
			}
			goto LA31_;
			LA34_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T40_;
				T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T37_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36134350135273744));
				if (!((*T37_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23))) goto LA38_;
				T40_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T40_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36134350135273744));
				asgnRef((void**) (&(*result).typ), toVar__ltkZL9cdOU06qIwP1L9aFqcw((*result).typ, (*T40_).kind));
			}
			goto LA31_;
			LA38_: ;
			LA31_: ;
		}
		LA29_: ;
	}
	break;
	default:
	{
		{
			NIM_BOOL T44_;
			T44_ = (NIM_BOOL)0;
			T44_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind == a);
			if (T44_) goto LA45_;
			T44_ = ((*(*n_2)._kind_6.sons->data[((NI) 0)]).kind == b);
			LA45_: ;
			if (!T44_) goto LA46_;
			result = (*(*n_2)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)];
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
				T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T50_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n_2).typ, IL64(36275087632017680));
				if (!!(((*T50_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27)))) goto LA51_;
				asgnRef((void**) (&(*result).typ), (*n_2).typ);
			}
			LA51_: ;
		}
		LA46_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformCall__x9bzuCn2mNRReiUBcSXmpNQ_12)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op;
	tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	n_2 = flattenTree__4jym4pu5X8jJvM0PYQomDA(n);
	op = getMergeOp__EuK0aY8I1jCqHxmYwogXtg(n_2);
	magic = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(n_2);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T10_;
		NI j;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((op == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = !(((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
		T3_ = (((NI) 3) <= T7_);
		LA6_: ;
		if (!T3_) goto LA8_;
		result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), n_2, ((NI) 0));
		T10_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T10_ = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n_2)._kind_6.sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, T10_);
		j = ((NI) 1);
		{
			while (1) {
				NI T13_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				T13_ = (NI)0;
				T13_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
				if (!(j < T13_)) goto LA12;
				a = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n_2)._kind_6.sons->data[j]);
				j += ((NI) 1);
				{
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2(a);
					if (!T16_) goto LA17_;
					{
						while (1) {
							NI T21_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
							T21_ = (NI)0;
							T21_ = len__P89cqdlERShb9alU3iC0yj8wast(n_2);
							if (!(j < T21_)) goto LA20;
							b = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n_2)._kind_6.sons->data[j]);
							{
								NIM_BOOL T24_;
								T24_ = (NIM_BOOL)0;
								T24_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2(b);
								if (!!(T24_)) goto LA25_;
								goto LA19;
							}
							LA25_: ;
							a = evalOp__naTMtRq9avUKkKDwI0csDMg((*op).magic, n_2, a, b, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), (*c).graph);
							j += ((NI) 1);
						} LA20: ;
					} LA19: ;
				}
				LA17_: ;
				add__P8dDSotTW25BkfbyspojGg(result, a);
			} LA12: ;
		}
		{
			NI T29_;
			T29_ = (NI)0;
			T29_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!(T29_ == ((NI) 2))) goto LA30_;
			result = (*result)._kind_6.sons->data[((NI) 1)];
		}
		LA30_: ;
	}
	goto LA1_;
	LA8_: ;
	{
		if (!(magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 16))) goto LA33_;
		result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63), n_2, ((NI) 1));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), (*n_2)._kind_6.sons->data[((NI) 1)]);
		result = transformAddrDeref__oB0ZJYmKjtxbUq9azE9as4GQ(c, result, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
	}
	goto LA1_;
	LA33_: ;
	{
		if (!(magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 246) || magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 18) || magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 263))) goto LA36_;
		result = n_2;
	}
	goto LA1_;
	LA36_: ;
	{
		if (!(magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 199))) goto LA39_;
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, (*n_2)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA1_;
	LA39_: ;
	{
		if (!(magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 107))) goto LA42_;
		result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n_2)._kind_6.sons->data[((NI) 1)]);
	}
	goto LA1_;
	LA42_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
		s = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n_2);
		{
			NIM_BOOL T47_;
			T47_ = (NIM_BOOL)0;
			T47_ = ((*(*s)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T47_)) goto LA48_;
			T47_ = ((*(*(*s)._kind_6.sons->data[((NI) 0)])._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 14));
			LA48_: ;
			if (!T47_) goto LA49_;
			result = methodCall__8CKh3oS3FPdX9cqBY8VV6MQ(s, (*(*c).graph).config);
		}
		goto LA45_;
		LA49_: ;
		{
			result = s;
		}
		LA45_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, generateThunk__XhGS8C5uskyoYzXjsKDuiw)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* conv;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*(*(*c).graph).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3))) goto LA3_;
		result = prc;
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155), (*prc).info, dest);
	conv = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), (*prc).info, dest);
	T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T5_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*prc).info);
	add__P8dDSotTW25BkfbyspojGg(conv, T5_);
	add__P8dDSotTW25BkfbyspojGg(conv, prc);
	{
		if (!((*prc).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA8_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*prc).info, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_12), TM__2w3VcOiOmEqxgfH4AylIpg_13);
	}
	LA8_: ;
	add__P8dDSotTW25BkfbyspojGg(result, conv);
	T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T10_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*prc).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
	T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T11_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23), (*prc).info, T10_);
	add__P8dDSotTW25BkfbyspojGg(result, T11_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformConv__x9bzuCn2mNRReiUBcSXmpNQ_13)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* source;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36134350144710928));
	source = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 1)]).typ, IL64(36134350144710928));
	switch ((*dest).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(source, NIM_FALSE);
			if (!!(T4_)) goto LA5_;
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		goto LA2_;
		LA5_: ;
		{
			NIM_BOOL T8_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T10_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T13_;
			T8_ = (NIM_BOOL)0;
			T9_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, (*n).typ);
			T10_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			T8_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T9_, T10_);
			if (!(T8_)) goto LA11_;
			T12_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, (*(*n)._kind_6.sons->data[((NI) 1)]).typ);
			T13_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, (*n).typ);
			T8_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T12_, T13_);
			LA11_: ;
			if (!T8_) goto LA14_;
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		goto LA2_;
		LA14_: ;
		{
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T24_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T25_;
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = ((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35));
				if (T19_) goto LA20_;
				T19_ = ((*source).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35));
				LA20_: ;
				if (!T19_) goto LA21_;
				result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 69), n, ((NI) 3));
			}
			goto LA17_;
			LA21_: ;
			{
				result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 70), n, ((NI) 3));
			}
			LA17_: ;
			dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
			T24_ = firstOrd__hjogdnp59cMX1rwmjikBhqw((*(*c).graph).config, dest);
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g(T24_, dest));
			T25_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2((*(*c).graph).config, dest);
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g(T25_, dest));
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T29_;
			T29_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T29_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
			if (!((*T29_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20))) goto LA30_;
			result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 68), n, ((NI) 3));
			dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(36275087632017680));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*dest).n)._kind_6.sons->data[((NI) 0)]));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*(*dest).n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA27_;
		LA30_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA27_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]);
		asgnRef((void**) (&(*result).typ), takeType__0FGAKd3dm9aUGX9cs9aj1kraA((*n).typ, (*(*n)._kind_6.sons->data[((NI) 1)]).typ));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		{
			if (!((*source).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28))) goto LA37_;
			result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 71), n, ((NI) 1));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA35_;
		LA37_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA35_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		{
			if (!((*source).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29))) goto LA43_;
			result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 72), n, ((NI) 1));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA41_;
		LA43_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA41_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	{
		dest = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(dest, IL64(36275087638309136));
		source = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(source, IL64(36275087638309136));
		{
			NI diff;
			if (!((*source).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA49_;
			diff = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(dest, source);
			{
				if (!(diff < ((NI) 0))) goto LA53_;
				result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67), n, ((NI) 1));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
			}
			goto LA51_;
			LA53_: ;
			{
				NIM_BOOL T56_;
				T56_ = (NIM_BOOL)0;
				T56_ = (((NI) 0) < diff);
				if (!(T56_)) goto LA57_;
				T56_ = !((diff == ((NI) 2147483647)));
				LA57_: ;
				if (!T56_) goto LA58_;
				result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66), n, ((NI) 1));
				asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
			}
			goto LA51_;
			LA58_: ;
			{
				result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]);
			}
			LA51_: ;
		}
		goto LA47_;
		LA49_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA47_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		NI diff_2;
		diff_2 = inheritanceDiff__1dM2iQB5qStJfnn3684ijQ_2(dest, source);
		{
			if (!(diff_2 < ((NI) 0))) goto LA65_;
			result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 67), n, ((NI) 1));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA63_;
		LA65_: ;
		{
			NIM_BOOL T68_;
			T68_ = (NIM_BOOL)0;
			T68_ = (((NI) 0) < diff_2);
			if (!(T68_)) goto LA69_;
			T68_ = !((diff_2 == ((NI) 2147483647)));
			LA69_: ;
			if (!T68_) goto LA70_;
			result = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 66), n, ((NI) 1));
			asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
		}
		goto LA63_;
		LA70_: ;
		{
			result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]);
		}
		LA63_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	{
		result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		{
			NIM_BOOL T77_;
			T77_ = (NIM_BOOL)0;
			T77_ = ((*dest).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			if (!(T77_)) goto LA78_;
			T77_ = ((*source).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0));
			LA78_: ;
			if (!T77_) goto LA79_;
			result = generateThunk__XhGS8C5uskyoYzXjsKDuiw(c, (*result)._kind_6.sons->data[((NI) 1)], dest);
		}
		LA79_: ;
	}
	break;
	default:
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformConstSection__fVJbvRdbXsZk6wrZ9cHGJCg)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = v;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_14));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_15));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_16));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVar__SdYC3nz0w1cFDftpjGBhxQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	owner = getCurrOwner__9csPEyXsx5TqxkXBMpf3h0g(c);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = !((*c).tooEarly);
		LA6_: ;
		if (!T3_) goto LA7_;
		result = freshVarForClosureIter__JA4vA9a9b64Ti9cPXENYI6L5g((*c).graph, v, owner);
	}
	goto LA1_;
	LA7_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* newVar;
		newVar = copySym__lIu8wX6Beq6dBJgESOFFjg(v);
		(*newVar).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
		asgnRef((void**) (&(*newVar).owner), owner);
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(newVar);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((16640 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformVarSection__fVJbvRdbXsZk6wrZ9cHGJCg_2)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newTransNode__6JdTBPckyxXesjJbA5eHMwtransf(v);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(v);
		i_2 = ((NI) 0);
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				it = (*v)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125))) goto LA6_;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), it);
				}
				goto LA4_;
				LA6_: ;
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35))) goto LA9_;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
						tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T20_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* defs;
						if (!((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA13_;
						{
							NI T17_;
							NimStringDesc* argX60gensym28_;
							T17_ = (NI)0;
							T17_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
							if (!!((T17_ == ((NI) 3)))) goto LA18_;
							argX60gensym28_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__2w3VcOiOmEqxgfH4AylIpg_17);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym28_, TM__2w3VcOiOmEqxgfH4AylIpg_17);
						}
						LA18_: ;
						x = freshVar__SdYC3nz0w1cFDftpjGBhxQ(c, (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
						T20_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
						T20_ = &(*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym->Sup;
						idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*(*c).transCon).mapping), T20_, x);
						defs = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*it).info, ((NI) 3));
						{
							NIM_BOOL T23_;
							NimStringDesc* T26_;
							T23_ = (NIM_BOOL)0;
							T23_ = importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions((*(*c).graph).config);
							if (!T23_) goto LA24_;
							T26_ = (NimStringDesc*)0;
							T26_ = (*defs).comment; (*defs).comment = copyStringRC1((*it).comment);
							if (T26_) nimGCunrefNoCycle(T26_);
						}
						LA24_: ;
						asgnRef((void**) (&(*defs)._kind_6.sons->data[((NI) 0)]), x);
						asgnRef((void**) (&(*defs)._kind_6.sons->data[((NI) 1)]), (*it)._kind_6.sons->data[((NI) 1)]);
						asgnRef((void**) (&(*defs)._kind_6.sons->data[((NI) 2)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*it)._kind_6.sons->data[((NI) 2)]));
						{
							if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA29_;
							asgnRef((void**) (&(*(*x)._kind_4.sym).ast), (*defs)._kind_6.sons->data[((NI) 2)]);
						}
						LA29_: ;
						asgnRef((void**) (&(*result)._kind_6.sons->data[i]), defs);
					}
					goto LA11_;
					LA13_: ;
					{
						asgnRef((void**) (&(*result)._kind_6.sons->data[i]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, it));
					}
					LA11_: ;
				}
				goto LA4_;
				LA9_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* defs_2;
					NI T37_;
					NI T48_;
					NI T49_;
					NI T50_;
					{
						if (!!(((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36)))) goto LA35_;
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*it).info, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_18), TM__2w3VcOiOmEqxgfH4AylIpg_19);
					}
					LA35_: ;
					T37_ = (NI)0;
					T37_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					defs_2 = newTransNode__T00TWsJvsUcixkQXPnIphAtransf((*it).kind, (*it).info, T37_);
					{
						NI j;
						NI colontmp__2;
						NI T39_;
						NI i_3;
						j = (NI)0;
						colontmp__2 = (NI)0;
						T39_ = (NI)0;
						T39_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						colontmp__2 = (NI)(T39_ - ((NI) 2));
						i_3 = ((NI) 0);
						{
							while (1) {
								if (!(i_3 < colontmp__2)) goto LA41;
								j = i_3;
								{
									tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x_2;
									tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T46_;
									if (!((*(*it)._kind_6.sons->data[j]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA44_;
									x_2 = freshVar__SdYC3nz0w1cFDftpjGBhxQ(c, (*(*it)._kind_6.sons->data[j])._kind_4.sym);
									T46_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
									T46_ = &(*(*it)._kind_6.sons->data[j])._kind_4.sym->Sup;
									idNodeTablePut__q49bPlVa9aAaI9bWhgzYAzoBg((&(*(*c).transCon).mapping), T46_, x_2);
									asgnRef((void**) (&(*defs_2)._kind_6.sons->data[j]), x_2);
								}
								goto LA42_;
								LA44_: ;
								{
									asgnRef((void**) (&(*defs_2)._kind_6.sons->data[j]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*it)._kind_6.sons->data[j]));
								}
								LA42_: ;
								i_3 += ((NI) 1);
							} LA41: ;
						}
					}
					T48_ = (NI)0;
					T48_ = len__P89cqdlERShb9alU3iC0yj8wast(defs_2);
					asgnRef((void**) (&(*defs_2)._kind_6.sons->data[(NI)(T48_ - ((NI) 2))]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*it).info));
					T49_ = (NI)0;
					T49_ = len__P89cqdlERShb9alU3iC0yj8wast(defs_2);
					T50_ = (NI)0;
					T50_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
					asgnRef((void**) (&(*defs_2)._kind_6.sons->data[(NI)(T49_ - ((NI) 1))]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*it)._kind_6.sons->data[(NI)(T50_ - ((NI) 1))]));
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), defs_2);
				}
				LA4_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_NIMCALL(void, Marker_tyRef__7lgNfGoBjgvsM5K1jkApkg)(void* p, NI op) {
	tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw* a;
	a = (tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*)p;
	nimGCvisit((void*)(*a).c1, op);
}
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, asgnTo__MJeJEZTxLrk1GPzHVc547Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs, void* ClE_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw* colonenvP_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	colonenvP_ = (tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*) ClE_0;
	switch ((*lhs).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			NimStringDesc* argX60gensym106_;
			if (!!(((*(*lhs)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21)))) goto LA4_;
			argX60gensym106_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__2w3VcOiOmEqxgfH4AylIpg_21);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*colonenvP_).c1).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym106_, TM__2w3VcOiOmEqxgfH4AylIpg_21);
		}
		LA4_: ;
		result = newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA((*colonenvP_).c1, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74), lhs, rhs);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45):
	{
		result = newAsgnStmt__U69bSkVkYTAcUXjyDVfSQzA((*colonenvP_).c1, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), lhs, rhs);
	}
	break;
	default:
	{
		{
			NimStringDesc* argX60gensym108_;
			if (!NIM_TRUE) goto LA10_;
			argX60gensym108_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__2w3VcOiOmEqxgfH4AylIpg_22);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*colonenvP_).c1).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym108_, TM__2w3VcOiOmEqxgfH4AylIpg_22);
		}
		LA10_: ;
	}
	break;
	}
	return result;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, introduceNewLocalVars__x9bzuCn2mNRReiUBcSXmpNQ_15)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = transformSym__x9bzuCn2mNRReiUBcSXmpNQ_2(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = n;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		result = transformVarSection__fVJbvRdbXsZk6wrZ9cHGJCg_2(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		a = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA7_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), transformSymAux__x9bzuCn2mNRReiUBcSXmpNQ_3(c, a));
		}
		LA7_: ;
		result = n;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = newTransNode__6JdTBPckyxXesjJbA5eHMwtransf(n);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), introduceNewLocalVars__x9bzuCn2mNRReiUBcSXmpNQ_15(c, (*n)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA12: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformYield__x9bzuCn2mNRReiUBcSXmpNQ_14)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw* colonenv_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	colonenv_ = (tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*)0;
	colonenv_ = (tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*) newObj((&NTI__7lgNfGoBjgvsM5K1jkApkg_), sizeof(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw));
	(*colonenv_).Sup.m_type = (&NTI__k9ckC7egSTPlxMaCeJlF9aLw_);
	asgnRef((void**) (&(*colonenv_).c1), c);
	result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info, ((NI) 0));
	e = (*n)._kind_6.sons->data[((NI) 0)];
	{
		if (!((*e).typ == 0)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*colonenv_).c1).transCon).forStmt);
		if (!!((T7_ == ((NI) 3)))) goto LA8_;
		e = skipConv__BH9abOhPX8pH0DnEWlRxmlw(e);
		{
			if (!((*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*e).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160))) goto LA12_;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(e);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
						if (!(i_2 < colontmp_)) goto LA16;
						i = i_2;
						v = (*e)._kind_6.sons->data[i];
						{
							if (!((*v).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA19_;
							v = (*v)._kind_6.sons->data[((NI) 1)];
						}
						LA19_: ;
						{
							if (!((*(*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA23_;
							{
								NI j;
								NI colontmp__2;
								NI T26_;
								NI i_3;
								j = (NI)0;
								colontmp__2 = (NI)0;
								T26_ = (NI)0;
								T26_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[i]);
								colontmp__2 = (NI)(T26_ - ((NI) 1));
								i_3 = ((NI) 0);
								{
									while (1) {
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
										tyProc__5qqAV51RjFgqAF4yOP2S7Q T30_;
										tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T31_;
										if (!(i_3 < colontmp__2)) goto LA28;
										j = i_3;
										lhs = (*(*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[i])._kind_6.sons->data[j];
										T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T29_ = newTupleAccess__9bplMpBXm4y9buiuIhASVmzA((*(*colonenv_).c1).graph, v, j);
										rhs = transform__x9bzuCn2mNRReiUBcSXmpNQ((*colonenv_).c1, T29_);
										nimZeroMem((void*)(&T30_), sizeof(tyProc__5qqAV51RjFgqAF4yOP2S7Q));
										T30_.ClP_0 = asgnTo__MJeJEZTxLrk1GPzHVc547Q; T30_.ClE_0 = colonenv_;
										T31_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
										T31_ = T30_.ClE_0? T30_.ClP_0(lhs, rhs, T30_.ClE_0):((TM__2w3VcOiOmEqxgfH4AylIpg_23)(T30_.ClP_0))(lhs, rhs);
										add__P8dDSotTW25BkfbyspojGg(result, T31_);
										i_3 += ((NI) 1);
									} LA28: ;
								}
							}
						}
						goto LA21_;
						LA23_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs_2;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs_2;
							tyProc__5qqAV51RjFgqAF4yOP2S7Q T33_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T34_;
							lhs_2 = (*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[i];
							rhs_2 = transform__x9bzuCn2mNRReiUBcSXmpNQ((*colonenv_).c1, v);
							nimZeroMem((void*)(&T33_), sizeof(tyProc__5qqAV51RjFgqAF4yOP2S7Q));
							T33_.ClP_0 = asgnTo__MJeJEZTxLrk1GPzHVc547Q; T33_.ClE_0 = colonenv_;
							T34_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T34_ = T33_.ClE_0? T33_.ClP_0(lhs_2, rhs_2, T33_.ClE_0):((TM__2w3VcOiOmEqxgfH4AylIpg_24)(T33_.ClP_0))(lhs_2, rhs_2);
							add__P8dDSotTW25BkfbyspojGg(result, T34_);
						}
						LA21_: ;
						i_2 += ((NI) 1);
					} LA16: ;
				}
			}
		}
		goto LA10_;
		LA12_: ;
		{
			{
				NI i_4;
				NI colontmp__3;
				NI T37_;
				NI i_5;
				i_4 = (NI)0;
				colontmp__3 = (NI)0;
				T37_ = (NI)0;
				T37_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*colonenv_).c1).transCon).forStmt);
				colontmp__3 = (NI)(T37_ - ((NI) 2));
				i_5 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs_3;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs_3;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T40_;
						tyProc__5qqAV51RjFgqAF4yOP2S7Q T41_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T42_;
						if (!(i_5 < colontmp__3)) goto LA39;
						i_4 = i_5;
						lhs_3 = (*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[i_4];
						T40_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T40_ = newTupleAccess__9bplMpBXm4y9buiuIhASVmzA((*(*colonenv_).c1).graph, e, i_4);
						rhs_3 = transform__x9bzuCn2mNRReiUBcSXmpNQ((*colonenv_).c1, T40_);
						nimZeroMem((void*)(&T41_), sizeof(tyProc__5qqAV51RjFgqAF4yOP2S7Q));
						T41_.ClP_0 = asgnTo__MJeJEZTxLrk1GPzHVc547Q; T41_.ClE_0 = colonenv_;
						T42_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T42_ = T41_.ClE_0? T41_.ClP_0(lhs_3, rhs_3, T41_.ClE_0):((TM__2w3VcOiOmEqxgfH4AylIpg_25)(T41_.ClP_0))(lhs_3, rhs_3);
						add__P8dDSotTW25BkfbyspojGg(result, T42_);
						i_5 += ((NI) 1);
					} LA39: ;
				}
			}
		}
		LA10_: ;
	}
	goto LA5_;
	LA8_: ;
	{
		{
			if (!((*(*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36))) goto LA46_;
			{
				NI i_6;
				NI colontmp__4;
				NI T49_;
				NI i_7;
				i_6 = (NI)0;
				colontmp__4 = (NI)0;
				T49_ = (NI)0;
				T49_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[((NI) 0)]);
				colontmp__4 = (NI)(T49_ - ((NI) 1));
				i_7 = ((NI) 0);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs_4;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs_4;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T52_;
						tyProc__5qqAV51RjFgqAF4yOP2S7Q T53_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T54_;
						if (!(i_7 < colontmp__4)) goto LA51;
						i_6 = i_7;
						lhs_4 = (*(*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[i_6];
						T52_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T52_ = newTupleAccess__9bplMpBXm4y9buiuIhASVmzA((*(*colonenv_).c1).graph, e, i_6);
						rhs_4 = transform__x9bzuCn2mNRReiUBcSXmpNQ((*colonenv_).c1, T52_);
						nimZeroMem((void*)(&T53_), sizeof(tyProc__5qqAV51RjFgqAF4yOP2S7Q));
						T53_.ClP_0 = asgnTo__MJeJEZTxLrk1GPzHVc547Q; T53_.ClE_0 = colonenv_;
						T54_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T54_ = T53_.ClE_0? T53_.ClP_0(lhs_4, rhs_4, T53_.ClE_0):((TM__2w3VcOiOmEqxgfH4AylIpg_26)(T53_.ClP_0))(lhs_4, rhs_4);
						add__P8dDSotTW25BkfbyspojGg(result, T54_);
						i_7 += ((NI) 1);
					} LA51: ;
				}
			}
		}
		goto LA44_;
		LA46_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs_5;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs_5;
			tyProc__5qqAV51RjFgqAF4yOP2S7Q T56_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T57_;
			lhs_5 = (*(*(*(*colonenv_).c1).transCon).forStmt)._kind_6.sons->data[((NI) 0)];
			rhs_5 = transform__x9bzuCn2mNRReiUBcSXmpNQ((*colonenv_).c1, e);
			nimZeroMem((void*)(&T56_), sizeof(tyProc__5qqAV51RjFgqAF4yOP2S7Q));
			T56_.ClP_0 = asgnTo__MJeJEZTxLrk1GPzHVc547Q; T56_.ClE_0 = colonenv_;
			T57_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T57_ = T56_.ClE_0? T56_.ClP_0(lhs_5, rhs_5, T56_.ClE_0):((TM__2w3VcOiOmEqxgfH4AylIpg_27)(T56_.ClP_0))(lhs_5, rhs_5);
			add__P8dDSotTW25BkfbyspojGg(result, T57_);
		}
		LA44_: ;
	}
	LA5_: ;
	(*(*(*colonenv_).c1).transCon).yieldStmts += ((NI) 1);
	{
		if (!((*(*(*colonenv_).c1).transCon).yieldStmts <= ((NI) 1))) goto LA60_;
		add__P8dDSotTW25BkfbyspojGg(result, (*(*(*colonenv_).c1).transCon).forLoopBody);
	}
	goto LA58_;
	LA60_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T63_;
		T63_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T63_ = introduceNewLocalVars__x9bzuCn2mNRReiUBcSXmpNQ_15((*colonenv_).c1, (*(*(*colonenv_).c1).transCon).forLoopBody);
		add__P8dDSotTW25BkfbyspojGg(result, T63_);
	}
	LA58_: ;
	{
		NI T66_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* changeNode;
		T66_ = (NI)0;
		T66_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
		if (!(((NI) 0) < T66_)) goto LA67_;
		changeNode = (*result)._kind_6.sons->data[((NI) 0)];
		(*changeNode).info = (*(*(*(*colonenv_).c1).transCon).forStmt).info;
		{
			NI i_8;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* child;
			i_8 = (NI)0;
			child = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_9;
				NI colontmp__5;
				NI i_10;
				i_9 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(changeNode);
				i_10 = ((NI) 0);
				{
					while (1) {
						if (!(i_10 < colontmp__5)) goto LA72;
						i_9 = i_10;
						i_8 = i_9;
						child = (*changeNode)._kind_6.sons->data[i_9];
						(*child).info = (*changeNode).info;
						i_10 += ((NI) 1);
					} LA72: ;
				}
			}
		}
	}
	LA67_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformAsgn__x9bzuCn2mNRReiUBcSXmpNQ_16)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rhs;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* letSection;
	NI T5_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* newTupleConstr;
	NI T6_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* asgnNode;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	rhs = (*n)._kind_6.sons->data[((NI) 1)];
	{
		if (!!(((*rhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160)))) goto LA3_;
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (NI)0;
	T5_ = len__P89cqdlERShb9alU3iC0yj8wast(rhs);
	letSection = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100), (*n).info, T5_);
	T6_ = (NI)0;
	T6_ = len__P89cqdlERShb9alU3iC0yj8wast(rhs);
	newTupleConstr = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160), (*n).info, T6_);
	{
		NI i;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field;
		i = (NI)0;
		field = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(rhs);
			i_3 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* def;
					if (!(i_3 < colontmp_)) goto LA10;
					i_2 = i_3;
					i = i_2;
					field = (*rhs)._kind_6.sons->data[i_2];
					{
						if (!((*field).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA13_;
						val = (*field)._kind_6.sons->data[((NI) 1)];
					}
					goto LA11_;
					LA13_: ;
					{
						val = field;
					}
					LA11_: ;
					def = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*field).info, ((NI) 3));
					asgnRef((void**) (&(*def)._kind_6.sons->data[((NI) 0)]), newTemp__8R75N1yxpZ5H5DEY9c3VDOQ(c, (*val).typ, (*field).info));
					asgnRef((void**) (&(*def)._kind_6.sons->data[((NI) 1)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*field).info));
					asgnRef((void**) (&(*def)._kind_6.sons->data[((NI) 2)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, val));
					asgnRef((void**) (&(*letSection)._kind_6.sons->data[i]), def);
					asgnRef((void**) (&(*newTupleConstr)._kind_6.sons->data[i]), (*def)._kind_6.sons->data[((NI) 0)]);
					i_3 += ((NI) 1);
				} LA10: ;
			}
		}
	}
	asgnRef((void**) (&(*newTupleConstr).typ), (*rhs).typ);
	asgnNode = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), (*n).info, ((NI) 2));
	asgnRef((void**) (&(*asgnNode)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 0)]));
	asgnRef((void**) (&(*asgnNode)._kind_6.sons->data[((NI) 1)]), newTupleConstr);
	result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), letSection);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), asgnNode);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformExceptBranch__x9bzuCn2mNRReiUBcSXmpNQ_17)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* excTypeNode;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* actions;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* excCall;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* convNode;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* identDefs;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* letSection;
		T3_ = (NIM_BOOL)0;
		T3_ = isInfixAs__CZaoTkWCFI9acor4BmYF3Yw((*n)._kind_6.sons->data[((NI) 0)]);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isImportedException__dZW9czpRSiiVl9cyT6tyk84A((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]).typ, (*(*c).graph).config);
		T3_ = !(T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		excTypeNode = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
		actions = newTransNode__IwUzSDXaRhwfYD9aD9aV9cxcgtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n)._kind_6.sons->data[((NI) 1)], ((NI) 2));
		excCall = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw((*c).graph, ((NimStringDesc*) &TM__2w3VcOiOmEqxgfH4AylIpg_28), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		convNode = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((NI) 2));
		asgnRef((void**) (&(*convNode)._kind_6.sons->data[((NI) 0)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info));
		asgnRef((void**) (&(*convNode)._kind_6.sons->data[((NI) 1)]), excCall);
		asgnRef((void**) (&(*convNode).typ), toRef__IIQZtbSxQZOu2WmBJ9bnpCg((*excTypeNode).typ));
		identDefs = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((NI) 3));
		asgnRef((void**) (&(*identDefs)._kind_6.sons->data[((NI) 0)]), (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 2)]);
		asgnRef((void**) (&(*identDefs)._kind_6.sons->data[((NI) 1)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*n).info));
		asgnRef((void**) (&(*identDefs)._kind_6.sons->data[((NI) 2)]), convNode);
		letSection = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100), (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((NI) 1));
		asgnRef((void**) (&(*letSection)._kind_6.sons->data[((NI) 0)]), identDefs);
		asgnRef((void**) (&(*actions)._kind_6.sons->data[((NI) 0)]), letSection);
		asgnRef((void**) (&(*actions)._kind_6.sons->data[((NI) 1)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 1)]));
		result = newTransNode__T00TWsJvsUcixkQXPnIphAtransf(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87), (*(*n)._kind_6.sons->data[((NI) 1)]).info, ((NI) 2));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), actions);
	}
	goto LA1_;
	LA6_: ;
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* orig, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NI T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*orig).kind == (*cnst).kind));
	if (!(T2_)) goto LA3_;
	T2_ = ((*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 37) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = (NI)0;
	T5_ = len__P89cqdlERShb9alU3iC0yj8wast(cnst);
	T1_ = (((*cnst).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38)) < T5_);
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transform__x9bzuCn2mNRReiUBcSXmpNQ)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL exprIsPointerCast;
	NIM_BOOL T76_;
	NIM_BOOL T77_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = transformSym__x9bzuCn2mNRReiUBcSXmpNQ_2(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	{
		result = n;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 42):
	{
		result = transformArrayAccess__x9bzuCn2mNRReiUBcSXmpNQ_4(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA8_: ;
			if (!T7_) goto LA9_;
			result = transformSym__x9bzuCn2mNRReiUBcSXmpNQ_2(c, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA13_;
				result = n;
			}
			LA13_: ;
		}
		goto LA5_;
		LA9_: ;
		{
			result = n;
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	{
		result = n;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94):
	{
		result = transformFor__x9bzuCn2mNRReiUBcSXmpNQ_5(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 95):
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 97):
	{
		result = transformCase__x9bzuCn2mNRReiUBcSXmpNQ_8(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96):
	{
		result = transformWhile__x9bzuCn2mNRReiUBcSXmpNQ_9(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 112):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 127):
	{
		result = transformBlock__x9bzuCn2mNRReiUBcSXmpNQ_10(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 105):
	{
		(*c).deferDetected = NIM_TRUE;
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 111):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* labl;
		NI T24_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110), (*n).info);
		T24_ = (((*c).contSyms ? (*c).contSyms->Sup.len : 0)-1);
		labl = (*c).contSyms->data[T24_];
		T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T25_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(labl);
		add__P8dDSotTW25BkfbyspojGg(result, T25_);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110):
	{
		result = transformBreak__x9bzuCn2mNRReiUBcSXmpNQ_11(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32):
	{
		result = transformCall__x9bzuCn2mNRReiUBcSXmpNQ_12(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64):
	{
		result = transformAddrDeref__oB0ZJYmKjtxbUq9azE9as4GQ(c, n, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 47):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65):
	{
		result = transformAddrDeref__oB0ZJYmKjtxbUq9azE9as4GQ(c, n, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 63), ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60):
	{
		result = transformConv__x9bzuCn2mNRReiUBcSXmpNQ_13(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 114):
	{
		result = n;
		{
			if (!!(((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)))) goto LA34_;
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
			{
				NIM_BOOL T38_;
				T38_ = (NIM_BOOL)0;
				T38_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2((*result)._kind_6.sons->data[((NI) 0)]);
				if (!T38_) goto LA39_;
				result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125));
			}
			LA39_: ;
		}
		LA34_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 116):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 113):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 118):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 119):
	{
		result = n;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 101):
	{
		result = transformConstSection__fVJbvRdbXsZk6wrZ9cHGJCg(c, n);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
		result = n;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100):
	{
		{
			if (!(((NI) 0) < (*c).inlining)) goto LA47_;
			result = transformVarSection__fVJbvRdbXsZk6wrZ9cHGJCg_2(c, n);
		}
		goto LA45_;
		LA47_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 104):
	{
		{
			if (!(((NI) 0) < (*c).inlining)) goto LA53_;
			result = transformYield__x9bzuCn2mNRReiUBcSXmpNQ_14(c, n);
		}
		goto LA51_;
		LA53_: ;
		{
			result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73):
	{
		result = transformAsgn__x9bzuCn2mNRReiUBcSXmpNQ_16(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 102):
	{
		result = n;
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 0)]));
		asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 2)]), transform__x9bzuCn2mNRReiUBcSXmpNQ(c, (*n)._kind_6.sons->data[((NI) 2)]));
		{
			NIM_BOOL T60_;
			NimStringDesc* T63_;
			T60_ = (NIM_BOOL)0;
			T60_ = importantComments__TzsgO9bY9cwAf4hwmbs7dTmgoptions((*(*c).graph).config);
			if (!T60_) goto LA61_;
			T63_ = (NimStringDesc*)0;
			T63_ = (*result).comment; (*result).comment = copyStringRC1((*n).comment);
			if (T63_) nimGCunrefNoCycle(T63_);
		}
		LA61_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
		a = (*n)._kind_6.sons->data[((NI) 1)];
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA67_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), transformSymAux__x9bzuCn2mNRReiUBcSXmpNQ_3(c, a));
		}
		LA67_: ;
		result = n;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87):
	{
		result = transformExceptBranch__x9bzuCn2mNRReiUBcSXmpNQ_17(c, n);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 46):
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
		{
			if (!!(((*(*result)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45)))) goto LA73_;
			result = (*result)._kind_6.sons->data[((NI) 0)];
		}
		LA73_: ;
	}
	break;
	default:
	{
		result = transformSons__x9bzuCn2mNRReiUBcSXmpNQ_7(c, n);
	}
	break;
	}
	T76_ = (NIM_BOOL)0;
	T77_ = (NIM_BOOL)0;
	T77_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 60) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58));
	if (!(T77_)) goto LA78_;
	T77_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
	LA78_: ;
	T76_ = T77_;
	if (!(T76_)) goto LA79_;
	T76_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
	LA79_: ;
	exprIsPointerCast = T76_;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst;
		if (!!(exprIsPointerCast)) goto LA82_;
		cnst = getConstExpr__A7gcXCy5E3uGBy5F37NoHA((*c).module, result, (*c).graph);
		{
			NIM_BOOL T86_;
			NIM_BOOL T88_;
			T86_ = (NIM_BOOL)0;
			T86_ = !((cnst == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T86_)) goto LA87_;
			T88_ = (NIM_BOOL)0;
			T88_ = dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees(n, cnst);
			T86_ = !(T88_);
			LA87_: ;
			if (!T86_) goto LA89_;
			result = cnst;
		}
		LA89_: ;
	}
	LA82_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, processTransf__vQ6WkB89cnNhnYNYOnfVCDw)(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw* T5_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5))&31U)))!=0)) goto LA3_;
		result = n;
		goto BeforeRet_;
	}
	LA3_: ;
	T5_ = (tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*)0;
	T5_ = newTransCon__gHBjh7dKE1v5tJDPFQImxA(owner);
	pushTransCon__Q7kqtvaYdgT06r9a1oTEwOg(c, T5_);
	result = transform__x9bzuCn2mNRReiUBcSXmpNQ(c, n);
	popTransCon__uND2ekcuj27zfq5DWCAPjg(c);
	(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5)) & 31);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, flattenStmts__N9aNOI5jUJs7HuqSqY7VqPw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL goOn;
	goOn = NIM_TRUE;
	{
		while (1) {
			NI i;
			if (!goOn) goto LA2;
			goOn = NIM_FALSE;
			i = ((NI) 0);
			{
				while (1) {
					NI T5_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
					T5_ = (NI)0;
					T5_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					if (!(i < T5_)) goto LA4;
					it = (*n)._kind_6.sons->data[i];
					{
						tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T10_;
						NI T11_;
						tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T12_;
						tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* T13_;
						if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA8_;
						T10_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(i, i);
						T11_ = (NI)0;
						T11_ = len__P89cqdlERShb9alU3iC0yj8wast(it);
						T12_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 0), (NI)(T11_ - ((NI) 1)));
						T13_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
						T13_ = X5BX5D___5Y2wMdX1Q5sV9abRFAviD9aw((*it)._kind_6.sons->data, ((*it)._kind_6.sons ? (*it)._kind_6.sons->Sup.len : 0), T12_);
						X5BX5Deq___txCax6HTxTvaDY9bSHIRipg((&(*n)._kind_6.sons), T10_, T13_->data, (T13_ ? T13_->Sup.len : 0));
						goOn = NIM_TRUE;
					}
					LA8_: ;
					i += ((NI) 1);
				} LA4: ;
			}
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL goOn;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA3_;
		flattenStmts__N9aNOI5jUJs7HuqSqY7VqPw_2(n);
		goOn = NIM_TRUE;
		{
			while (1) {
				NI last;
				NI T7_;
				if (!goOn) goto LA6;
				goOn = NIM_FALSE;
				T7_ = (NI)0;
				T7_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				last = (NI)(T7_ - ((NI) 1));
				{
					NI i;
					NI res;
					i = (NI)0;
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= last)) goto LA10;
							i = res;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* deferPart;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tryStmt;
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
								if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 105))) goto LA13_;
								deferPart = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 107), (*(*n)._kind_6.sons->data[i]).info);
								add__P8dDSotTW25BkfbyspojGg(deferPart, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)]);
								tryStmt = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 106), (*(*n)._kind_6.sons->data[i]).info, (*n).typ);
								body = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg((*n).kind, (*(*n)._kind_6.sons->data[i]).info, (*n).typ);
								{
									tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T19_;
									if (!(i < last)) goto LA17_;
									T19_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem((NI)(i + ((NI) 1)), last);
									asgnRef((void**) (&(*body)._kind_6.sons), X5BX5D___5Y2wMdX1Q5sV9abRFAviD9aw((*n)._kind_6.sons->data, ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0), T19_));
								}
								LA17_: ;
								add__P8dDSotTW25BkfbyspojGg(tryStmt, body);
								add__P8dDSotTW25BkfbyspojGg(tryStmt, deferPart);
								asgnRef((void**) (&(*n)._kind_6.sons->data[i]), tryStmt);
								asgnRef((void**) (&(*n)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*n)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(i + ((NI) 1))))));
								asgnRef((void**) (&(*n).typ), (*tryStmt).typ);
								goOn = NIM_TRUE;
								goto LA8;
							}
							LA13_: ;
							res += ((NI) 1);
						} LA10: ;
					}
				} LA8: ;
			} LA6: ;
		}
	}
	LA3_: ;
	{
		NI i_2;
		NI colontmp_;
		NI T21_;
		NI res_2;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		T21_ = (NI)0;
		T21_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		colontmp_ = (NI)(T21_ - ((NI) 1));
		res_2 = ((NI) 0);
		{
			while (1) {
				if (!(res_2 <= colontmp_)) goto LA23;
				i_2 = res_2;
				liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw((*n)._kind_6.sons->data[i_2]);
				res_2 += ((NI) 1);
			} LA23: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBody__ocxOgPRHWfivNZELIhOv7w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL cache) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!!(((*prc)._kind_2.transformedBody == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		result = (*prc)._kind_2.transformedBody;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		T6_ = (NIM_BOOL)0;
		T6_ = (((*(*(*prc).ast)._kind_6.sons->data[((NI) 6)]).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5))&31U)))!=0);
		if (T6_) goto LA7_;
		T6_ = ((262144 &((NU32)1<<((NU)((*prc).kind)&31U)))!=0);
		LA7_: ;
		if (!T6_) goto LA8_;
		result = (*(*prc).ast)._kind_6.sons->data[((NI) 6)];
	}
	goto LA1_;
	LA8_: ;
	{
		tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T11_;
		asgnRef((void**) (&(*prc)._kind_2.transformedBody), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		T11_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T11_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(prc);
		c = openTransf__3DaoTzFM8siFEsr9areRAsg(g, T11_, ((NimStringDesc*) NIM_NIL));
		result = liftLambdas__dmTb5DSkbT8504NMz3NOoA(g, prc, (*(*prc).ast)._kind_6.sons->data[((NI) 6)], (&(*c).tooEarly));
		result = processTransf__vQ6WkB89cnNhnYNYOnfVCDw(c, result, prc);
		{
			if (!(*c).deferDetected) goto LA14_;
			liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw(result);
		}
		LA14_: ;
		result = liftLocalsIfRequested__LPFQUSXwjhtGHYhcDkDrbA(prc, result, (*g).cache, (*g).config);
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = ((*prc).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
			if (!(T18_)) goto LA19_;
			T18_ = ((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA19_: ;
			if (!T18_) goto LA20_;
			result = transformClosureIterator__pOvzY9bL6Z9bAquTmdZOUhVg(g, prc, result);
		}
		LA20_: ;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5)) & 31);
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = cache;
			if (T24_) goto LA25_;
			T24_ = ((*(*prc).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 5));
			LA25_: ;
			if (!T24_) goto LA26_;
			asgnRef((void**) (&(*prc)._kind_2.transformedBody), result);
		}
		goto LA22_;
		LA26_: ;
		{
			asgnRef((void**) (&(*prc)._kind_2.transformedBody), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		}
		LA22_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformExpr__o9bTtoSsaDmuiyVzV15dOyg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5))&31U)))!=0)) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c;
		c = openTransf__3DaoTzFM8siFEsr9areRAsg(g, module, ((NimStringDesc*) NIM_NIL));
		result = processTransf__vQ6WkB89cnNhnYNYOnfVCDw(c, n, module);
		{
			if (!(*c).deferDetected) goto LA8_;
			liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw(result);
		}
		LA8_: ;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5)) & 31);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* op;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*result)._kind_6.sons->data[i]), commonOptimizations__0A2Fu3iOZ9aCzHX2sVSYlhg(g, c, (*n)._kind_6.sons->data[i]));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	op = getMergeOp__EuK0aY8I1jCqHxmYwogXtg(n);
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NI T10_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* args;
		NI j;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = !((op == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*op).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0)));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		T6_ = (((NI) 3) <= T10_);
		LA9_: ;
		if (!T6_) goto LA11_;
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, (*n).typ);
		add__P8dDSotTW25BkfbyspojGg(result, (*n)._kind_6.sons->data[((NI) 0)]);
		args = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152));
		flattenTreeAux__cz5kqNnGwAu9cFHQaWrJE9cw(args, n, op);
		j = ((NI) 0);
		{
			while (1) {
				NI T15_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
				T15_ = (NI)0;
				T15_ = len__P89cqdlERShb9alU3iC0yj8wast(args);
				if (!(j < T15_)) goto LA14;
				a = (*args)._kind_6.sons->data[j];
				j += ((NI) 1);
				{
					NIM_BOOL T18_;
					T18_ = (NIM_BOOL)0;
					T18_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2(a);
					if (!T18_) goto LA19_;
					{
						while (1) {
							NI T23_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b;
							T23_ = (NI)0;
							T23_ = len__P89cqdlERShb9alU3iC0yj8wast(args);
							if (!(j < T23_)) goto LA22;
							b = (*args)._kind_6.sons->data[j];
							{
								NIM_BOOL T26_;
								T26_ = (NIM_BOOL)0;
								T26_ = isConstExpr__9cP6JNeOKqczaXCI4Zo4SBQ_2(b);
								if (!!(T26_)) goto LA27_;
								goto LA21;
							}
							LA27_: ;
							a = evalOp__naTMtRq9avUKkKDwI0csDMg((*op).magic, result, a, b, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), g);
							j += ((NI) 1);
						} LA22: ;
					} LA21: ;
				}
				LA19_: ;
				add__P8dDSotTW25BkfbyspojGg(result, a);
			} LA14: ;
		}
		{
			NI T31_;
			T31_ = (NI)0;
			T31_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
			if (!(T31_ == ((NI) 2))) goto LA32_;
			result = (*result)._kind_6.sons->data[((NI) 1)];
		}
		LA32_: ;
	}
	goto LA4_;
	LA11_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* cnst;
		cnst = getConstExpr__A7gcXCy5E3uGBy5F37NoHA(c, n, g);
		{
			NIM_BOOL T37_;
			NIM_BOOL T39_;
			T37_ = (NIM_BOOL)0;
			T37_ = !((cnst == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T37_)) goto LA38_;
			T39_ = (NIM_BOOL)0;
			T39_ = dontInlineConstant__164nxsacBEejwonWVg9c9aQQtrees(n, cnst);
			T37_ = !(T39_);
			LA38_: ;
			if (!T37_) goto LA40_;
			result = cnst;
		}
		goto LA35_;
		LA40_: ;
		{
			result = n;
		}
		LA35_: ;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformStmt__o9bTtoSsaDmuiyVzV15dOyg_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5))&31U)))!=0)) goto LA3_;
		result = n;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A* c;
		c = openTransf__3DaoTzFM8siFEsr9areRAsg(g, module, ((NimStringDesc*) NIM_NIL));
		result = processTransf__vQ6WkB89cnNhnYNYOnfVCDw(c, n, module);
		{
			if (!(*c).deferDetected) goto LA8_;
			liftDeferAux__N9aNOI5jUJs7HuqSqY7VqPw(result);
		}
		LA8_: ;
		(*result).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 5)) & 31);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_transfDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__2w3VcOiOmEqxgfH4AylIpg_2_9[9];
static TNimNode* TM__2w3VcOiOmEqxgfH4AylIpg_3_6[6];
static TNimNode* TM__2w3VcOiOmEqxgfH4AylIpg_20_2[2];
static TNimNode TM__2w3VcOiOmEqxgfH4AylIpg_0[20];

/* section: NIM_merge_TYPE_INIT3 */
NTI__m7cKlfKYTeFRQpBypUYc2A_.size = sizeof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A);
NTI__m7cKlfKYTeFRQpBypUYc2A_.align = NIM_ALIGNOF(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A);
NTI__m7cKlfKYTeFRQpBypUYc2A_.kind = 17;
NTI__m7cKlfKYTeFRQpBypUYc2A_.base = (&NTI__Hb6rFM0ecvtlLf2kv9aU75w_);
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[0] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[1];
TM__2w3VcOiOmEqxgfH4AylIpg_0[1].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[1].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, module);
TM__2w3VcOiOmEqxgfH4AylIpg_0[1].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[1].name = "module";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[1] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[2];
NTI__VDvyAvJlyyy8i9bxzTgZE9cw_.size = sizeof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw);
NTI__VDvyAvJlyyy8i9bxzTgZE9cw_.align = NIM_ALIGNOF(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw);
NTI__VDvyAvJlyyy8i9bxzTgZE9cw_.kind = 18;
NTI__VDvyAvJlyyy8i9bxzTgZE9cw_.base = 0;
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[0] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[4];
TM__2w3VcOiOmEqxgfH4AylIpg_0[4].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[4].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, mapping);
TM__2w3VcOiOmEqxgfH4AylIpg_0[4].typ = (&NTI__UWAp0mDjKLG1NEwUafSRhA_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[4].name = "mapping";
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[1] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[5];
TM__2w3VcOiOmEqxgfH4AylIpg_0[5].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[5].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, owner);
TM__2w3VcOiOmEqxgfH4AylIpg_0[5].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[5].name = "owner";
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[2] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[6];
TM__2w3VcOiOmEqxgfH4AylIpg_0[6].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[6].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, forStmt);
TM__2w3VcOiOmEqxgfH4AylIpg_0[6].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[6].name = "forStmt";
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[3] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[7];
TM__2w3VcOiOmEqxgfH4AylIpg_0[7].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[7].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, forLoopBody);
TM__2w3VcOiOmEqxgfH4AylIpg_0[7].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[7].name = "forLoopBody";
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[4] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[8];
TM__2w3VcOiOmEqxgfH4AylIpg_0[8].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[8].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, yieldStmts);
TM__2w3VcOiOmEqxgfH4AylIpg_0[8].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[8].name = "yieldStmts";
TM__2w3VcOiOmEqxgfH4AylIpg_3_6[5] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[9];
TM__2w3VcOiOmEqxgfH4AylIpg_0[9].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[9].offset = offsetof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw, next);
TM__2w3VcOiOmEqxgfH4AylIpg_0[9].typ = (&NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[9].name = "next";
TM__2w3VcOiOmEqxgfH4AylIpg_0[3].len = 6; TM__2w3VcOiOmEqxgfH4AylIpg_0[3].kind = 2; TM__2w3VcOiOmEqxgfH4AylIpg_0[3].sons = &TM__2w3VcOiOmEqxgfH4AylIpg_3_6[0];
NTI__VDvyAvJlyyy8i9bxzTgZE9cw_.node = &TM__2w3VcOiOmEqxgfH4AylIpg_0[3];
NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_.size = sizeof(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*);
NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_.align = NIM_ALIGNOF(tyObject_TTransCon__VDvyAvJlyyy8i9bxzTgZE9cw*);
NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_.kind = 22;
NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_.base = (&NTI__VDvyAvJlyyy8i9bxzTgZE9cw_);
NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_.marker = Marker_tyRef__CFQvJAfmRh5qxjY9bLo9c7Fg;
TM__2w3VcOiOmEqxgfH4AylIpg_0[2].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[2].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, transCon);
TM__2w3VcOiOmEqxgfH4AylIpg_0[2].typ = (&NTI__CFQvJAfmRh5qxjY9bLo9c7Fg_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[2].name = "transCon";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[2] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[10];
TM__2w3VcOiOmEqxgfH4AylIpg_0[10].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[10].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, inlining);
TM__2w3VcOiOmEqxgfH4AylIpg_0[10].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[10].name = "inlining";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[3] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[11];
TM__2w3VcOiOmEqxgfH4AylIpg_0[11].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[11].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, nestedProcs);
TM__2w3VcOiOmEqxgfH4AylIpg_0[11].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[11].name = "nestedProcs";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[4] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[12];
TM__2w3VcOiOmEqxgfH4AylIpg_0[12].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[12].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, contSyms);
TM__2w3VcOiOmEqxgfH4AylIpg_0[12].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[12].name = "contSyms";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[5] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[13];
TM__2w3VcOiOmEqxgfH4AylIpg_0[13].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[13].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, breakSyms);
TM__2w3VcOiOmEqxgfH4AylIpg_0[13].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[13].name = "breakSyms";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[6] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[14];
TM__2w3VcOiOmEqxgfH4AylIpg_0[14].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[14].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, deferDetected);
TM__2w3VcOiOmEqxgfH4AylIpg_0[14].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[14].name = "deferDetected";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[7] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[15];
TM__2w3VcOiOmEqxgfH4AylIpg_0[15].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[15].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, tooEarly);
TM__2w3VcOiOmEqxgfH4AylIpg_0[15].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[15].name = "tooEarly";
TM__2w3VcOiOmEqxgfH4AylIpg_2_9[8] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[16];
TM__2w3VcOiOmEqxgfH4AylIpg_0[16].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[16].offset = offsetof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A, graph);
TM__2w3VcOiOmEqxgfH4AylIpg_0[16].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[16].name = "graph";
TM__2w3VcOiOmEqxgfH4AylIpg_0[0].len = 9; TM__2w3VcOiOmEqxgfH4AylIpg_0[0].kind = 2; TM__2w3VcOiOmEqxgfH4AylIpg_0[0].sons = &TM__2w3VcOiOmEqxgfH4AylIpg_2_9[0];
NTI__m7cKlfKYTeFRQpBypUYc2A_.node = &TM__2w3VcOiOmEqxgfH4AylIpg_0[0];
NTI__TGWT2zXHjsFJka0TXFMVzw_.size = sizeof(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*);
NTI__TGWT2zXHjsFJka0TXFMVzw_.align = NIM_ALIGNOF(tyObject_TTransfContext__m7cKlfKYTeFRQpBypUYc2A*);
NTI__TGWT2zXHjsFJka0TXFMVzw_.kind = 22;
NTI__TGWT2zXHjsFJka0TXFMVzw_.base = (&NTI__m7cKlfKYTeFRQpBypUYc2A_);
NTI__TGWT2zXHjsFJka0TXFMVzw_.marker = Marker_tyRef__TGWT2zXHjsFJka0TXFMVzw;
NTI__k9ckC7egSTPlxMaCeJlF9aLw_.size = sizeof(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw);
NTI__k9ckC7egSTPlxMaCeJlF9aLw_.align = NIM_ALIGNOF(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw);
NTI__k9ckC7egSTPlxMaCeJlF9aLw_.kind = 17;
NTI__k9ckC7egSTPlxMaCeJlF9aLw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__2w3VcOiOmEqxgfH4AylIpg_20_2[0] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[18];
TM__2w3VcOiOmEqxgfH4AylIpg_0[18].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[18].offset = offsetof(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw, colonstate_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[18].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[18].name = ":state";
TM__2w3VcOiOmEqxgfH4AylIpg_20_2[1] = &TM__2w3VcOiOmEqxgfH4AylIpg_0[19];
TM__2w3VcOiOmEqxgfH4AylIpg_0[19].kind = 1;
TM__2w3VcOiOmEqxgfH4AylIpg_0[19].offset = offsetof(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw, c1);
TM__2w3VcOiOmEqxgfH4AylIpg_0[19].typ = (&NTI__TGWT2zXHjsFJka0TXFMVzw_);
TM__2w3VcOiOmEqxgfH4AylIpg_0[19].name = "c1";
TM__2w3VcOiOmEqxgfH4AylIpg_0[17].len = 2; TM__2w3VcOiOmEqxgfH4AylIpg_0[17].kind = 2; TM__2w3VcOiOmEqxgfH4AylIpg_0[17].sons = &TM__2w3VcOiOmEqxgfH4AylIpg_20_2[0];
NTI__k9ckC7egSTPlxMaCeJlF9aLw_.node = &TM__2w3VcOiOmEqxgfH4AylIpg_0[17];
NTI__7lgNfGoBjgvsM5K1jkApkg_.size = sizeof(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*);
NTI__7lgNfGoBjgvsM5K1jkApkg_.align = NIM_ALIGNOF(tyObject_Env_transfdotnim_transformYield___k9ckC7egSTPlxMaCeJlF9aLw*);
NTI__7lgNfGoBjgvsM5K1jkApkg_.kind = 22;
NTI__7lgNfGoBjgvsM5K1jkApkg_.base = (&NTI__k9ckC7egSTPlxMaCeJlF9aLw_);
NTI__7lgNfGoBjgvsM5K1jkApkg_.marker = Marker_tyRef__7lgNfGoBjgvsM5K1jkApkg;
}

