/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <setjmp.h>
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ;
typedef struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tySequence__oYkV9aFZe0MXcEAprJaOUsA tySequence__oYkV9aFZe0MXcEAprJaOUsA;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tySequence__arD7Tw6eD6lvOczWZl9buNg tySequence__arD7Tw6eD6lvOczWZl9buNg;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tySequence__jWKvSdankQPoT5bw9cBU9aiw tySequence__jWKvSdankQPoT5bw9cBU9aiw;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__YceFcaugL2PWNtVbyffD9bQ tySequence__YceFcaugL2PWNtVbyffD9bQ;
typedef struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ tySequence__d4l6E4jBnTQ3BEfsLOpmEQ;
typedef struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tySequence__i7xpiUsxyv6cQ1xK3JbcGQ tySequence__i7xpiUsxyv6cQ1xK3JbcGQ;
typedef struct Exception Exception;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA;
typedef struct tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw;
typedef struct tySequence__nl5fX6g5vxdA4inU5zASDQ tySequence__nl5fX6g5vxdA4inU5zASDQ;
typedef struct tyTuple__gOsvkY4zLbqYcgABB1VEQg tyTuple__gOsvkY4zLbqYcgABB1VEQg;
typedef struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ tyTuple__DJxbl4DYEJfb29cy1MYaUPQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ;
typedef struct tySequence__0dpGN6F4ocevqUQGsaf41w tySequence__0dpGN6F4ocevqUQGsaf41w;
typedef struct tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__KlSLWBROOViO04uLQHu7ig tyTuple__KlSLWBROOViO04uLQHu7ig;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__RcJNn9bSvWdJgUmA1O6sbHA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef NU32 tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__39auogS0nN05zO6JrT7za9cQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__msQKNa7Ucgnt49aAZ3YRJww) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__7JwrY3AhkVNlleAJXClX9cw;
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__qlV9aWvA5wrWVg9bI5PqwJyA) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw filter, tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags);
typedef N_NIMCALL_PTR(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, tyProc__PiEiMdzXg9bcm3lEo4Q6iNw) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, void* ClE_0);
void* ClE_0;
} tyProc__3cacbJ4la9bDJNibHybQSnA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, ClP_0) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, void* ClE_0);
void* ClE_0;
} tyProc__L4XfH7VEp8aJssG3EbEBaQ;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__9amcenQyXzP9cCQNnXZVgnYQ) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
struct tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w {
tySequence__Bis5AbpONWcIRrPyPJS8Yw* data;
NI counter;
};
struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* enforceVoidContext;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* currentScope;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* importTable;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* topLevelScope;
tyObject_TProcCon__s5jyYR8yL1QmFqiHICzU9aQ* p;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* matchedConcept;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* friendModules;
NI instCounter;
NI* templInstCounter;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg ambiguousSymbols;
NI inGenericContext;
NI inStaticContext;
NI inUnrolledContext;
NI compilesContextId;
NI compilesContextIdGenerator;
NI inGenericInst;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* converters;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* patterns;
tySequence__oYkV9aFZe0MXcEAprJaOUsA* optionStack;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q symMapping;
tySequence__arD7Tw6eD6lvOczWZl9buNg* libs;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semExpr;
tyProc__39auogS0nN05zO6JrT7za9cQ semTryExpr;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semTryConstExpr;
tyProc__msQKNa7Ucgnt49aAZ3YRJww computeRequiresInit;
tyProc__7JwrY3AhkVNlleAJXClX9cw hasUnresolvedArgs;
tyProc__39auogS0nN05zO6JrT7za9cQ semOperand;
tyProc__RcJNn9bSvWdJgUmA1O6sbHA semConstBoolExpr;
tyProc__qlV9aWvA5wrWVg9bI5PqwJyA semOverloadedCall;
tyProc__PiEiMdzXg9bcm3lEo4Q6iNw semTypeNode;
tyProc__3cacbJ4la9bDJNibHybQSnA semInferredLambda;
tyProc__L4XfH7VEp8aJssG3EbEBaQ semGenerateInstance;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg includedFiles;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA pureEnumFields;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA userPragmas;
tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* evalContext;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg unknownIdents;
tySequence__jWKvSdankQPoT5bw9cBU9aiw* generics;
NI topStmts;
NI lastGenericIdx;
NI hloLoopDetector;
NI inParallelStmt;
tyProc__9amcenQyXzP9cCQNnXZVgnYQ instTypeBoundOp;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* selfName;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA signatures;
NimStringDesc* recursiveDep;
NIM_BOOL suggestionsMade;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
NI inTypeContext;
tySequence__YceFcaugL2PWNtVbyffD9bQ* typesWithOps;
tySequence__d4l6E4jBnTQ3BEfsLOpmEQ* unusedImports;
tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w exportIndirections;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastTLineInfo;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q;
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg {
NI h;
};
struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw {
NI depthLevel;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* parent;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ {
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ section;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* qualifiedPath;
NimStringDesc** name;
NimStringDesc* filePath;
NI line;
NI column;
NimStringDesc* doc;
NimStringDesc* forth;
NI quality;
NIM_BOOL isGlobal;
NIM_BOOL contextFits;
tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q prefix;
NU8 symkind;
NI scope;
NI localUsages;
NI globalUsages;
NI tokenLen;
NI version;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
struct tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ {
  RootObj Sup;
NI colonstate_;
NimStringDesc* line1;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (NI col, void* ClE_0);
void* ClE_0;
} tyProc__cOOsXj9cY0bKt2oqNqLbhZw;
typedef N_CLOSURE_PTR(NIM_BOOL, TM__EV5hHJmjIY9cla9b9be7fSVJQ_5) (NI col);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__EV5hHJmjIY9cla9b9be7fSVJQ_6) (NI col);
typedef N_CLOSURE_PTR(NIM_BOOL, TM__EV5hHJmjIY9cla9b9be7fSVJQ_7) (NI col);
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg;
typedef NU8 tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w;
struct tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ {
tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w kind;
NI arg;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formal;
};
struct tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA {
tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
NI exactMatches;
NI genericMatches;
NI subtypeMatches;
NI intConvMatches;
NI convMatches;
tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg state;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* calleeSym;
NI calleeScope;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q bindings;
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
NIM_BOOL baseTypeMatch;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag fauxMatch;
NIM_BOOL genericConverter;
NIM_BOOL coerceDistincts;
NIM_BOOL typedescMatched;
NIM_BOOL isNoCall;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* inferredTypes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NI inheritancePenalty;
tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ firstMismatch;
NIM_BOOL diagnosticsEnabled;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ;
typedef NU8 tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg;
struct tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* candidateType;
tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* prev;
NI depth;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
typedef NU8 tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg;
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw;
typedef NU8 tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ;
typedef NU8 tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ;
struct tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw {
  RootObj Sup;
NI colonstate_;
NimStringDesc* errorPrefix1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeClass2;
tyProc__k2HFjxisIgDALbEUFojxaQ oldWriteHook3;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics4;
};
struct tyTuple__gOsvkY4zLbqYcgABB1VEQg {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
typedef N_CLOSURE_PTR(void, TM__EV5hHJmjIY9cla9b9be7fSVJQ_26) (NimStringDesc* output);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__EV5hHJmjIY9cla9b9be7fSVJQ_33) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef N_CLOSURE_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, TM__EV5hHJmjIY9cla9b9be7fSVJQ_34) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_CLOSURE_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, TM__EV5hHJmjIY9cla9b9be7fSVJQ_39) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
typedef N_CLOSURE_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, TM__EV5hHJmjIY9cla9b9be7fSVJQ_40) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__jlWPjgtbdjE069arIWHC9c9bg[1];
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
struct tyTuple__DJxbl4DYEJfb29cy1MYaUPQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field0;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field1;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
NI Field0;
NI Field1;
};
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
typedef NI tyArray__HU7qaqKu9czJLT84iCBJnsA[2];
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* x, tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* y, void* ClE_0);
void* ClE_0;
} tyProc__pNH4eLNN9aK2oskAhILvUcw;
typedef NU8 tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA;
typedef N_CLOSURE_PTR(NI, TM__EV5hHJmjIY9cla9b9be7fSVJQ_70) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* x, tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* y, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__EV5hHJmjIY9cla9b9be7fSVJQ_71) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result);
typedef NU8 tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg;
struct tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ firstMismatch;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* diagnostics;
NIM_BOOL enabled;
};
typedef NU16 tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw;
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef N_CLOSURE_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, TM__EV5hHJmjIY9cla9b9be7fSVJQ_84) (tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
struct tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* genericSym;
tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* inst;
};
struct tyTuple__KlSLWBROOViO04uLQHu7ig {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field0;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
NI Field0;
tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__i7xpiUsxyv6cQ1xK3JbcGQ {
  TGenericSeq Sup;
  tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__nl5fX6g5vxdA4inU5zASDQ {
  TGenericSeq Sup;
  tyTuple__gOsvkY4zLbqYcgABB1VEQg data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__0dpGN6F4ocevqUQGsaf41w {
  TGenericSeq Sup;
  tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__oYkV9aFZe0MXcEAprJaOUsA {
  TGenericSeq Sup;
  tyObject_TOptionEntry__H9ac5KbrDJVwT1zH5O83r7w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__arD7Tw6eD6lvOczWZl9buNg {
  TGenericSeq Sup;
  tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* data[SEQ_DECL_SIZE];
};
struct tySequence__jWKvSdankQPoT5bw9cBU9aiw {
  TGenericSeq Sup;
  tyObject_TInstantiationPair__HkXM4cJmOpk8zFcmq9c9c3gQ data[SEQ_DECL_SIZE];
};
struct tySequence__YceFcaugL2PWNtVbyffD9bQ {
  TGenericSeq Sup;
  tyTuple__KlSLWBROOViO04uLQHu7ig data[SEQ_DECL_SIZE];
};
struct tySequence__d4l6E4jBnTQ3BEfsLOpmEQ {
  TGenericSeq Sup;
  tyTuple__DJxbl4DYEJfb29cy1MYaUPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  TGenericSeq Sup;
  tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exactEquals__59bygf5b7AsTVb9a1lVM66oA_2)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q a, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q b);
N_LIB_PRIVATE N_NIMCALL(void, suggestExprNoCheck__wb6KhAx6bZ5NV37kY4bXJw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, sugExpr__1VfUSh4M09adXSHz7X3Fe9cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, safeSemExpr__wmMigIhDNhpgfhVcHQRifA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, suggestFieldAccess__OR9bF44BXFsRVnhukOo9cgLw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
static N_INLINE(NIM_BOOL, filterSym__bcqYtfxSrIczthAmGccX0Asigmatch)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q* res);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q, prefixMatch__9cyp8Sjrw866Z4MGxz0DeLg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q, prefixMatch__pK9a9aTI3V8r6eOzZI8EfYlw)(NimStringDesc* p, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*, symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isLocal, tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ section, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI quality, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q prefix, NIM_BOOL inTypeContext, NI scope, NIM_BOOL useSuppliedInfo);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(NIM_BOOL, contains__RPVlURtov7G07Wgl1Pwc9cAsystem)(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA s, NI value);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 fileIdx);
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NI, getTokenLenFromSource__Ag69bMcP2z1X5yPIF8diKPw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tyRef__AQEmz0epsPFaQWAZOZKqTA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, isOpeningBacktick__MCqrgtCgrhBqRN307gIKtA)(NI col, void* ClE_0);
static N_INLINE(NI, skipUntil__HcbgRIqguzsS4r2WE04C6gparseutils)(NimStringDesc* s, NIM_CHAR until, NI start);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(NIM_CHAR, X5BX5D___okzHJ6GE9cv0bYG3b4r5KCAsystem)(NimStringDesc* s, NI i);
N_LIB_PRIVATE N_NIMCALL(NI, identLen__cr8f4oiC7y4wZkhdloxc7w)(NimStringDesc* line, NI start);
static N_INLINE(NI, parseWhile__aIOGZyeHx2rHC71Dcc2SCwparseutils)(NimStringDesc* s, NimStringDesc** token, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw validChars, NI start);
N_LIB_PRIVATE N_NIMCALL(void, fastSubstr__a88zu6ztJ3SBDTHcnqFjsg)(NimStringDesc* s, NimStringDesc** token, NI start, NI length);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___0oyFvH6YyZCaqn8h3bbKMwsystem)(NI b);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2)(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg* ti, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab);
N_LIB_PRIVATE N_NIMCALL(void, suggestEverything__CNgl7zyt4docO57SnwwZuQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(void, suggestSymList__Kt0rYFU9b6Yu9b2P7xFWUJ7A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(void, suggestField__eY0NQ17HSi1QPRouRIEVXg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
static N_INLINE(NIM_BOOL, fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getModule__xfh8ar7fDxVX2A4OO9b5sqQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, suggestOperations__dyCk01GCQtAHexivg9cHqOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
static N_INLINE(NIM_BOOL, filterSymNoOpr__bcqYtfxSrIczthAmGccX0A_2sigmatch)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q* res);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__N1ZnIJchVZRKfKk15xA7QQ)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* i);
static N_INLINE(NIM_BOOL, typeFits__OIugBvRq9c2phfT0MWx8Gcgsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* firstArg);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, elemType__PfgI9ap7WOnsRfFV4znQ27w_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argtypeMatches__gpWCq1law3K3m6Z2JETYnw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, NIM_BOOL fromHlo);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__rFFaxk6TYVlvnKNibvVmkg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__GPx9buyQn9cq0nARN4Amyarw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee);
static N_INLINE(void, initCandidateAux__kxeVK8KvdIa8ne7AuBlgnQsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee);
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, paramTypesMatch__MkZIYaWSL2Febv66liB9aIA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argOrig);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, paramTypesMatchAux__nswM7DVSnPjX5r3urUls5Q)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argSemantized, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argOrig);
N_LIB_PRIVATE N_NIMCALL(void, assignType__RDstL9c8H9bSHUphDz0iB0hg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeS__xb5E2cGIynZweqWlCP8Tig)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, typeRel__3a3tkQB9aY8V2J9acM5cZ6nA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aOrig, tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg flags);
static N_INLINE(void, put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* key, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* val);
N_LIB_PRIVATE N_NIMCALL(void, idTablePut__anELyz7VLsjbCIoxLpxbfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key, RootObj* val);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, copyType__4O4aYoscFPo2FRSh4rP9ayg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL keepId);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(RootObj*, idTableGet__K5M5T7J9c0H7M5ahfeRl8xw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q t, tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL allowUnresolved);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, replaceTypesInBody__JQMwbj1fgdFwBCg7mhUBRQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL allowMetaTypes);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, base__PfgI9ap7WOnsRfFV4znQ27w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, add__9a8CdZqChTyqzq5bpSL3TzA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, maybeSkipDistinct__81UcA7TE8rJ8Gai4W1iW9cg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldSkipDistinct__nU6tuBd3HbyqPo9a608qr9aA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rules, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* callIdent);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* origin);
static N_INLINE(NIM_BOOL, sameEnumTypes__aVVjNzmtPf6fjiBzSvfSQg_2types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NOINLINE(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, typeRangeRel__w3WJH5XKeovEI9cb9cseqgmQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrdinalType__6euCPZwUsyXzP1vAm4IthA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL allowEnumWithHoles);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___7c5Zw7H31uJfWmmhZe9aEqw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, firstOrd__hjogdnp59cMX1rwmjikBhqw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lastOrd__hjogdnp59cMX1rwmjikBhqw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___7c5Zw7H31uJfWmmhZe9aEqw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(NF, firstFloat__5WwccqVm6xApk9c8p9c1efRA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NF, lastFloat__5WwccqVm6xApk9c8p9c1efRA_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConvertibleToRange__je559cQ286PtxNuVoMCjyww)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
static N_INLINE(NIM_BOOL, isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag min, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag max);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___nr9cP9b0OL9cabygV9bo19cJgZA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___xL5gyZrjbGMarSdRAXOo9ag)(NI64 a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
static N_INLINE(NIM_BOOL, isFloatLit__F9ciDIanrWYqbJ4rgLlNAAg_2types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCovariantPtr__OS0a7EtgsSjPvphc5aG65w)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, inferStaticsInRange__hRaLa1Ge0r7UTGASvA1ocQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inferred, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, lengthOrd__hjogdnp59cMX1rwmjikBhqw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, minus___hiijuMqvH9aC9aKmwIYuqUAA)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, plus___hiijuMqvH9aC9aKmwIYuqUAA_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, NI64 b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inferStaticParam__Fz18GssDhipSzpDxzhkUXw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, NI64 rhs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__1szweXXq3RBN50owrYu2Xw)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(void, failureToInferStaticParam__2rPrKzcn1sisAtRnbza1NA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, minus___Sp7OcCEIFoBYolB6PB1fAg_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA a, tyObject_Int128__9a9axPfb75jdWY25AamJewkA b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, allowsNilDeprecated__AbnwgaBsy37utKNens69aOg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f);
static N_INLINE(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, recordRel__jLWLF6Jks9cJgmPzh2I6lSg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameType__3isNyHKb0U1OCnClmflXSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b, tySet_tyEnum_TTypeCmpFlag__72pgRXSg7774cr9aCWVPORw flags);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, minRel__7YozvgTVcSzTGrASvCO0ZA)(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ a, tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ b);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameObjectTypes__6sVmgh7vIWM9axOIPRliopQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(NI, isObjectSubtype__C1JCauhsK9aI1g4xqINNSyQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin);
N_LIB_PRIVATE N_NIMCALL(void, genericParamPut__z5a4ZOu3KDJ5RptiscEp5g)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* last, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin);
static N_INLINE(NIM_BOOL, sameDistinctTypes__aVVjNzmtPf6fjiBzSvfSQg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, procTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_2)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, procParamTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_3)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__aVxWxXLmf103vwE8uZ9cXRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
static N_INLINE(NIM_BOOL, inconsistentVarTypes__tUOqr3q1OVzVDquDgQiutwsigmatch)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
N_LIB_PRIVATE N_NIMCALL(tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ, compatibleEffects__jMDzK5tLgCQpWKRW9azac5w)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, prepareMetatypeForSigmatch__ab5BITmU2P8zKztV9cfNtsg_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* p, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q pt, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipToObject__ec9bR2l2DprlWYvY8hoXvOw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ* skipped);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericSubtype__ys4SMiUV3x7hCCSTZl9cNPg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, NI* d, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, concreteType__s6oL9aoscwdxar7x6MeckLw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, matchUserTypeClass__med55njOHF6RW5cCXCP9bbQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a);
static N_NIMCALL(void, Marker_tyRef__T9cB3MofzwLcK9bH1dcRQNsg)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*, openScope__HbQKk9aDdsJVs9bASTXwa5Lw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeTypeDesc__BhLel1oiCddEysrc3uc6iQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_NIMCALL(void, Marker_tySequence__nl5fX6g5vxdA4inU5zASDQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, addDecl__aPXKqZJT9c7r7gT8X3uZAHw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___09a2v5CSVCqRsz63PUgUIwQ)(NimStringDesc* s, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuReplaceStr)(NimStringDesc* s, NimStringDesc* sub, NimStringDesc* by);
N_LIB_PRIVATE N_NIMCALL(void, closeScope__TX9bi5b9bIHR13FiwHwV59a4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b, NIM_BOOL strictSymEquality);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, incMatches__A6Mml3n6SH4wRXsgNwTrfQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ r, NI convMatch);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, implicitConv__ekWYb9baoe72jjRpfCUrNQQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, errorType__9aXTnVBVS5pbBC3zrwMhttg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newProcNode__g5PEkYP0A0RT03uHbJ6wKQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pattern, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptions);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, userConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__kCP6QlI8uS4X0pOQUdr7tg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, markUsed__QlWTWY7567sCdiTkeUTTDA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, warnAboutDeprecated__2mdCrePWCLH8F2Wb8QkFIw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, extractPragma__WA2vCsoKtzcTWMS9asDfXEg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw, whichPragma__Pjztiiq9bHmTTxDuLd39cNRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, userError__2mdCrePWCLH8F2Wb8QkFIw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NI32 info);
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUse__k3cqh606mJPYNzLXdtZjIg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__59b0yGhHVwyyUm0ZIA71uAg)(tyObject_HashSet__Gy4haGrophX9bC5RxnPAc6w s, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key);
N_LIB_PRIVATE N_NIMCALL(void, del__euuxT1DiEjSOKbaBvsuoZA)(tySequence__d4l6E4jBnTQ3BEfsLOpmEQ** x, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, localConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind);
N_LIB_PRIVATE N_NIMCALL(void, copyCandidate__6gwMmb9c2kKKE0RsLWc5nig)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b);
N_LIB_PRIVATE N_NIMCALL(void, copyIdTable__kWmPoTDdSpeN1EEQ59bRmKA)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* dest, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q src);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(NI, cmpCandidates__K2h4nBXAyIEnS4gvLx162g)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b);
N_LIB_PRIVATE N_NIMCALL(NI, checkGeneric__K2h4nBXAyIEnS4gvLx162g_2)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b);
N_LIB_PRIVATE N_NIMCALL(NI, complexDisambiguation__k9aBdDx9b2bJWirx4sqr6Jqg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b);
N_LIB_PRIVATE N_NIMCALL(NI, sumGeneric__thN9cO4mDmZW8QN0cIQUBlA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
static N_INLINE(NIM_BOOL, contains__RQ7v5MK0dOhApn0wj6F1iAsystem)(NI* a, NI aLen_0, NI item);
static N_INLINE(NI, find__9cqYOCx35UdU7TYhesWvYeAsystem)(NI* a, NI aLen_0, NI item);
N_LIB_PRIVATE N_NIMCALL(NI, getQuality__vHs9cON0sbP6NRfnEp9aW1yw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(void, suggestCall__VcXgzdApjYF6lYmfuQKAog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nameFits__aJoStyNeZRBrvbk5AX0UaA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argsFit__WujSFOET74uwiawdbvuemQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig);
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__BdjBO3HF6dSjQEzna7SJ1A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__KpVjtqarjr9c7ddovPDNqvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, NIM_BOOL diagnosticsEnabled);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, originatingModule__lIu8wX6Beq6dBJgESOFFjg_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, partialMatch__BxEsf1Gt7Hq3usrwPERzyA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, matchesAux__jWX5qJnM9cS16h0kw9aDyhrg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* marker);
N_LIB_PRIVATE N_NIMCALL(void, openShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, setSon__BZM7caO8KSYHHY8TNvb6UQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI at, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, arrayConstr__wDvUGprK4A7uVE8fdY6XSw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, NI64 first, NI64 last, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType);
N_LIB_PRIVATE N_NIMCALL(void, incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, prepareNamedParam__tMDbwsTYLLwCGe2R49c2n4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getNamedParamFromList__AuQyLRN9a3PM9cDeuxoao3hA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, prepareOperand__9bDDu8F9caJW9c9coOiby8kXyQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, arrayConstr__gCfYOEslDczkFV2a7yIcrw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, prepareOperand__lArHfX4A9cwcRE9cEIjQFVtA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(void, closeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_5)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c);
N_LIB_PRIVATE N_NIMCALL(void, suggestVar__1VfUSh4M09adXSHz7X3Fe9cA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs);
N_LIB_PRIVATE N_NIMCALL(void, produceOutput__QAZcajHr1x9cYjb78UsSezg)(tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** a, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(void, sort__9bZAwMDiICxVWu0iUtdMZaw)(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ** a, NI aLen_0, tyProc__pNH4eLNN9aK2oskAhILvUcw cmp, tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA order);
N_LIB_PRIVATE N_NIMCALL(NI, cmpSuggestions__a8u3Q3vmNopA4GVRUCtBuw)(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* a, tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* b);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__NAicU5bAGXmkx2NJujGi7g)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(void, suggestWriteln__NefEsy9c5k5U9cqqVIWMbpKg_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___MsqAj9adr5oy3fofpSrXHeA)(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* suggest);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___45FkS6XbvkDha3K7JLSsgQ)(tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuJoinSep)(NimStringDesc** a, NI aLen_0, NimStringDesc* sep);
N_LIB_PRIVATE N_NIMCALL(void, suggestQuit__5gyVlJxpO0KQGkItjZbJJg)(void);
static N_NIMCALL(void, Marker_tySequence__0dpGN6F4ocevqUQGsaf41w)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TRenderFlag__wrPgUo1ExBlHvFnXN2nSHw renderFlags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, argTypeToString__4EtZe89aZdrkU6I6iZJr4Yg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, suggestExpr__wb6KhAx6bZ5NV37kY4bXJw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q, newLineInfo__NPagzbOMpGo9aqJmfnDrITg)(NI32 fileInfoIdx, NI line, NI col);

/* section: NIM_merge_DATA */
extern TNimType NTI__IxbcvonC7TQkv166Uvdu1g_;
extern TNimType NTI__qG8FNvsuCmStKCBZxTA0eg_;
extern TNimType NTI__sM4lkSb7zS6F7OVMvW9cffQ_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__EV5hHJmjIY9cla9b9be7fSVJQ_3 = {
0x00, 0x00, 0x00, 0x00, 0x72, 0xed, 0x00, 0xf4,
0x01, 0x00, 0x00, 0x58, 0x00, 0x00, 0x00, 0x58,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
extern TNimType NTI__ytyiCJqK439aF9cIibuRVpAg_;
N_LIB_PRIVATE TNimType NTI__OOiDxDXQlxWHlb9aU1AkbWQ_;
extern TNimType NTI__xHTZrq9aYs6boc9bCba0JbpQ_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__AQEmz0epsPFaQWAZOZKqTA_;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__EV5hHJmjIY9cla9b9be7fSVJQ_8 = {
0x00, 0x00, 0x00, 0x00, 0x72, 0xef, 0x00, 0xf4,
0x01, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x78,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_9, "=", 1);
extern TNimType NTI__i7xpiUsxyv6cQ1xK3JbcGQ_;
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
extern NIM_CONST tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag abstractInst__dLigiD0wrfdW59cejPpTktA;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_10, "unknown", 7);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_11, "cannot infer the value of the static param \'", 44);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_12, "\'", 1);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_14, "/home/runner/work/nightlies/nightlies/nim/compiler/sigmatch.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_13 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 917),
((NI) 12)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_15, "wrong instantiated type!", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_16 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1525),
((NI) 23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_17 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1556),
((NI) 25)}
;
N_LIB_PRIVATE TNimType NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_;
extern TNimType NTI__AgIT5feFR9a9aoVjv9cx2rOtg_;
extern TNimType NTI__k2HFjxisIgDALbEUFojxaQ_;
N_LIB_PRIVATE TNimType NTI__T9cB3MofzwLcK9bH1dcRQNsg_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_19, " too nested for type matching", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_20 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 704),
((NI) 16)}
;
N_LIB_PRIVATE TNimType NTI__gOsvkY4zLbqYcgABB1VEQg_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__nl5fX6g5vxdA4inU5zASDQ_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_23, ":", 1);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_24, "Error:", 6);
static NIM_CONST tyProc__k2HFjxisIgDALbEUFojxaQ TM__EV5hHJmjIY9cla9b9be7fSVJQ_25 = {NIM_NIL,NIM_NIL};
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_27, "(", 1);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_28, ", ", 2);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_29, ")", 1);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_30 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1684),
((NI) 27)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_31, " unknown type kind ", 19);
extern TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_32 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1845),
((NI) 18)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_35, "getInstantiatedType", 19);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_36 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1872),
((NI) 17)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_37, "implicitConv", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_38 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 1885),
((NI) 37)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_41, "suggest.nim(517, 12) `result == nil or result.kind == nkPragma`"
" ", 64);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_42, "enum \'", 6);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_43, "\' which contains field \'", 24);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_44, "; ", 2);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_45, " is deprecated", 14);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_47, "/home/runner/work/nightlies/nightlies/nim/compiler/suggest.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_46 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_47),
((NI) 529),
((NI) 15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_48 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_47),
((NI) 531),
((NI) 9)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_49, "$1usage of \'$2\' is an {.error.} defined at $3", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_50 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_47),
((NI) 542),
((NI) 12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_51 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_47),
((NI) 544),
((NI) 6)}
;
N_LIB_PRIVATE TNimType NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_;
extern TNimType NTI__EjEifkTC8tg9afiUW4StSSA_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__C8RXb59bvbxaTzDOqx49aVVg_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__9aiv9bp2t5icFNINcg9c4xi1Q_;
extern TNimType NTI__shZhZOdbVC5nnFvcXQAImg_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_;
N_LIB_PRIVATE TNimType NTI__9a6KkG9auuBdYowCMkBNpD6w_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_60, "x.state is not csMatch", 22);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_61 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2234),
((NI) 21)}
;
static NIM_CONST tyArray__HU7qaqKu9czJLT84iCBJnsA TM__EV5hHJmjIY9cla9b9be7fSVJQ_62 = {((NI) 0),
((NI) 256)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_63, "sigmatch.nim(2357, 18) `n[a][0].kind == nkEmpty and n[a][1].kin"
"d in {nkBracket, nkArgList}` ", 92);
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_64, "named parameter has to be an identifier", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_65 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2374),
((NI) 18)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_66, "matches", 7);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_67 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2442),
((NI) 23)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_68, "cannot convert $1 to $2", 23);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_69 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2492),
((NI) 22)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_72, "skGlobalVar", 11);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_73, "skGlobalLet", 11);
extern TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_74, ".", 1);
extern TNimType NTI__Dkww2nY9cxJVLF9cfoQS5U6Q_;
N_LIB_PRIVATE TNimType NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_;
N_LIB_PRIVATE TNimType NTI__0dpGN6F4ocevqUQGsaf41w_;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_76, ": ", 2);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_77, " | ", 3);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_78, "void", 4);
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_79, "The default parameter \'$1\' has incompatible type with the expli"
"citly requested proc instantiation", 97);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_80 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2554),
((NI) 20)}
;
STRING_LITERAL(TM__EV5hHJmjIY9cla9b9be7fSVJQ_81, "cannot instantiate: \'", 21);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_82 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2596),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__EV5hHJmjIY9cla9b9be7fSVJQ_83 = {((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_14),
((NI) 2605),
((NI) 14)}
;

/* section: NIM_merge_VARS */
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern TSafePoint* excHandler__rqLlY5bs9atDw2OXYqJEn5g;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern Exception* currException__9bVPeDJlYTi9bQApZpfH8wjg;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__rqLlY5bs9atDw2OXYqJEn5g;
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__rqLlY5bs9atDw2OXYqJEn5g = (*excHandler__rqLlY5bs9atDw2OXYqJEn5g).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = (Exception*)0;
	result = currException__9bVPeDJlYTi9bQApZpfH8wjg;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__9bVPeDJlYTi9bQApZpfH8wjg), (*currException__9bVPeDJlYTi9bQApZpfH8wjg).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, safeSemExpr__wmMigIhDNhpgfhVcHQRifA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* volatile result;
	TSafePoint TM__EV5hHJmjIY9cla9b9be7fSVJQ_2;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	pushSafePoint(&TM__EV5hHJmjIY9cla9b9be7fSVJQ_2);
	TM__EV5hHJmjIY9cla9b9be7fSVJQ_2.status = setjmp(TM__EV5hHJmjIY9cla9b9be7fSVJQ_2.context);
	if (TM__EV5hHJmjIY9cla9b9be7fSVJQ_2.status == 0) {
	result = (*c).semExpr(c, n, 0);
	popSafePoint();
	}
	else {
		popSafePoint();
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTI__IxbcvonC7TQkv166Uvdu1g_))) {
			TM__EV5hHJmjIY9cla9b9be7fSVJQ_2.status = 0;
			result = (*(*c).graph).emptyNode;
			popCurrentException();
		}
	}
	if (TM__EV5hHJmjIY9cla9b9be7fSVJQ_2.status != 0) reraiseException();
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q, prefixMatch__9cyp8Sjrw866Z4MGxz0DeLg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q result;
	result = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		result = prefixMatch__pK9a9aTI3V8r6eOzZI8EfYlw((*(*n)._kind_5.ident).s, (*(*s).name).s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		result = prefixMatch__pK9a9aTI3V8r6eOzZI8EfYlw((*(*(*n)._kind_4.sym).name).s, (*(*s).name).s);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53):
	{
		{
			NI T6_;
			T6_ = (NI)0;
			T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T6_)) goto LA7_;
			result = prefixMatch__9cyp8Sjrw866Z4MGxz0DeLg(s, (*n)._kind_6.sons->data[((NI) 0)]);
		}
		LA7_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL, filterSym__bcqYtfxSrIczthAmGccX0Asigmatch)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q* res) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!!(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA3_;
		{
			if (!!((prefix == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA7_;
			(*res) = prefixMatch__9cyp8Sjrw866Z4MGxz0DeLg(s, prefix);
			result = !(((*res) == ((tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q) 0)));
		}
		goto LA5_;
		LA7_: ;
		{
			result = NIM_TRUE;
		}
		LA5_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NIM_BOOL, contains__RPVlURtov7G07Wgl1Pwc9cAsystem)(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA s, NI value) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (s.a <= value);
	if (!(T1_)) goto LA2_;
	T1_ = (value <= s.b);
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
static N_INLINE(void, appendChar)(NimStringDesc* dest, NIM_CHAR c) {
	(*dest).data[(*dest).Sup.len] = c;
	(*dest).data[(NI)((*dest).Sup.len + ((NI) 1))] = 0;
	(*dest).Sup.len += ((NI) 1);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.line));
	return result;
}
static N_INLINE(NI, toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	result = (NI)0;
	result = ((NI) (info.col));
	return result;
}
static N_NIMCALL(void, Marker_tyRef__AQEmz0epsPFaQWAZOZKqTA)(void* p, NI op) {
	tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ* a;
	a = (tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*)p;
	nimGCvisit((void*)(*a).line1, op);
}
N_LIB_PRIVATE N_CLOSURE(NIM_BOOL, isOpeningBacktick__MCqrgtCgrhBqRN307gIKtA)(NI col, void* ClE_0) {
	NIM_BOOL result;
	tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ* colonenvP_;
	result = (NIM_BOOL)0;
	colonenvP_ = (tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*) ClE_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI) 0) <= col);
		if (!(T3_)) goto LA4_;
		T3_ = (col < ((*colonenvP_).line1 ? (*colonenvP_).line1->Sup.len : 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyProc__cOOsXj9cY0bKt2oqNqLbhZw T11_;
			NIM_BOOL T12_;
			if (!((NU8)((*colonenvP_).line1->data[col]) == (NU8)(96))) goto LA9_;
			nimZeroMem((void*)(&T11_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
			T11_.ClP_0 = isOpeningBacktick__MCqrgtCgrhBqRN307gIKtA; T11_.ClE_0 = colonenvP_;
			T12_ = (NIM_BOOL)0;
			T12_ = T11_.ClE_0? T11_.ClP_0((NI)(col - ((NI) 1)), T11_.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_5)(T11_.ClP_0))((NI)(col - ((NI) 1)));
			result = !(T12_);
		}
		goto LA7_;
		LA9_: ;
		{
			tyProc__cOOsXj9cY0bKt2oqNqLbhZw T14_;
			nimZeroMem((void*)(&T14_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
			T14_.ClP_0 = isOpeningBacktick__MCqrgtCgrhBqRN307gIKtA; T14_.ClE_0 = colonenvP_;
			result = T14_.ClE_0? T14_.ClP_0((NI)(col - ((NI) 1)), T14_.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_6)(T14_.ClP_0))((NI)(col - ((NI) 1)));
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		result = NIM_FALSE;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, skipUntil__HcbgRIqguzsS4r2WE04C6gparseutils)(NimStringDesc* s, NIM_CHAR until, NI start) {
	NI result;
	result = (NI)0;
	result = ((NI) 0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((NI)(start + result) < (s ? s->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = !(((NU8)(s->data[(NI)(result + start)]) == (NU8)(until)));
			LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI) 1);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(NIM_CHAR, X5BX5D___okzHJ6GE9cv0bYG3b4r5KCAsystem)(NimStringDesc* s, NI i) {
	NIM_CHAR result;
	result = (NIM_CHAR)0;
	result = s->data[(NI)((s ? s->Sup.len : 0) - i)];
	return result;
}
static N_INLINE(NI, parseWhile__aIOGZyeHx2rHC71Dcc2SCwparseutils)(NimStringDesc* s, NimStringDesc** token, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw validChars, NI start) {
	NI result;
	NI i;
	result = (NI)0;
	i = start;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (i < (s ? s->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = ((validChars[(NU)(((NU8)(s->data[i])))>>3] &(1U<<((NU)(((NU8)(s->data[i])))&7U)))!=0);
			LA4_: ;
			if (!T3_) goto LA2;
			i += ((NI) 1);
		} LA2: ;
	}
	result = (NI)(i - start);
	fastSubstr__a88zu6ztJ3SBDTHcnqFjsg(s, token, start, result);
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___0oyFvH6YyZCaqn8h3bbKMwsystem)(NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = ((NI) 0);
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getTokenLenFromSource__Ag69bMcP2z1X5yPIF8diKPw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NI result;
	tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ* colonenv_;
	NI column;
	result = (NI)0;
	colonenv_ = (tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*)0;
	colonenv_ = (tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*) newObj((&NTI__AQEmz0epsPFaQWAZOZKqTA_), sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ));
	(*colonenv_).Sup.m_type = (&NTI__OOiDxDXQlxWHlb9aU1AkbWQ_);
	asgnRef((void**) (&(*colonenv_).line1), sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ(conf, info));
	column = toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs(info);
	{
		if (!(((*colonenv_).line1 ? (*colonenv_).line1->Sup.len : 0) < column)) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		tyProc__cOOsXj9cY0bKt2oqNqLbhZw T10_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = (((NI) 0) < column);
		if (!(T7_)) goto LA8_;
		T7_ = ((NU8)((*colonenv_).line1->data[(NI)(column - ((NI) 1))]) == (NU8)(96));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		nimZeroMem((void*)(&T10_), sizeof(tyProc__cOOsXj9cY0bKt2oqNqLbhZw));
		T10_.ClP_0 = isOpeningBacktick__MCqrgtCgrhBqRN307gIKtA; T10_.ClE_0 = colonenv_;
		T6_ = T10_.ClE_0? T10_.ClP_0((NI)(column - ((NI) 1)), T10_.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_7)(T10_.ClP_0))((NI)(column - ((NI) 1)));
		LA9_: ;
		if (!T6_) goto LA11_;
		result = skipUntil__HcbgRIqguzsS4r2WE04C6gparseutils((*colonenv_).line1, 96, column);
		{
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T15_;
			NimStringDesc* T16_;
			NI T17_;
			T15_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(column, (NI)((NI)(column + result) - ((NI) 1)));
			T16_ = (NimStringDesc*)0;
			T16_ = X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem((*colonenv_).line1, T15_);
			T17_ = (NI)0;
			T17_ = nsuCmpIgnoreStyle(T16_, ident);
			if (!!((T17_ == ((NI) 0)))) goto LA18_;
			result = ((NI) 0);
		}
		LA18_: ;
	}
	goto LA1_;
	LA11_: ;
	{
		NIM_BOOL T21_;
		NIM_CHAR T23_;
		T21_ = (NIM_BOOL)0;
		T21_ = (((NU8)(ident->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)(ident->data[((NI) 0)])) == ((NU8)(95)));
		if (!(T21_)) goto LA22_;
		T23_ = (NIM_CHAR)0;
		T23_ = X5BX5D___okzHJ6GE9cv0bYG3b4r5KCAsystem(ident, ((NI) 1));
		T21_ = !(((NU8)(T23_) == (NU8)(61)));
		LA22_: ;
		if (!T21_) goto LA24_;
		result = identLen__cr8f4oiC7y4wZkhdloxc7w((*colonenv_).line1, column);
		{
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T28_;
			NimStringDesc* T29_;
			NI T30_;
			T28_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(column, (NI)((NI)(column + result) - ((NI) 1)));
			T29_ = (NimStringDesc*)0;
			T29_ = X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem((*colonenv_).line1, T28_);
			T30_ = (NI)0;
			T30_ = nsuCmpIgnoreStyle(T29_, ident);
			if (!!((T30_ == ((NI) 0)))) goto LA31_;
			result = ((NI) 0);
		}
		LA31_: ;
	}
	goto LA1_;
	LA24_: ;
	{
		NimStringDesc* sourceIdent;
		sourceIdent = (NimStringDesc*)0;
		result = parseWhile__aIOGZyeHx2rHC71Dcc2SCwparseutils((*colonenv_).line1, (&sourceIdent), TM__EV5hHJmjIY9cla9b9be7fSVJQ_8, column);
		{
			NIM_BOOL T36_;
			NIM_CHAR T37_;
			T36_ = (NIM_BOOL)0;
			T37_ = (NIM_CHAR)0;
			T37_ = X5BX5D___okzHJ6GE9cv0bYG3b4r5KCAsystem(ident, ((NI) 1));
			T36_ = ((NU8)(T37_) == (NU8)(61));
			if (!(T36_)) goto LA38_;
			T36_ = (((NU8)(ident->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)(ident->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)(ident->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)(ident->data[((NI) 0)])) == ((NU8)(95)));
			LA38_: ;
			if (!T36_) goto LA39_;
			{
				if (!!(eqStrings(sourceIdent, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_9)))) goto LA43_;
				result = ((NI) 0);
			}
			LA43_: ;
		}
		goto LA34_;
		LA39_: ;
		{
			NIM_BOOL T46_;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T48_;
			NimStringDesc* T49_;
			T46_ = (NIM_BOOL)0;
			T46_ = ((ident ? ident->Sup.len : 0) < (sourceIdent ? sourceIdent->Sup.len : 0));
			if (!(T46_)) goto LA47_;
			T48_ = dotdot___0oyFvH6YyZCaqn8h3bbKMwsystem(((ident ? ident->Sup.len : 0)-1));
			T49_ = (NimStringDesc*)0;
			T49_ = X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem(sourceIdent, T48_);
			T46_ = eqStrings(T49_, ident);
			LA47_: ;
			if (!T46_) goto LA50_;
			result = (ident ? ident->Sup.len : 0);
		}
		goto LA34_;
		LA50_: ;
		{
			if (!!(eqStrings(sourceIdent, ident))) goto LA53_;
			result = ((NI) 0);
		}
		goto LA34_;
		LA53_: ;
		LA34_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*, symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, NIM_BOOL isLocal, tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ section, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI quality, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q prefix, NIM_BOOL inTypeContext, NI scope, NIM_BOOL useSuppliedInfo) {
	tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result;
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q infox;
	result = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
	result = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*) newObj((&NTI__qG8FNvsuCmStKCBZxTA0eg_), sizeof(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ));
	(*result).section = section;
	(*result).quality = quality;
	(*result).isGlobal = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0);
	(*result).prefix = prefix;
	(*result).contextFits = (inTypeContext == ((144 &((NU32)1<<((NU)((*s).kind)&31U)))!=0));
	(*result).scope = scope;
	(*result).name = (&(*(*s).name).s);
	(*result).symkind = ((NU8) ((*s).kind));
	{
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 30))&63U)))!=0))) goto LA3_;
		if ((*result).qualifiedPath) { nimGCunrefNoCycle((*result).qualifiedPath); (*result).qualifiedPath = NIM_NIL; }
		{
			NIM_BOOL T7_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ow;
			T7_ = (NIM_BOOL)0;
			T7_ = !(isLocal);
			if (!(T7_)) goto LA8_;
			T7_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
			LA8_: ;
			if (!T7_) goto LA9_;
			ow = (*s).owner;
			{
				NIM_BOOL T13_;
				NIM_BOOL T14_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ow2;
				NI T19_;
				NimStringDesc* T20_;
				T13_ = (NIM_BOOL)0;
				T14_ = (NIM_BOOL)0;
				T14_ = !((ow == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T14_)) goto LA15_;
				T14_ = !(((*ow).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
				LA15_: ;
				T13_ = T14_;
				if (!(T13_)) goto LA16_;
				T13_ = !(((*ow).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				LA16_: ;
				if (!T13_) goto LA17_;
				ow2 = (*ow).owner;
				asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T19_ = (*result).qualifiedPath->Sup.len++;
				T20_ = (NimStringDesc*)0;
				T20_ = (*result).qualifiedPath->data[T19_]; (*result).qualifiedPath->data[T19_] = copyStringRC1((*(*ow2).name).s);
				if (T20_) nimGCunrefNoCycle(T20_);
			}
			LA17_: ;
			{
				NI T25_;
				NimStringDesc* T26_;
				if (!!((ow == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA23_;
				asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T25_ = (*result).qualifiedPath->Sup.len++;
				T26_ = (NimStringDesc*)0;
				T26_ = (*result).qualifiedPath->data[T25_]; (*result).qualifiedPath->data[T25_] = copyStringRC1((*(*ow).name).s);
				if (T26_) nimGCunrefNoCycle(T26_);
			}
			LA23_: ;
		}
		LA9_: ;
		{
			NIM_BOOL T29_;
			tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T31_;
			NimStringDesc* T34_;
			NI T35_;
			NimStringDesc* T36_;
			T29_ = (NIM_BOOL)0;
			T29_ = ((TM__EV5hHJmjIY9cla9b9be7fSVJQ_3[(NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))>>3] &(1U<<((NU)(((NU8)((*(*s).name).s->data[((NI) 0)])))&7U)))!=0);
			if (T29_) goto LA30_;
			T31_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(((NI) 1), ((NI) 66));
			T29_ = contains__RPVlURtov7G07Wgl1Pwc9cAsystem(T31_, (*(*s).name).Sup.id);
			LA30_: ;
			if (!T29_) goto LA32_;
			T34_ = (NimStringDesc*)0;
			T34_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 2);
appendChar(T34_, 96);
appendString(T34_, (*(*s).name).s);
appendChar(T34_, 96);
			asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T35_ = (*result).qualifiedPath->Sup.len++;
			T36_ = (NimStringDesc*)0;
			T36_ = (*result).qualifiedPath->data[T35_]; (*result).qualifiedPath->data[T35_] = copyStringRC1(T34_);
			if (T36_) nimGCunrefNoCycle(T36_);
		}
		goto LA27_;
		LA32_: ;
		{
			NI T38_;
			NimStringDesc* T39_;
			asgnRef((void**) (&(*result).qualifiedPath), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*result).qualifiedPath), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T38_ = (*result).qualifiedPath->Sup.len++;
			T39_ = (NimStringDesc*)0;
			T39_ = (*result).qualifiedPath->data[T38_]; (*result).qualifiedPath->data[T38_] = copyStringRC1((*(*s).name).s);
			if (T39_) nimGCunrefNoCycle(T39_);
		}
		LA27_: ;
		{
			if (!!(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA42_;
			asgnRef((void**) (&(*result).forth), typeToString__QlvraUan7WbHowhAbvDvdA((*s).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0)));
		}
		goto LA40_;
		LA42_: ;
		{
			asgnRef((void**) (&(*result).forth), ((NimStringDesc*) NIM_NIL));
		}
		LA40_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T47_;
		T47_ = (NIM_BOOL)0;
		T47_ = useSuppliedInfo;
		if (T47_) goto LA48_;
		T47_ = ((784 &((NU16)1<<((NU)(section)&15U)))!=0);
		LA48_: ;
		if (!T47_) goto LA49_;
		infox = info;
	}
	goto LA45_;
	LA49_: ;
	{
		infox = (*s).info;
	}
	LA45_: ;
	asgnRef((void**) (&(*result).filePath), toFullPath__VW1RaR1l9c9bPnJxr1KuvIrg(conf, infox.fileIndex));
	(*result).line = toLinenumber__6D4Rmpw7LpcRI1j7CMqEsAmsgs(infox);
	(*result).column = toColumn__6D4Rmpw7LpcRI1j7CMqEsA_2msgs(infox);
	(*result).version = (*conf).suggestVersion;
	{
		if (!!((section == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 8)))) goto LA54_;
		(*result).tokenLen = ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0);
	}
	goto LA52_;
	LA54_: ;
	{
		(*result).tokenLen = getTokenLenFromSource__Ag69bMcP2z1X5yPIF8diKPw(conf, (*(*s).name).s, infox);
	}
	LA52_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestEverything__CNgl7zyt4docO57SnwwZuQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	NIM_BOOL isLocal;
	NI scopeN;
	isLocal = NIM_TRUE;
	scopeN = ((NI) 0);
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA6_;
					isLocal = NIM_FALSE;
				}
				LA6_: ;
				scopeN -= ((NI) 1);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it_2;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					it = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it_2), (*scope).symbols);
					{
						while (1) {
							tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
							it = s;
							pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
							{
								NIM_BOOL T13_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T16_;
								NI T17_;
								T13_ = (NIM_BOOL)0;
								T13_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(it, f, (&pm));
								if (!T13_) goto LA14_;
								T16_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T16_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it, isLocal, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), (*n).info, ((NI) 0), pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T17_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T17_]), T16_);
							}
							LA14_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it_2), (*scope).symbols);
						} LA10: ;
					}
				}
				current = (*current).parent;
			} LA3: ;
		}
	}
}
static N_INLINE(NIM_BOOL, fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* f) {
	NIM_BOOL result;
	NI fmoduleId;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(f);
	fmoduleId = (*T1_).Sup.id;
	T2_ = (NIM_BOOL)0;
	T2_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 1))&63U)))!=0);
	if (T2_) goto LA3_;
	T2_ = (fmoduleId == (*(*c).module).Sup.id);
	LA3_: ;
	result = T2_;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w** module;
		NI i;
		NI L;
		NI T5_;
		module = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w**)0;
		i = ((NI) 0);
		T5_ = ((*c).friendModules ? (*c).friendModules->Sup.len : 0);
		L = T5_;
		{
			while (1) {
				if (!(i < L)) goto LA7;
				module = &(*c).friendModules->data[i];
				{
					if (!(fmoduleId == (*(*module)).Sup.id)) goto LA10_;
					result = NIM_TRUE;
					goto LA4;
				}
				LA10_: ;
				i += ((NI) 1);
			} LA7: ;
		}
	} LA4: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestField__eY0NQ17HSi1QPRouRIEVXg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
	pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
	{
		NIM_BOOL T3_;
		tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(s, f, (&pm));
		if (!(T3_)) goto LA4_;
		T3_ = fieldVisible__9bfgTfDbdDjqc3nAFjdnkKwsigmatch(c, s);
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
		T7_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, s, NIM_TRUE, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), info, ((NI) 100), pm, (((NI) 0) < (*c).inTypeContext), ((NI) 0), NIM_FALSE);
		unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
		T8_ = (*outputs)->Sup.len++;
		asgnRef((void**) (&(*outputs)->data[T8_]), T7_);
	}
	LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestSymList__Kt0rYFU9b6Yu9b2P7xFWUJ7A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* list, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(list);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!((*(*list)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA6_;
					suggestField__eY0NQ17HSi1QPRouRIEVXg(c, (*(*list)._kind_6.sons->data[i])._kind_4.sym, f, info, outputs);
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(NIM_BOOL, filterSymNoOpr__bcqYtfxSrIczthAmGccX0A_2sigmatch)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix, tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q* res) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(s, prefix, res);
	if (!(T2_)) goto LA3_;
	T2_ = (((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(255)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = isKeyword__N1ZnIJchVZRKfKk15xA7QQ((*s).name);
	T1_ = !(T5_);
	LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, initCandidateAux__kxeVK8KvdIa8ne7AuBlgnQsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee) {
	tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ T1_;
	unsureAsgnRef((void**) (&(*c).c), ctx);
	(*c).exactMatches = ((NI) 0);
	(*c).subtypeMatches = ((NI) 0);
	(*c).convMatches = ((NI) 0);
	(*c).intConvMatches = ((NI) 0);
	(*c).genericMatches = ((NI) 0);
	(*c).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ));
	(*c).firstMismatch.kind = T1_.kind;
	(*c).firstMismatch.arg = T1_.arg;
	unsureAsgnRef((void**) (&(*c).firstMismatch.formal), T1_.formal);
	unsureAsgnRef((void**) (&(*c).callee), callee);
	unsureAsgnRef((void**) (&(*c).call), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	(*c).baseTypeMatch = NIM_FALSE;
	(*c).genericConverter = NIM_FALSE;
	(*c).inheritancePenalty = ((NI) 0);
}
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__GPx9buyQn9cq0nARN4Amyarw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee) {
	initCandidateAux__kxeVK8KvdIa8ne7AuBlgnQsigmatch(ctx, c, callee);
	unsureAsgnRef((void**) (&(*c).calleeSym), ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL));
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&(*c).bindings));
}
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__rFFaxk6TYVlvnKNibvVmkg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* callee, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initCandidate__GPx9buyQn9cq0nARN4Amyarw(ctx, Result, callee);
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((IL64(70866960384) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = copyType__4O4aYoscFPo2FRSh4rP9ayg(t, (*t).owner, NIM_FALSE);
		asgnRef((void**) (&(*result).n), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	}
	goto LA1_;
	LA5_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* key, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* val) {
	tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	RootObj* T3_;
	T1_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
	T1_ = &key->Sup;
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(val);
	T3_ = (RootObj*)0;
	T3_ = &T2_->Sup.Sup;
	idTablePut__anELyz7VLsjbCIoxLpxbfQ((&(*c).bindings), T1_, T3_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NIM_BOOL allowUnresolved) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* instantiated;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	instantiated = replaceTypesInBody__JQMwbj1fgdFwBCg7mhUBRQ((*c).c, (*c).bindings, n, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), allowUnresolved);
	result = (*(*c).c).semExpr((*c).c, instantiated, 0);
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldSkipDistinct__nU6tuBd3HbyqPo9a608qr9aA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* rules, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* callIdent) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!((*rules).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 130))) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r;
			r = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(rules);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						r = (*rules)._kind_6.sons->data[i];
						{
							tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T11_;
							T11_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
							T11_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*m).c, r, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
							if (!(T11_ == callIdent)) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
						LA12_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* r_2;
			r_2 = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(rules);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA18;
						i_3 = i_4;
						r_2 = (*rules)._kind_6.sons->data[i_3];
						{
							tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T21_;
							T21_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
							T21_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw((*m).c, r_2, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
							if (!(T21_ == callIdent)) goto LA22_;
							result = NIM_FALSE;
							goto BeforeRet_;
						}
						LA22_: ;
						i_4 += ((NI) 1);
					} LA18: ;
				}
			}
		}
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, maybeSkipDistinct__81UcA7TE8rJ8Gai4W1iW9cg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = shouldSkipDistinct__nU6tuBd3HbyqPo9a608qr9aA(m, (*t).n, (*callee).name);
		LA8_: ;
		if (!T3_) goto LA9_;
		result = base__PfgI9ap7WOnsRfFV4znQ27w(t);
	}
	goto LA1_;
	LA9_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, sameEnumTypes__aVVjNzmtPf6fjiBzSvfSQg_2types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*a).Sup.id == (*b).Sup.id);
	return result;
}
N_LIB_PRIVATE N_NOINLINE(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, typeRangeRel__w3WJH5XKeovEI9cb9cseqgmQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(f, NIM_FALSE);
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T9_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T10_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T12_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T13_;
			T8_ = (NIM_BOOL)0;
			T9_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T10_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T8_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T9_, T10_);
			if (!(T8_)) goto LA11_;
			T12_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T13_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T8_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T12_, T13_);
			LA11_: ;
			if (!T8_) goto LA14_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		goto LA6_;
		LA14_: ;
		{
			NIM_BOOL T17_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T18_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T19_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T21_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T22_;
			T17_ = (NIM_BOOL)0;
			T18_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T19_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T17_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T18_, T19_);
			if (!(T17_)) goto LA20_;
			T21_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T22_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T17_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T21_, T22_);
			LA20_: ;
			if (!T17_) goto LA23_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA6_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T27_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T28_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T30_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T31_;
			T26_ = (NIM_BOOL)0;
			T27_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T28_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T26_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T27_, T28_);
			if (!(T26_)) goto LA29_;
			T30_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T31_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), a);
			T26_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T30_, T31_);
			LA29_: ;
			if (!T26_) goto LA32_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA6_;
		LA32_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		{
			NIM_BOOL T38_;
			NF T39_;
			NF T40_;
			NF T42_;
			NF T43_;
			T38_ = (NIM_BOOL)0;
			T39_ = (NF)0;
			T39_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(a);
			T40_ = (NF)0;
			T40_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(f);
			T38_ = (T39_ == T40_);
			if (!(T38_)) goto LA41_;
			T42_ = (NF)0;
			T42_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(a);
			T43_ = (NF)0;
			T43_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(f);
			T38_ = (T42_ == T43_);
			LA41_: ;
			if (!T38_) goto LA44_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		goto LA36_;
		LA44_: ;
		{
			NIM_BOOL T47_;
			NF T48_;
			NF T49_;
			NF T51_;
			NF T52_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NF)0;
			T48_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(f);
			T49_ = (NF)0;
			T49_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(a);
			T47_ = (T48_ <= T49_);
			if (!(T47_)) goto LA50_;
			T51_ = (NF)0;
			T51_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(a);
			T52_ = (NF)0;
			T52_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(f);
			T47_ = (T51_ <= T52_);
			LA50_: ;
			if (!T47_) goto LA53_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA36_;
		LA53_: ;
		{
			NIM_BOOL T56_;
			NF T57_;
			NF T58_;
			NF T60_;
			NF T61_;
			T56_ = (NIM_BOOL)0;
			T57_ = (NF)0;
			T57_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(a);
			T58_ = (NF)0;
			T58_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(f);
			T56_ = (T57_ <= T58_);
			if (!(T56_)) goto LA59_;
			T60_ = (NF)0;
			T60_ = firstFloat__5WwccqVm6xApk9c8p9c1efRA(f);
			T61_ = (NF)0;
			T61_ = lastFloat__5WwccqVm6xApk9c8p9c1efRA_2(a);
			T56_ = (T60_ <= T61_);
			LA59_: ;
			if (!T56_) goto LA62_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA36_;
		LA62_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA36_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConvertibleToRange__je559cQ286PtxNuVoMCjyww)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((IL64(34151432454144) &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = ((IL64(34151432454144) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		switch ((*f).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T8_) goto LA9_;
			T8_ = ((IL64(4294967296) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA9_: ;
			result = T8_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T11_) goto LA12_;
			T11_ = ((IL64(12884901888) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA12_: ;
			result = T11_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T14_) goto LA15_;
			T14_ = ((IL64(30064771072) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA15_: ;
			result = T14_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
		{
			result = NIM_TRUE;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T18_) goto LA19_;
			T18_ = ((IL64(66571993088) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA19_: ;
			result = T18_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41):
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T21_) goto LA22_;
			T21_ = ((IL64(2199023255552) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA22_: ;
			result = T21_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42):
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T24_) goto LA25_;
			T24_ = ((IL64(6597069766656) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA25_: ;
			result = T24_;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
		{
			NIM_BOOL T27_;
			T27_ = (NIM_BOOL)0;
			T27_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
			if (T27_) goto LA28_;
			T27_ = ((IL64(15393162788864) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
			LA28_: ;
			result = T27_;
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T33_;
		if (!((IL64(1030792151040) &((NU64)1<<((NU)((*f).kind)&63U)))!=0)) goto LA31_;
		T33_ = (NIM_BOOL)0;
		T33_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(a);
		if (T33_) goto LA34_;
		T33_ = ((IL64(1030792151040) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
		LA34_: ;
		result = T33_;
	}
	goto LA1_;
	LA31_: ;
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag min, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag max) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		if (!((*a).kind == (*f).kind)) goto LA3_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ab;
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k;
		ab = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, 1048576);
		k = (*ab).kind;
		{
			if (!(k == (*f).kind)) goto LA8_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4);
		}
		goto LA6_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			NIM_BOOL T14_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T18_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T19_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T21_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T22_;
			T11_ = (NIM_BOOL)0;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T14_ = (NIM_BOOL)0;
			T14_ = (k == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
			if (!(T14_)) goto LA15_;
			T14_ = ((IL64(34149286019072) &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
			LA15_: ;
			T13_ = T14_;
			if (!(T13_)) goto LA16_;
			T13_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(ab);
			LA16_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA17_;
			T18_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T19_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw((*ab).n);
			T12_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T18_, T19_);
			LA17_: ;
			T11_ = T12_;
			if (!(T11_)) goto LA20_;
			T21_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw((*ab).n);
			T22_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T11_ = lteq___7c5Zw7H31uJfWmmhZe9aEqw_2(T21_, T22_);
			LA20_: ;
			if (!T11_) goto LA23_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 9);
		}
		goto LA6_;
		LA23_: ;
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31));
			if (!(T26_)) goto LA27_;
			T26_ = ((IL64(30064771072) &((NU64)1<<((NU)(k)&63U)))!=0);
			LA27_: ;
			if (!T26_) goto LA28_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2);
		}
		goto LA6_;
		LA28_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40));
			if (!(T31_)) goto LA32_;
			T31_ = ((IL64(15393162788864) &((NU64)1<<((NU)(k)&63U)))!=0);
			LA32_: ;
			if (!T31_) goto LA33_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2);
		}
		goto LA6_;
		LA33_: ;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = (min <= k);
			if (!(T36_)) goto LA37_;
			T36_ = (k <= max);
			LA37_: ;
			if (!T36_) goto LA38_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA6_;
		LA38_: ;
		{
			NIM_BOOL T41_;
			NIM_BOOL T42_;
			NIM_BOOL T43_;
			NIM_BOOL T45_;
			NIM_BOOL T46_;
			NIM_BOOL T49_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T52_;
			tyObject_Int128__9a9axPfb75jdWY25AamJewkA T54_;
			T41_ = (NIM_BOOL)0;
			T42_ = (NIM_BOOL)0;
			T43_ = (NIM_BOOL)0;
			T43_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20));
			if (!(T43_)) goto LA44_;
			T45_ = (NIM_BOOL)0;
			T46_ = (NIM_BOOL)0;
			T46_ = ((IL64(66571993088) &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
			if (!(T46_)) goto LA47_;
			T46_ = ((IL64(66571993088) &((NU64)1<<((NU)((*(*a).sons->data[((NI) 0)]).kind)&63U)))!=0);
			LA47_: ;
			T45_ = T46_;
			if (T45_) goto LA48_;
			T49_ = (NIM_BOOL)0;
			T49_ = ((IL64(15393162788864) &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
			if (!(T49_)) goto LA50_;
			T49_ = ((0 &((NU64)1<<((NU)((*(*a).sons->data[((NI) 0)]).kind)&63U)))!=0);
			LA50_: ;
			T45_ = T49_;
			LA48_: ;
			T43_ = T45_;
			LA44_: ;
			T42_ = T43_;
			if (!(T42_)) goto LA51_;
			T52_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T42_ = lteq___nr9cP9b0OL9cabygV9bo19cJgZA(T52_, (*(*(*a).n)._kind_6.sons->data[((NI) 0)])._kind_1.intVal);
			LA51_: ;
			T41_ = T42_;
			if (!(T41_)) goto LA53_;
			T54_ = lastOrd__hjogdnp59cMX1rwmjikBhqw_2(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), f);
			T41_ = lteq___xL5gyZrjbGMarSdRAXOo9ag((*(*(*a).n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal, T54_);
			LA53_: ;
			if (!T41_) goto LA55_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA6_;
		LA55_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA6_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isFloatLit__F9ciDIanrWYqbJ4rgLlNAAg_2types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t).n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		if (!((*a).kind == (*f).kind)) goto LA3_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ab;
		tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag k;
		ab = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, 1048576);
		k = (*ab).kind;
		{
			if (!(k == (*f).kind)) goto LA8_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4);
		}
		goto LA6_;
		LA8_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isFloatLit__F9ciDIanrWYqbJ4rgLlNAAg_2types(ab);
			if (!T11_) goto LA12_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 9);
		}
		goto LA6_;
		LA12_: ;
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = isIntLit__F9ciDIanrWYqbJ4rgLlNAAgtypes(ab);
			if (!T15_) goto LA16_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		goto LA6_;
		LA16_: ;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = (((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) <= k);
			if (!(T19_)) goto LA20_;
			T19_ = (k <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39));
			LA20_: ;
			if (!T19_) goto LA21_;
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37))) goto LA25_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA23_;
			LA25_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2);
			}
			LA23_: ;
		}
		goto LA6_;
		LA21_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA6_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCovariantPtr__OS0a7EtgsSjPvphc5aG65w)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*f).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		NIM_BOOL T2_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T5_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T7_;
		T2_ = (NIM_BOOL)0;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
		T2_ = !(((IL64(175921875124224) &((NU64)1<<((NU)((*T3_).kind)&63U)))!=0));
		if (!(T2_)) goto LA4_;
		T5_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T5_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
		T7_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
		T7_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T5_, T6_, 2);
		T2_ = (T7_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3));
		LA4_: ;
		result = T2_;
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* body;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
		NI T14_;
		NIM_BOOL T17_;
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T19_;
		body = base__PfgI9ap7WOnsRfFV4znQ27w(f);
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T12_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
		T11_ = (body == T12_);
		if (!(T11_)) goto LA13_;
		T14_ = (NI)0;
		T14_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
		T11_ = (T14_ == ((NI) 3));
		LA13_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA15_;
		T10_ = !((((*(*body).sons->data[((NI) 0)]).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 36))&63U)))!=0));
		LA15_: ;
		T9_ = T10_;
		if (!(T9_)) goto LA16_;
		T17_ = (NIM_BOOL)0;
		T17_ = !(((IL64(175921875124224) &((NU64)1<<((NU)((*(*f).sons->data[((NI) 1)]).kind)&63U)))!=0));
		if (!(T17_)) goto LA18_;
		T19_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
		T19_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[((NI) 1)], (*a).sons->data[((NI) 1)], 2);
		T17_ = (T19_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3));
		LA18_: ;
		T9_ = T17_;
		LA16_: ;
		result = T9_;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inferStaticParam__Fz18GssDhipSzpDxzhkUXw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lhs, NI64 rhs) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*lhs)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA4_: ;
		if (!T3_) goto LA5_;
		switch ((*(*(*lhs)._kind_6.sons->data[((NI) 0)])._kind_4.sym).magic) {
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 46):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 65):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 29):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 51):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA10_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)(rhs - (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA8_;
			LA10_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA13_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs - (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA8_;
			LA13_: ;
			LA8_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 30):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 47):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 66):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 52):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA18_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal - rhs));
				goto BeforeRet_;
			}
			goto LA16_;
			LA18_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA21_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs + (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
				goto BeforeRet_;
			}
			goto LA16_;
			LA21_: ;
			LA16_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 48):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 67):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA26_;
				{
					if (!((NI64)(rhs % (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal) == IL64(0))) goto LA30_;
					result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)(rhs / (*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal));
					goto BeforeRet_;
				}
				LA30_: ;
			}
			goto LA24_;
			LA26_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA33_;
				{
					if (!((NI64)(rhs % (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal) == IL64(0))) goto LA37_;
					result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)(rhs / (*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal));
					goto BeforeRet_;
				}
				LA37_: ;
			}
			goto LA24_;
			LA33_: ;
			LA24_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 49):
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 68):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA42_;
				{
					if (!((NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal % rhs) == IL64(0))) goto LA46_;
					result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 2)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 1)])._kind_1.intVal / rhs));
					goto BeforeRet_;
				}
				LA46_: ;
			}
			goto LA40_;
			LA42_: ;
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA49_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal * rhs));
				goto BeforeRet_;
			}
			goto LA40_;
			LA49_: ;
			LA40_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 58):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA54_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NI64)(rhs) >> (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA54_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 57):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA59_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NU64)(rhs) << (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA59_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 59):
		{
			{
				if (!((*(*lhs)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA64_;
				result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], (NI64)((NI64)(rhs) >> (NU64)((*(*lhs)._kind_6.sons->data[((NI) 2)])._kind_1.intVal)));
				goto BeforeRet_;
			}
			LA64_: ;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 93):
		{
			result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], -(rhs));
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 97):
		{
			result = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, (*lhs)._kind_6.sons->data[((NI) 1)], rhs);
			goto BeforeRet_;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	goto LA1_;
	LA5_: ;
	{
		NIM_BOOL T70_;
		NIM_BOOL T71_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inferred;
		T70_ = (NIM_BOOL)0;
		T71_ = (NIM_BOOL)0;
		T71_ = ((*lhs).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T71_)) goto LA72_;
		T71_ = ((*(*lhs).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
		LA72_: ;
		T70_ = T71_;
		if (!(T70_)) goto LA73_;
		T70_ = ((*(*lhs).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		LA73_: ;
		if (!T70_) goto LA74_;
		inferred = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q((*c).c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), (*(*lhs).typ).sons);
		asgnRef((void**) (&(*inferred).n), newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), rhs));
		put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, (*lhs).typ, inferred);
		{
			if (!!(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)))) goto LA78_;
			asgnRef((void**) (&(*(*lhs).typ).n), (*inferred).n);
		}
		LA78_: ;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA74_: ;
	LA1_: ;
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, failureToInferStaticParam__2rPrKzcn1sisAtRnbza1NA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* staticParam;
	NimStringDesc* name;
	NimStringDesc* T6_;
	staticParam = findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2(n);
	{
		if (!!((staticParam == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		name = (*(*(*staticParam)._kind_4.sym).name).s;
	}
	goto LA1_;
	LA3_: ;
	{
		name = copyString(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_10));
	}
	LA1_: ;
	T6_ = (NimStringDesc*)0;
	T6_ = rawNewString((name ? name->Sup.len : 0) + 45);
appendString(T6_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_11));
appendString(T6_, name);
appendString(T6_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_12));
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_13, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, inferStaticsInRange__hRaLa1Ge0r7UTGASvA1ocQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inferred, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lowerBound;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* upperBound;
{	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	lowerBound = tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw(c, (*(*inferred).n)._kind_6.sons->data[((NI) 0)], NIM_TRUE);
	upperBound = tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw(c, (*(*inferred).n)._kind_6.sons->data[((NI) 1)], NIM_TRUE);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* expX60gensym228_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA rhsX60gensym228_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T16_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T17_;
		if (!((*lowerBound).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA3_;
		{
			if (!((*upperBound).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA7_;
			{
				tyObject_Int128__9a9axPfb75jdWY25AamJewkA T11_;
				NIM_BOOL T12_;
				T11_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c).c).graph).config, concrete);
				T12_ = (NIM_BOOL)0;
				T12_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T11_, (NI64)((NI64)((*upperBound)._kind_1.intVal - (*lowerBound)._kind_1.intVal) + IL64(1)));
				if (!T12_) goto LA13_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				goto BeforeRet_;
			}
			goto LA9_;
			LA13_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				goto BeforeRet_;
			}
			LA9_: ;
		}
		LA7_: ;
		expX60gensym228_ = upperBound;
		T16_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c).c).graph).config, concrete);
		T17_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(T16_, (*lowerBound)._kind_1.intVal);
		rhsX60gensym228_ = minus___hiijuMqvH9aC9aKmwIYuqUAA(T17_, IL64(1));
		{
			NI64 T20_;
			NIM_BOOL T21_;
			T20_ = (NI64)0;
			T20_ = toInt64__1szweXXq3RBN50owrYu2Xw(rhsX60gensym228_);
			T21_ = (NIM_BOOL)0;
			T21_ = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, expX60gensym228_, T20_);
			if (!T21_) goto LA22_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		goto LA18_;
		LA22_: ;
		{
			failureToInferStaticParam__2rPrKzcn1sisAtRnbza1NA((*(*(*c).c).graph).config, expX60gensym228_);
		}
		LA18_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* expX60gensym231_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA rhsX60gensym231_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T28_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T29_;
		tyObject_Int128__9a9axPfb75jdWY25AamJewkA T30_;
		if (!((*upperBound).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6))) goto LA26_;
		expX60gensym231_ = lowerBound;
		T28_ = getInt__Ml9bTZ5dXYSLBfnGRkErokw(upperBound);
		T29_ = plus___hiijuMqvH9aC9aKmwIYuqUAA_2(T28_, IL64(1));
		T30_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c).c).graph).config, concrete);
		rhsX60gensym231_ = minus___Sp7OcCEIFoBYolB6PB1fAg_2(T29_, T30_);
		{
			NI64 T33_;
			NIM_BOOL T34_;
			T33_ = (NI64)0;
			T33_ = toInt64__1szweXXq3RBN50owrYu2Xw(rhsX60gensym231_);
			T34_ = (NIM_BOOL)0;
			T34_ = inferStaticParam__Fz18GssDhipSzpDxzhkUXw(c, expX60gensym231_, T33_);
			if (!T34_) goto LA35_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		goto LA31_;
		LA35_: ;
		{
			failureToInferStaticParam__2rPrKzcn1sisAtRnbza1NA((*(*(*c).c).graph).config, expX60gensym231_);
		}
		LA31_: ;
	}
	goto LA1_;
	LA26_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		if (!!((((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0))) goto LA3_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, allowsNilDeprecated__AbnwgaBsy37utKNens69aOg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		if (!(((*(*(*(*c).c).graph).config).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 25))&31U)))!=0)) goto LA3_;
		result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
	}
	goto LA1_;
	LA3_: ;
	{
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, minRel__7YozvgTVcSzTGrASvCO0ZA)(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ a, tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ b) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	{
		if (!(a <= b)) goto LA3_;
		result = a;
	}
	goto LA1_;
	LA3_: ;
	{
		result = b;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, recordRel__jLWLF6Jks9cJgmPzh2I6lSg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
{	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameType__3isNyHKb0U1OCnClmflXSg(f, a, 0);
		if (!T3_) goto LA4_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
	}
	goto LA1_;
	LA4_: ;
	{
		NI T7_;
		NI T8_;
		NI firstField;
		T7_ = (NI)0;
		T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
		T8_ = (NI)0;
		T8_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
		if (!(T7_ == T8_)) goto LA9_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA13_;
			firstField = ((NI) 0);
		}
		goto LA11_;
		LA13_: ;
		{
			firstField = ((NI) 1);
		}
		LA11_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			i_2 = firstField;
			{
				while (1) {
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ m;
					if (!(i_2 < colontmp_)) goto LA18;
					i = i_2;
					m = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[i], (*a).sons->data[i], 0);
					{
						if (!(m < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3))) goto LA21_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
						goto BeforeRet_;
					}
					LA21_: ;
					result = minRel__7YozvgTVcSzTGrASvCO0ZA(result, m);
					i_2 += ((NI) 1);
				} LA18: ;
			}
		}
		{
			NIM_BOOL T25_;
			T25_ = (NIM_BOOL)0;
			T25_ = !(((*f).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T25_)) goto LA26_;
			T25_ = !(((*a).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA26_: ;
			if (!T25_) goto LA27_;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast((*f).n);
				i_4 = ((NI) 0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA31;
						i_3 = i_4;
						{
							if (!!(((*(*(*f).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA34_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						goto LA32_;
						LA34_: ;
						{
							if (!!(((*(*(*a).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA37_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						goto LA32_;
						LA37_: ;
						{
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* x;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* y;
							x = (*(*(*f).n)._kind_6.sons->data[i_3])._kind_4.sym;
							y = (*(*(*a).n)._kind_6.sons->data[i_3])._kind_4.sym;
							{
								NIM_BOOL T42_;
								tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T44_;
								T42_ = (NIM_BOOL)0;
								T42_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
								if (!(T42_)) goto LA43_;
								T44_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
								T44_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*x).typ, (*y).typ, 0);
								T42_ = (T44_ < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3));
								LA43_: ;
								if (!T42_) goto LA45_;
								result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
								goto BeforeRet_;
							}
							LA45_: ;
							{
								if (!!(((*(*x).name).Sup.id == (*(*y).name).Sup.id))) goto LA49_;
								result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
								goto BeforeRet_;
							}
							LA49_: ;
						}
						LA32_: ;
						i_4 += ((NI) 1);
					} LA31: ;
				}
			}
		}
		LA27_: ;
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genericParamPut__z5a4ZOu3KDJ5RptiscEp5g)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* last, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin) {
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !((fGenericOrigin == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*last).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast(last);
		T8_ = (NI)0;
		T8_ = len__5mJADrRYkP3r9auuiuDZN9cQast(fGenericOrigin);
		T3_ = ((NI)(T7_ - ((NI) 1)) == T8_);
		LA6_: ;
		if (!T3_) goto LA9_;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(fGenericOrigin);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x;
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T14_;
					RootObj* T15_;
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					T14_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T14_ = &(*fGenericOrigin).sons->data[i]->Sup;
					T15_ = (RootObj*)0;
					T15_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T14_);
					x = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T15_));
					{
						if (!(x == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA18_;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, (*fGenericOrigin).sons->data[i], (*last).sons->data[i]);
					}
					LA18_: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, isObjectSubtype__C1JCauhsK9aI1g4xqINNSyQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin) {
	NI result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	NI depth;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* last;
	result = (NI)0;
	t = a;
	depth = ((NI) 0);
	last = a;
	{
		while (1) {
			NIM_BOOL T3_;
			NIM_BOOL T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T5_ = (NIM_BOOL)0;
			T5_ = sameObjectTypes__6sVmgh7vIWM9axOIPRliopQ(f, t);
			T3_ = !(T5_);
			LA4_: ;
			if (!T3_) goto LA2;
			t = (*t).sons->data[((NI) 0)];
			{
				if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA8_;
				goto LA1;
			}
			LA8_: ;
			last = t;
			t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36275087638268176));
			depth += ((NI) 1);
		} LA2: ;
	} LA1: ;
	{
		if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA12_;
		genericParamPut__z5a4ZOu3KDJ5RptiscEp5g(c, last, fGenericOrigin);
		result = depth;
	}
	goto LA10_;
	LA12_: ;
	{
		result = ((NI) -1);
	}
	LA10_: ;
	return result;
}
static N_INLINE(NIM_BOOL, sameDistinctTypes__aVVjNzmtPf6fjiBzSvfSQg_3types)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = sameObjectTypes__6sVmgh7vIWM9axOIPRliopQ(a, b);
	return result;
}
static N_INLINE(NIM_BOOL, inconsistentVarTypes__tUOqr3q1OVzVDquDgQiutwsigmatch)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*f).kind == (*a).kind));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((IL64(211106240921600) &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
	if (T3_) goto LA4_;
	T3_ = ((IL64(211106240921600) &((NU64)1<<((NU)((*a).kind)&63U)))!=0);
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, procParamTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_3)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f_2;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a_2;
{	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	f_2 = f;
	a_2 = a;
	{
		NIM_BOOL T3_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aResolved;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T6_;
		RootObj* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(a_2);
		if (!T3_) goto LA4_;
		T6_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T6_ = &a_2->Sup;
		T7_ = (RootObj*)0;
		T7_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T6_);
		aResolved = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T7_));
		{
			if (!!((aResolved == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA10_;
			a_2 = aResolved;
		}
		LA10_: ;
	}
	LA4_: ;
	{
		NIM_BOOL T14_;
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ reverseRel;
		T14_ = (NIM_BOOL)0;
		T14_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(a_2);
		if (!T14_) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(f_2);
			if (!T19_) goto LA20_;
			{
				if (!!(((*c).call == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA24_;
				f_2 = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg((*c).c, (*c).bindings, (*(*c).call).info, f_2);
			}
			goto LA22_;
			LA24_: ;
			{
				f_2 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
			}
			LA22_: ;
			{
				NIM_BOOL T29_;
				T29_ = (NIM_BOOL)0;
				T29_ = (f_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				if (T29_) goto LA30_;
				T29_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(f_2);
				LA30_: ;
				if (!T29_) goto LA31_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5);
				goto BeforeRet_;
			}
			LA31_: ;
		}
		LA20_: ;
		reverseRel = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, a_2, f_2, 0);
		{
			if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= reverseRel)) goto LA35_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 6);
		}
		LA35_: ;
	}
	goto LA12_;
	LA15_: ;
	{
		result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f_2, a_2, 0);
	}
	LA12_: ;
	{
		NIM_BOOL T40_;
		T40_ = (NIM_BOOL)0;
		T40_ = (result <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2));
		if (T40_) goto LA41_;
		T40_ = inconsistentVarTypes__tUOqr3q1OVzVDquDgQiutwsigmatch(f_2, a_2);
		LA41_: ;
		if (!T40_) goto LA42_;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	}
	LA42_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, procTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_2)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
{	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	switch ((*a).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			NI T4_;
			NI T5_;
			T4_ = (NI)0;
			T4_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			T5_ = (NI)0;
			T5_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
			if (!!((T4_ == T5_))) goto LA6_;
			goto BeforeRet_;
		}
		LA6_: ;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T11_;
					if (!(i_2 < colontmp_)) goto LA10;
					i = i_2;
					T11_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
					T11_ = procParamTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_3(c, (*f).sons->data[i], (*a).sons->data[i]);
					result = minRel__7YozvgTVcSzTGrASvCO0ZA(result, T11_);
					{
						if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA14_;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA10: ;
			}
		}
		{
			if (!!(((*f).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA18_;
			{
				tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T24_;
				if (!!(((*a).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA22_;
				T24_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
				T24_ = procParamTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_3(c, (*f).sons->data[((NI) 0)], (*a).sons->data[((NI) 0)]);
				result = minRel__7YozvgTVcSzTGrASvCO0ZA(result, T24_);
				{
					if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA27_;
					goto BeforeRet_;
				}
				LA27_: ;
			}
			goto LA20_;
			LA22_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				goto BeforeRet_;
			}
			LA20_: ;
		}
		goto LA16_;
		LA18_: ;
		{
			if (!!(((*a).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA31_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		goto LA16_;
		LA31_: ;
		LA16_: ;
		{
			NIM_BOOL T35_;
			T35_ = (NIM_BOOL)0;
			T35_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0);
			if (!(T35_)) goto LA36_;
			T35_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 1))&63U)))!=0));
			LA36_: ;
			if (!T35_) goto LA37_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		goto LA33_;
		LA37_: ;
		{
			NIM_BOOL T40_;
			NIM_BOOL T41_;
			T40_ = (NIM_BOOL)0;
			T41_ = (NIM_BOOL)0;
			T41_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 7))&63U)))!=0);
			if (!(T41_)) goto LA42_;
			T41_ = (((*a).flags & 130) == 0);
			LA42_: ;
			T40_ = T41_;
			if (!(T40_)) goto LA43_;
			T40_ = (((*(*(*(*c).c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 24))&63U)))!=0);
			LA43_: ;
			if (!T40_) goto LA44_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		goto LA33_;
		LA44_: ;
		{
			if (!!((((*f).flags & 32768) == ((*a).flags & 32768)))) goto LA47_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		goto LA33_;
		LA47_: ;
		{
			if (!!(((*f).callConv == (*a).callConv))) goto LA50_;
			{
				NIM_BOOL T54_;
				T54_ = (NIM_BOOL)0;
				T54_ = ((*f).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				if (!(T54_)) goto LA55_;
				T54_ = ((*a).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0));
				LA55_: ;
				if (!T54_) goto LA56_;
				{
					if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 6))) goto LA60_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 7);
				}
				goto LA58_;
				LA60_: ;
				{
					if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5))) goto LA63_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5);
				}
				goto LA58_;
				LA63_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				LA58_: ;
			}
			goto LA52_;
			LA56_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				goto BeforeRet_;
			}
			LA52_: ;
		}
		goto LA33_;
		LA50_: ;
		LA33_: ;
		{
			tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ T69_;
			T69_ = (tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ)0;
			T69_ = compatibleEffects__jMDzK5tLgCQpWKRW9azac5w(f, a);
			if (!!((T69_ == ((tyEnum_EffectsCompat__xpkKZ2yw9a7eyibhzepiEFQ) 0)))) goto LA70_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		LA70_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipToObject__ec9bR2l2DprlWYvY8hoXvOw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ* skipped) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
	NI ptrs;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	r = t;
	ptrs = ((NI) 0);
	{
		while (1) {
			if (!!((r == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA2;
			switch ((*r).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
			{
				r = (*r).sons->data[((NI) 0)];
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
			{
				ptrs += ((NI) 1);
				(*skipped) = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 1);
				r = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(r);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
			{
				ptrs += ((NI) 1);
				(*skipped) = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 2);
				r = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(r);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
			{
				r = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(r);
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		} LA2: ;
	} LA1: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*r).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17));
		if (!(T10_)) goto LA11_;
		T10_ = (ptrs <= ((NI) 1));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = r;
	}
	LA12_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericSubtype__ys4SMiUV3x7hCCSTZl9cNPg)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, NI* d, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fGenericOrigin) {
	NIM_BOOL result;
	tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ askip;
	tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ fskip;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
	NI depth;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* last;
{	result = (NIM_BOOL)0;
	askip = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 0);
	fskip = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 0);
	t = skipToObject__ec9bR2l2DprlWYvY8hoXvOw(a, (&askip));
	r = skipToObject__ec9bR2l2DprlWYvY8hoXvOw(f, (&fskip));
	{
		if (!(r == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	depth = ((NI) 0);
	last = a;
	{
		while (1) {
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T8_)) goto LA9_;
			T8_ = !(((*r).sym == (*t).sym));
			LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T7_ = (askip == fskip);
			LA10_: ;
			if (!T7_) goto LA6;
			t = (*t).sons->data[((NI) 0)];
			{
				if (!(t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA13_;
				goto LA5;
			}
			LA13_: ;
			last = t;
			t = skipToObject__ec9bR2l2DprlWYvY8hoXvOw(t, (&askip));
			depth += ((NI) 1);
		} LA6: ;
	} LA5: ;
	{
		NIM_BOOL T17_;
		T17_ = (NIM_BOOL)0;
		T17_ = !((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T17_)) goto LA18_;
		T17_ = (askip == fskip);
		LA18_: ;
		if (!T17_) goto LA19_;
		genericParamPut__z5a4ZOu3KDJ5RptiscEp5g(c, last, fGenericOrigin);
		(*d) = depth;
		result = NIM_TRUE;
	}
	LA19_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, concreteType__s6oL9aoscwdxar7x6MeckLw)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	{
		{
			if (!(*c).isNoCall) goto LA4_;
			result = t;
		}
		goto LA2_;
		LA4_: ;
		{
			result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		}
		LA2_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			if (!((*(*t).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3))) goto LA10_;
			result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		}
		goto LA8_;
		LA10_: ;
		{
			result = t;
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	{
		result = t;
		{
			while (1) {
				tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T16_;
				RootObj* T17_;
				T16_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
				T16_ = &t->Sup;
				T17_ = (RootObj*)0;
				T17_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T16_);
				result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T17_));
				{
					if (!(result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA20_;
					goto LA14;
				}
				LA20_: ;
				{
					if (!!(((*result).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)))) goto LA24_;
					goto LA14;
				}
				LA24_: ;
			}
		} LA14: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	{
		result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		{
			NIM_BOOL T30_;
			NIM_BOOL T31_;
			NI T33_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T35_;
			T30_ = (NIM_BOOL)0;
			T31_ = (NIM_BOOL)0;
			T31_ = !((f == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T31_)) goto LA32_;
			T33_ = (NI)0;
			T33_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			T31_ = (((NI) 0) < T33_);
			LA32_: ;
			T30_ = T31_;
			if (!(T30_)) goto LA34_;
			T35_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T35_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*f).sons->data[((NI) 0)], IL64(2251799813685248));
			T30_ = ((*T35_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA34_: ;
			if (!T30_) goto LA36_;
			result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		}
		goto LA28_;
		LA36_: ;
		{
			result = t;
		}
		LA28_: ;
	}
	break;
	default:
	{
		result = t;
	}
	break;
	}
	return result;
}
static N_NIMCALL(void, Marker_tyRef__T9cB3MofzwLcK9bH1dcRQNsg)(void* p, NI op) {
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw* a;
	a = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*)p;
	nimGCvisit((void*)(*a).errorPrefix1, op);
	nimGCvisit((void*)(*a).typeClass2, op);
	nimGCvisit((void*)(*a).oldWriteHook3.ClE_0, op);
	nimGCvisit((void*)(*a).diagnostics4, op);
}
static N_NIMCALL(void, Marker_tySequence__nl5fX6g5vxdA4inU5zASDQ)(void* p, NI op) {
	tySequence__nl5fX6g5vxdA4inU5zASDQ* a;
	NI T1_;
	a = (tySequence__nl5fX6g5vxdA4inU5zASDQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___09a2v5CSVCqRsz63PUgUIwQ)(NimStringDesc* s, void* ClE_0) {
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw* colonenvP_;
	NimStringDesc* msg;
	NI T10_;
	NimStringDesc* T11_;
	colonenvP_ = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*) ClE_0;
	{
		NimStringDesc* T5_;
		if (!(((*colonenvP_).errorPrefix1 ? (*colonenvP_).errorPrefix1->Sup.len : 0) == ((NI) 0))) goto LA3_;
		T5_ = (NimStringDesc*)0;
		T5_ = rawNewString(((*(*(*(*colonenvP_).typeClass2).sym).name).s ? (*(*(*(*colonenvP_).typeClass2).sym).name).s->Sup.len : 0) + 1);
appendString(T5_, (*(*(*(*colonenvP_).typeClass2).sym).name).s);
appendString(T5_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_23));
		asgnRef((void**) (&(*colonenvP_).errorPrefix1), T5_);
	}
	LA3_: ;
	msg = nsuReplaceStr(s, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_24), (*colonenvP_).errorPrefix1);
	{
		if (!!(((*colonenvP_).oldWriteHook3.ClP_0 == TM__EV5hHJmjIY9cla9b9be7fSVJQ_25.ClP_0 && (*colonenvP_).oldWriteHook3.ClE_0 == TM__EV5hHJmjIY9cla9b9be7fSVJQ_25.ClE_0))) goto LA8_;
		(*colonenvP_).oldWriteHook3.ClE_0? (*colonenvP_).oldWriteHook3.ClP_0(msg, (*colonenvP_).oldWriteHook3.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_26)((*colonenvP_).oldWriteHook3.ClP_0))(msg);
	}
	LA8_: ;
	asgnRef((void**) (&(*colonenvP_).diagnostics4), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*colonenvP_).diagnostics4), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
	T10_ = (*colonenvP_).diagnostics4->Sup.len++;
	T11_ = (NimStringDesc*)0;
	T11_ = (*colonenvP_).diagnostics4->data[T10_]; (*colonenvP_).diagnostics4->data[T10_] = copyStringRC1(msg);
	if (T11_) nimGCunrefNoCycle(T11_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, matchUserTypeClass__med55njOHF6RW5cCXCP9bbQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw* colonenv_;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
	tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg matchedConceptContext;
	tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg* prevMatchedConcept;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevCandidateType;
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* T11_;
	TSafePoint TM__EV5hHJmjIY9cla9b9be7fSVJQ_21;
	tySequence__nl5fX6g5vxdA4inU5zASDQ* typeParams;
	tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags;
	NIM_BOOL collectDiagnostics;
	NIM_BOOL T53_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* checkedBody;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	colonenv_ = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*)0;
	colonenv_ = (tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*) newObj((&NTI__T9cB3MofzwLcK9bH1dcRQNsg_), sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw));
	(*colonenv_).Sup.m_type = (&NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_);
	c = (*m).c;
	asgnRef((void**) (&(*colonenv_).typeClass2), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(ff, IL64(9007199254740992)));
	body = (*(*(*colonenv_).typeClass2).n)._kind_6.sons->data[((NI) 3)];
	nimZeroMem((void*)(&matchedConceptContext), sizeof(tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg));
	prevMatchedConcept = (*c).matchedConcept;
	prevCandidateType = (*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)];
	{
		if (!!((prevMatchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)))) goto LA3_;
		matchedConceptContext.prev = prevMatchedConcept;
		matchedConceptContext.depth = (NI)((*prevMatchedConcept).depth + ((NI) 1));
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			if (!(((NI) 4) < (*prevMatchedConcept).depth)) goto LA7_;
			T9_ = (NimStringDesc*)0;
			T10_ = (NimStringDesc*)0;
			T10_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(body);
			T9_ = rawNewString((T10_ ? T10_->Sup.len : 0) + 29);
appendString(T9_, T10_);
appendString(T9_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_19));
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*(*m).c).graph).config, (*body).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T9_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_20, NIM_FALSE);
			result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
			goto BeforeRet_;
		}
		LA7_: ;
	}
	LA3_: ;
	T11_ = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
	T11_ = openScope__HbQKk9aDdsJVs9bASTXwa5Lw(c);
	matchedConceptContext.candidateType = a;
	asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), a);
	(*c).matchedConcept = (&matchedConceptContext);
	pushSafePoint(&TM__EV5hHJmjIY9cla9b9be7fSVJQ_21);
	TM__EV5hHJmjIY9cla9b9be7fSVJQ_21.status = setjmp(TM__EV5hHJmjIY9cla9b9be7fSVJQ_21.context);
	if (TM__EV5hHJmjIY9cla9b9be7fSVJQ_21.status == 0) {
	typeParams = (tySequence__nl5fX6g5vxdA4inU5zASDQ*)0;
	{
		if (!((*ff).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53))) goto LA14_;
		{
			NI i;
			NI colontmp_;
			NI T17_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T17_ = (NI)0;
			T17_ = len__5mJADrRYkP3r9auuiuDZN9cQast(ff);
			colontmp_ = (NI)(T17_ - ((NI) 1));
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* typeParamName;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T20_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* alreadyBound;
					tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T21_;
					RootObj* T22_;
					if (!(i_2 < colontmp_)) goto LA19;
					i = i_2;
					T20_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T20_ = base__PfgI9ap7WOnsRfFV4znQ27w(ff);
					typeParamName = (*(*(*T20_).sons->data[(NI)(i - ((NI) 1))]).sym).name;
					typ = (*ff).sons->data[i];
					param = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					T21_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
					T21_ = &typ->Sup;
					T22_ = (RootObj*)0;
					T22_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*m).bindings, T21_);
					alreadyBound = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T22_));
					{
						if (!!((alreadyBound == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA25_;
						typ = alreadyBound;
					}
					LA25_: ;
					{
						tyTuple__gOsvkY4zLbqYcgABB1VEQg T51_;
						NI T52_;
						{
							tyTuple__gOsvkY4zLbqYcgABB1VEQg* prev;
							NI i_3;
							NI L;
							NI T29_;
							prev = (tyTuple__gOsvkY4zLbqYcgABB1VEQg*)0;
							i_3 = ((NI) 0);
							T29_ = (typeParams ? typeParams->Sup.len : 0);
							L = T29_;
							{
								while (1) {
									if (!(i_3 < L)) goto LA31;
									prev = (&typeParams->data[i_3]);
									{
										if (!((*(*prev).Field1).Sup.id == (*typ).Sup.id)) goto LA34_;
										param = newSym__IXbidcxhXTQGZY9abN63Cxg((*(*prev).Field0).kind, typeParamName, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
										asgnRef((void**) (&(*param).typ), (*(*prev).Field0).typ);
										goto LA27;
									}
									LA34_: ;
									i_3 += ((NI) 1);
								} LA31: ;
							}
						}
						switch ((*typ).kind) {
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
						{
							param = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10), typeParamName, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							asgnRef((void**) (&(*param).typ), exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ(typ));
							{
								if (!((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA39_;
								(*(*param).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 27)) & 63);
							}
							goto LA37_;
							LA39_: ;
							{
								asgnRef((void**) (&(*param).ast), (*typ).n);
							}
							LA37_: ;
						}
						break;
						case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
						{
							param = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), typeParamName, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							asgnRef((void**) (&(*param).typ), exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ(typ));
						}
						break;
						default:
						{
							param = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7), typeParamName, (*(*colonenv_).typeClass2).sym, (*(*(*colonenv_).typeClass2).sym).info, 0);
							{
								NIM_BOOL T46_;
								tySequence__Ef05srmQTDulnBdXR4Ja6Q* T49_;
								T46_ = (NIM_BOOL)0;
								T46_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(typ);
								if (!T46_) goto LA47_;
								T49_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
								T49_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
								asgnRef((void**) (&T49_->data[0]), typ);
								asgnRef((void**) (&(*param).typ), newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q(c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55), T49_));
							}
							goto LA44_;
							LA47_: ;
							{
								asgnRef((void**) (&(*param).typ), makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(c, typ));
							}
							LA44_: ;
						}
						break;
						}
						nimZeroMem((void*)(&T51_), sizeof(tyTuple__gOsvkY4zLbqYcgABB1VEQg));
						T51_.Field0 = param;
						T51_.Field1 = typ;
						typeParams = (tySequence__nl5fX6g5vxdA4inU5zASDQ*) incrSeqV3((TGenericSeq*)(typeParams), (&NTI__nl5fX6g5vxdA4inU5zASDQ_));
						T52_ = typeParams->Sup.len++;
						asgnRef((void**) (&typeParams->data[T52_].Field0), T51_.Field0);
						asgnRef((void**) (&typeParams->data[T52_].Field1), T51_.Field1);
					} LA27: ;
					addDecl__aPXKqZJT9c7r7gT8X3uZAHw(c, param);
					i_2 += ((NI) 1);
				} LA19: ;
			}
		}
	}
	LA14_: ;
	nimZeroMem((void*)(&(*colonenv_).oldWriteHook3), sizeof(tyProc__k2HFjxisIgDALbEUFojxaQ));
	(*colonenv_).diagnostics4 = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*)0;
	(*colonenv_).errorPrefix1 = (NimStringDesc*)0;
	flags = 0;
	T53_ = (NIM_BOOL)0;
	T53_ = (*m).diagnosticsEnabled;
	if (T53_) goto LA54_;
	T53_ = (((*(*(*colonenv_).typeClass2).sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 23))&63U)))!=0);
	LA54_: ;
	collectDiagnostics = T53_;
	{
		tyProc__k2HFjxisIgDALbEUFojxaQ T59_;
		if (!collectDiagnostics) goto LA57_;
		asgnRef((void**) (&(*colonenv_).oldWriteHook3.ClE_0), (*(*(*(*m).c).graph).config).writelnHook.ClE_0);
		(*colonenv_).oldWriteHook3.ClP_0 = (*(*(*(*m).c).graph).config).writelnHook.ClP_0;
		if ((*colonenv_).diagnostics4) { nimGCunrefNoCycle((*colonenv_).diagnostics4); (*colonenv_).diagnostics4 = NIM_NIL; }
		flags = 512;
		nimZeroMem((void*)(&T59_), sizeof(tyProc__k2HFjxisIgDALbEUFojxaQ));
		T59_.ClP_0 = colonanonymous___09a2v5CSVCqRsz63PUgUIwQ; T59_.ClE_0 = colonenv_;
		asgnRef((void**) (&(*(*(*(*m).c).graph).config).writelnHook.ClE_0), T59_.ClE_0);
		(*(*(*(*m).c).graph).config).writelnHook.ClP_0 = T59_.ClP_0;
	}
	LA57_: ;
	T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T60_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(body);
	checkedBody = (*c).semTryExpr(c, T60_, flags);
	{
		if (!collectDiagnostics) goto LA63_;
		asgnRef((void**) (&(*(*(*(*m).c).graph).config).writelnHook.ClE_0), (*colonenv_).oldWriteHook3.ClE_0);
		(*(*(*(*m).c).graph).config).writelnHook.ClP_0 = (*colonenv_).oldWriteHook3.ClP_0;
		{
			NimStringDesc** msg;
			NI i_4;
			NI L_2;
			NI T66_;
			msg = (NimStringDesc**)0;
			i_4 = ((NI) 0);
			T66_ = ((*colonenv_).diagnostics4 ? (*colonenv_).diagnostics4->Sup.len : 0);
			L_2 = T66_;
			{
				while (1) {
					NI T69_;
					NimStringDesc* T70_;
					if (!(i_4 < L_2)) goto LA68;
					msg = (&(*colonenv_).diagnostics4->data[i_4]);
					unsureAsgnRef((void**) (&(*m).diagnostics), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*m).diagnostics), (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_)));
					T69_ = (*m).diagnostics->Sup.len++;
					T70_ = (NimStringDesc*)0;
					T70_ = (*m).diagnostics->data[T69_]; (*m).diagnostics->data[T69_] = copyStringRC1((*msg));
					if (T70_) nimGCunrefNoCycle(T70_);
					(*m).diagnosticsEnabled = NIM_TRUE;
					i_4 += ((NI) 1);
				} LA68: ;
			}
		}
	}
	LA63_: ;
	{
		if (!(checkedBody == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA73_;
		result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		popSafePoint();
		(*c).matchedConcept = prevMatchedConcept;
		asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), prevCandidateType);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
		goto BeforeRet_;
	}
	LA73_: ;
	{
		tyTuple__gOsvkY4zLbqYcgABB1VEQg* p;
		NI i_5;
		NI L_3;
		NI T76_;
		p = (tyTuple__gOsvkY4zLbqYcgABB1VEQg*)0;
		i_5 = ((NI) 0);
		T76_ = (typeParams ? typeParams->Sup.len : 0);
		L_3 = T76_;
		{
			while (1) {
				if (!(i_5 < L_3)) goto LA78;
				p = (&typeParams->data[i_5]);
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(m, (*p).Field1, (*(*p).Field0).typ);
				i_5 += ((NI) 1);
			} LA78: ;
		}
	}
	{
		if (!((*ff).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53))) goto LA81_;
		result = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, (*m).bindings, (*(*(*colonenv_).typeClass2).sym).info, ff);
	}
	goto LA79_;
	LA81_: ;
	{
		result = copyType__4O4aYoscFPo2FRSh4rP9ayg(ff, (*ff).owner, NIM_TRUE);
	}
	LA79_: ;
	asgnRef((void**) (&(*result).n), checkedBody);
	popSafePoint();
	}
	else {
		popSafePoint();
	}
	{
		(*c).matchedConcept = prevMatchedConcept;
		asgnRef((void**) (&(*(*(*colonenv_).typeClass2).sons->data[((NI) 0)]).sons->data[((NI) 0)]), prevCandidateType);
		closeScope__TX9bi5b9bIHR13FiwHwV59a4w(c);
		if (TM__EV5hHJmjIY9cla9b9be7fSVJQ_21.status != 0) nimLeaveFinally();
	}
	if (TM__EV5hHJmjIY9cla9b9be7fSVJQ_21.status != 0) reraiseException();
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_27));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_28));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_29));
	}
	LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, typeRel__3a3tkQB9aY8V2J9acM5cZ6nA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aOrig, tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg flags) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	NIM_BOOL useTypeLoweringRuleInTypeClass;
	NIM_BOOL T9_;
	NIM_BOOL T10_;
	NIM_BOOL T11_;
	NIM_BOOL T12_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aOrig_2;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T56_;
{	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	{
		if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6))) goto LA3_;
		{
			if (!!((aOrig == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA7_;
			put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, aOrig);
		}
		LA7_: ;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		goto BeforeRet_;
	}
	LA3_: ;
	T9_ = (NIM_BOOL)0;
	T10_ = (NIM_BOOL)0;
	T11_ = (NIM_BOOL)0;
	T12_ = (NIM_BOOL)0;
	T12_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
	if (!(T12_)) goto LA13_;
	T12_ = !((*c).isNoCall);
	LA13_: ;
	T11_ = T12_;
	if (!(T11_)) goto LA14_;
	T11_ = !(((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)));
	LA14_: ;
	T10_ = T11_;
	if (!(T10_)) goto LA15_;
	T10_ = !((((*aOrig).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 29))&63U)))!=0));
	LA15_: ;
	T9_ = T10_;
	if (!(T9_)) goto LA16_;
	T9_ = !((((*aOrig).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 28))&63U)))!=0));
	LA16_: ;
	useTypeLoweringRuleInTypeClass = T9_;
	{
		if (!useTypeLoweringRuleInTypeClass) goto LA19_;
		aOrig_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig, 256);
	}
	goto LA17_;
	LA19_: ;
	{
		aOrig_2 = aOrig;
	}
	LA17_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev;
		if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55))) goto LA24_;
		{
			NI T28_;
			T28_ = ((*aOrig_2).sons ? (*aOrig_2).sons->Sup.len : 0);
			if (!(((NI) 1) < T28_)) goto LA29_;
			prev = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(aOrig_2);
		}
		goto LA26_;
		LA29_: ;
		{
			prev = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		}
		LA26_: ;
		{
			if (!!((prev == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA34_;
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, prev, flags);
			goto BeforeRet_;
		}
		goto LA32_;
		LA34_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* candidate;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T50_;
			candidate = f;
			switch ((*f).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_2;
				tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T38_;
				RootObj* T39_;
				T38_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
				T38_ = &f->Sup;
				T39_ = (RootObj*)0;
				T39_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T38_);
				prev_2 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T39_));
				{
					if (!!((prev_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA42_;
					candidate = prev_2;
				}
				LA42_: ;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* computedType;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T45_;
				T45_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T45_ = tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw(c, (*f).n, NIM_FALSE);
				computedType = (*T45_).typ;
				switch ((*computedType).kind) {
				case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
				{
					candidate = base__PfgI9ap7WOnsRfFV4znQ27w(computedType);
				}
				break;
				case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
				{
					candidate = computedType;
				}
				break;
				default:
				{
				}
				break;
				}
			}
			break;
			default:
			{
			}
			break;
			}
			T50_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T50_ = base__PfgI9ap7WOnsRfFV4znQ27w(aOrig_2);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T50_, candidate, flags);
			{
				NI T55_;
				if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA53_;
				unsureAsgnRef((void**) (&(*c).inferredTypes), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*c).inferredTypes), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
				T55_ = (*c).inferredTypes->Sup.len++;
				asgnRef((void**) (&(*c).inferredTypes->data[T55_]), aOrig_2);
				add__9a8CdZqChTyqzq5bpSL3TzA(aOrig_2, candidate);
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			LA53_: ;
			goto BeforeRet_;
		}
		LA32_: ;
	}
	LA24_: ;
	T56_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T56_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig_2, IL64(1153132610847768576));
	a = maybeSkipDistinct__81UcA7TE8rJ8Gai4W1iW9cg((&(*c)), T56_, (*c).calleeSym);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T61_;
		if (!((IL64(70368744177680) &((NU64)1<<((NU)((*aOrig_2).kind)&63U)))!=0)) goto LA59_;
		T61_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T61_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(aOrig_2);
		result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, T61_, flags);
		goto BeforeRet_;
	}
	LA59_: ;
	{
		NIM_BOOL T64_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T66_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T69_;
		T64_ = (NIM_BOOL)0;
		T64_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
		if (!(T64_)) goto LA65_;
		T66_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T66_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(f, IL64(1153132610847768576));
		T64_ = !(((IL64(1114640907774205440) &((NU64)1<<((NU)((*T66_).kind)&63U)))!=0));
		LA65_: ;
		if (!T64_) goto LA67_;
		T69_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T69_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
		result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, T69_, flags);
		goto BeforeRet_;
	}
	LA67_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T74_;
		if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0)) goto LA72_;
		T74_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T74_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
		result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, T74_, flags);
		goto BeforeRet_;
	}
	LA72_: ;
	switch ((*a).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
	{
		(*c).typedescMatched = NIM_TRUE;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch;
			NI i;
			NI L;
			NI T77_;
			branch = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i = ((NI) 0);
			T77_ = ((*a).sons ? (*a).sons->Sup.len : 0);
			L = T77_;
			{
				while (1) {
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ x;
					if (!(i < L)) goto LA79;
					branch = &(*a).sons->data[i];
					x = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, (*branch), (flags | 1));
					{
						if (!(x == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA82_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
						goto BeforeRet_;
					}
					LA82_: ;
					{
						if (!(x < result)) goto LA86_;
						result = x;
					}
					LA86_: ;
					i += ((NI) 1);
				} LA79: ;
			}
		}
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
	{
		(*c).typedescMatched = NIM_TRUE;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch_2;
			NI i_2;
			NI L_2;
			NI T90_;
			branch_2 = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i_2 = ((NI) 0);
			T90_ = ((*a).sons ? (*a).sons->Sup.len : 0);
			L_2 = T90_;
			{
				while (1) {
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ x_2;
					if (!(i_2 < L_2)) goto LA92;
					branch_2 = &(*a).sons->data[i_2];
					x_2 = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f, (*branch_2), (flags | 1));
					{
						if (!!((x_2 == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA95_;
						{
							if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= x_2)) goto LA99_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
						}
						goto LA97_;
						LA99_: ;
						{
							result = x_2;
						}
						LA97_: ;
						goto BeforeRet_;
					}
					LA95_: ;
					i_2 += ((NI) 1);
				} LA92: ;
			}
		}
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
	{
		switch ((*f).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T104_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T105_;
			T104_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T104_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
			T105_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T105_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T104_, T105_, flags);
			goto BeforeRet_;
		}
		break;
		default:
		{
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59))) goto LA109_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			goto LA107_;
			LA109_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA107_: ;
			goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	{
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59))) goto LA115_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		goto LA113_;
		LA115_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			goto BeforeRet_;
		}
		LA113_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	{
		{
			NIM_BOOL T121_;
			tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ x_3;
			T121_ = (NIM_BOOL)0;
			T121_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
			if (!(T121_)) goto LA122_;
			T121_ = ((*(*(*c).c).matchedConcept).depth <= ((NI) 4));
			LA122_: ;
			if (!T121_) goto LA123_;
			(*(*(*c).c).matchedConcept).depth += ((NI) 1);
			x_3 = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, a, f, (flags | 1));
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= x_3)) goto LA127_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				goto BeforeRet_;
			}
			LA127_: ;
		}
		LA123_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	switch ((*f).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		{
			NIM_BOOL T133_;
			T133_ = (NIM_BOOL)0;
			T133_ = ((*a).kind == (*f).kind);
			if (!(T133_)) goto LA134_;
			T133_ = sameEnumTypes__aVVjNzmtPf6fjiBzSvfSQg_2types(f, a);
			LA134_: ;
			if (!T133_) goto LA135_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		goto LA131_;
		LA135_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T138_;
			NIM_BOOL T139_;
			T138_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T138_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, 1048576);
			T139_ = (NIM_BOOL)0;
			T139_ = sameEnumTypes__aVVjNzmtPf6fjiBzSvfSQg_2types(f, T138_);
			if (!T139_) goto LA140_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
		}
		goto LA131_;
		LA140_: ;
		LA131_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		{
			if (!((*a).kind == (*f).kind)) goto LA145_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		goto LA143_;
		LA145_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T148_;
			T148_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T148_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, 1048576);
			if (!((*T148_).kind == (*f).kind)) goto LA149_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
		}
		goto LA143_;
		LA149_: ;
		LA143_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T161_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T162_;
			if (!((*a).kind == (*f).kind)) goto LA154_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T158_;
				T158_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T158_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				if (!((*T158_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA159_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				goto BeforeRet_;
			}
			LA159_: ;
			T161_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T161_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			T162_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T162_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T161_, T162_, flags);
			{
				if (!!(((257 &((NU16)1<<((NU)(result)&15U)))!=0))) goto LA165_;
				{
					NI i_3;
					NI res;
					i_3 = (NI)0;
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= ((NI) 1))) goto LA169;
							i_3 = res;
							{
								if (!((*(*(*f).n)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 62))) goto LA172_;
								asgnRef((void**) (&(*(*f).n)._kind_6.sons->data[i_3]), tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw(c, (*(*f).n)._kind_6.sons->data[i_3], NIM_FALSE));
							}
							LA172_: ;
							res += ((NI) 1);
						} LA169: ;
					}
				}
				result = typeRangeRel__w3WJH5XKeovEI9cb9cseqgmQ(f, a);
			}
			LA165_: ;
		}
		goto LA152_;
		LA154_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f_2;
			f_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(f, 1048576);
			{
				NIM_BOOL T177_;
				NIM_BOOL T179_;
				T177_ = (NIM_BOOL)0;
				T177_ = ((*f_2).kind == (*a).kind);
				if (!(T177_)) goto LA178_;
				T179_ = (NIM_BOOL)0;
				T179_ = !(((*f_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14)));
				if (T179_) goto LA180_;
				T179_ = sameEnumTypes__aVVjNzmtPf6fjiBzSvfSQg_2types(f_2, a);
				LA180_: ;
				T177_ = T179_;
				LA178_: ;
				if (!T177_) goto LA181_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2);
			}
			goto LA175_;
			LA181_: ;
			{
				NIM_BOOL T184_;
				T184_ = (NIM_BOOL)0;
				T184_ = isConvertibleToRange__je559cQ286PtxNuVoMCjyww(f_2, a);
				if (!T184_) goto LA185_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA175_;
			LA185_: ;
			LA175_: ;
		}
		LA152_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		result = handleRange__Ryahaw9cTs6HZ9c8J3K9adeXA(f, a, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40), ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36):
	{
		result = handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 37):
	{
		result = handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 38):
	{
		result = handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		result = handleFloatRange__QydFJgT9bqyTv2wpqQZ2vGQ(f, a);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T206_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T207_;
			if (!((*aOrig_2).kind == (*f).kind)) goto LA204_;
			T206_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T206_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			T207_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T207_ = base__PfgI9ap7WOnsRfFV4znQ27w(aOrig_2);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T206_, T207_, flags);
		}
		goto LA202_;
		LA204_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T209_;
			T209_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T209_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T209_, aOrig_2, (flags | 2));
		}
		LA202_: ;
		{
			NIM_BOOL T212_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T214_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T215_;
			T212_ = (NIM_BOOL)0;
			T212_ = (result <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4));
			if (!(T212_)) goto LA213_;
			T214_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T214_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			T215_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T215_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T214_, abstractInst__dLigiD0wrfdW59cejPpTktA);
			T212_ = ((IL64(175921875124224) &((NU64)1<<((NU)((*T215_).kind)&63U)))!=0);
			LA213_: ;
			if (!T212_) goto LA216_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA216_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fRange;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aRange;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa;
			fRange = (*f).sons->data[((NI) 0)];
			aRange = (*a).sons->data[((NI) 0)];
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_3;
				tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T224_;
				RootObj* T225_;
				if (!((*fRange).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA222_;
				T224_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
				T224_ = &fRange->Sup;
				T225_ = (RootObj*)0;
				T225_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T224_);
				prev_3 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T225_));
				{
					if (!(prev_3 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA228_;
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, fRange, (*a).sons->data[((NI) 0)]);
					fRange = a;
				}
				goto LA226_;
				LA228_: ;
				{
					fRange = prev_3;
				}
				LA226_: ;
			}
			LA222_: ;
			ff = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*f).sons->data[((NI) 1)], 256);
			aa = (*a).sons->data[((NI) 1)];
			{
				NIM_BOOL T233_;
				T233_ = (NIM_BOOL)0;
				T233_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
				if (!(T233_)) goto LA234_;
				T233_ = ((*aa).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
				LA234_: ;
				if (!T233_) goto LA235_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			goto LA231_;
			LA235_: ;
			{
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ff, aa, flags);
			}
			LA231_: ;
			{
				if (!(result < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA240_;
				{
					NIM_BOOL T244_;
					NIM_BOOL T245_;
					NIM_BOOL T246_;
					T244_ = (NIM_BOOL)0;
					T245_ = (NIM_BOOL)0;
					T246_ = (NIM_BOOL)0;
					T246_ = NIM_FALSE;
					if (!(T246_)) goto LA247_;
					T246_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 1))&7U)))!=0));
					LA247_: ;
					T245_ = T246_;
					if (!(T245_)) goto LA248_;
					T245_ = ((*ff).kind == (*aa).kind);
					LA248_: ;
					T244_ = T245_;
					if (!(T244_)) goto LA249_;
					T244_ = isCovariantPtr__OS0a7EtgsSjPvphc5aG65w(c, ff, aa);
					LA249_: ;
					if (!T244_) goto LA250_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
				}
				goto LA242_;
				LA250_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
					goto BeforeRet_;
				}
				LA242_: ;
			}
			LA240_: ;
			{
				if (!(((*fRange).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0)) goto LA255_;
				result = inferStaticsInRange__hRaLa1Ge0r7UTGASvA1ocQ(c, fRange, a);
				goto BeforeRet_;
			}
			goto LA253_;
			LA255_: ;
			{
				NIM_BOOL T258_;
				T258_ = (NIM_BOOL)0;
				T258_ = !(((*(*c).c).matchedConcept == ((tyObject_TMatchedConcept__9blNHn9cqK8EfxnwsfjDnKvg*) NIM_NIL)));
				if (!(T258_)) goto LA259_;
				T258_ = (((*aRange).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0);
				LA259_: ;
				if (!T258_) goto LA260_;
				result = inferStaticsInRange__hRaLa1Ge0r7UTGASvA1ocQ(c, aRange, f);
				goto BeforeRet_;
			}
			goto LA253_;
			LA260_: ;
			{
				{
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T265_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T266_;
					NIM_BOOL T267_;
					T265_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c).c).graph).config, fRange);
					T266_ = lengthOrd__hjogdnp59cMX1rwmjikBhqw_3((*(*(*c).c).graph).config, aRange);
					T267_ = (NIM_BOOL)0;
					T267_ = eqeq___7c5Zw7H31uJfWmmhZe9aEqw(T265_, T266_);
					if (!!(T267_)) goto LA268_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA268_: ;
			}
			LA253_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T276_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T277_;
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49))) goto LA274_;
			T276_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T276_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			T277_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T277_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T276_, T277_, flags);
			{
				if (!(result < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA280_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA280_: ;
		}
		goto LA272_;
		LA274_: ;
		{
		}
		LA272_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
	{
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA286_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T292_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T293_;
				if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0))&63U)))!=0)) goto LA290_;
				T292_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T292_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				T293_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T293_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T292_, T293_, flags);
				goto BeforeRet_;
			}
			LA290_: ;
			{
				if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7))) goto LA296_;
				goto BeforeRet_;
			}
			LA296_: ;
		}
		LA286_: ;
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T299_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T300_;
			T299_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T299_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			T300_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T300_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T299_, T300_, flags);
			{
				if (!(result < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA303_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA303_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ffX60gensym298_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aaX60gensym298_;
			tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ baseRelX60gensym298_;
			{
				NIM_BOOL T308_;
				T308_ = (NIM_BOOL)0;
				T308_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
				if (!(T308_)) goto LA309_;
				T308_ = ((*(*a).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
				LA309_: ;
				if (!T308_) goto LA310_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
				goto BeforeRet_;
			}
			LA310_: ;
			ffX60gensym298_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			aaX60gensym298_ = (*a).sons->data[((NI) 1)];
			baseRelX60gensym298_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ffX60gensym298_, aaX60gensym298_, flags);
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= baseRelX60gensym298_)) goto LA314_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA312_;
			LA314_: ;
			{
				NIM_BOOL T317_;
				NIM_BOOL T318_;
				NIM_BOOL T319_;
				T317_ = (NIM_BOOL)0;
				T318_ = (NIM_BOOL)0;
				T319_ = (NIM_BOOL)0;
				T319_ = NIM_FALSE;
				if (!(T319_)) goto LA320_;
				T319_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 1))&7U)))!=0));
				LA320_: ;
				T318_ = T319_;
				if (!(T318_)) goto LA321_;
				T318_ = ((*ffX60gensym298_).kind == (*aaX60gensym298_).kind);
				LA321_: ;
				T317_ = T318_;
				if (!(T317_)) goto LA322_;
				T317_ = isCovariantPtr__OS0a7EtgsSjPvphc5aG65w(c, ffX60gensym298_, aaX60gensym298_);
				LA322_: ;
				if (!T317_) goto LA323_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA312_;
			LA323_: ;
			LA312_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ffX60gensym305_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aaX60gensym305_;
			tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ baseRelX60gensym305_;
			{
				NIM_BOOL T328_;
				T328_ = (NIM_BOOL)0;
				T328_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
				if (!(T328_)) goto LA329_;
				T328_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
				LA329_: ;
				if (!T328_) goto LA330_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				goto BeforeRet_;
			}
			LA330_: ;
			ffX60gensym305_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			aaX60gensym305_ = (*a).sons->data[((NI) 0)];
			baseRelX60gensym305_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ffX60gensym305_, aaX60gensym305_, flags);
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= baseRelX60gensym305_)) goto LA334_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA332_;
			LA334_: ;
			{
				NIM_BOOL T337_;
				NIM_BOOL T338_;
				NIM_BOOL T339_;
				T337_ = (NIM_BOOL)0;
				T338_ = (NIM_BOOL)0;
				T339_ = (NIM_BOOL)0;
				T339_ = NIM_FALSE;
				if (!(T339_)) goto LA340_;
				T339_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 1))&7U)))!=0));
				LA340_: ;
				T338_ = T339_;
				if (!(T338_)) goto LA341_;
				T338_ = ((*ffX60gensym305_).kind == (*aaX60gensym305_).kind);
				LA341_: ;
				T337_ = T338_;
				if (!(T337_)) goto LA342_;
				T337_ = isCovariantPtr__OS0a7EtgsSjPvphc5aG65w(c, ffX60gensym305_, aaX60gensym305_);
				LA342_: ;
				if (!T337_) goto LA343_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA332_;
			LA343_: ;
			LA332_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		{
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27))) goto LA348_;
				{
					if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA352_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA350_;
				LA352_: ;
				{
					NIM_BOOL T355_;
					NIM_BOOL T356_;
					NI T358_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T360_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T361_;
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T362_;
					T355_ = (NIM_BOOL)0;
					T356_ = (NIM_BOOL)0;
					T356_ = ((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
					if (!(T356_)) goto LA357_;
					T358_ = (NI)0;
					T358_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
					T356_ = (((NI) 0) < T358_);
					LA357_: ;
					T355_ = T356_;
					if (!(T355_)) goto LA359_;
					T360_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T360_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					T361_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T361_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
					T362_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
					T362_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T360_, T361_, flags);
					T355_ = (((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) <= T362_);
					LA359_: ;
					if (!T355_) goto LA363_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA350_;
				LA363_: ;
				LA350_: ;
			}
			LA348_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
		{
			{
				NIM_BOOL T370_;
				T370_ = (NIM_BOOL)0;
				T370_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
				if (!(T370_)) goto LA371_;
				T370_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
				LA371_: ;
				if (!T370_) goto LA372_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
			}
			goto LA368_;
			LA372_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff_2;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa_2;
				ff_2 = (*f).sons->data[((NI) 0)];
				aa_2 = (*a).sons->data[((NI) 0)];
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ff_2, aa_2, flags);
				{
					if (!(result < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA377_;
					{
						NIM_BOOL T381_;
						NIM_BOOL T382_;
						NIM_BOOL T383_;
						T381_ = (NIM_BOOL)0;
						T382_ = (NIM_BOOL)0;
						T383_ = (NIM_BOOL)0;
						T383_ = NIM_FALSE;
						if (!(T383_)) goto LA384_;
						T383_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 1))&7U)))!=0));
						LA384_: ;
						T382_ = T383_;
						if (!(T382_)) goto LA385_;
						T382_ = ((*ff_2).kind == (*aa_2).kind);
						LA385_: ;
						T381_ = T382_;
						if (!(T381_)) goto LA386_;
						T381_ = isCovariantPtr__OS0a7EtgsSjPvphc5aG65w(c, ff_2, aa_2);
						LA386_: ;
						if (!T381_) goto LA387_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
					}
					goto LA379_;
					LA387_: ;
					{
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
					}
					LA379_: ;
				}
				goto LA375_;
				LA377_: ;
				{
					NIM_BOOL T391_;
					T391_ = (NIM_BOOL)0;
					T391_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
					if (!(T391_)) goto LA392_;
					T391_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
					LA392_: ;
					if (!T391_) goto LA393_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA375_;
				LA393_: ;
				LA375_: ;
			}
			LA368_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = allowsNilDeprecated__AbnwgaBsy37utKNens69aOg((&(*c)), f);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15):
	{
		{
			NIM_BOOL T400_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x_4;
			T400_ = (NIM_BOOL)0;
			T400_ = isOrdinalType__6euCPZwUsyXzP1vAm4IthA(a, (((*(*(*(*c).c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 47))&63U)))!=0));
			if (!T400_) goto LA401_;
			{
				if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 15))) goto LA405_;
				x_4 = (*a).sons->data[((NI) 0)];
			}
			goto LA403_;
			LA405_: ;
			{
				x_4 = a;
			}
			LA403_: ;
			{
				if (!((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA410_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			goto LA408_;
			LA410_: ;
			{
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[((NI) 0)], x_4, flags);
				{
					if (!(result < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA415_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA415_: ;
			}
			LA408_: ;
		}
		goto LA398_;
		LA401_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA418_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		}
		goto LA398_;
		LA418_: ;
		LA398_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 30):
	{
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA424_;
			a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(35184372090880));
		}
		LA424_: ;
		{
			if (!((*a).kind == (*f).kind)) goto LA428_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		LA428_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18))) goto LA433_;
			result = recordRel__jLWLF6Jks9cJgmPzh2I6lSg(c, f, a);
		}
		LA433_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA438_;
			{
				NIM_BOOL T442_;
				T442_ = (NIM_BOOL)0;
				T442_ = sameObjectTypes__6sVmgh7vIWM9axOIPRliopQ(f, a);
				if (!T442_) goto LA443_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			goto LA440_;
			LA443_: ;
			{
				NI depth;
				depth = isObjectSubtype__C1JCauhsK9aI1g4xqINNSyQ(c, a, f, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				{
					if (!(((NI) 0) < depth)) goto LA448_;
					(*c).inheritancePenalty += depth;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
				}
				LA448_: ;
			}
			LA440_: ;
		}
		LA438_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
	{
		a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(35184373139456));
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13))) goto LA453_;
			{
				NIM_BOOL T457_;
				T457_ = (NIM_BOOL)0;
				T457_ = sameDistinctTypes__aVVjNzmtPf6fjiBzSvfSQg_3types(f, a);
				if (!T457_) goto LA458_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			goto LA455_;
			LA458_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T463_;
				if (!(*c).coerceDistincts) goto LA461_;
				T463_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T463_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T463_, a, flags);
			}
			goto LA455_;
			LA461_: ;
			LA455_: ;
		}
		goto LA451_;
		LA453_: ;
		{
			NIM_BOOL T465_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T467_;
			T465_ = (NIM_BOOL)0;
			T465_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
			if (!(T465_)) goto LA466_;
			T467_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T467_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			T465_ = ((IL64(1125900550668288) &((NU64)1<<((NU)((*T467_).kind)&63U)))!=0);
			LA466_: ;
			if (!T465_) goto LA468_;
			result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
		}
		goto LA451_;
		LA468_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T473_;
			if (!(*c).coerceDistincts) goto LA471_;
			T473_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T473_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T473_, a, flags);
		}
		goto LA451_;
		LA471_: ;
		LA451_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19))) goto LA477_;
			{
				NIM_BOOL T481_;
				T481_ = (NIM_BOOL)0;
				T481_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12)));
				if (!(T481_)) goto LA482_;
				T481_ = ((*(*a).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3));
				LA482_: ;
				if (!T481_) goto LA483_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
			}
			goto LA479_;
			LA483_: ;
			{
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[((NI) 0)], (*a).sons->data[((NI) 0)], flags);
				{
					if (!(result <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1))) goto LA488_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA488_: ;
			}
			LA479_: ;
		}
		LA477_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA493_;
			a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(35184372090880));
		}
		LA493_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T514_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T515_;
			if (!((*a).kind == (*f).kind)) goto LA497_;
			{
				NI T501_;
				NI T502_;
				T501_ = (NI)0;
				T501_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
				T502_ = (NI)0;
				T502_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
				if (!(T501_ < T502_)) goto LA503_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				goto BeforeRet_;
			}
			LA503_: ;
			{
				NI i_4;
				NI colontmp_;
				NI T506_;
				NI i_5;
				i_4 = (NI)0;
				colontmp_ = (NI)0;
				T506_ = (NI)0;
				T506_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
				colontmp_ = (NI)(T506_ - ((NI) 1));
				i_5 = ((NI) 0);
				{
					while (1) {
						if (!(i_5 < colontmp_)) goto LA508;
						i_4 = i_5;
						{
							tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T511_;
							T511_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
							T511_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[i_4], (*a).sons->data[i_4], flags);
							if (!(T511_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA512_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						LA512_: ;
						i_5 += ((NI) 1);
					} LA508: ;
				}
			}
			T514_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T514_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			T515_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T515_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T514_, T515_, (flags | 2));
			{
				NIM_BOOL T518_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T520_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T521_;
				T518_ = (NIM_BOOL)0;
				T518_ = (result <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4));
				if (!(T518_)) goto LA519_;
				T520_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T520_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
				T521_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T521_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T520_, abstractInst__dLigiD0wrfdW59cejPpTktA);
				T518_ = ((IL64(175921875124224) &((NU64)1<<((NU)((*T521_).kind)&63U)))!=0);
				LA519_: ;
				if (!T518_) goto LA522_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA522_: ;
			{
				if (!(result <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2))) goto LA526_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			goto LA524_;
			LA526_: ;
			{
				NIM_BOOL T529_;
				T529_ = (NIM_BOOL)0;
				T529_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
				if (!(T529_)) goto LA530_;
				T529_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
				LA530_: ;
				if (!T529_) goto LA531_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA524_;
			LA531_: ;
			LA524_: ;
		}
		goto LA495_;
		LA497_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5))) goto LA534_;
			result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
		}
		goto LA495_;
		LA534_: ;
		{
		}
		LA495_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA540_;
			a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(35184372090880));
		}
		LA540_: ;
		result = procTypeRel__jLWLF6Jks9cJgmPzh2I6lSg_2(c, f, a);
		{
			NIM_BOOL T544_;
			NIM_BOOL T545_;
			T544_ = (NIM_BOOL)0;
			T545_ = (NIM_BOOL)0;
			T545_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
			if (!(T545_)) goto LA546_;
			T545_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
			LA546_: ;
			T544_ = T545_;
			if (!(T544_)) goto LA547_;
			T544_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
			LA547_: ;
			if (!T544_) goto LA548_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		LA548_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T552_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T553_;
			T552_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T552_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			T553_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T553_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(a);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T552_, T553_, flags);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45))) goto LA559_;
			a = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(35184372090880));
		}
		LA559_: ;
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
		{
			{
				NIM_BOOL T564_;
				T564_ = (NIM_BOOL)0;
				T564_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
				if (!(T564_)) goto LA565_;
				T564_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
				LA565_: ;
				if (!T564_) goto LA566_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA562_;
			LA566_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			LA562_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
		{
			{
				if (!!(((*a).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9)))) goto LA573_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			LA573_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
		{
			{
				NI T578_;
				T578_ = (NI)0;
				T578_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
				if (!(T578_ == ((NI) 1))) goto LA579_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			LA579_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		{
			{
				NIM_BOOL T587_;
				T587_ = (NIM_BOOL)0;
				T587_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
				if (!(T587_)) goto LA588_;
				T587_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
				LA588_: ;
				if (!T587_) goto LA589_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA585_;
			LA589_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			LA585_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = allowsNilDeprecated__AbnwgaBsy37utKNens69aOg((&(*c)), f);
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		switch ((*a).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
		{
			{
				NIM_BOOL T598_;
				T598_ = (NIM_BOOL)0;
				T598_ = (((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0);
				if (!(T598_)) goto LA599_;
				T598_ = !((((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0));
				LA599_: ;
				if (!T598_) goto LA600_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
			}
			goto LA596_;
			LA600_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			}
			LA596_: ;
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5):
		{
			result = allowsNil__Usnkxkn9cp7o9b0Qe2e3ROZQsigmatch(f);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
		{
			{
				NI T608_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* pointsTo;
				T608_ = (NI)0;
				T608_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
				if (!(T608_ == ((NI) 1))) goto LA609_;
				pointsTo = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*a).sons->data[((NI) 0)], IL64(36134350135273744));
				{
					if (!((*pointsTo).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2))) goto LA613_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA611_;
				LA613_: ;
				{
					NIM_BOOL T616_;
					T616_ = (NIM_BOOL)0;
					T616_ = ((*pointsTo).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49));
					if (!(T616_)) goto LA617_;
					T616_ = ((*(*pointsTo).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2));
					LA617_: ;
					if (!T616_) goto LA618_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA611_;
				LA618_: ;
				{
					NIM_BOOL T621_;
					NIM_BOOL T622_;
					NIM_BOOL T623_;
					tyObject_Int128__9a9axPfb75jdWY25AamJewkA T625_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T627_;
					T621_ = (NIM_BOOL)0;
					T622_ = (NIM_BOOL)0;
					T623_ = (NIM_BOOL)0;
					T623_ = ((*pointsTo).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16));
					if (!(T623_)) goto LA624_;
					T625_ = firstOrd__hjogdnp59cMX1rwmjikBhqw(((tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw*) NIM_NIL), (*pointsTo).sons->data[((NI) 0)]);
					T623_ = eqeq___nr9cP9b0OL9cabygV9bo19cJgZA_2(T625_, IL64(0));
					LA624_: ;
					T622_ = T623_;
					if (!(T622_)) goto LA626_;
					T627_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T627_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*pointsTo).sons->data[((NI) 0)], 1048576);
					T622_ = ((IL64(66571993088) &((NU64)1<<((NU)((*T627_).kind)&63U)))!=0);
					LA626_: ;
					T621_ = T622_;
					if (!(T621_)) goto LA628_;
					T621_ = ((*(*pointsTo).sons->data[((NI) 1)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2));
					LA628_: ;
					if (!T621_) goto LA629_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1);
				}
				goto LA611_;
				LA629_: ;
				LA611_: ;
			}
			LA609_: ;
		}
		break;
		default:
		{
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63):
	{
		{
			if (!((*a).kind == (*f).kind)) goto LA635_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		LA635_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T638_;
		T638_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T638_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
		result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T638_, a, flags);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_4;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T640_;
		RootObj* T641_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* origF;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f_3;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* roota;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rootf;
		T640_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T640_ = &f->Sup;
		T641_ = (RootObj*)0;
		T641_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T640_);
		prev_4 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T641_));
		origF = f;
		{
			if (!(prev_4 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA644_;
			f_3 = f;
		}
		goto LA642_;
		LA644_: ;
		{
			f_3 = prev_4;
		}
		LA642_: ;
		roota = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(a);
		rootf = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(f_3);
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11))) goto LA649_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T653_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T654_;
				tySet_tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg nextFlags;
				NIM_BOOL hasCovariance;
				T653_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T653_ = base__PfgI9ap7WOnsRfFV4znQ27w(roota);
				T654_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T654_ = base__PfgI9ap7WOnsRfFV4znQ27w(rootf);
				if (!(T653_ == T654_)) goto LA655_;
				nextFlags = (flags | 2);
				hasCovariance = NIM_FALSE;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
				{
					NI i_6;
					NI colontmp__2;
					NI T658_;
					NI i_7;
					i_6 = (NI)0;
					colontmp__2 = (NI)0;
					T658_ = (NI)0;
					T658_ = len__5mJADrRYkP3r9auuiuDZN9cQast(rootf);
					colontmp__2 = (NI)(T658_ - ((NI) 1));
					i_7 = ((NI) 1);
					{
						while (1) {
							if (!(i_7 < colontmp__2)) goto LA660;
							i_6 = i_7;
							{
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff_3;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa_3;
								tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ res_2;
								ff_3 = (*rootf).sons->data[i_6];
								aa_3 = (*roota).sons->data[i_6];
								res_2 = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ff_3, aa_3, nextFlags);
								{
									NIM_BOOL T664_;
									T664_ = (NIM_BOOL)0;
									T664_ = !((res_2 == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
									if (!(T664_)) goto LA665_;
									T664_ = !((res_2 == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10)));
									LA665_: ;
									if (!T664_) goto LA666_;
									result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
								}
								LA666_: ;
								{
									if (!!(((1280 &((NU16)1<<((NU)(res_2)&15U)))!=0))) goto LA670_;
									{
										NIM_BOOL T674_;
										tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw paramFlags;
										tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T678_;
										T674_ = (NIM_BOOL)0;
										T674_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 1))&7U)))!=0));
										if (!(T674_)) goto LA675_;
										T674_ = ((*ff_3).kind == (*aa_3).kind);
										LA675_: ;
										if (!T674_) goto LA676_;
										T678_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
										T678_ = base__PfgI9ap7WOnsRfFV4znQ27w(rootf);
										paramFlags = (*(*T678_).sons->data[(NI)(i_6 - ((NI) 1))]).flags;
										{
											if (!((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 35))&63U)))!=0)) goto LA681_;
											{
												if (!((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 36))&63U)))!=0)) goto LA685_;
												hasCovariance = isCovariantPtr__OS0a7EtgsSjPvphc5aG65w(c, ff_3, aa_3);
											}
											goto LA683_;
											LA685_: ;
											{
												NIM_BOOL T688_;
												T688_ = (NIM_BOOL)0;
												T688_ = !(((6291456 &((NU64)1<<((NU)((*ff_3).kind)&63U)))!=0));
												if (!(T688_)) goto LA689_;
												T688_ = (res_2 == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3));
												LA689_: ;
												hasCovariance = T688_;
											}
											LA683_: ;
										}
										goto LA679_;
										LA681_: ;
										{
											NIM_BOOL T691_;
											tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T693_;
											T691_ = (NIM_BOOL)0;
											T691_ = ((paramFlags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 37))&63U)))!=0);
											if (!(T691_)) goto LA692_;
											T693_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
											T693_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, aa_3, ff_3, flags);
											T691_ = (T693_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3));
											LA692_: ;
											hasCovariance = T691_;
										}
										LA679_: ;
										{
											if (!hasCovariance) goto LA696_;
											goto LA661;
										}
										LA696_: ;
									}
									LA676_: ;
									result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
									goto BeforeRet_;
								}
								LA670_: ;
							} LA661: ;
							i_7 += ((NI) 1);
						} LA660: ;
					}
				}
				{
					if (!(prev_4 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA700_;
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f_3, a);
				}
				LA700_: ;
			}
			goto LA651_;
			LA655_: ;
			{
				tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag fKind;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T703_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aAsObject;
				T703_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T703_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(rootf);
				fKind = (*T703_).kind;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T708_;
					if (!((IL64(216172782113783808) &((NU64)1<<((NU)(fKind)&63U)))!=0)) goto LA706_;
					T708_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T708_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f_3);
					result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T708_, a, flags);
					{
						if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA711_;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f_3, a);
					}
					LA711_: ;
					goto BeforeRet_;
				}
				LA706_: ;
				aAsObject = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(roota);
				{
					if (!((6291456 &((NU64)1<<((NU)(fKind)&63U)))!=0)) goto LA715_;
					{
						if (!((*aAsObject).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA719_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
						goto BeforeRet_;
					}
					goto LA717_;
					LA719_: ;
					{
						if (!((*aAsObject).kind == fKind)) goto LA722_;
						aAsObject = base__PfgI9ap7WOnsRfFV4znQ27w(aAsObject);
					}
					goto LA717_;
					LA722_: ;
					LA717_: ;
				}
				LA715_: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* baseType;
					if (!((*aAsObject).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA726_;
					baseType = base__PfgI9ap7WOnsRfFV4znQ27w(aAsObject);
					{
						tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ ret;
						if (!!((baseType == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA730_;
						(*c).inheritancePenalty += ((NI) 1);
						ret = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, f_3, baseType, flags);
						{
							if (!((1280 &((NU16)1<<((NU)(ret)&15U)))!=0)) goto LA734_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
						}
						goto LA732_;
						LA734_: ;
						{
							result = ret;
						}
						LA732_: ;
						goto BeforeRet_;
					}
					LA730_: ;
				}
				LA726_: ;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA651_: ;
		}
		goto LA647_;
		LA649_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T738_;
			T738_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T738_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(origF);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T738_, a, flags);
			{
				NIM_BOOL T741_;
				T741_ = (NIM_BOOL)0;
				T741_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
				if (!(T741_)) goto LA742_;
				T741_ = !(((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5)));
				LA742_: ;
				if (!T741_) goto LA743_;
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f_3, a);
			}
			LA743_: ;
		}
		LA647_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym379_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T746_;
		RootObj* T747_;
		T746_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T746_ = &f->Sup;
		T747_ = (RootObj*)0;
		T747_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T746_);
		prevX60gensym379_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T747_));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff_4;
			if (!(prevX60gensym379_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA750_;
			{
				NIM_BOOL T754_;
				NIM_BOOL T756_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T758_;
				T754_ = (NIM_BOOL)0;
				T754_ = (a == f);
				if (T754_) goto LA755_;
				T756_ = (NIM_BOOL)0;
				T756_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
				if (!(T756_)) goto LA757_;
				T758_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T758_ = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(a);
				T756_ = ((*T758_).sons->data[((NI) 0)] == f);
				LA757_: ;
				T754_ = T756_;
				LA755_: ;
				if (!T754_) goto LA759_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boundX60gensym381_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T765_;
					if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0))) goto LA763_;
					T765_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T765_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig_2, 1048576);
					boundX60gensym381_ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T765_);
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, boundX60gensym381_);
				}
				LA763_: ;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				goto BeforeRet_;
			}
			LA759_: ;
			ff_4 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			{
				if (!!((ff_4 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA768_;
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ff_4, a, flags);
			}
			LA768_: ;
		}
		goto LA748_;
		LA750_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym379_, a, flags);
			goto BeforeRet_;
		}
		LA748_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x_5;
		NIM_BOOL preventHack;
		x_5 = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(a);
		preventHack = NIM_FALSE;
		{
			NIM_BOOL T774_;
			T774_ = (NIM_BOOL)0;
			T774_ = ((*x_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45));
			if (!(T774_)) goto LA775_;
			T774_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45)));
			LA775_: ;
			if (!T774_) goto LA776_;
			preventHack = NIM_TRUE;
			x_5 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(x_5);
		}
		LA776_: ;
		{
			NIM_BOOL T780_;
			NIM_BOOL T781_;
			NIM_BOOL T782_;
			NIM_BOOL T783_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* inst;
			T780_ = (NIM_BOOL)0;
			T781_ = (NIM_BOOL)0;
			T782_ = (NIM_BOOL)0;
			T783_ = (NIM_BOOL)0;
			T783_ = ((67584 &((NU64)1<<((NU)((*x_5).kind)&63U)))!=0);
			if (!(T783_)) goto LA784_;
			T783_ = !(((*c).calleeSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			LA784_: ;
			T782_ = T783_;
			if (!(T782_)) goto LA785_;
			T782_ = ((12288 &((NU32)1<<((NU)((*(*c).calleeSym).kind)&31U)))!=0);
			LA785_: ;
			T781_ = T782_;
			if (!(T781_)) goto LA786_;
			T781_ = !(((*c).call == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA786_: ;
			T780_ = T781_;
			if (!(T780_)) goto LA787_;
			T780_ = !(preventHack);
			LA787_: ;
			if (!T780_) goto LA788_;
			inst = prepareMetatypeForSigmatch__ab5BITmU2P8zKztV9cfNtsg_2((*c).c, (*c).bindings, (*(*c).call).info, f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, inst, a, flags);
			goto BeforeRet_;
		}
		LA788_: ;
		{
			if (!((*x_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA792_;
			{
				if (!((*f).sons->data[((NI) 0)] == (*x_5).sons->data[((NI) 0)])) goto LA796_;
				{
					NI i_8;
					NI colontmp__3;
					NI i_9;
					i_8 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
					i_9 = ((NI) 1);
					{
						while (1) {
							tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ tr;
							if (!(i_9 < colontmp__3)) goto LA800;
							i_8 = i_9;
							tr = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[i_8], (*x_5).sons->data[i_8], flags);
							{
								if (!(tr <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3))) goto LA803_;
								goto BeforeRet_;
							}
							LA803_: ;
							i_9 += ((NI) 1);
						} LA800: ;
					}
				}
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			LA796_: ;
		}
		goto LA790_;
		LA792_: ;
		{
			NIM_BOOL T806_;
			NIM_BOOL T807_;
			NI T810_;
			NI T811_;
			T806_ = (NIM_BOOL)0;
			T807_ = (NIM_BOOL)0;
			T807_ = ((*x_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
			if (!(T807_)) goto LA808_;
			T807_ = ((*f).sons->data[((NI) 0)] == (*x_5).sons->data[((NI) 0)]);
			LA808_: ;
			T806_ = T807_;
			if (!(T806_)) goto LA809_;
			T810_ = (NI)0;
			T810_ = len__5mJADrRYkP3r9auuiuDZN9cQast(x_5);
			T811_ = (NI)0;
			T811_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			T806_ = ((NI)(T810_ - ((NI) 1)) == T811_);
			LA809_: ;
			if (!T806_) goto LA812_;
			{
				NI i_10;
				NI colontmp__4;
				NI i_11;
				i_10 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
				i_11 = ((NI) 1);
				{
					while (1) {
						if (!(i_11 < colontmp__4)) goto LA816;
						i_10 = i_11;
						{
							if (!((*(*x_5).sons->data[i_10]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA819_;
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c).c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_15), TM__EV5hHJmjIY9cla9b9be7fSVJQ_16);
						}
						goto LA817_;
						LA819_: ;
						{
							tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T822_;
							T822_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
							T822_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[i_10], (*x_5).sons->data[i_10], flags);
							if (!(T822_ <= ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3))) goto LA823_;
							{
								if (!!(((*(*f).sons->data[i_10]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA827_;
								goto BeforeRet_;
							}
							LA827_: ;
						}
						goto LA817_;
						LA823_: ;
						LA817_: ;
						i_11 += ((NI) 1);
					} LA816: ;
				}
			}
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		}
		goto LA790_;
		LA812_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* genericBody;
			tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ askip;
			tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ fskip;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aobj;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fobj;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T830_;
			NI depth_2;
			genericBody = (*f).sons->data[((NI) 0)];
			askip = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 0);
			fskip = ((tyEnum_SkippedPtr__WOSTpykTcTHo6Kb9bHoOUqQ) 0);
			aobj = skipToObject__ec9bR2l2DprlWYvY8hoXvOw(x_5, (&askip));
			T830_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T830_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(genericBody);
			fobj = skipToObject__ec9bR2l2DprlWYvY8hoXvOw(T830_, (&fskip));
			depth_2 = ((NI) -1);
			{
				NIM_BOOL T833_;
				NIM_BOOL T834_;
				T833_ = (NIM_BOOL)0;
				T834_ = (NIM_BOOL)0;
				T834_ = !((fobj == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T834_)) goto LA835_;
				T834_ = !((aobj == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				LA835_: ;
				T833_ = T834_;
				if (!(T833_)) goto LA836_;
				T833_ = (askip == fskip);
				LA836_: ;
				if (!T833_) goto LA837_;
				depth_2 = isObjectSubtype__C1JCauhsK9aI1g4xqINNSyQ(c, aobj, fobj, f);
			}
			LA837_: ;
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, genericBody, x_5, flags);
			{
				if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA841_;
				{
					NI i_12;
					NI colontmp__5;
					NI i_13;
					i_12 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__5 = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
					i_13 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x_6;
							tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T846_;
							RootObj* T847_;
							if (!(i_13 < colontmp__5)) goto LA845;
							i_12 = i_13;
							T846_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
							T846_ = &(*genericBody).sons->data[(NI)(i_12 - ((NI) 1))]->Sup;
							T847_ = (RootObj*)0;
							T847_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T846_);
							x_6 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T847_));
							{
								if (!(x_6 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA850_;
							}
							goto LA848_;
							LA850_: ;
							{
								if (!((4608 &((NU64)1<<((NU)((*x_6).kind)&63U)))!=0)) goto LA853_;
								internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c).c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_15), TM__EV5hHJmjIY9cla9b9be7fSVJQ_17);
							}
							goto LA848_;
							LA853_: ;
							{
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* key;
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* old;
								tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T856_;
								RootObj* T857_;
								key = (*f).sons->data[i_12];
								T856_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
								T856_ = &key->Sup;
								T857_ = (RootObj*)0;
								T857_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T856_);
								old = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T857_));
								{
									if (!(old == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA860_;
									put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, key, x_6);
								}
								goto LA858_;
								LA860_: ;
								{
									tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T863_;
									T863_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
									T863_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, old, x_6, (flags | 1));
									if (!(T863_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA864_;
									result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
									goto BeforeRet_;
								}
								goto LA858_;
								LA864_: ;
								LA858_: ;
							}
							LA848_: ;
							i_13 += ((NI) 1);
						} LA845: ;
					}
				}
			}
			LA841_: ;
			{
				NIM_BOOL genericSubtype;
				if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA868_;
				genericSubtype = isGenericSubtype__ys4SMiUV3x7hCCSTZl9cNPg(c, x_5, f, (&depth_2), f);
				{
					NIM_BOOL T872_;
					NIM_BOOL T873_;
					T872_ = (NIM_BOOL)0;
					T873_ = (NIM_BOOL)0;
					T873_ = genericSubtype;
					if (!(T873_)) goto LA874_;
					T873_ = !(((*(*aobj).sym).Sup.id == (*(*fobj).sym).Sup.id));
					LA874_: ;
					T872_ = !(T873_);
					if (!(T872_)) goto LA875_;
					T872_ = !(((*aOrig_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10)));
					LA875_: ;
					if (!T872_) goto LA876_;
					depth_2 = ((NI) -1);
				}
				LA876_: ;
			}
			LA868_: ;
			{
				if (!(((NI) 0) <= depth_2)) goto LA880_;
				(*c).inheritancePenalty += depth_2;
				{
					if (!(depth_2 == ((NI) 0))) goto LA884_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				goto LA882_;
				LA884_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3);
				}
				LA882_: ;
			}
			LA880_: ;
		}
		LA790_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym416_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T888_;
		RootObj* T889_;
		T888_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T888_ = &f->Sup;
		T889_ = (RootObj*)0;
		T889_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T888_);
		prevX60gensym416_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T889_));
		{
			if (!(prevX60gensym416_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA892_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch_3;
				NI i_14;
				NI L_3;
				NI T895_;
				branch_3 = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i_14 = ((NI) 0);
				T895_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_3 = T895_;
				{
					while (1) {
						tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ x_7;
						if (!(i_14 < L_3)) goto LA897;
						branch_3 = &(*f).sons->data[i_14];
						x_7 = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*branch_3), aOrig_2, flags);
						{
							if (!(x_7 < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3))) goto LA900_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						LA900_: ;
						{
							if (!(x_7 < result)) goto LA904_;
							result = x_7;
						}
						LA904_: ;
						i_14 += ((NI) 1);
					} LA897: ;
				}
			}
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) < result)) goto LA908_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			LA908_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boundX60gensym418_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T914_;
				if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0))) goto LA912_;
				T914_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T914_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig_2, 1048576);
				boundX60gensym418_ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T914_);
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, boundX60gensym418_);
			}
			LA912_: ;
			goto BeforeRet_;
		}
		goto LA890_;
		LA892_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym416_, a, flags);
			goto BeforeRet_;
		}
		LA890_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym421_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T917_;
		RootObj* T918_;
		T917_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T917_ = &f->Sup;
		T918_ = (RootObj*)0;
		T918_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T917_);
		prevX60gensym421_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T918_));
		{
			NI oldInheritancePenalty;
			NI maxInheritance;
			if (!(prevX60gensym421_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA921_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			oldInheritancePenalty = (*c).inheritancePenalty;
			maxInheritance = ((NI) 0);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch_4;
				NI i_15;
				NI L_4;
				NI T924_;
				branch_4 = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i_15 = ((NI) 0);
				T924_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_4 = T924_;
				{
					while (1) {
						tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ x_8;
						if (!(i_15 < L_4)) goto LA926;
						branch_4 = &(*f).sons->data[i_15];
						(*c).inheritancePenalty = ((NI) 0);
						x_8 = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*branch_4), aOrig_2, flags);
						maxInheritance = ((maxInheritance >= (*c).inheritancePenalty) ? maxInheritance : (*c).inheritancePenalty);
						{
							if (!(result < x_8)) goto LA929_;
							result = x_8;
						}
						LA929_: ;
						i_15 += ((NI) 1);
					} LA926: ;
				}
			}
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3) <= result)) goto LA933_;
				{
					if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) < result)) goto LA937_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				LA937_: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boundX60gensym425_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T943_;
					if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0))) goto LA941_;
					T943_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T943_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig_2, 1048576);
					boundX60gensym425_ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T943_);
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, boundX60gensym425_);
				}
				LA941_: ;
				goto BeforeRet_;
			}
			goto LA931_;
			LA933_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA931_: ;
			(*c).inheritancePenalty = (NI)(oldInheritancePenalty + maxInheritance);
		}
		goto LA919_;
		LA921_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym421_, a, flags);
			goto BeforeRet_;
		}
		LA919_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 58):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym428_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T947_;
		RootObj* T948_;
		T947_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T947_ = &f->Sup;
		T948_ = (RootObj*)0;
		T948_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T947_);
		prevX60gensym428_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T948_));
		{
			if (!(prevX60gensym428_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA951_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch_5;
				NI i_16;
				NI L_5;
				NI T954_;
				branch_5 = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
				i_16 = ((NI) 0);
				T954_ = ((*f).sons ? (*f).sons->Sup.len : 0);
				L_5 = T954_;
				{
					while (1) {
						if (!(i_16 < L_5)) goto LA956;
						branch_5 = &(*f).sons->data[i_16];
						{
							tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T959_;
							T959_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
							T959_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*branch_5), aOrig_2, flags);
							if (!!((T959_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA960_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						LA960_: ;
						i_16 += ((NI) 1);
					} LA956: ;
				}
			}
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boundX60gensym430_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T966_;
				if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0))) goto LA964_;
				T966_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T966_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(aOrig_2, 1048576);
				boundX60gensym430_ = skipIntLit__PyQcLUUKkDYcpwke36Qpxgmagicsys(T966_);
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, boundX60gensym430_);
			}
			LA964_: ;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		goto LA949_;
		LA951_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym428_, a, flags);
			goto BeforeRet_;
		}
		LA949_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym433_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T969_;
		RootObj* T970_;
		T969_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T969_ = &f->Sup;
		T970_ = (RootObj*)0;
		T970_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T969_);
		prevX60gensym433_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T970_));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete;
			if (!(prevX60gensym433_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA973_;
			concrete = concreteType__s6oL9aoscwdxar7x6MeckLw((&(*c)), a, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			{
				NIM_BOOL T977_;
				T977_ = (NIM_BOOL)0;
				T977_ = !((concrete == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				if (!(T977_)) goto LA978_;
				T977_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0));
				LA978_: ;
				if (!T977_) goto LA979_;
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, concrete);
			}
			LA979_: ;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		goto LA971_;
		LA973_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym433_, a, flags);
			goto BeforeRet_;
		}
		LA971_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym437_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T983_;
		RootObj* T984_;
		T983_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T983_ = &f->Sup;
		T984_ = (RootObj*)0;
		T984_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T983_);
		prevX60gensym437_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T984_));
		{
			tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag targetKind;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* effectiveArgType;
			NIM_BOOL typeClassMatches;
			NIM_BOOL T989_;
			NIM_BOOL T991_;
			if (!(prevX60gensym437_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA987_;
			targetKind = (*(*f).sons->data[((NI) 0)]).kind;
			effectiveArgType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(a, IL64(2357352931002384));
			T989_ = (NIM_BOOL)0;
			T989_ = (targetKind == (*effectiveArgType).kind);
			if (!(T989_)) goto LA990_;
			T991_ = (NIM_BOOL)0;
			T991_ = isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4(effectiveArgType);
			T989_ = !(T991_);
			LA990_: ;
			typeClassMatches = T989_;
			{
				NIM_BOOL T994_;
				NIM_BOOL T996_;
				T994_ = (NIM_BOOL)0;
				T994_ = typeClassMatches;
				if (T994_) goto LA995_;
				T996_ = (NIM_BOOL)0;
				T996_ = ((100663296 &((NU64)1<<((NU)(targetKind)&63U)))!=0);
				if (!(T996_)) goto LA997_;
				T996_ = ((*effectiveArgType).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
				LA997_: ;
				T994_ = T996_;
				LA995_: ;
				if (!T994_) goto LA998_;
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, a);
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				goto BeforeRet_;
			}
			goto LA992_;
			LA998_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				goto BeforeRet_;
			}
			LA992_: ;
		}
		goto LA985_;
		LA987_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym437_, a, flags);
			goto BeforeRet_;
		}
		LA985_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 53):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 52):
	{
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1007_;
			if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10))&63U)))!=0)) goto LA1005_;
			T1007_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T1007_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1007_, a, flags);
		}
		goto LA1003_;
		LA1005_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym442_;
			tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1009_;
			RootObj* T1010_;
			T1009_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
			T1009_ = &f->Sup;
			T1010_ = (RootObj*)0;
			T1010_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T1009_);
			prevX60gensym442_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T1010_));
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* matched;
				if (!(prevX60gensym442_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1013_;
				{
					if (!(aOrig_2 == f)) goto LA1017_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
					goto BeforeRet_;
				}
				LA1017_: ;
				matched = matchUserTypeClass__med55njOHF6RW5cCXCP9bbQ(c, f, aOrig_2);
				{
					if (!!((matched == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA1021_;
					add__9a8CdZqChTyqzq5bpSL3TzA(matched, a);
					(*matched).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 10)) & 63);
					{
						if (!!(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0))) goto LA1025_;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, matched);
					}
					LA1025_: ;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				goto LA1019_;
				LA1021_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA1019_: ;
			}
			goto LA1011_;
			LA1013_: ;
			{
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym442_, a, flags);
				goto BeforeRet_;
			}
			LA1011_: ;
		}
		LA1003_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prevX60gensym447_;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1030_;
		RootObj* T1031_;
		T1030_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T1030_ = &f->Sup;
		T1031_ = (RootObj*)0;
		T1031_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T1030_);
		prevX60gensym447_ = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T1031_));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* roota_2;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* rootf_2;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1036_;
			if (!(prevX60gensym447_ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1034_;
			roota_2 = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(a);
			T1036_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T1036_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
			rootf_2 = skipGenericAlias__PfgI9ap7WOnsRfFV4znQ27w_3(T1036_);
			{
				NIM_BOOL T1039_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1041_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1042_;
				T1039_ = (NIM_BOOL)0;
				T1039_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11));
				if (!(T1039_)) goto LA1040_;
				T1041_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1041_ = base__PfgI9ap7WOnsRfFV4znQ27w(roota_2);
				T1042_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1042_ = base__PfgI9ap7WOnsRfFV4znQ27w(rootf_2);
				T1039_ = (T1041_ == T1042_);
				LA1040_: ;
				if (!T1039_) goto LA1043_;
				{
					NI i_17;
					NI colontmp__6;
					NI T1046_;
					NI i_18;
					i_17 = (NI)0;
					colontmp__6 = (NI)0;
					T1046_ = (NI)0;
					T1046_ = len__5mJADrRYkP3r9auuiuDZN9cQast(rootf_2);
					colontmp__6 = (NI)(T1046_ - ((NI) 1));
					i_18 = ((NI) 1);
					{
						while (1) {
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ff_5;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa_4;
							if (!(i_18 < colontmp__6)) goto LA1048;
							i_17 = i_18;
							ff_5 = (*rootf_2).sons->data[i_17];
							aa_4 = (*roota_2).sons->data[i_17];
							result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, ff_5, aa_4, flags);
							{
								if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA1051_;
								goto BeforeRet_;
							}
							LA1051_: ;
							{
								NIM_BOOL T1055_;
								T1055_ = (NIM_BOOL)0;
								T1055_ = ((*ff_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20));
								if (!(T1055_)) goto LA1056_;
								T1055_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10)));
								LA1056_: ;
								if (!T1055_) goto LA1057_;
								result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
								goto BeforeRet_;
							}
							LA1057_: ;
							i_18 += ((NI) 1);
						} LA1048: ;
					}
				}
			}
			goto LA1037_;
			LA1043_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1060_;
				T1060_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1060_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(rootf_2);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1060_, a, flags);
			}
			LA1037_: ;
			{
				if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA1063_;
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, a);
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			LA1063_: ;
		}
		goto LA1032_;
		LA1034_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prevX60gensym447_, a, flags);
			goto BeforeRet_;
		}
		LA1032_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
	{
		NIM_BOOL doBindGP;
		NIM_BOOL T1067_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* x_9;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1069_;
		RootObj* T1070_;
		T1067_ = (NIM_BOOL)0;
		T1067_ = !(((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 0))&7U)))!=0));
		if (T1067_) goto LA1068_;
		T1067_ = ((flags &((NU8)1<<((NU)(((tyEnum_TTypeRelFlag__oebzuK0gHqNtaStfyppjAg) 2))&7U)))!=0);
		LA1068_: ;
		doBindGP = T1067_;
		T1069_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T1069_ = &f->Sup;
		T1070_ = (RootObj*)0;
		T1070_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T1069_);
		x_9 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T1070_));
		{
			if (!(x_9 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1073_;
			{
				NIM_BOOL T1077_;
				T1077_ = (NIM_BOOL)0;
				T1077_ = ((*(*c).callee).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10));
				if (!(T1077_)) goto LA1078_;
				T1077_ = !((*c).typedescMatched);
				LA1078_: ;
				if (!T1077_) goto LA1079_;
				{
					if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0)) goto LA1083_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				goto LA1081_;
				LA1083_: ;
				{
					if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA1086_;
					{
						NI T1090_;
						T1090_ = (NI)0;
						T1090_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
						if (!(T1090_ == ((NI) 0))) goto LA1091_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
					}
					goto LA1088_;
					LA1091_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa_5;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1108_;
						{
							NI T1096_;
							NimStringDesc* argX60gensym457_;
							T1096_ = (NI)0;
							T1096_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
							if (!!((((NI) 0) < T1096_))) goto LA1097_;
							argX60gensym457_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__EV5hHJmjIY9cla9b9be7fSVJQ_30);
							internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c).c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym457_, TM__EV5hHJmjIY9cla9b9be7fSVJQ_30);
						}
						LA1097_: ;
						(*c).typedescMatched = NIM_TRUE;
						aa_5 = a;
						{
							while (1) {
								NIM_BOOL T1101_;
								NI T1103_;
								T1101_ = (NIM_BOOL)0;
								T1101_ = ((4352 &((NU64)1<<((NU)((*aa_5).kind)&63U)))!=0);
								if (!(T1101_)) goto LA1102_;
								T1103_ = (NI)0;
								T1103_ = len__5mJADrRYkP3r9auuiuDZN9cQast(aa_5);
								T1101_ = (((NI) 0) < T1103_);
								LA1102_: ;
								if (!T1101_) goto LA1100;
								aa_5 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(aa_5);
							} LA1100: ;
						}
						{
							if (!((*aa_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA1106_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
							goto BeforeRet_;
						}
						LA1106_: ;
						T1108_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T1108_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
						result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1108_, aa_5, flags);
						{
							if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) < result)) goto LA1111_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
						}
						LA1111_: ;
					}
					LA1088_: ;
				}
				goto LA1081_;
				LA1086_: ;
				{
					if (!(*c).isNoCall) goto LA1114_;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete_2;
						if (!doBindGP) goto LA1118_;
						concrete_2 = concreteType__s6oL9aoscwdxar7x6MeckLw((&(*c)), a, f);
						{
							if (!(concrete_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1122_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						LA1122_: ;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, concrete_2);
					}
					LA1118_: ;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				goto LA1081_;
				LA1114_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA1081_: ;
			}
			goto LA1075_;
			LA1079_: ;
			{
				{
					NIM_BOOL T1128_;
					NI T1129_;
					NI oldInheritancePenalty_2;
					T1128_ = (NIM_BOOL)0;
					T1129_ = (NI)0;
					T1129_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
					T1128_ = (((NI) 0) < T1129_);
					if (!(T1128_)) goto LA1130_;
					T1128_ = !(((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)));
					LA1130_: ;
					if (!T1128_) goto LA1131_;
					oldInheritancePenalty_2 = (*c).inheritancePenalty;
					result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, (*f).sons->data[((NI) 0)], a, (flags | 5));
					{
						NIM_BOOL T1135_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete_3;
						T1135_ = (NIM_BOOL)0;
						T1135_ = doBindGP;
						if (!(T1135_)) goto LA1136_;
						T1135_ = !(((257 &((NU16)1<<((NU)(result)&15U)))!=0));
						LA1136_: ;
						if (!T1135_) goto LA1137_;
						concrete_3 = concreteType__s6oL9aoscwdxar7x6MeckLw((&(*c)), a, f);
						{
							if (!(concrete_3 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1141_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
							goto BeforeRet_;
						}
						LA1141_: ;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, concrete_3);
					}
					LA1137_: ;
					{
						if (!((1032 &((NU16)1<<((NU)(result)&15U)))!=0)) goto LA1145_;
						(*c).inheritancePenalty = (NI)((NI)(oldInheritancePenalty_2 - (*c).inheritancePenalty) - (NI)(((NI) 100) * (result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10))));
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
					}
					LA1145_: ;
				}
				goto LA1126_;
				LA1131_: ;
				{
					if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA1148_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				goto LA1126_;
				LA1148_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				LA1126_: ;
			}
			LA1075_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* concrete_4;
				if (!(result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA1153_;
				concrete_4 = a;
				{
					if (!(((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0)) goto LA1157_;
					transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw((*a).sym);
					(*a).flags &= ~(((NU64)1) << ((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30)) & 63));
				}
				goto LA1155_;
				LA1157_: ;
				{
					concrete_4 = concreteType__s6oL9aoscwdxar7x6MeckLw((&(*c)), a, f);
					{
						if (!(concrete_4 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1162_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
						goto BeforeRet_;
					}
					LA1162_: ;
				}
				LA1155_: ;
				{
					if (!doBindGP) goto LA1166_;
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, concrete_4);
				}
				LA1166_: ;
			}
			goto LA1151_;
			LA1153_: ;
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) < result)) goto LA1169_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			goto LA1151_;
			LA1169_: ;
			LA1151_: ;
		}
		goto LA1071_;
		LA1073_: ;
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3))) goto LA1172_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		}
		goto LA1071_;
		LA1172_: ;
		{
			if (!((*x_9).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12))) goto LA1175_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
		}
		goto LA1071_;
		LA1175_: ;
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, x_9, a, flags);
			{
				if (!(((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8) < result)) goto LA1180_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			LA1180_: ;
		}
		LA1071_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_5;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1183_;
		RootObj* T1184_;
		T1183_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T1183_ = &f->Sup;
		T1184_ = (RootObj*)0;
		T1184_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T1183_);
		prev_5 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T1184_));
		{
			if (!(prev_5 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1187_;
			{
				if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA1191_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1195_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1198_;
					T1195_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T1195_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					if (!!(((*T1195_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)))) goto LA1196_;
					T1198_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T1198_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1198_, a, flags);
					{
						NIM_BOOL T1201_;
						T1201_ = (NIM_BOOL)0;
						T1201_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
						if (!(T1201_)) goto LA1202_;
						T1201_ = !(((*f).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
						LA1202_: ;
						if (!T1201_) goto LA1203_;
						{
							NIM_BOOL T1207_;
							T1207_ = (NIM_BOOL)0;
							T1207_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*f).n, (*aOrig_2).n, NIM_FALSE);
							if (!!(T1207_)) goto LA1208_;
							result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
						}
						LA1208_: ;
					}
					LA1203_: ;
				}
				goto LA1193_;
				LA1196_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				LA1193_: ;
				{
					if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA1213_;
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, aOrig_2);
				}
				LA1213_: ;
			}
			goto LA1189_;
			LA1191_: ;
			{
				NIM_BOOL T1216_;
				T1216_ = (NIM_BOOL)0;
				T1216_ = !(((*aOrig_2).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
				if (!(T1216_)) goto LA1217_;
				T1216_ = !(((*(*aOrig_2).n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
				LA1217_: ;
				if (!T1216_) goto LA1218_;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1222_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1225_;
					T1222_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T1222_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					if (!!(((*T1222_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0)))) goto LA1223_;
					T1225_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T1225_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
					result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1225_, (*(*aOrig_2).n).typ, flags);
				}
				goto LA1220_;
				LA1223_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				LA1220_: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* boundType;
					tySequence__Ef05srmQTDulnBdXR4Ja6Q* T1231_;
					if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA1229_;
					T1231_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)0;
					T1231_ = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeq((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
					asgnRef((void**) (&T1231_->data[0]), (*(*aOrig_2).n).typ);
					boundType = newTypeWithSons__7doBlU1jfuQUQdCuB7BM4Q((*c).c, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), T1231_);
					asgnRef((void**) (&(*boundType).n), (*aOrig_2).n);
					put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, boundType);
				}
				LA1229_: ;
			}
			goto LA1189_;
			LA1218_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA1189_: ;
		}
		goto LA1185_;
		LA1187_: ;
		{
			if (!((*prev_5).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA1234_;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1240_;
				if (!((*aOrig_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA1238_;
				T1240_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1240_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(prev_5);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1240_, a, flags);
				{
					NIM_BOOL T1243_;
					T1243_ = (NIM_BOOL)0;
					T1243_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
					if (!(T1243_)) goto LA1244_;
					T1243_ = !(((*prev_5).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
					LA1244_: ;
					if (!T1243_) goto LA1245_;
					{
						NIM_BOOL T1249_;
						T1249_ = (NIM_BOOL)0;
						T1249_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*prev_5).n, (*aOrig_2).n, NIM_FALSE);
						if (!!(T1249_)) goto LA1250_;
						result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
					}
					LA1250_: ;
				}
				LA1245_: ;
			}
			goto LA1236_;
			LA1238_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA1236_: ;
		}
		goto LA1185_;
		LA1234_: ;
		{
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
		}
		LA1185_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 55):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_6;
		{
			NI T1257_;
			T1257_ = ((*f).sons ? (*f).sons->Sup.len : 0);
			if (!(((NI) 1) < T1257_)) goto LA1258_;
			prev_6 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
		}
		goto LA1255_;
		LA1258_: ;
		{
			prev_6 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
		}
		LA1255_: ;
		{
			if (!!((prev_6 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA1263_;
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, prev_6, a, flags);
		}
		goto LA1261_;
		LA1263_: ;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1266_;
			T1266_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T1266_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1266_, a, flags);
			{
				NI T1271_;
				if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA1269_;
				unsureAsgnRef((void**) (&(*c).inferredTypes), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*c).inferredTypes), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
				T1271_ = (*c).inferredTypes->Sup.len++;
				asgnRef((void**) (&(*c).inferredTypes->data[T1271_]), f);
				add__9a8CdZqChTyqzq5bpSL3TzA(f, a);
			}
			LA1269_: ;
		}
		LA1261_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* prev_7;
		tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1273_;
		RootObj* T1274_;
		T1273_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
		T1273_ = &f->Sup;
		T1274_ = (RootObj*)0;
		T1274_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*c).bindings, T1273_);
		prev_7 = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T1274_));
		{
			if (!(prev_7 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA1277_;
			{
				if (!!(((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA1281_;
				{
					NIM_BOOL T1285_;
					T1285_ = (NIM_BOOL)0;
					T1285_ = ((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
					if (!(T1285_)) goto LA1286_;
					T1285_ = (((*a).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0);
					LA1286_: ;
					if (!T1285_) goto LA1287_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
				}
				goto LA1283_;
				LA1287_: ;
				{
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA1283_: ;
			}
			goto LA1279_;
			LA1281_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1291_;
				T1291_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1291_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				if (!((*T1291_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA1292_;
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			}
			goto LA1279_;
			LA1292_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1295_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1296_;
				T1295_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1295_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				T1296_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1296_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1295_, T1296_, flags);
			}
			LA1279_: ;
			{
				if (!!((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA1299_;
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, a);
			}
			LA1299_: ;
		}
		goto LA1275_;
		LA1277_: ;
		{
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1306_;
				if (!(((*f).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0)) goto LA1304_;
				T1306_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1306_ = base__PfgI9ap7WOnsRfFV4znQ27w(prev_7);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1306_, a, flags);
			}
			goto LA1302_;
			LA1304_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1310_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1311_;
				if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA1308_;
				T1310_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1310_ = base__PfgI9ap7WOnsRfFV4znQ27w(prev_7);
				T1311_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T1311_ = base__PfgI9ap7WOnsRfFV4znQ27w(a);
				result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, T1310_, T1311_, flags);
			}
			goto LA1302_;
			LA1308_: ;
			{
				result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
			}
			LA1302_: ;
		}
		LA1275_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
	{
		{
			if (!!((aOrig_2 == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA1316_;
			put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, f, aOrig_2);
		}
		LA1316_: ;
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50):
	{
		result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 61):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* reevaluated;
		{
			NIM_BOOL T1322_;
			T1322_ = (NIM_BOOL)0;
			T1322_ = ((*f).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			if (T1322_) goto LA1323_;
			T1322_ = ((*(*f).n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
			LA1323_: ;
			if (!T1322_) goto LA1324_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8);
			goto BeforeRet_;
		}
		LA1324_: ;
		reevaluated = tryResolvingStaticExpr__eSHkSNaT1zNcY5kU9aaf9cKw(c, (*f).n, NIM_FALSE);
		switch ((*(*reevaluated).typ).kind) {
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1327_;
			T1327_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T1327_ = base__PfgI9ap7WOnsRfFV4znQ27w((*reevaluated).typ);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, a, T1327_, flags);
		}
		break;
		case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1329_;
			T1329_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T1329_ = base__PfgI9ap7WOnsRfFV4znQ27w((*reevaluated).typ);
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, a, T1329_, flags);
			{
				NIM_BOOL T1332_;
				T1332_ = (NIM_BOOL)0;
				T1332_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
				if (!(T1332_)) goto LA1333_;
				T1332_ = !(((*(*reevaluated).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
				LA1333_: ;
				if (!T1332_) goto LA1334_;
				{
					NIM_BOOL T1338_;
					T1338_ = (NIM_BOOL)0;
					T1338_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*aOrig_2).n, (*(*reevaluated).typ).n, NIM_FALSE);
					if (!!(T1338_)) goto LA1339_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA1339_: ;
			}
			LA1334_: ;
		}
		break;
		default:
		{
			result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(c, a, (*reevaluated).typ, flags);
			{
				NIM_BOOL T1344_;
				T1344_ = (NIM_BOOL)0;
				T1344_ = !((result == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
				if (!(T1344_)) goto LA1345_;
				T1344_ = !(((*(*reevaluated).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
				LA1345_: ;
				if (!T1344_) goto LA1346_;
				{
					NIM_BOOL T1350_;
					T1350_ = (NIM_BOOL)0;
					T1350_ = exprStructuralEquivalent__E1mnSzj2NONtG7h9cR3AuFA((*aOrig_2).n, (*(*reevaluated).typ).n, NIM_FALSE);
					if (!!(T1350_)) goto LA1351_;
					result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0);
				}
				LA1351_: ;
			}
			LA1346_: ;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0):
	{
		{
			if (!((*a).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))) goto LA1356_;
			result = ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10);
		}
		LA1356_: ;
	}
	break;
	default:
	{
		NimStringDesc* T1359_;
		T1359_ = (NimStringDesc*)0;
		T1359_ = rawNewString((reprEnum((NI)(*f).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)(*f).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 19);
appendString(T1359_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_31));
appendString(T1359_, reprEnum((NI)(*f).kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*c).c).graph).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T1359_, TM__EV5hHJmjIY9cla9b9be7fSVJQ_32);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incMatches__A6Mml3n6SH4wRXsgNwTrfQ)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ r, NI convMatch) {
	switch (r) {
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1):
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2):
	{
		(*m).convMatches += convMatch;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3):
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4):
	{
		(*m).subtypeMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8):
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 6):
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5):
	{
		(*m).genericMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 9):
	{
		(*m).intConvMatches += ((NI) 256);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 7):
	{
		(*m).convMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10):
	{
		(*m).exactMatches += ((NI) 1);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0):
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T1_;
	RootObj* T2_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
	T1_ = &f->Sup;
	T2_ = (RootObj*)0;
	T2_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*m).bindings, T1_);
	result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T2_));
	{
		if (!(result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA5_;
		result = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, (*m).bindings, (*arg).info, f);
	}
	LA5_: ;
	{
		if (!(result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA9_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*arg).info, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_35), TM__EV5hHJmjIY9cla9b9be7fSVJQ_36);
		result = errorType__9aXTnVBVS5pbBC3zrwMhttg(c);
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, implicitConv__ekWYb9baoe72jjRpfCUrNQQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(kind, (*arg).info);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(f);
		if (!T3_) goto LA4_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T10_;
			if (!!(!(((*m).fauxMatch == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0))))) goto LA8_;
			T10_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T10_ = getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow(c, arg, m, f);
			asgnRef((void**) (&(*result).typ), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T10_, IL64(70368744177664)));
		}
		goto LA6_;
		LA8_: ;
		{
			asgnRef((void**) (&(*result).typ), errorType__9aXTnVBVS5pbBC3zrwMhttg(c));
		}
		LA6_: ;
	}
	goto LA1_;
	LA4_: ;
	{
		asgnRef((void**) (&(*result).typ), skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(f, IL64(70368744177664)));
	}
	LA1_: ;
	{
		if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA15_;
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*arg).info, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_37), TM__EV5hHJmjIY9cla9b9be7fSVJQ_38);
	}
	LA15_: ;
	add__P8dDSotTW25BkfbyspojGg(result, (*(*c).graph).emptyNode);
	add__P8dDSotTW25BkfbyspojGg(result, arg);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, extractPragma__WA2vCsoKtzcTWMS9asDfXEg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA3_;
		result = (*(*s).ast)._kind_6.sons->data[((NI) 4)];
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((896 &((NU32)1<<((NU)((*s).kind)&31U)))!=0)) goto LA6_;
		{
			NIM_BOOL T10_;
			NI T12_;
			T10_ = (NIM_BOOL)0;
			T10_ = !(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T10_)) goto LA11_;
			T12_ = (NI)0;
			T12_ = len__P89cqdlERShb9alU3iC0yj8wast((*s).ast);
			T10_ = (((NI) 0) < T12_);
			LA11_: ;
			if (!T10_) goto LA13_;
			{
				NIM_BOOL T17_;
				NI T19_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*(*(*s).ast)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 43));
				if (!(T17_)) goto LA18_;
				T19_ = (NI)0;
				T19_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*s).ast)._kind_6.sons->data[((NI) 0)]);
				T17_ = (((NI) 1) < T19_);
				LA18_: ;
				if (!T17_) goto LA20_;
				result = (*(*(*s).ast)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)];
			}
			LA20_: ;
		}
		LA13_: ;
	}
	goto LA1_;
	LA6_: ;
	LA1_: ;
	{
		NIM_BOOL T24_;
		T24_ = (NIM_BOOL)0;
		T24_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T24_) goto LA25_;
		T24_ = ((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 90));
		LA25_: ;
		if (!!(T24_)) goto LA26_;
		failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_41));
	}
	LA26_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, warnAboutDeprecated__2mdCrePWCLH8F2Wb8QkFIw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaNode;
	NimStringDesc* name;
	NimStringDesc* T33_;
{	pragmaNode = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20))) goto LA3_;
		pragmaNode = extractPragma__WA2vCsoKtzcTWMS9asDfXEg((*s).owner);
	}
	goto LA1_;
	LA3_: ;
	{
		pragmaNode = extractPragma__WA2vCsoKtzcTWMS9asDfXEg(s);
	}
	LA1_: ;
	{
		NIM_BOOL T8_;
		NimStringDesc* T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20));
		if (!(T8_)) goto LA9_;
		T8_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22))&63U)))!=0));
		LA9_: ;
		if (!T8_) goto LA10_;
		T12_ = (NimStringDesc*)0;
		T12_ = rawNewString(((*(*(*s).owner).name).s ? (*(*(*s).owner).name).s->Sup.len : 0) + ((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 31);
appendString(T12_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_42));
appendString(T12_, (*(*(*s).owner).name).s);
appendString(T12_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_43));
appendString(T12_, (*(*s).name).s);
appendString(T12_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_12));
		name = T12_;
	}
	goto LA6_;
	LA10_: ;
	{
		name = (*(*s).name).s;
	}
	LA6_: ;
	{
		if (!!((pragmaNode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA16_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(pragmaNode);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA21;
						i = i_2;
						it = (*pragmaNode)._kind_6.sons->data[i];
						{
							NIM_BOOL T24_;
							NIM_BOOL T25_;
							tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T26_;
							NI T28_;
							NimStringDesc* T32_;
							T24_ = (NIM_BOOL)0;
							T25_ = (NIM_BOOL)0;
							T26_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
							T26_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(it);
							T25_ = (T26_ == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 134));
							if (!(T25_)) goto LA27_;
							T28_ = (NI)0;
							T28_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
							T25_ = (T28_ == ((NI) 2));
							LA27_: ;
							T24_ = T25_;
							if (!(T24_)) goto LA29_;
							T24_ = ((*(*it)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*it)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
							LA29_: ;
							if (!T24_) goto LA30_;
							T32_ = (NimStringDesc*)0;
							T32_ = rawNewString(((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal ? (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal->Sup.len : 0) + (name ? name->Sup.len : 0) + 16);
appendString(T32_, (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
appendString(T32_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_44));
appendString(T32_, name);
appendString(T32_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_45));
							liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), T32_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_46, NIM_FALSE);
							goto BeforeRet_;
						}
						LA30_: ;
						i_2 += ((NI) 1);
					} LA21: ;
				}
			}
		}
	}
	LA16_: ;
	T33_ = (NimStringDesc*)0;
	T33_ = rawNewString((name ? name->Sup.len : 0) + 14);
appendString(T33_, name);
appendString(T33_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_45));
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 16), T33_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_48, NIM_FALSE);
	}BeforeRet_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	result = (NimStringDesc*)0;
	T1_ = (NimStringDesc*)0;
	T1_ = toMsgFilename__eX9aCxa5NfPq9alDDS1zYbvw(conf, info.fileIndex);
	result = resizeString(result, (T1_ ? T1_->Sup.len : 0) + 0);
appendString(result, T1_);
	{
		if (!(((NI) 0) < ((NI) (info.line)))) goto LA4_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_27));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (((NI) (info.line)))));
		{
			if (!(((NI) 0) < (NI)(((NI) (info.col)) + ((NI) 1)))) goto LA8_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_28));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(((NI) (info.col)) + ((NI) 1)))));
		}
		LA8_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_29));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, userError__2mdCrePWCLH8F2Wb8QkFIw_2)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmaNode;
	tyArray__24KAM9afIUgUaqBaEBB6r9bg T22_;
	NimStringDesc* T23_;
{	pragmaNode = extractPragma__WA2vCsoKtzcTWMS9asDfXEg(s);
	{
		if (!!((pragmaNode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
			it = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(pragmaNode);
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i = i_2;
						it = (*pragmaNode)._kind_6.sons->data[i];
						{
							NIM_BOOL T11_;
							NIM_BOOL T12_;
							tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw T13_;
							NI T15_;
							tyArray__24KAM9afIUgUaqBaEBB6r9bg T19_;
							NimStringDesc* T20_;
							NimStringDesc* T21_;
							T11_ = (NIM_BOOL)0;
							T12_ = (NIM_BOOL)0;
							T13_ = (tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw)0;
							T13_ = whichPragma__Pjztiiq9bHmTTxDuLd39cNRw(it);
							T12_ = (T13_ == ((tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw) 119));
							if (!(T12_)) goto LA14_;
							T15_ = (NI)0;
							T15_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(it);
							T12_ = (T15_ == ((NI) 2));
							LA14_: ;
							T11_ = T12_;
							if (!(T11_)) goto LA16_;
							T11_ = ((*(*it)._kind_6.sons->data[((NI) 1)]).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) && (*(*it)._kind_6.sons->data[((NI) 1)]).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22));
							LA16_: ;
							if (!T11_) goto LA17_;
							nimZeroMem((void*)T19_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
							T20_ = (NimStringDesc*)0;
							T20_ = rawNewString(((*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal ? (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal->Sup.len : 0) + 2);
appendString(T20_, (*(*it)._kind_6.sons->data[((NI) 1)])._kind_3.strVal);
appendString(T20_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_44));
							T19_[0] = T20_;
							T19_[1] = copyString((*(*s).name).s);
							T19_[2] = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, (*(*s).ast).info);
							T21_ = (NimStringDesc*)0;
							T21_ = nsuFormatOpenArray(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_49), T19_, 3);
							liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_50, NIM_FALSE);
							goto BeforeRet_;
						}
						LA17_: ;
						i_2 += ((NI) 1);
					} LA8: ;
				}
			}
		}
	}
	LA3_: ;
	nimZeroMem((void*)T22_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
	T22_[0] = ((NimStringDesc*) NIM_NIL);
	T22_[1] = copyString((*(*s).name).s);
	T22_[2] = toFileLineCol__WM0LdwjY884aJ9cup7BS2vwmsgs(conf, (*(*s).ast).info);
	T23_ = (NimStringDesc*)0;
	T23_ = nsuFormatOpenArray(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_49), T22_, 3);
	liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T23_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_51, NIM_FALSE);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
	module = s;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*module).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			module = (*module).owner;
		} LA2: ;
	}
	{
		NIM_BOOL T7_;
		NI i;
		T7_ = (NIM_BOOL)0;
		T7_ = !((module == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !((module == (*c).module));
		LA8_: ;
		if (!T7_) goto LA9_;
		i = ((NI) 0);
		{
			while (1) {
				NI T13_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate;
				T13_ = (((*c).unusedImports ? (*c).unusedImports->Sup.len : 0)-1);
				if (!(i <= T13_)) goto LA12;
				candidate = (*c).unusedImports->data[i].Field0;
				{
					NIM_BOOL T16_;
					tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T18_;
					T16_ = (NIM_BOOL)0;
					T16_ = (candidate == module);
					if (T16_) goto LA17_;
					T18_.Field0 = (*candidate).Sup.id;
					T18_.Field1 = (*s).Sup.id;
					T16_ = contains__59b0yGhHVwyyUm0ZIA71uAg((*c).exportIndirections, T18_);
					LA17_: ;
					if (!T16_) goto LA19_;
					del__euuxT1DiEjSOKbaBvsuoZA((&(*c).unusedImports), ((NI) (i)));
				}
				goto LA14_;
				LA19_: ;
				{
					i += ((NI) 1);
				}
				LA14_: ;
			} LA12: ;
		}
	}
	LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markUsed__QlWTWY7567sCdiTkeUTTDA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf;
	conf = (*(*c).graph).config;
	(*s).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA4_: ;
		if (!T3_) goto LA5_;
		(*(*s).owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
		{
			if (!(((*(*s).owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22))&63U)))!=0)) goto LA9_;
			warnAboutDeprecated__2mdCrePWCLH8F2Wb8QkFIw(conf, info, s);
		}
		LA9_: ;
	}
	LA5_: ;
	{
		if (!!(((20971520 & (*s).flags) == 0))) goto LA13_;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 22))&63U)))!=0)) goto LA17_;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = ((*c).lastTLineInfo.line == info.line);
				if (!(T21_)) goto LA22_;
				T21_ = ((*c).lastTLineInfo.col == info.col);
				LA22_: ;
				if (!!(T21_)) goto LA23_;
				warnAboutDeprecated__2mdCrePWCLH8F2Wb8QkFIw(conf, info, s);
				(*c).lastTLineInfo = info;
			}
			LA23_: ;
		}
		LA17_: ;
		{
			if (!(((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24))&63U)))!=0)) goto LA27_;
			userError__2mdCrePWCLH8F2Wb8QkFIw_2(conf, info, s);
		}
		LA27_: ;
	}
	LA13_: ;
	{
		if (!!(((49152 & (*conf).globalOptions) == 0))) goto LA31_;
		styleCheckUse__k3cqh606mJPYNzLXdtZjIg(conf, info, s);
	}
	LA31_: ;
	markOwnerModuleAsUsed__YW6ZVaTpPDUETmgx3UgpFw(c, s);
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65), (*n).info, (*(*n).typ).sons->data[((NI) 0)]);
	add__P8dDSotTW25BkfbyspojGg(result, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, userConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*c).converters ? (*c).converters->Sup.len : 0);
		colontmp_ = T2_;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i = i_2;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest;
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ srca;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
					NIM_BOOL destIsGeneric;
					tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ fdest;
					src = (*(*(*c).converters->data[i]).typ).sons->data[((NI) 1)];
					dest = (*(*(*c).converters->data[i]).typ).sons->data[((NI) 0)];
					srca = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, src, a, 0);
					{
						if (!!(((1288 &((NU16)1<<((NU)(srca)&15U)))!=0))) goto LA8_;
						goto LA5;
					}
					LA8_: ;
					constraint = (*(*(*(*(*(*c).converters->data[i]).typ).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym).constraint;
					{
						NIM_BOOL T12_;
						NIM_BOOL T14_;
						T12_ = (NIM_BOOL)0;
						T12_ = !((constraint == 0));
						if (!(T12_)) goto LA13_;
						T14_ = (NIM_BOOL)0;
						T14_ = matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw(constraint, arg);
						T12_ = !(T14_);
						LA13_: ;
						if (!T12_) goto LA15_;
						goto LA5;
					}
					LA15_: ;
					{
						NIM_BOOL T19_;
						NIM_BOOL T21_;
						T19_ = (NIM_BOOL)0;
						T19_ = ((IL64(140737496743936) &((NU64)1<<((NU)((*src).kind)&63U)))!=0);
						if (!(T19_)) goto LA20_;
						T21_ = (NIM_BOOL)0;
						T21_ = isLValue__kCP6QlI8uS4X0pOQUdr7tg(arg);
						T19_ = !(T21_);
						LA20_: ;
						if (!T19_) goto LA22_;
						goto LA5;
					}
					LA22_: ;
					destIsGeneric = containsGenericType__YPjOkGV9axAnGR3UfLeWZ1g_2(dest);
					{
						if (!destIsGeneric) goto LA26_;
						dest = generateTypeInstance__ab5BITmU2P8zKztV9cfNtsg(c, (*m).bindings, (*arg).info, dest);
					}
					LA26_: ;
					fdest = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, f, dest, 0);
					{
						NIM_BOOL T30_;
						NIM_BOOL T32_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* s;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* param;
						T30_ = (NIM_BOOL)0;
						T30_ = ((1280 &((NU16)1<<((NU)(fdest)&15U)))!=0);
						if (!(T30_)) goto LA31_;
						T32_ = (NIM_BOOL)0;
						T32_ = ((*dest).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47));
						if (!(T32_)) goto LA33_;
						T32_ = ((8388608 &((NU64)1<<((NU)((*f).kind)&63U)))!=0);
						LA33_: ;
						T30_ = !(T32_);
						LA31_: ;
						if (!T30_) goto LA34_;
						markUsed__QlWTWY7567sCdiTkeUTTDA(c, (*arg).info, (*c).converters->data[i]);
						s = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*c).converters->data[i]);
						asgnRef((void**) (&(*s).typ), (*(*c).converters->data[i]).typ);
						(*s).info = (*arg).info;
						result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32), (*arg).info, dest);
						add__P8dDSotTW25BkfbyspojGg(result, s);
						param = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T40_;
							if (!(srca == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3))) goto LA38_;
							T40_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T40_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
							param = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), src, T40_, (&(*m)), c);
						}
						goto LA36_;
						LA38_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
							if (!((8388608 &((NU64)1<<((NU)((*src).kind)&63U)))!=0)) goto LA42_;
							param = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 64), (*arg).info, (*(*s).typ).sons->data[((NI) 1)]);
							T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T44_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
							add__P8dDSotTW25BkfbyspojGg(param, T44_);
						}
						goto LA36_;
						LA42_: ;
						{
							param = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
						}
						LA36_: ;
						add__P8dDSotTW25BkfbyspojGg(result, param);
						{
							if (!((IL64(140737496743936) &((NU64)1<<((NU)((*dest).kind)&63U)))!=0)) goto LA48_;
							(*dest).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 20)) & 63);
							result = newDeref__RzKgK8tcIIFHt7HBTQVoYQlowerings(result);
						}
						LA48_: ;
						(*m).convMatches += ((NI) 1);
						{
							NIM_BOOL T54_;
							if (!!((*m).genericConverter)) goto LA52_;
							T54_ = (NIM_BOOL)0;
							T54_ = (srca == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8));
							if (T54_) goto LA55_;
							T54_ = destIsGeneric;
							LA55_: ;
							(*m).genericConverter = T54_;
						}
						LA52_: ;
						goto BeforeRet_;
					}
					LA34_: ;
				} LA5: ;
				i_2 += ((NI) 1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, localConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T12_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*arg).typ == 0)) goto LA3_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (f == (*arg).typ);
		if (!(T7_)) goto LA8_;
		T7_ = ((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = arg;
		goto BeforeRet_;
	}
	LA9_: ;
	call = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*arg).info);
	T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T11_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*f).n);
	add__P8dDSotTW25BkfbyspojGg(call, T11_);
	T12_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T12_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
	add__P8dDSotTW25BkfbyspojGg(call, T12_);
	result = (*c).semTryExpr(c, call, 131072);
	{
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ r;
		if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA15_;
		{
			if (!((*result).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA19_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA19_: ;
		result = (*c).semExpr(c, call, 0);
		r = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, (*f).sons->data[((NI) 0)], (*result).typ, 0);
		{
			if (!(r < ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA23_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		LA23_: ;
		{
			if (!((*result).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27))) goto LA27_;
			transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag(result, ((tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g) 32));
		}
		LA27_: ;
		(*m).convMatches += ((NI) 1);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T33_;
			if (!(r == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8))) goto LA31_;
			T33_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T33_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
			asgnRef((void**) (&(*result).typ), getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow(c, arg, (&(*m)), T33_));
		}
		LA31_: ;
		(*m).baseTypeMatch = NIM_TRUE;
	}
	LA15_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, paramTypesMatchAux__nswM7DVSnPjX5r3urUls5Q)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argSemantized, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argOrig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fMaybeStatic;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a_2;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	NI oldInheritancePenalty;
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ r;
	NI bothMetaCounter;
	NI lastBindingsLength;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	fMaybeStatic = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(f, 8192);
	arg = argSemantized;
	a_2 = a;
	c = (*m).c;
	{
		if (!(((*fMaybeStatic).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 24))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*a_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12));
			if (!(T7_)) goto LA8_;
			T7_ = (((*a_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 30))&63U)))!=0);
			LA8_: ;
			if (!T7_) goto LA9_;
			assignType__RDstL9c8H9bSHUphDz0iB0hg(a_2, f);
			result = argSemantized;
			goto BeforeRet_;
		}
		LA9_: ;
		{
			if (!((*a_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60))) goto LA13_;
			{
				NIM_BOOL T17_;
				NIM_BOOL T18_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
				T17_ = (NIM_BOOL)0;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*(*m).callee).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10));
				if (!(T18_)) goto LA19_;
				T18_ = ((*a_2).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
				LA19_: ;
				T17_ = T18_;
				if (!(T17_)) goto LA20_;
				T17_ = !((((*a_2).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 25))&63U)))!=0));
				LA20_: ;
				if (!T17_) goto LA21_;
				T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T23_ = makeTypeFromExpr__D2YW7F23KYvdV39aTScM3IQ(c, arg);
				result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4), (*argOrig).info, T23_);
				goto BeforeRet_;
			}
			LA21_: ;
		}
		goto LA11_;
		LA13_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* evaluated;
			evaluated = (*c).semTryConstExpr(c, arg);
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
				if (!!((evaluated == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA27_;
				typ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60), c);
				if ((*typ).sons) { nimGCunrefNoCycle((*typ).sons); (*typ).sons = NIM_NIL; }
				(*typ).sons = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) newSeqRC1((&NTI__Ef05srmQTDulnBdXR4Ja6Q_), 1);
				asgnRef((void**) (&(*typ).sons->data[0]), (*evaluated).typ);
				asgnRef((void**) (&(*typ).n), evaluated);
				arg = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
				asgnRef((void**) (&(*arg).typ), typ);
				a_2 = typ;
			}
			goto LA25_;
			LA27_: ;
			{
				{
					if (!((*(*m).callee).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10))) goto LA32_;
					{
						NIM_BOOL T36_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T38_;
						tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T39_;
						T36_ = (NIM_BOOL)0;
						T36_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
						if (!(T36_)) goto LA37_;
						T38_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T38_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
						T39_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
						T39_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, T38_, a_2, 0);
						T36_ = !((T39_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
						LA37_: ;
						if (!T36_) goto LA40_;
						result = makeStaticExpr__g3ODV709caO5lfQfPGeUxSQ((*m).c, arg);
						(*(*result).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9)) & 63);
						asgnRef((void**) (&(*(*result).typ).n), arg);
						goto BeforeRet_;
					}
					LA40_: ;
				}
				LA32_: ;
			}
			LA25_: ;
		}
		LA11_: ;
	}
	LA3_: ;
	oldInheritancePenalty = (*m).inheritancePenalty;
	r = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, f, a_2, 0);
	{
		NIM_BOOL T44_;
		NIM_BOOL T45_;
		T44_ = (NIM_BOOL)0;
		T45_ = (NIM_BOOL)0;
		T45_ = !((r == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)));
		if (!(T45_)) goto LA46_;
		T45_ = !(((*m).calleeSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		LA46_: ;
		T44_ = T45_;
		if (!(T44_)) goto LA47_;
		T44_ = ((393216 &((NU32)1<<((NU)((*(*m).calleeSym).kind)&31U)))!=0);
		LA47_: ;
		if (!T44_) goto LA48_;
		incMatches__A6Mml3n6SH4wRXsgNwTrfQ(m, r, ((NI) 1));
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7))) goto LA52_;
			result = arg;
			goto BeforeRet_;
		}
		goto LA50_;
		LA52_: ;
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA55_;
			result = arg;
			goto BeforeRet_;
		}
		goto LA50_;
		LA55_: ;
		{
			NIM_BOOL T58_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
			if (!(T58_)) goto LA59_;
			T58_ = !(((*(*arg).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA59_: ;
			if (!T58_) goto LA60_;
			result = (*(*arg).typ).n;
			goto BeforeRet_;
		}
		goto LA50_;
		LA60_: ;
		{
			result = argSemantized;
			goto BeforeRet_;
		}
		LA50_: ;
	}
	LA48_: ;
	bothMetaCounter = ((NI) 0);
	lastBindingsLength = ((NI) -1);
	{
		while (1) {
			NIM_BOOL T65_;
			NIM_BOOL T66_;
			T65_ = (NIM_BOOL)0;
			T66_ = (NIM_BOOL)0;
			T66_ = (r == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5));
			if (!(T66_)) goto LA67_;
			T66_ = !((lastBindingsLength == (*m).bindings.counter));
			LA67_: ;
			T65_ = T66_;
			if (!(T65_)) goto LA68_;
			T65_ = (bothMetaCounter < ((NI) 100));
			LA68_: ;
			if (!T65_) goto LA64;
			lastBindingsLength = (*m).bindings.counter;
			bothMetaCounter += ((NI) 1);
			{
				if (!((*arg).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) && (*arg).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159))) goto LA71_;
				result = (*c).semInferredLambda.ClE_0? (*c).semInferredLambda.ClP_0(c, (*m).bindings, arg, (*c).semInferredLambda.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_33)((*c).semInferredLambda.ClP_0))(c, (*m).bindings, arg);
			}
			goto LA69_;
			LA71_: ;
			{
				if (!!(((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA74_;
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
				goto BeforeRet_;
			}
			goto LA69_;
			LA74_: ;
			{
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* inferred;
				inferred = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info, (*c).semGenerateInstance.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_34)((*c).semGenerateInstance.ClP_0))(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info);
				result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(inferred, (*arg).info);
			}
			LA69_: ;
			(*m).convMatches += ((NI) 1);
			arg = result;
			r = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, f, (*arg).typ, 0);
		} LA64: ;
	}
	switch (r) {
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 1):
	{
		(*m).convMatches += ((NI) 1);
		result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 2):
	{
		(*m).intConvMatches += ((NI) 1);
		result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3):
	{
		(*m).subtypeMatches += ((NI) 1);
		{
			if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA82_;
			result = arg;
		}
		goto LA80_;
		LA82_: ;
		{
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), f, arg, (&(*m)), c);
		}
		LA80_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 4):
	{
		(*m).subtypeMatches += ((NI) 1);
		{
			if (!((8388608 &((NU64)1<<((NU)((*f).kind)&63U)))!=0)) goto LA88_;
			result = arg;
		}
		goto LA86_;
		LA88_: ;
		{
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, arg, (&(*m)), c);
		}
		LA86_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 6):
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 7):
	{
		{
			if (!((*arg).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) && (*arg).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159))) goto LA94_;
			result = (*c).semInferredLambda.ClE_0? (*c).semInferredLambda.ClP_0(c, (*m).bindings, arg, (*c).semInferredLambda.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_39)((*c).semInferredLambda.ClP_0))(c, (*m).bindings, arg);
		}
		goto LA92_;
		LA94_: ;
		{
			if (!!(((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA97_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			goto BeforeRet_;
		}
		goto LA92_;
		LA97_: ;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* inferred_2;
			inferred_2 = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info, (*c).semGenerateInstance.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_40)((*c).semGenerateInstance.ClP_0))(c, (*arg)._kind_4.sym, (*m).bindings, (*arg).info);
			result = newSymNode__AFd9c9cdRrILXl9anrr9aRvqig(inferred_2, (*arg).info);
		}
		LA92_: ;
		{
			if (!(r == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 7))) goto LA102_;
			(*m).convMatches += ((NI) 1);
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, result, (&(*m)), c);
		}
		goto LA100_;
		LA102_: ;
		{
			(*m).genericMatches += ((NI) 1);
		}
		LA100_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8):
	{
		(*m).genericMatches += ((NI) 1);
		{
			if (!((*arg).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA108_;
			result = arg;
		}
		goto LA106_;
		LA108_: ;
		{
			NIM_BOOL T111_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T112_;
			T111_ = (NIM_BOOL)0;
			T112_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T112_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36275087632017424));
			T111_ = ((*T112_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
			if (T111_) goto LA113_;
			T111_ = (oldInheritancePenalty < (*m).inheritancePenalty);
			LA113_: ;
			if (!T111_) goto LA114_;
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), f, arg, (&(*m)), c);
		}
		goto LA106_;
		LA114_: ;
		{
			NIM_BOOL T117_;
			T117_ = (NIM_BOOL)0;
			T117_ = isEmptyContainer__YPjOkGV9axAnGR3UfLeWZ1g_4((*arg).typ);
			if (!T117_) goto LA118_;
			result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
			asgnRef((void**) (&(*result).typ), getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow(c, arg, (&(*m)), f));
		}
		goto LA106_;
		LA118_: ;
		{
			result = arg;
		}
		LA106_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 5):
	{
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 9):
	{
		(*m).intConvMatches += ((NI) 256);
		result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, arg, (&(*m)), c);
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10):
	{
		(*m).exactMatches += ((NI) 1);
		result = arg;
		{
			NIM_BOOL T126_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T127_;
			NIM_BOOL T129_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T131_;
			T126_ = (NIM_BOOL)0;
			T127_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T127_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(f, IL64(36275087632017424));
			T126_ = ((*T127_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
			if (T126_) goto LA128_;
			T129_ = (NIM_BOOL)0;
			T129_ = !(((*arg).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T129_)) goto LA130_;
			T131_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T131_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*arg).typ, IL64(36275087632017424));
			T129_ = ((*T131_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
			LA130_: ;
			T126_ = T129_;
			LA128_: ;
			if (!T126_) goto LA132_;
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), f, arg, (&(*m)), c);
		}
		LA132_: ;
	}
	break;
	case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0):
	{
		{
			if (!((IL64(2306968909120536576) &((NU64)1<<((NU)((*a_2).kind)&63U)))!=0)) goto LA137_;
			(*m).genericMatches += ((NI) 1);
			(*m).fauxMatch = (*a_2).kind;
			result = arg;
			goto BeforeRet_;
		}
		goto LA135_;
		LA137_: ;
		{
			NIM_BOOL T140_;
			NIM_BOOL T141_;
			NIM_BOOL T143_;
			NIM_BOOL T144_;
			NIM_BOOL T145_;
			NI T147_;
			NIM_BOOL T150_;
			tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* p;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lifted;
			tyArray__jlWPjgtbdjE069arIWHC9c9bg T155_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T156_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T157_;
			T140_ = (NIM_BOOL)0;
			T141_ = (NIM_BOOL)0;
			T141_ = ((*a_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 63));
			if (!(T141_)) goto LA142_;
			T143_ = (NIM_BOOL)0;
			T144_ = (NIM_BOOL)0;
			T145_ = (NIM_BOOL)0;
			T145_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			if (!(T145_)) goto LA146_;
			T147_ = (NI)0;
			T147_ = len__5mJADrRYkP3r9auuiuDZN9cQast(f);
			T145_ = (T147_ == ((NI) 1));
			LA146_: ;
			T144_ = T145_;
			if (!(T144_)) goto LA148_;
			T144_ = ((*f).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
			LA148_: ;
			T143_ = T144_;
			if (T143_) goto LA149_;
			T150_ = (NIM_BOOL)0;
			T150_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51));
			if (!(T150_)) goto LA151_;
			T150_ = ((*(*f).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
			LA151_: ;
			T143_ = T150_;
			LA149_: ;
			T141_ = T143_;
			LA142_: ;
			T140_ = T141_;
			if (!(T140_)) goto LA152_;
			T140_ = ((*argOrig).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115));
			LA152_: ;
			if (!T140_) goto LA153_;
			p = (*c).graph;
			nimZeroMem((void*)T155_, sizeof(tyArray__jlWPjgtbdjE069arIWHC9c9bg));
			T155_[0] = (*p).emptyNode;
			T156_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T156_ = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), T155_, 1);
			T157_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T157_ = newProcNode__g5PEkYP0A0RT03uHbJ6wKQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52), (*argOrig).info, argOrig, T156_, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode, (*p).emptyNode);
			lifted = (*c).semExpr(c, T157_, 0);
			{
				if (!((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51))) goto LA160_;
				(*m).genericMatches += ((NI) 1);
				put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(m, f, (*lifted).typ);
			}
			LA160_: ;
			(*m).convMatches += ((NI) 1);
			result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), f, lifted, (&(*m)), c);
			goto BeforeRet_;
		}
		goto LA135_;
		LA153_: ;
		LA135_: ;
		result = userConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w(c, m, f, a_2, arg);
		{
			NIM_BOOL T164_;
			T164_ = (NIM_BOOL)0;
			T164_ = (result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			if (!(T164_)) goto LA165_;
			T164_ = ((*f).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48));
			LA165_: ;
			if (!T164_) goto LA166_;
			{
				if (!!(((*f).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA170_;
				result = localConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w_2(c, m, f, a_2, arg);
			}
			goto LA168_;
			LA170_: ;
			{
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T173_;
				T173_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T173_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
				r = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA(m, T173_, a_2, 0);
				switch (r) {
				case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8):
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T175_;
					(*m).convMatches += ((NI) 1);
					result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
					T175_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T175_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					asgnRef((void**) (&(*result).typ), getInstantiatedType__z9aG9avyRv9aLw1OJcFMh8bow(c, arg, (&(*m)), T175_));
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 9):
				{
					(*m).intConvMatches += ((NI) 256);
					result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), (*f).sons->data[((NI) 0)], arg, (&(*m)), c);
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 10):
				{
					(*m).convMatches += ((NI) 1);
					result = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(arg);
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				case ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 3):
				{
					(*m).subtypeMatches += ((NI) 1);
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T181_;
						T181_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T181_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
						if (!((*T181_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA182_;
						result = arg;
					}
					goto LA179_;
					LA182_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T185_;
						T185_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T185_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
						result = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 59), T185_, arg, (&(*m)), c);
					}
					LA179_: ;
					(*m).baseTypeMatch = NIM_TRUE;
				}
				break;
				default:
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T187_;
					T187_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T187_ = base__PfgI9ap7WOnsRfFV4znQ27w(f);
					result = userConvMatch__BJPd9cq0VOz9aNeDyOE3Wq4w(c, m, T187_, a_2, arg);
					{
						if (!!((result == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA190_;
						(*m).baseTypeMatch = NIM_TRUE;
					}
					LA190_: ;
				}
				break;
				}
			}
			LA168_: ;
		}
		LA166_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, copyCandidate__6gwMmb9c2kKKE0RsLWc5nig)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b) {
	unsureAsgnRef((void**) (&(*a).c), (*b).c);
	(*a).exactMatches = (*b).exactMatches;
	(*a).subtypeMatches = (*b).subtypeMatches;
	(*a).convMatches = (*b).convMatches;
	(*a).intConvMatches = (*b).intConvMatches;
	(*a).genericMatches = (*b).genericMatches;
	(*a).state = (*b).state;
	unsureAsgnRef((void**) (&(*a).callee), (*b).callee);
	unsureAsgnRef((void**) (&(*a).calleeSym), (*b).calleeSym);
	unsureAsgnRef((void**) (&(*a).call), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*b).call));
	(*a).baseTypeMatch = (*b).baseTypeMatch;
	copyIdTable__kWmPoTDdSpeN1EEQ59bRmKA((&(*a).bindings), (*b).bindings);
}
N_LIB_PRIVATE N_NIMCALL(NI, checkGeneric__K2h4nBXAyIEnS4gvLx162g_2)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b) {
	NI result;
	tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* aa;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bb;
	NI winner;
{	result = (NI)0;
	c = (*a).c;
	aa = (*a).callee;
	bb = (*b).callee;
	winner = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__5mJADrRYkP3r9auuiuDZN9cQast(aa);
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast(bb);
		colontmp_ = ((T2_ <= T3_) ? T2_ : T3_);
		i_2 = ((NI) 1);
		{
			while (1) {
				tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA ma;
				tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ tra;
				tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA mb;
				tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ trb;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				nimZeroMem((void*)(&ma), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
				newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*bb).sons->data[i], (&ma));
				tra = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&ma), (*bb).sons->data[i], (*aa).sons->data[i], 1);
				nimZeroMem((void*)(&mb), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
				newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*aa).sons->data[i], (&mb));
				trb = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&mb), (*aa).sons->data[i], (*bb).sons->data[i], 1);
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = (tra == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8));
					if (!(T8_)) goto LA9_;
					T8_ = (trb == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0));
					LA9_: ;
					if (!T8_) goto LA10_;
					{
						if (!(winner == ((NI) -1))) goto LA14_;
						result = ((NI) 0);
						goto BeforeRet_;
					}
					LA14_: ;
					winner = ((NI) 1);
				}
				LA10_: ;
				{
					NIM_BOOL T18_;
					T18_ = (NIM_BOOL)0;
					T18_ = (trb == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 8));
					if (!(T18_)) goto LA19_;
					T18_ = (tra == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0));
					LA19_: ;
					if (!T18_) goto LA20_;
					{
						if (!(winner == ((NI) 1))) goto LA24_;
						result = ((NI) 0);
						goto BeforeRet_;
					}
					LA24_: ;
					winner = ((NI) -1);
				}
				LA20_: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	result = winner;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, sumGeneric__thN9cO4mDmZW8QN0cIQUBlA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NI result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NI isvar;
{	result = (NI)0;
	t_2 = t;
	isvar = ((NI) 1);
	{
		while (1) {
			switch ((*t_2).kind) {
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 49):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 47):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45):
			{
				t_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
				result += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 57):
			{
				NI maxBranch;
				maxBranch = ((NI) 0);
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** branch;
					NI i;
					NI L;
					NI T6_;
					branch = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
					i = ((NI) 0);
					T6_ = ((*t_2).sons ? (*t_2).sons->Sup.len : 0);
					L = T6_;
					{
						while (1) {
							NI branchSum;
							if (!(i < L)) goto LA8;
							branch = &(*t_2).sons->data[i];
							branchSum = sumGeneric__thN9cO4mDmZW8QN0cIQUBlA((*branch));
							{
								if (!(maxBranch < branchSum)) goto LA11_;
								maxBranch = branchSum;
							}
							LA11_: ;
							i += ((NI) 1);
						} LA8: ;
					}
				}
				result += maxBranch;
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 23):
			{
				t_2 = (*t_2).sons->data[((NI) 0)];
				result += ((NI) 1);
				isvar += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8):
			{
				t_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
				{
					if (!((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3))) goto LA17_;
					goto LA1;
				}
				LA17_: ;
				result += ((NI) 1);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56):
			{
				result += ((IL64(72057594037928448) &((NU64)1<<((NU)((*t_2).kind)&63U)))!=0);
				{
					NI i_2;
					NI colontmp_;
					NI i_3;
					i_2 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t_2);
					i_3 = ((NI) 0);
					{
						while (1) {
							if (!(i_3 < colontmp_)) goto LA22;
							i_2 = i_3;
							{
								NI T27_;
								if (!!(((*t_2).sons->data[i_2] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA25_;
								T27_ = (NI)0;
								T27_ = sumGeneric__thN9cO4mDmZW8QN0cIQUBlA((*t_2).sons->data[i_2]);
								result += T27_;
							}
							LA25_: ;
							i_3 += ((NI) 1);
						} LA22: ;
					}
				}
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
			{
				NI T29_;
				T29_ = (NI)0;
				T29_ = sumGeneric__thN9cO4mDmZW8QN0cIQUBlA((*t_2).sons->data[((NI) 0)]);
				result = (NI)(T29_ + ((NI) 1));
				goto BeforeRet_;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 7):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
			{
				t_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
			}
			break;
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
			case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54):
			{
				result = isvar;
				goto BeforeRet_;
			}
			break;
			default:
			{
				result = ((NI) 0);
				goto BeforeRet_;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, complexDisambiguation__k9aBdDx9b2bJWirx4sqr6Jqg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* b) {
	NI result;
	NI winner;
{	result = (NI)0;
	winner = ((NI) 0);
	{
		NI i;
		NI colontmp_;
		NI T2_;
		NI T3_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__5mJADrRYkP3r9auuiuDZN9cQast(a);
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast(b);
		colontmp_ = ((T2_ <= T3_) ? T2_ : T3_);
		i_2 = ((NI) 1);
		{
			while (1) {
				NI x;
				NI y;
				if (!(i_2 < colontmp_)) goto LA5;
				i = i_2;
				x = sumGeneric__thN9cO4mDmZW8QN0cIQUBlA((*a).sons->data[i]);
				y = sumGeneric__thN9cO4mDmZW8QN0cIQUBlA((*b).sons->data[i]);
				{
					if (!!((x == y))) goto LA8_;
					{
						if (!(winner == ((NI) 0))) goto LA12_;
						{
							if (!(y < x)) goto LA16_;
							winner = ((NI) 1);
						}
						goto LA14_;
						LA16_: ;
						{
							winner = ((NI) -1);
						}
						LA14_: ;
					}
					goto LA10_;
					LA12_: ;
					{
						if (!(y < x)) goto LA20_;
						{
							if (!!((winner == ((NI) 1)))) goto LA24_;
							result = ((NI) 0);
							goto BeforeRet_;
						}
						LA24_: ;
					}
					goto LA10_;
					LA20_: ;
					{
						{
							if (!!((winner == ((NI) -1)))) goto LA29_;
							result = ((NI) 0);
							goto BeforeRet_;
						}
						LA29_: ;
					}
					LA10_: ;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA5: ;
		}
	}
	result = winner;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpCandidates__K2h4nBXAyIEnS4gvLx162g)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* a, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* b) {
	NI result;
{	result = (NI)0;
	result = (NI)((*a).exactMatches - (*b).exactMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = (NI)((*a).genericMatches - (*b).genericMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	result = (NI)((*a).subtypeMatches - (*b).subtypeMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	result = (NI)((*a).intConvMatches - (*b).intConvMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	result = (NI)((*a).convMatches - (*b).convMatches);
	{
		if (!!((result == ((NI) 0)))) goto LA19_;
		goto BeforeRet_;
	}
	LA19_: ;
	result = (NI)((*b).inheritancePenalty - (*a).inheritancePenalty);
	{
		if (!!((result == ((NI) 0)))) goto LA23_;
		goto BeforeRet_;
	}
	LA23_: ;
	result = checkGeneric__K2h4nBXAyIEnS4gvLx162g_2(a, b);
	{
		if (!!((result == ((NI) 0)))) goto LA27_;
		goto BeforeRet_;
	}
	LA27_: ;
	result = complexDisambiguation__k9aBdDx9b2bJWirx4sqr6Jqg((*a).callee, (*b).callee);
	{
		if (!!((result == ((NI) 0)))) goto LA31_;
		goto BeforeRet_;
	}
	LA31_: ;
	result = (NI)((*a).calleeScope - (*b).calleeScope);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, paramTypesMatch__MkZIYaWSL2Febv66liB9aIA)(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argOrig) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (arg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = !(((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = paramTypesMatchAux__nswM7DVSnPjX5r3urUls5Q(m, f, a, arg, argOrig);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA x;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA T8_;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA y;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA T9_;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA z;
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA T10_;
		NI best;
		c = (*m).c;
		nimZeroMem((void*)(&x), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		nimZeroMem((void*)(&T8_), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*m).callee, (&T8_));
		nimCopyMem((void*)(&x), (NIM_CONST void*)(&T8_), sizeof(x));
		nimZeroMem((void*)(&y), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*m).callee, (&T9_));
		nimCopyMem((void*)(&y), (NIM_CONST void*)(&T9_), sizeof(y));
		nimZeroMem((void*)(&z), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		nimZeroMem((void*)(&T10_), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*m).callee, (&T10_));
		nimCopyMem((void*)(&z), (NIM_CONST void*)(&T10_), sizeof(z));
		x.calleeSym = (*m).calleeSym;
		y.calleeSym = (*m).calleeSym;
		z.calleeSym = (*m).calleeSym;
		best = ((NI) -1);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(arg);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA13;
					i = i_2;
					{
						{
							tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ r;
							if (!((520192 &((NU32)1<<((NU)((*(*(*arg)._kind_6.sons->data[i])._kind_4.sym).kind)&31U)))!=0)) goto LA17_;
							copyCandidate__6gwMmb9c2kKKE0RsLWc5nig((&z), (&(*m)));
							z.callee = (*(*arg)._kind_6.sons->data[i]).typ;
							{
								if (!(((*z.callee).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 9))&63U)))!=0)) goto LA21_;
								goto LA14;
							}
							LA21_: ;
							z.calleeSym = (*(*arg)._kind_6.sons->data[i])._kind_4.sym;
							r = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&z), f, (*(*arg)._kind_6.sons->data[i]).typ, 0);
							incMatches__A6Mml3n6SH4wRXsgNwTrfQ((&z), r, ((NI) 2));
							{
								if (!!((r == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0)))) goto LA25_;
								z.state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1);
								switch (x.state) {
								case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0):
								case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2):
								{
									genericAssign((void*)(&x), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
									best = i;
								}
								break;
								case ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1):
								{
									NI cmp;
									cmp = cmpCandidates__K2h4nBXAyIEnS4gvLx162g((&x), (&z));
									{
										if (!(cmp < ((NI) 0))) goto LA31_;
										best = i;
										genericAssign((void*)(&x), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
									}
									goto LA29_;
									LA31_: ;
									{
										if (!(cmp == ((NI) 0))) goto LA34_;
										genericAssign((void*)(&y), (void*)(&z), (&NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_));
									}
									goto LA29_;
									LA34_: ;
									LA29_: ;
								}
								break;
								}
							}
							LA25_: ;
						}
						LA17_: ;
					} LA14: ;
					i_2 += ((NI) 1);
				} LA13: ;
			}
		}
		{
			if (!(x.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 0))) goto LA38_;
			result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		goto LA36_;
		LA38_: ;
		{
			NIM_BOOL T41_;
			NI T43_;
			T41_ = (NIM_BOOL)0;
			T41_ = (y.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1));
			if (!(T41_)) goto LA42_;
			T43_ = (NI)0;
			T43_ = cmpCandidates__K2h4nBXAyIEnS4gvLx162g((&x), (&y));
			T41_ = (T43_ == ((NI) 0));
			LA42_: ;
			if (!T41_) goto LA44_;
			{
				if (!!((x.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1)))) goto LA48_;
				internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*(*m).c).graph).config, (*arg).info, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_60), TM__EV5hHJmjIY9cla9b9be7fSVJQ_61);
			}
			LA48_: ;
			{
				if (!((192 &((NU64)1<<((NU)((*f).kind)&63U)))!=0)) goto LA52_;
				result = arg;
			}
			goto LA50_;
			LA52_: ;
			{
				result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
			}
			LA50_: ;
		}
		goto LA36_;
		LA44_: ;
		{
			markUsed__QlWTWY7567sCdiTkeUTTDA((*m).c, (*arg).info, (*(*arg)._kind_6.sons->data[best])._kind_4.sym);
			result = paramTypesMatchAux__nswM7DVSnPjX5r3urUls5Q(m, f, (*(*arg)._kind_6.sons->data[best]).typ, (*arg)._kind_6.sons->data[best], argOrig);
		}
		LA36_: ;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, find__9cqYOCx35UdU7TYhesWvYeAsystem)(NI* a, NI aLen_0, NI item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NI* i;
		NI i_2;
		i = (NI*)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = (&a[i_2]);
				{
					if (!((*i) == item)) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__RQ7v5MK0dOhApn0wj6F1iAsystem)(NI* a, NI aLen_0, NI item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__9cqYOCx35UdU7TYhesWvYeAsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argtypeMatches__gpWCq1law3K3m6Z2JETYnw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a, NIM_BOOL fromHlo) {
	NIM_BOOL result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res;
	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, f, (&m));
	res = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA((&m), f, a, (*(*c).graph).emptyNode, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	{
		if (!!(fromHlo)) goto LA3_;
		result = !((res == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = !((res == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = (m.convMatches == ((NI) 0));
		LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T6_ = contains__RQ7v5MK0dOhApn0wj6F1iAsystem(TM__EV5hHJmjIY9cla9b9be7fSVJQ_62, 2, m.intConvMatches);
		LA9_: ;
		result = T6_;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, typeFits__OIugBvRq9c2phfT0MWx8Gcgsigmatch)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* firstArg) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
		T4_ = (((NI) 1) < T6_);
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = !(((*(*s).typ).sons->data[((NI) 1)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA7_: ;
		if (!T3_) goto LA8_;
		m = getModule__xfh8ar7fDxVX2A4OO9b5sqQ(s);
		{
			NIM_BOOL T12_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* exp_1;
			T12_ = (NIM_BOOL)0;
			T12_ = !((m == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T12_)) goto LA13_;
			T12_ = (((*m).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 15))&63U)))!=0);
			LA13_: ;
			if (!T12_) goto LA14_;
			{
				if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7))) goto LA18_;
				goto BeforeRet_;
			}
			LA18_: ;
			exp_1 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*s).typ).sons->data[((NI) 1)], IL64(211106240923664));
			{
				if (!((*exp_1).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA22_;
				exp_1 = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(exp_1);
			}
			LA22_: ;
			{
				if (!((IL64(576460752303427776) &((NU64)1<<((NU)((*exp_1).kind)&63U)))!=0)) goto LA26_;
				goto BeforeRet_;
			}
			LA26_: ;
		}
		LA14_: ;
		result = argtypeMatches__gpWCq1law3K3m6Z2JETYnw(c, (*(*s).typ).sons->data[((NI) 1)], firstArg, NIM_FALSE);
	}
	LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getQuality__vHs9cON0sbP6NRfnEp9aW1yw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NI result;
{	result = (NI)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* exp_1;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
		T3_ = (((NI) 1) < T5_);
		LA4_: ;
		if (!T3_) goto LA6_;
		exp_1 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*s).typ).sons->data[((NI) 1)], IL64(211106240923664));
		{
			if (!((*exp_1).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA10_;
			exp_1 = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(exp_1);
		}
		LA10_: ;
		{
			if (!((IL64(576460752303427776) &((NU64)1<<((NU)((*exp_1).kind)&63U)))!=0)) goto LA14_;
			result = ((NI) 50);
			goto BeforeRet_;
		}
		LA14_: ;
	}
	LA6_: ;
	result = ((NI) 100);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestOperations__dyCk01GCQtAHexivg9cHqOQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	NIM_BOOL isLocal;
	NI scopeN;
	info = (*n).info;
	isLocal = NIM_TRUE;
	scopeN = ((NI) 0);
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA6_;
					isLocal = NIM_FALSE;
				}
				LA6_: ;
				scopeN -= ((NI) 1);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* item;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					item = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it), (*scope).symbols);
					{
						while (1) {
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it_2;
							tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
							item = s;
							it_2 = item;
							pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
							{
								NIM_BOOL T13_;
								NI T17_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T18_;
								NI T19_;
								T13_ = (NIM_BOOL)0;
								T13_ = filterSymNoOpr__bcqYtfxSrIczthAmGccX0A_2sigmatch(it_2, f, (&pm));
								if (!(T13_)) goto LA14_;
								T13_ = typeFits__OIugBvRq9c2phfT0MWx8Gcgsigmatch(c, it_2, typ);
								LA14_: ;
								if (!T13_) goto LA15_;
								T17_ = (NI)0;
								T17_ = getQuality__vHs9cON0sbP6NRfnEp9aW1yw(it_2);
								T18_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T18_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it_2, isLocal, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), info, T17_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T19_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T19_]), T18_);
							}
							LA15_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it), (*scope).symbols);
						} LA10: ;
					}
				}
				current = (*current).parent;
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w(c, (*n)._kind_6.sons->data[i], f, info, outputs);
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		{
			NI T8_;
			T8_ = (NI)0;
			T8_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(((NI) 0) < T8_)) goto LA9_;
			suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w(c, (*n)._kind_6.sons->data[((NI) 0)], f, info, outputs);
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_4 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
						if (!(i_4 < colontmp__2)) goto LA13;
						i_3 = i_4;
						T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T14_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
						suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w(c, T14_, f, info, outputs);
						i_4 += ((NI) 1);
					} LA13: ;
				}
			}
		}
		LA9_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		suggestField__eY0NQ17HSi1QPRouRIEVXg(c, (*n)._kind_4.sym, f, info, outputs);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestFieldAccess__OR9bF44BXFsRVnhukOo9cgLw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* field, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
	tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
	typ = (*n).typ;
	pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
	{
		if (!(typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			if (!(T7_)) goto LA8_;
			T7_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6));
			LA8_: ;
			if (!T7_) goto LA9_;
			{
				if (!((*n)._kind_4.sym == (*c).module)) goto LA13_;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it_2;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					it = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it_2), (*(*c).topLevelScope).symbols);
					{
						while (1) {
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA17;
							it = s;
							{
								NIM_BOOL T20_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T23_;
								NI T24_;
								T20_ = (NIM_BOOL)0;
								T20_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(it, field, (&pm));
								if (!T20_) goto LA21_;
								T23_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T23_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it, NIM_FALSE, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), (*n).info, ((NI) 100), pm, (((NI) 0) < (*c).inTypeContext), ((NI) -99), NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T24_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T24_]), T23_);
							}
							LA21_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it_2), (*(*c).topLevelScope).symbols);
						} LA17: ;
					}
				}
			}
			goto LA11_;
			LA13_: ;
			{
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it_3;
					tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA colontmp_;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it_4;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s_2;
					it_3 = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&colontmp_), sizeof(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA));
					colontmp_.counter = (*(*n)._kind_4.sym)._kind_3.tab.counter;
					colontmp_.data = (*(*n)._kind_4.sym)._kind_3.tab.data;
					nimZeroMem((void*)(&it_4), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s_2 = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it_4), colontmp_);
					{
						while (1) {
							if (!!((s_2 == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA28;
							it_3 = s_2;
							{
								NIM_BOOL T31_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T34_;
								NI T35_;
								T31_ = (NIM_BOOL)0;
								T31_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(it_3, field, (&pm));
								if (!T31_) goto LA32_;
								T34_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T34_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it_3, NIM_FALSE, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), (*n).info, ((NI) 100), pm, (((NI) 0) < (*c).inTypeContext), ((NI) -99), NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T35_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T35_]), T34_);
							}
							LA32_: ;
							s_2 = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it_4), colontmp_);
						} LA28: ;
					}
				}
			}
			LA11_: ;
		}
		goto LA5_;
		LA9_: ;
		{
			suggestEverything__CNgl7zyt4docO57SnwwZuQ(c, n, field, outputs);
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T38_;
		NIM_BOOL T39_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
		T38_ = (NIM_BOOL)0;
		T39_ = (NIM_BOOL)0;
		T39_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14));
		if (!(T39_)) goto LA40_;
		T39_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		LA40_: ;
		T38_ = T39_;
		if (!(T38_)) goto LA41_;
		T38_ = ((*(*n)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7));
		LA41_: ;
		if (!T38_) goto LA42_;
		t = typ;
		{
			while (1) {
				if (!!((t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA45;
				suggestSymList__Kt0rYFU9b6Yu9b2P7xFWUJ7A(c, (*t).n, field, (*n).info, outputs);
				t = (*t).sons->data[((NI) 0)];
			} LA45: ;
		}
		suggestOperations__dyCk01GCQtAHexivg9cHqOQ(c, n, field, typ, outputs);
	}
	goto LA1_;
	LA42_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig;
		orig = typ;
		typ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(246290619303952));
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
			if (!((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA49_;
			t_2 = typ;
			{
				while (1) {
					suggestObject__2cCDuXP9bu1Mi3kFWFZvc2w(c, (*t_2).n, field, (*n).info, outputs);
					{
						if (!((*t_2).sons->data[((NI) 0)] == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA55_;
						goto LA51;
					}
					LA55_: ;
					t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*t_2).sons->data[((NI) 0)], IL64(36275087638268176));
				}
			} LA51: ;
		}
		goto LA47_;
		LA49_: ;
		{
			NIM_BOOL T58_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18));
			if (!(T58_)) goto LA59_;
			T58_ = !(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			LA59_: ;
			if (!T58_) goto LA60_;
			suggestSymList__Kt0rYFU9b6Yu9b2P7xFWUJ7A(c, (*typ).n, field, (*n).info, outputs);
		}
		goto LA47_;
		LA60_: ;
		LA47_: ;
		suggestOperations__dyCk01GCQtAHexivg9cHqOQ(c, n, field, orig, outputs);
		{
			if (!!((typ == orig))) goto LA64_;
			suggestOperations__dyCk01GCQtAHexivg9cHqOQ(c, n, field, typ, outputs);
		}
		LA64_: ;
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sugExpr__1VfUSh4M09adXSHz7X3Fe9cA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* obj;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix;
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 45))) goto LA3_;
		obj = safeSemExpr__wmMigIhDNhpgfhVcHQRifA(c, (*n)._kind_6.sons->data[((NI) 0)]);
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T9_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T9_ = (NI)0;
			T9_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			T8_ = (T9_ == ((NI) 2));
			if (!(T8_)) goto LA10_;
			T8_ = ((*(*n)._kind_6.sons->data[((NI) 1)]).info.line == (*(*n)._kind_6.sons->data[((NI) 0)]).info.line);
			LA10_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA11_;
			T7_ = !((*(*(*c).graph).config).m.trackPosAttached);
			LA11_: ;
			if (!T7_) goto LA12_;
			prefix = (*n)._kind_6.sons->data[((NI) 1)];
		}
		goto LA5_;
		LA12_: ;
		{
			prefix = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		LA5_: ;
		suggestFieldAccess__OR9bF44BXFsRVnhukOo9cgLw(c, obj, prefix, outputs);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* prefix_2;
		{
			if (!(*(*(*c).graph).config).m.trackPosAttached) goto LA18_;
			prefix_2 = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		}
		goto LA16_;
		LA18_: ;
		{
			prefix_2 = n;
		}
		LA16_: ;
		suggestEverything__CNgl7zyt4docO57SnwwZuQ(c, n, prefix_2, outputs);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nameFits__aJoStyNeZRBrvbk5AX0UaA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* opr;
{	result = (NIM_BOOL)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA3_;
		op = (*n)._kind_6.sons->data[((NI) 0)];
	}
	goto LA1_;
	LA3_: ;
	{
		op = n;
	}
	LA1_: ;
	{
		if (!((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56))) goto LA8_;
		op = (*op)._kind_6.sons->data[((NI) 0)];
	}
	LA8_: ;
	opr = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	switch ((*op).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		opr = (*(*op)._kind_4.sym).name;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		opr = (*op)._kind_5.ident;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	result = ((*opr).Sup.id == (*(*s).name).Sup.id);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initCandidate__KpVjtqarjr9c7ddovPDNqvA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, NIM_BOOL diagnosticsEnabled) {
	initCandidateAux__kxeVK8KvdIa8ne7AuBlgnQsigmatch(ctx, c, (*callee).typ);
	unsureAsgnRef((void**) (&(*c).calleeSym), callee);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((520192 &((NU32)1<<((NU)((*callee).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (calleeScope == ((NI) -1));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T9_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
			T9_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T9_ = originatingModule__lIu8wX6Beq6dBJgESOFFjg_2(callee);
			if (!(T9_ == (*ctx).module)) goto LA10_;
			(*c).calleeScope = ((NI) 2);
			owner = callee;
			{
				while (1) {
					owner = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(owner);
					{
						if (!((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA16_;
						goto LA12;
					}
					LA16_: ;
					(*c).calleeScope += ((NI) 1);
				}
			} LA12: ;
		}
		goto LA7_;
		LA10_: ;
		{
			(*c).calleeScope = ((NI) 1);
		}
		LA7_: ;
	}
	goto LA1_;
	LA5_: ;
	{
		(*c).calleeScope = calleeScope;
	}
	LA1_: ;
	unsureAsgnRef((void**) (&(*c).diagnostics), NIM_NIL);
	(*c).diagnosticsEnabled = diagnosticsEnabled;
	(*c).magic = (*(*c).calleeSym).magic;
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ((&(*c).bindings));
	{
		NIM_BOOL T22_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* typeParams;
		T22_ = (NIM_BOOL)0;
		T22_ = !((binding == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T22_)) goto LA23_;
		T22_ = ((520192 &((NU32)1<<((NU)((*callee).kind)&31U)))!=0);
		LA23_: ;
		if (!T22_) goto LA24_;
		typeParams = (*(*callee).ast)._kind_6.sons->data[((NI) 2)];
		{
			NI i;
			NI colontmp_;
			NI T27_;
			NI T28_;
			NI res;
			i = (NI)0;
			colontmp_ = (NI)0;
			T27_ = (NI)0;
			T27_ = len__P89cqdlERShb9alU3iC0yj8wast(typeParams);
			T28_ = (NI)0;
			T28_ = len__P89cqdlERShb9alU3iC0yj8wast(binding);
			colontmp_ = ((T27_ <= (NI)(T28_ - ((NI) 1))) ? T27_ : (NI)(T28_ - ((NI) 1)));
			res = ((NI) 1);
			{
				while (1) {
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formalTypeParam;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* bound;
					if (!(res <= colontmp_)) goto LA30;
					i = res;
					formalTypeParam = (*(*typeParams)._kind_6.sons->data[(NI)(i - ((NI) 1))]).typ;
					bound = (*(*binding)._kind_6.sons->data[i]).typ;
					{
						if (!!((bound == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA33_;
						{
							if (!((*formalTypeParam).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8))) goto LA37_;
							{
								if (!!(((*bound).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8)))) goto LA41_;
								bound = makeTypeDesc__BhLel1oiCddEysrc3uc6iQ(ctx, bound);
							}
							LA41_: ;
						}
						goto LA35_;
						LA37_: ;
						{
							bound = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(bound, 256);
						}
						LA35_: ;
						put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(c, formalTypeParam, bound);
					}
					LA33_: ;
					res += ((NI) 1);
				} LA30: ;
			}
		}
	}
	LA24_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newCandidate__BdjBO3HF6dSjQEzna7SJ1A)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* ctx, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* callee, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* binding, NI calleeScope, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* Result) {
	unsureAsgnRef((void**)&(*Result).c, NIM_NIL);
	(*Result).exactMatches = 0;
	(*Result).genericMatches = 0;
	(*Result).subtypeMatches = 0;
	(*Result).intConvMatches = 0;
	(*Result).convMatches = 0;
	(*Result).state = 0;
	unsureAsgnRef((void**)&(*Result).callee, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).calleeSym, NIM_NIL);
	(*Result).calleeScope = 0;
	unsureAsgnRef((void**)&(*Result).call, NIM_NIL);
	(*Result).bindings.counter = 0;
	unsureAsgnRef((void**)&(*Result).bindings.data, NIM_NIL);
	(*Result).magic = 0;
	(*Result).baseTypeMatch = 0;
	(*Result).fauxMatch = 0;
	(*Result).genericConverter = 0;
	(*Result).coerceDistincts = 0;
	(*Result).typedescMatched = 0;
	(*Result).isNoCall = 0;
	unsureAsgnRef((void**)&(*Result).inferredTypes, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).diagnostics, NIM_NIL);
	(*Result).inheritancePenalty = 0;
	(*Result).firstMismatch.kind = 0;
	(*Result).firstMismatch.arg = 0;
	unsureAsgnRef((void**)&(*Result).firstMismatch.formal, NIM_NIL);
	(*Result).diagnosticsEnabled = 0;
	initCandidate__KpVjtqarjr9c7ddovPDNqvA(ctx, Result, callee, binding, calleeScope, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, setSon__BZM7caO8KSYHHY8TNvb6UQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI at, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son) {
	NI oldLen;
	oldLen = len__P89cqdlERShb9alU3iC0yj8wast(father);
	{
		if (!(oldLen <= at)) goto LA3_;
		asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*father)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(at + ((NI) 1))))));
	}
	LA3_: ;
	asgnRef((void**) (&(*father)._kind_6.sons->data[at]), son);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, arrayConstr__wDvUGprK4A7uVE8fdY6XSw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), c);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), IL64(-1), info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T1_, NIM_TRUE);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 3), c);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T2_, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	(*(*(*(*t).sons->data[((NI) 0)]).n)._kind_6.sons->data[((NI) 1)])._kind_1.intVal += ((NI) 1);
}
N_LIB_PRIVATE N_NIMCALL(void, prepareNamedParam__tMDbwsTYLLwCGe2R49c2n4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	{
		tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T5_;
		if (!!(((*(*a)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA3_;
		info = (*(*a)._kind_6.sons->data[((NI) 0)]).info;
		T5_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T5_ = considerQuotedIdent__HlOitK5F0BLVCXzV9aaF4aw(c, (*a)._kind_6.sons->data[((NI) 0)], ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		asgnRef((void**) (&(*a)._kind_6.sons->data[((NI) 0)]), newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ(T5_, info));
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, prepareOperand__9bDDu8F9caJW9c9coOiby8kXyQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NI T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*formal).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
		if (!(T3_)) goto LA4_;
		T5_ = (NI)0;
		T5_ = len__5mJADrRYkP3r9auuiuDZN9cQast(formal);
		T3_ = !((T5_ == ((NI) 1)));
		LA4_: ;
		if (!T3_) goto LA6_;
		result = a;
	}
	goto LA1_;
	LA6_: ;
	{
		tySet_tyEnum_TExprFlag__0WWd9a4ssQWuY7Q6ZKepq9cQ flags;
		if (!((*a).typ == 0)) goto LA9_;
		flags = 384;
		result = (*c).semOperand(c, a, flags);
	}
	goto LA1_;
	LA9_: ;
	{
		result = a;
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, result);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, arrayConstr__gCfYOEslDczkFV2a7yIcrw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newTypeS__xb5E2cGIynZweqWlCP8Tig(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16), c);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = makeRangeType__Jrbal1EnVldk9cZ2EZVjuLQ(c, IL64(0), IL64(0), (*n).info, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T1_, NIM_TRUE);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*n).typ, IL64(140737496778752));
	addSonSkipIntLit__2IwAMgUJgjdjR7Qyvt9bjCQ(result, T2_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, prepareOperand__lArHfX4A9cwcRE9cEIjQFVtA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*a).typ == 0)) goto LA3_;
		result = (*c).semOperand(c, a, 256);
	}
	goto LA1_;
	LA3_: ;
	{
		result = a;
		considerGenSyms__mQRLEYWj7fi9a0kZxdT9cvjQ(c, result);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, matchesAux__jWX5qJnM9cS16h0kw9aDyhrg)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* marker) {
	tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	NI a;
	NI f;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
	NI formalLen;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formal;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* container;
{	(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ));
	(*m).firstMismatch.kind = T1_.kind;
	(*m).firstMismatch.arg = T1_.arg;
	unsureAsgnRef((void**) (&(*m).firstMismatch.formal), T1_.formal);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = base__PfgI9ap7WOnsRfFV4znQ27w((*m).callee);
	unsureAsgnRef((void**) (&(*m).call), newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg((*n).kind, (*n).info, T2_));
	add__P8dDSotTW25BkfbyspojGg((*m).call, (*n)._kind_6.sons->data[((NI) 0)]);
	a = ((NI) 1);
	{
		if (!!(((*(*m).callee).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10)))) goto LA5_;
		f = ((NI) 1);
	}
	goto LA3_;
	LA5_: ;
	{
		f = ((NI) 0);
	}
	LA3_: ;
	arg = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	formalLen = len__P89cqdlERShb9alU3iC0yj8wast((*(*m).callee).n);
	{
		if (!(((NI) 1) < formalLen)) goto LA10_;
		formal = (*(*(*(*m).callee).n)._kind_6.sons->data[((NI) 1)])._kind_4.sym;
	}
	goto LA8_;
	LA10_: ;
	{
		formal = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
	}
	LA8_: ;
	container = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		while (1) {
			NI T15_;
			T15_ = (NI)0;
			T15_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(a < T15_)) goto LA14;
			openShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_3(c);
			{
				NIM_BOOL T18_;
				NIM_BOOL T19_;
				NIM_BOOL T22_;
				T18_ = (NIM_BOOL)0;
				T19_ = (NIM_BOOL)0;
				T19_ = ((NI)(formalLen - ((NI) 1)) <= a);
				if (!(T19_)) goto LA20_;
				T19_ = (f < formalLen);
				LA20_: ;
				T18_ = T19_;
				if (!(T18_)) goto LA21_;
				T22_ = (NIM_BOOL)0;
				T22_ = ((*(*(*(*(*m).callee).n)._kind_6.sons->data[f]).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48));
				if (!(T22_)) goto LA23_;
				T22_ = ((*(*(*(*(*(*m).callee).n)._kind_6.sons->data[f]).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
				LA23_: ;
				T18_ = T22_;
				LA21_: ;
				if (!T18_) goto LA24_;
				formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
				incl__jENnK9c9bPE73pKmo2vYjpqg(marker, (*formal).position);
				{
					if (!((*(*n)._kind_6.sons->data[a]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58))) goto LA28_;
					{
						NIM_BOOL T32_;
						T32_ = (NIM_BOOL)0;
						T32_ = ((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
						if (!(T32_)) goto LA33_;
						T32_ = ((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41) || (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152));
						LA33_: ;
						if (!!(T32_)) goto LA34_;
						failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_63));
					}
					LA34_: ;
					setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
				}
				goto LA26_;
				LA28_: ;
				{
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T41_;
						if (!(container == 0)) goto LA39_;
						T41_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T41_ = arrayConstr__wDvUGprK4A7uVE8fdY6XSw(c, (*n).info);
						container = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*(*n)._kind_6.sons->data[a]).info, T41_);
						setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), container);
					}
					goto LA37_;
					LA39_: ;
					{
						incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA((*container).typ);
					}
					LA37_: ;
					add__P8dDSotTW25BkfbyspojGg(container, (*n)._kind_6.sons->data[a]);
				}
				LA26_: ;
			}
			goto LA16_;
			LA24_: ;
			{
				if (!((*(*n)._kind_6.sons->data[a]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33))) goto LA44_;
				(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 2);
				prepareNamedParam__tMDbwsTYLLwCGe2R49c2n4Q((*n)._kind_6.sons->data[a], c);
				{
					if (!!(((*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2)))) goto LA48_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_64), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_65, NIM_FALSE);
					mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
					(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA48_: ;
				formal = getNamedParamFromList__AuQyLRN9a3PM9cDeuxoao3hA((*(*m).callee).n, (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 0)])._kind_5.ident);
				{
					if (!(formal == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA52_;
					mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
					(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA52_: ;
				{
					NIM_BOOL T56_;
					T56_ = (NIM_BOOL)0;
					T56_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(marker, (*formal).position);
					if (!T56_) goto LA57_;
					(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 1);
					mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
					(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA57_: ;
				(*m).baseTypeMatch = NIM_FALSE;
				(*m).typedescMatched = NIM_FALSE;
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]), prepareOperand__9bDDu8F9caJW9c9coOiby8kXyQ(c, (*formal).typ, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]));
				asgnRef((void**) (&(*(*n)._kind_6.sons->data[a]).typ), (*(*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]).typ);
				arg = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)], (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
				(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 3);
				{
					if (!(arg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA61_;
					mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
					(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
					(*m).firstMismatch.arg = a;
					unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
					goto BeforeRet_;
				}
				LA61_: ;
				{
					if (!!(((*formal).constraint == 0))) goto LA65_;
					{
						NIM_BOOL T69_;
						T69_ = (NIM_BOOL)0;
						T69_ = matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw((*formal).constraint, (*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
						if (!T69_) goto LA70_;
						(*m).genericMatches += ((NI) 100);
					}
					goto LA67_;
					LA70_: ;
					{
						mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
						(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA67_: ;
				}
				LA65_: ;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argConverter;
					if (!((8388608 &((NU64)1<<((NU)((*(*formal).typ).kind)&63U)))!=0)) goto LA75_;
					{
						if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA79_;
						argConverter = (*arg)._kind_6.sons->data[((NI) 0)];
					}
					goto LA77_;
					LA79_: ;
					{
						argConverter = arg;
					}
					LA77_: ;
					{
						if (!((*argConverter).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA84_;
						{
							if (!!(((8388608 &((NU64)1<<((NU)((*(*argConverter).typ).kind)&63U)))!=0))) goto LA88_;
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA88_: ;
					}
					goto LA82_;
					LA84_: ;
					{
						NIM_BOOL T91_;
						T91_ = (NIM_BOOL)0;
						T91_ = isLValue__kCP6QlI8uS4X0pOQUdr7tg((*(*n)._kind_6.sons->data[a])._kind_6.sons->data[((NI) 1)]);
						if (!!(T91_)) goto LA92_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
						mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
						(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					goto LA82_;
					LA92_: ;
					LA82_: ;
				}
				LA75_: ;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T98_;
					if (!(*m).baseTypeMatch) goto LA96_;
					T98_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T98_ = arrayConstr__gCfYOEslDczkFV2a7yIcrw(c, arg);
					container = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*(*n)._kind_6.sons->data[a]).info, T98_);
					add__P8dDSotTW25BkfbyspojGg(container, arg);
					setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), container);
					{
						if (!!((f == (NI)(formalLen - ((NI) 1))))) goto LA101_;
						container = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
					}
					LA101_: ;
				}
				goto LA94_;
				LA96_: ;
				{
					setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), arg);
				}
				LA94_: ;
				f += ((NI) 1);
			}
			goto LA16_;
			LA44_: ;
			{
				{
					if (!(formalLen <= f)) goto LA107_;
					{
						if (!(((*(*m).callee).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0))&63U)))!=0)) goto LA111_;
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__lArHfX4A9cwcRE9cEIjQFVtA(c, (*n)._kind_6.sons->data[a]));
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T115_;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T118_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T119_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T120_;
							T115_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T115_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[a]).typ, IL64(36275087632017424));
							if (!((*T115_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28))) goto LA116_;
							T118_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T118_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg((*c).graph, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29));
							T119_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T119_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[a]);
							T120_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T120_ = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), T118_, T119_, (&(*m)), c);
							add__P8dDSotTW25BkfbyspojGg((*m).call, T120_);
						}
						goto LA113_;
						LA116_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T122_;
							T122_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T122_ = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*n)._kind_6.sons->data[a]);
							add__P8dDSotTW25BkfbyspojGg((*m).call, T122_);
						}
						LA113_: ;
					}
					goto LA109_;
					LA111_: ;
					{
						NIM_BOOL T124_;
						T124_ = (NIM_BOOL)0;
						T124_ = !((formal == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T124_)) goto LA125_;
						T124_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48));
						LA125_: ;
						if (!T124_) goto LA126_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 3);
						(*m).baseTypeMatch = NIM_FALSE;
						(*m).typedescMatched = NIM_FALSE;
						incl__jENnK9c9bPE73pKmo2vYjpqg(marker, (*formal).position);
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__9bDDu8F9caJW9c9coOiby8kXyQ(c, (*formal).typ, (*n)._kind_6.sons->data[a]));
						arg = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*n)._kind_6.sons->data[a], (*nOrig)._kind_6.sons->data[a]);
						{
							NIM_BOOL T130_;
							NIM_BOOL T131_;
							T130_ = (NIM_BOOL)0;
							T131_ = (NIM_BOOL)0;
							T131_ = !((arg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
							if (!(T131_)) goto LA132_;
							T131_ = (*m).baseTypeMatch;
							LA132_: ;
							T130_ = T131_;
							if (!(T130_)) goto LA133_;
							T130_ = !((container == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
							LA133_: ;
							if (!T130_) goto LA134_;
							add__P8dDSotTW25BkfbyspojGg(container, arg);
							incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA((*container).typ);
							{
								if (!!(((*formal).constraint == 0))) goto LA138_;
								{
									NIM_BOOL T142_;
									T142_ = (NIM_BOOL)0;
									T142_ = matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw((*formal).constraint, (*n)._kind_6.sons->data[a]);
									if (!T142_) goto LA143_;
									(*m).genericMatches += ((NI) 100);
								}
								goto LA140_;
								LA143_: ;
								{
									mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
									(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
									(*m).firstMismatch.arg = a;
									unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
									goto BeforeRet_;
								}
								LA140_: ;
							}
							LA138_: ;
							{
								tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argConverter_2;
								if (!((8388608 &((NU64)1<<((NU)((*(*formal).typ).kind)&63U)))!=0)) goto LA148_;
								{
									if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA152_;
									argConverter_2 = (*arg)._kind_6.sons->data[((NI) 0)];
								}
								goto LA150_;
								LA152_: ;
								{
									argConverter_2 = arg;
								}
								LA150_: ;
								{
									if (!((*argConverter_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA157_;
									{
										if (!!(((8388608 &((NU64)1<<((NU)((*(*argConverter_2).typ).kind)&63U)))!=0))) goto LA161_;
										(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
										mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
										(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
										(*m).firstMismatch.arg = a;
										unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
										goto BeforeRet_;
									}
									LA161_: ;
								}
								goto LA155_;
								LA157_: ;
								{
									NIM_BOOL T164_;
									T164_ = (NIM_BOOL)0;
									T164_ = isLValue__kCP6QlI8uS4X0pOQUdr7tg((*n)._kind_6.sons->data[a]);
									if (!!(T164_)) goto LA165_;
									(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
									mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
									(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
									(*m).firstMismatch.arg = a;
									unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
									goto BeforeRet_;
								}
								goto LA155_;
								LA165_: ;
								LA155_: ;
							}
							LA148_: ;
						}
						goto LA128_;
						LA134_: ;
						{
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA128_: ;
					}
					goto LA109_;
					LA126_: ;
					{
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 6);
						mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
						(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA109_: ;
				}
				goto LA105_;
				LA107_: ;
				{
					{
						if (!!(((*(*(*(*m).callee).n)._kind_6.sons->data[f]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3)))) goto LA172_;
						internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_66), TM__EV5hHJmjIY9cla9b9be7fSVJQ_67);
						mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
						(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA172_: ;
					formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
					(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 3);
					{
						NIM_BOOL T176_;
						T176_ = (NIM_BOOL)0;
						T176_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(marker, (*formal).position);
						if (!(T176_)) goto LA177_;
						T176_ = (container == 0);
						LA177_: ;
						if (!T176_) goto LA178_;
						(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 7);
						mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
						(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
						(*m).firstMismatch.arg = a;
						unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
						goto BeforeRet_;
					}
					LA178_: ;
					{
						NIM_BOOL T182_;
						T182_ = (NIM_BOOL)0;
						T182_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48));
						if (!(T182_)) goto LA183_;
						T182_ = ((*(*(*formal).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
						LA183_: ;
						if (!T182_) goto LA184_;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T190_;
							if (!(container == 0)) goto LA188_;
							T190_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T190_ = arrayConstr__wDvUGprK4A7uVE8fdY6XSw(c, (*n).info);
							container = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*(*n)._kind_6.sons->data[a]).info, T190_);
							setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), container);
						}
						goto LA186_;
						LA188_: ;
						{
							incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA((*container).typ);
						}
						LA186_: ;
						add__P8dDSotTW25BkfbyspojGg(container, (*n)._kind_6.sons->data[a]);
					}
					goto LA180_;
					LA184_: ;
					{
						(*m).baseTypeMatch = NIM_FALSE;
						(*m).typedescMatched = NIM_FALSE;
						asgnRef((void**) (&(*n)._kind_6.sons->data[a]), prepareOperand__9bDDu8F9caJW9c9coOiby8kXyQ(c, (*formal).typ, (*n)._kind_6.sons->data[a]));
						arg = paramTypesMatch__MkZIYaWSL2Febv66liB9aIA(m, (*formal).typ, (*(*n)._kind_6.sons->data[a]).typ, (*n)._kind_6.sons->data[a], (*nOrig)._kind_6.sons->data[a]);
						{
							if (!(arg == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA195_;
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA195_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T207_;
							NI T208_;
							if (!(*m).baseTypeMatch) goto LA199_;
							{
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T205_;
								if (!(container == 0)) goto LA203_;
								T205_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
								T205_ = arrayConstr__gCfYOEslDczkFV2a7yIcrw(c, arg);
								container = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41), (*(*n)._kind_6.sons->data[a]).info, T205_);
								(*(*container).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 0)) & 63);
							}
							goto LA201_;
							LA203_: ;
							{
								incrIndexType__dgcZpiUW2uYjCpxkmV8l9aA((*container).typ);
							}
							LA201_: ;
							add__P8dDSotTW25BkfbyspojGg(container, arg);
							T207_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T207_ = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), (*formal).typ, container, (&(*m)), c);
							setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), T207_);
							T208_ = (NI)0;
							T208_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
							f = ((f >= (NI)((NI)((NI)(formalLen - T208_) + a) + ((NI) 1))) ? f : (NI)((NI)((NI)(formalLen - T208_) + a) + ((NI) 1)));
						}
						goto LA197_;
						LA199_: ;
						{
							NIM_BOOL T210_;
							T210_ = (NIM_BOOL)0;
							T210_ = !(((*(*formal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48)));
							if (T210_) goto LA211_;
							T210_ = (container == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
							LA211_: ;
							if (!T210_) goto LA212_;
							setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), arg);
							f += ((NI) 1);
							container = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
						}
						goto LA197_;
						LA212_: ;
						{
							tyArray__Re75IspeoxXy2oCZHwcRrA T215_;
							NimStringDesc* T216_;
							nimZeroMem((void*)T215_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
							T215_[0] = typeToString__QlvraUan7WbHowhAbvDvdA((*(*n)._kind_6.sons->data[a]).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
							T215_[1] = typeToString__QlvraUan7WbHowhAbvDvdA((*formal).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
							T216_ = (NimStringDesc*)0;
							T216_ = nsuFormatOpenArray(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_68), T215_, 2);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*n)._kind_6.sons->data[a]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T216_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_69, NIM_FALSE);
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA197_: ;
					}
					LA180_: ;
					{
						if (!!(((*formal).constraint == 0))) goto LA219_;
						{
							NIM_BOOL T223_;
							T223_ = (NIM_BOOL)0;
							T223_ = matchNodeKinds__WRbpWXbxOP9c3ULW5bbDujw((*formal).constraint, (*n)._kind_6.sons->data[a]);
							if (!T223_) goto LA224_;
							(*m).genericMatches += ((NI) 100);
						}
						goto LA221_;
						LA224_: ;
						{
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						LA221_: ;
					}
					LA219_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* argConverter_3;
						if (!((8388608 &((NU64)1<<((NU)((*(*formal).typ).kind)&63U)))!=0)) goto LA229_;
						{
							if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65))) goto LA233_;
							argConverter_3 = (*arg)._kind_6.sons->data[((NI) 0)];
						}
						goto LA231_;
						LA233_: ;
						{
							argConverter_3 = arg;
						}
						LA231_: ;
						{
							if (!((*argConverter_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA238_;
							{
								if (!!(((8388608 &((NU64)1<<((NU)((*(*argConverter_3).typ).kind)&63U)))!=0))) goto LA242_;
								(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
								mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
								(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
								(*m).firstMismatch.arg = a;
								unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
								goto BeforeRet_;
							}
							LA242_: ;
						}
						goto LA236_;
						LA238_: ;
						{
							NIM_BOOL T245_;
							T245_ = (NIM_BOOL)0;
							T245_ = isLValue__kCP6QlI8uS4X0pOQUdr7tg((*n)._kind_6.sons->data[a]);
							if (!!(T245_)) goto LA246_;
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 4);
							mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.arg = a;
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto BeforeRet_;
						}
						goto LA236_;
						LA246_: ;
						LA236_: ;
					}
					LA229_: ;
				}
				LA105_: ;
			}
			LA16_: ;
			{
				NIM_BOOL T250_;
				NIM_BOOL T252_;
				T250_ = (NIM_BOOL)0;
				T250_ = ((*m).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1));
				if (!(T250_)) goto LA251_;
				T252_ = (NIM_BOOL)0;
				T252_ = !(((*m).calleeSym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
				if (!(T252_)) goto LA253_;
				T252_ = ((393216 &((NU32)1<<((NU)((*(*m).calleeSym).kind)&31U)))!=0);
				LA253_: ;
				T250_ = !(T252_);
				LA251_: ;
				if (!T250_) goto LA254_;
				mergeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_4(c);
			}
			goto LA248_;
			LA254_: ;
			{
				closeShadowScope__TX9bi5b9bIHR13FiwHwV59a4w_5(c);
			}
			LA248_: ;
			a += ((NI) 1);
		} LA14: ;
	}
	(*m).firstMismatch.arg = a;
	unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, partialMatch__BxEsf1Gt7Hq3usrwPERzyA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg marker;
	nimZeroMem((void*)(&marker), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&marker));
	matchesAux__jWX5qJnM9cS16h0kw9aDyhrg(c, n, nOrig, m, (&marker));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, argsFit__WujSFOET74uwiawdbvuemQ)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* candidate, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*candidate).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
		nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
		newCandidate__BdjBO3HF6dSjQEzna7SJ1A(c, candidate, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((NI) -1), (&m));
		partialMatch__BxEsf1Gt7Hq3usrwPERzyA(c, n, nOrig, (&m));
		result = !((m.state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2)));
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestCall__VcXgzdApjYF6lYmfuQKAog)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	NIM_BOOL isLocal;
	NI scopeN;
	info = (*n).info;
	isLocal = NIM_TRUE;
	scopeN = ((NI) 0);
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA6_;
					isLocal = NIM_FALSE;
				}
				LA6_: ;
				scopeN -= ((NI) 1);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* item;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					item = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it), (*scope).symbols);
					{
						while (1) {
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it_2;
							tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
							item = s;
							it_2 = item;
							pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
							{
								NIM_BOOL T13_;
								NIM_BOOL T14_;
								NI T19_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T20_;
								NI T21_;
								T13_ = (NIM_BOOL)0;
								T14_ = (NIM_BOOL)0;
								T14_ = filterSym__bcqYtfxSrIczthAmGccX0Asigmatch(it_2, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), (&pm));
								if (!(T14_)) goto LA15_;
								T14_ = nameFits__aJoStyNeZRBrvbk5AX0UaA(c, it_2, n);
								LA15_: ;
								T13_ = T14_;
								if (!(T13_)) goto LA16_;
								T13_ = argsFit__WujSFOET74uwiawdbvuemQ(c, it_2, n, nOrig);
								LA16_: ;
								if (!T13_) goto LA17_;
								T19_ = (NI)0;
								T19_ = getQuality__vHs9cON0sbP6NRfnEp9aW1yw(it_2);
								T20_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T20_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it_2, isLocal, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 2), info, T19_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T21_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T21_]), T20_);
							}
							LA17_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it), (*scope).symbols);
						} LA10: ;
					}
				}
				current = (*current).parent;
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, suggestVar__1VfUSh4M09adXSHz7X3Fe9cA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** outputs) {
	tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
	NIM_BOOL isLocal;
	NI scopeN;
	info = (*n).info;
	isLocal = NIM_TRUE;
	scopeN = ((NI) 0);
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA3;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA6_;
					isLocal = NIM_FALSE;
				}
				LA6_: ;
				scopeN -= ((NI) 1);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* item;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					item = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it), (*scope).symbols);
					{
						while (1) {
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it_2;
							tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA10;
							item = s;
							it_2 = item;
							pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
							{
								NIM_BOOL T13_;
								NI T16_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T17_;
								NI T18_;
								T13_ = (NIM_BOOL)0;
								T13_ = nameFits__aJoStyNeZRBrvbk5AX0UaA(c, it_2, n);
								if (!T13_) goto LA14_;
								T16_ = (NI)0;
								T16_ = getQuality__vHs9cON0sbP6NRfnEp9aW1yw(it_2);
								T17_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T17_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it_2, isLocal, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 2), info, T16_, pm, (((NI) 0) < (*c).inTypeContext), scopeN, NIM_FALSE);
								unsureAsgnRef((void**) (&(*outputs)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)((*outputs)), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_)));
								T18_ = (*outputs)->Sup.len++;
								asgnRef((void**) (&(*outputs)->data[T18_]), T17_);
							}
							LA14_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it), (*scope).symbols);
						} LA10: ;
					}
				}
				current = (*current).parent;
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpSuggestions__a8u3Q3vmNopA4GVRUCtBuw)(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* a, tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* b) {
	NI result;
{	result = (NI)0;
	result = (NI)((*b).scope - (*a).scope);
	{
		if (!!((result == ((NI) 0)))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = (NI)(((NI) ((*b).prefix)) - ((NI) ((*a).prefix)));
	{
		if (!!((result == ((NI) 0)))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	result = (NI)(((NI) ((*b).quality)) - ((NI) ((*a).quality)));
	{
		if (!!((result == ((NI) 0)))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	result = (NI)(((NI) ((*b).contextFits)) - ((NI) ((*a).contextFits)));
	{
		if (!!((result == ((NI) 0)))) goto LA15_;
		goto BeforeRet_;
	}
	LA15_: ;
	result = (NI)((*b).localUsages - (*a).localUsages);
	{
		if (!!((result == ((NI) 0)))) goto LA19_;
		goto BeforeRet_;
	}
	LA19_: ;
	result = (NI)((*b).globalUsages - (*a).globalUsages);
	{
		if (!!((result == ((NI) 0)))) goto LA23_;
		goto BeforeRet_;
	}
	LA23_: ;
	result = cmp__NAicU5bAGXmkx2NJujGi7g((*(*a).name), (*(*b).name));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___MsqAj9adr5oy3fofpSrXHeA)(tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* suggest) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = dollar___45FkS6XbvkDha3K7JLSsgQ((*suggest).section);
	result = addChar(result, 9);
	{
		NimStringDesc* T17_;
		NimStringDesc* T18_;
		NimStringDesc* T19_;
		if (!((*suggest).section == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 8))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)) == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8));
			if (!(T7_)) goto LA8_;
			T7_ = (*suggest).isGlobal;
			LA8_: ;
			if (!T7_) goto LA9_;
			result = resizeString(result, 11);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_72));
		}
		goto LA5_;
		LA9_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = (((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)) == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9));
			if (!(T12_)) goto LA13_;
			T12_ = (*suggest).isGlobal;
			LA13_: ;
			if (!T12_) goto LA14_;
			result = resizeString(result, 11);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_73));
		}
		goto LA5_;
		LA14_: ;
		{
			result = resizeString(result, (reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_)) ? reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
		}
		LA5_: ;
		result = addChar(result, 9);
		T17_ = (NimStringDesc*)0;
		T17_ = nimIntToStr((*suggest).line);
		result = resizeString(result, (T17_ ? T17_->Sup.len : 0) + 0);
appendString(result, T17_);
		result = addChar(result, 9);
		T18_ = (NimStringDesc*)0;
		T18_ = nimIntToStr((*suggest).column);
		result = resizeString(result, (T18_ ? T18_->Sup.len : 0) + 0);
appendString(result, T18_);
		result = addChar(result, 9);
		T19_ = (NimStringDesc*)0;
		T19_ = nimIntToStr((*suggest).tokenLen);
		result = resizeString(result, (T19_ ? T19_->Sup.len : 0) + 0);
appendString(result, T19_);
	}
	goto LA1_;
	LA3_: ;
	{
		NimStringDesc* T27_;
		NimStringDesc* T28_;
		result = resizeString(result, (reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_)) ? reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) ((*suggest).symkind)), (&NTI__cNCW9acsSznmEccl1fgQwkw_)));
		result = addChar(result, 9);
		{
			NI T23_;
			NimStringDesc* T26_;
			T23_ = ((*suggest).qualifiedPath ? (*suggest).qualifiedPath->Sup.len : 0);
			if (!!((T23_ == ((NI) 0)))) goto LA24_;
			T26_ = (NimStringDesc*)0;
			T26_ = nsuJoinSep((*suggest).qualifiedPath->data, ((*suggest).qualifiedPath ? (*suggest).qualifiedPath->Sup.len : 0), ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_74));
			result = resizeString(result, (T26_ ? T26_->Sup.len : 0) + 0);
appendString(result, T26_);
		}
		LA24_: ;
		result = addChar(result, 9);
		result = resizeString(result, ((*suggest).forth ? (*suggest).forth->Sup.len : 0) + 0);
appendString(result, (*suggest).forth);
		result = addChar(result, 9);
		result = resizeString(result, ((*suggest).filePath ? (*suggest).filePath->Sup.len : 0) + 0);
appendString(result, (*suggest).filePath);
		result = addChar(result, 9);
		T27_ = (NimStringDesc*)0;
		T27_ = nimIntToStr((*suggest).line);
		result = resizeString(result, (T27_ ? T27_->Sup.len : 0) + 0);
appendString(result, T27_);
		result = addChar(result, 9);
		T28_ = (NimStringDesc*)0;
		T28_ = nimIntToStr((*suggest).column);
		result = resizeString(result, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(result, T28_);
		result = addChar(result, 9);
		{
			NimStringDesc* T33_;
			if (!((*suggest).version == ((NI) 0))) goto LA31_;
			result = addChar(result, 9);
			T33_ = (NimStringDesc*)0;
			T33_ = nimIntToStr(((NI) ((*suggest).quality)));
			result = resizeString(result, (T33_ ? T33_->Sup.len : 0) + 0);
appendString(result, T33_);
			{
				if (!((*suggest).section == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1))) goto LA36_;
				result = addChar(result, 9);
				result = resizeString(result, (reprEnum((NI)(*suggest).prefix, (&NTI__Dkww2nY9cxJVLF9cfoQS5U6Q_)) ? reprEnum((NI)(*suggest).prefix, (&NTI__Dkww2nY9cxJVLF9cfoQS5U6Q_))->Sup.len : 0) + 0);
appendString(result, reprEnum((NI)(*suggest).prefix, (&NTI__Dkww2nY9cxJVLF9cfoQS5U6Q_)));
			}
			LA36_: ;
		}
		LA31_: ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, produceOutput__QAZcajHr1x9cYjb78UsSezg)(tySequence__i7xpiUsxyv6cQ1xK3JbcGQ** a, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	{
		tyProc__pNH4eLNN9aK2oskAhILvUcw T5_;
		if (!((6 &((NU16)1<<((NU)((*conf).ideCmd)&15U)))!=0)) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyProc__pNH4eLNN9aK2oskAhILvUcw));
		T5_.ClP_0 = ((TM__EV5hHJmjIY9cla9b9be7fSVJQ_70) (cmpSuggestions__a8u3Q3vmNopA4GVRUCtBuw)); T5_.ClE_0 = NIM_NIL;
		sort__9bZAwMDiICxVWu0iUtdMZaw((*a)->data, ((*a) ? (*a)->Sup.len : 0), T5_, ((tyEnum_SortOrder__8iBc6wlNqBa9cju9cUAhUAxA) 1));
	}
	LA3_: ;
	{
		NI T8_;
		T8_ = ((*a) ? (*a)->Sup.len : 0);
		if (!((*conf).suggestMaxResults < T8_)) goto LA9_;
		unsureAsgnRef((void**) (&(*a)), (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) setLengthSeqV2(&((*a))->Sup, (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_), ((NI) ((*conf).suggestMaxResults))));
	}
	LA9_: ;
	{
		if (!!(((*conf).suggestionResultHook.ClP_0 == 0))) goto LA13_;
		{
			tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ** s;
			NI i;
			NI L;
			NI T16_;
			s = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ**)0;
			i = ((NI) 0);
			T16_ = ((*a) ? (*a)->Sup.len : 0);
			L = T16_;
			{
				while (1) {
					if (!(i < L)) goto LA18;
					s = &(*a)->data[i];
					(*conf).suggestionResultHook.ClE_0? (*conf).suggestionResultHook.ClP_0((*s), (*conf).suggestionResultHook.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_71)((*conf).suggestionResultHook.ClP_0))((*s));
					i += ((NI) 1);
				} LA18: ;
			}
		}
	}
	goto LA11_;
	LA13_: ;
	{
		{
			tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ** s_2;
			NI i_2;
			NI L_2;
			NI T21_;
			s_2 = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ**)0;
			i_2 = ((NI) 0);
			T21_ = ((*a) ? (*a)->Sup.len : 0);
			L_2 = T21_;
			{
				while (1) {
					NimStringDesc* T24_;
					if (!(i_2 < L_2)) goto LA23;
					s_2 = &(*a)->data[i_2];
					T24_ = (NimStringDesc*)0;
					T24_ = dollar___MsqAj9adr5oy3fofpSrXHeA((*s_2));
					suggestWriteln__NefEsy9c5k5U9cqqVIWMbpKg_2(conf, T24_);
					i_2 += ((NI) 1);
				} LA23: ;
			}
		}
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestExprNoCheck__wb6KhAx6bZ5NV37kY4bXJw_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tySequence__i7xpiUsxyv6cQ1xK3JbcGQ* outputs;
{	{
		if (!(((NI) 0) < (*c).compilesContextId)) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	(*c).compilesContextId += ((NI) 1);
	outputs = NIM_NIL;
	{
		if (!((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1))) goto LA7_;
		sugExpr__1VfUSh4M09adXSHz7X3Fe9cA(c, n, (&outputs));
	}
	goto LA5_;
	LA7_: ;
	{
		if (!((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 2))) goto LA10_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32))) goto LA14_;
			a = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2(n);
			x = safeSemExpr__wmMigIhDNhpgfhVcHQRifA(c, (*n)._kind_6.sons->data[((NI) 0)]);
			{
				NIM_BOOL T18_;
				T18_ = (NIM_BOOL)0;
				T18_ = ((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
				if (T18_) goto LA19_;
				T18_ = ((*x).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA19_: ;
				if (!T18_) goto LA20_;
				x = (*n)._kind_6.sons->data[((NI) 0)];
			}
			LA20_: ;
			add__P8dDSotTW25BkfbyspojGg(a, x);
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
				i_2 = ((NI) 1);
				{
					while (1) {
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x_2;
						if (!(i_2 < colontmp_)) goto LA24;
						i = i_2;
						x_2 = safeSemExpr__wmMigIhDNhpgfhVcHQRifA(c, (*n)._kind_6.sons->data[i]);
						{
							NIM_BOOL T27_;
							T27_ = (NIM_BOOL)0;
							T27_ = ((*x_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
							if (T27_) goto LA28_;
							T27_ = ((*x_2).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
							LA28_: ;
							if (!T27_) goto LA29_;
							goto LA22;
						}
						LA29_: ;
						add__P8dDSotTW25BkfbyspojGg(a, x_2);
						i_2 += ((NI) 1);
					} LA24: ;
				}
			} LA22: ;
			suggestCall__VcXgzdApjYF6lYmfuQKAog(c, a, n, (&outputs));
		}
		goto LA12_;
		LA14_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x_3;
			if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 53) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56))) goto LA32_;
			x_3 = safeSemExpr__wmMigIhDNhpgfhVcHQRifA(c, n);
			{
				NIM_BOOL T36_;
				T36_ = (NIM_BOOL)0;
				T36_ = ((*x_3).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
				if (T36_) goto LA37_;
				T36_ = ((*x_3).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
				LA37_: ;
				if (!T36_) goto LA38_;
				x_3 = n;
			}
			LA38_: ;
			suggestVar__1VfUSh4M09adXSHz7X3Fe9cA_2(c, x_3, (&outputs));
		}
		goto LA12_;
		LA32_: ;
		LA12_: ;
	}
	goto LA5_;
	LA10_: ;
	LA5_: ;
	(*c).compilesContextId -= ((NI) 1);
	{
		NIM_BOOL T42_;
		NI T43_;
		T42_ = (NIM_BOOL)0;
		T43_ = (outputs ? outputs->Sup.len : 0);
		T42_ = (((NI) 0) < T43_);
		if (!(T42_)) goto LA44_;
		T42_ = ((14 &((NU16)1<<((NU)((*(*(*c).graph).config).ideCmd)&15U)))!=0);
		LA44_: ;
		if (!T42_) goto LA45_;
		produceOutput__QAZcajHr1x9cYjb78UsSezg((&outputs), (*(*c).graph).config);
		suggestQuit__5gyVlJxpO0KQGkItjZbJJg();
	}
	LA45_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestExpr__wb6KhAx6bZ5NV37kY4bXJw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = exactEquals__59bygf5b7AsTVb9a1lVM66oA_2((*(*(*c).graph).config).m.trackPos, (*n).info);
		if (!T3_) goto LA4_;
		suggestExprNoCheck__wb6KhAx6bZ5NV37kY4bXJw_2(c, n);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg, inCheckpoint__39cgIJElcz9arpbYiRwV2TVw)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q current, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos) {
	tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg result;
{	result = (tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg)0;
	{
		if (!(current.fileIndex == trackPos.fileIndex)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (current.line == trackPos.line);
			if (!(T7_)) goto LA8_;
			T7_ = (((NI16)(current.col - trackPos.col) > 0? ((NI16)(current.col - trackPos.col)) : -((NI16)(current.col - trackPos.col))) < ((NI16) 4));
			LA8_: ;
			if (!T7_) goto LA9_;
			result = ((tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg) 2);
			goto BeforeRet_;
		}
		LA9_: ;
		{
			if (!((NU16)(trackPos.line) <= (NU16)(current.line))) goto LA13_;
			result = ((tyEnum_TCheckPointResult__mp7otVupbkudrLwM0IFcHg) 1);
			goto BeforeRet_;
		}
		LA13_: ;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, semFinishOperands__wb6KhAx6bZ5NV37kY4bXJw_3)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				asgnRef((void**) (&(*n)._kind_6.sons->data[i]), prepareOperand__lArHfX4A9cwcRE9cEIjQFVtA(c, (*n)._kind_6.sons->data[i]));
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_NIMCALL(void, Marker_tySequence__0dpGN6F4ocevqUQGsaf41w)(void* p, NI op) {
	tySequence__0dpGN6F4ocevqUQGsaf41w* a;
	NI T1_;
	a = (tySequence__0dpGN6F4ocevqUQGsaf41w*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].sym, op);
	nimGCvisit((void*)a->data[T1_].firstMismatch.formal, op);
	nimGCvisit((void*)a->data[T1_].diagnostics, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, argTypeToString__4EtZe89aZdrkU6I6iZJr4Yg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 56) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 57))) goto LA3_;
		result = typeToString__QlvraUan7WbHowhAbvDvdA((*(*arg)._kind_6.sons->data[((NI) 0)]).typ, prefer);
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(arg);
			i_2 = ((NI) 1);
			{
				while (1) {
					NimStringDesc* T8_;
					if (!(i_2 < colontmp_)) goto LA7;
					i = i_2;
					result = resizeString(result, 3);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_77));
					T8_ = (NimStringDesc*)0;
					T8_ = typeToString__QlvraUan7WbHowhAbvDvdA((*(*arg)._kind_6.sons->data[i]).typ, prefer);
					result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
					i_2 += ((NI) 1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
	LA3_: ;
	{
		if (!((*arg).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL))) goto LA10_;
		result = copyString(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_78));
	}
	goto LA1_;
	LA10_: ;
	{
		result = typeToString__QlvraUan7WbHowhAbvDvdA((*arg).typ, prefer);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, describeArgs__cCrxh8TxJsIrMINltM1ovw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI startIdx, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer) {
	NimStringDesc* result;
{	result = (NimStringDesc*)0;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = startIdx;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg;
				NimStringDesc* T28_;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				arg = (*n)._kind_6.sons->data[i];
				{
					NimStringDesc* T8_;
					if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 33))) goto LA6_;
					T8_ = (NimStringDesc*)0;
					T8_ = renderTree__ppjdh9aQ5L0SGPF8yz1gZ9cA((*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 0)], 0);
					result = resizeString(result, (T8_ ? T8_->Sup.len : 0) + 0);
appendString(result, T8_);
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_76));
					{
						NIM_BOOL T11_;
						T11_ = (NIM_BOOL)0;
						T11_ = ((*arg).typ == 0);
						if (!(T11_)) goto LA12_;
						T11_ = !(((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52)));
						LA12_: ;
						if (!T11_) goto LA13_;
						arg = (*c).semOperand(c, (*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)], 0);
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i]).typ), (*arg).typ);
						asgnRef((void**) (&(*(*n)._kind_6.sons->data[i])._kind_6.sons->data[((NI) 1)]), arg);
					}
					LA13_: ;
				}
				goto LA4_;
				LA6_: ;
				{
					{
						NIM_BOOL T18_;
						T18_ = (NIM_BOOL)0;
						T18_ = ((*arg).typ == 0);
						if (!(T18_)) goto LA19_;
						T18_ = !(((*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86) || (*arg).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 87)));
						LA19_: ;
						if (!T18_) goto LA20_;
						arg = (*c).semOperand(c, (*n)._kind_6.sons->data[i], 0);
						asgnRef((void**) (&(*n)._kind_6.sons->data[i]), arg);
					}
					LA20_: ;
				}
				LA4_: ;
				{
					NIM_BOOL T24_;
					T24_ = (NIM_BOOL)0;
					T24_ = !(((*arg).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
					if (!(T24_)) goto LA25_;
					T24_ = ((*(*arg).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 50));
					LA25_: ;
					if (!T24_) goto LA26_;
					goto BeforeRet_;
				}
				LA26_: ;
				T28_ = (NimStringDesc*)0;
				T28_ = argTypeToString__4EtZe89aZdrkU6I6iZJr4Yg(arg, prefer);
				result = resizeString(result, (T28_ ? T28_->Sup.len : 0) + 0);
appendString(result, T28_);
				{
					NI T31_;
					T31_ = (NI)0;
					T31_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
					if (!!((i == (NI)(T31_ - ((NI) 1))))) goto LA32_;
					result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_28));
				}
				LA32_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, matches__BxEsf1Gt7Hq3usrwPERzyA_2)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nOrig, tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA* m) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg marker;
{	{
		if (!((*m).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 5) || (*m).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 6))) goto LA3_;
		(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 1);
		unsureAsgnRef((void**) (&(*m).call), n);
		goto BeforeRet_;
	}
	LA3_: ;
	nimZeroMem((void*)(&marker), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&marker));
	matchesAux__jWX5qJnM9cS16h0kw9aDyhrg(c, n, nOrig, m, (&marker));
	{
		if (!((*m).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2))) goto LA7_;
		goto BeforeRet_;
	}
	LA7_: ;
	{
		NI f;
		NI colontmp_;
		NI i;
		f = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*m).callee).n);
		i = ((NI) 1);
		{
			while (1) {
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* formal;
				if (!(i < colontmp_)) goto LA11;
				f = i;
				formal = (*(*(*(*m).callee).n)._kind_6.sons->data[f])._kind_4.sym;
				{
					NIM_BOOL T14_;
					T14_ = (NIM_BOOL)0;
					T14_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&marker), (*formal).position);
					if (!!(T14_)) goto LA15_;
					{
						if (!((*formal).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA19_;
						{
							tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw cnKind;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* container;
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T32_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T33_;
							if (!((*(*formal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA23_;
							{
								NIM_BOOL T27_;
								T27_ = (NIM_BOOL)0;
								T27_ = ((*(*formal).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48));
								if (!(T27_)) goto LA28_;
								T27_ = ((*(*(*formal).typ).sons->data[((NI) 0)]).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6));
								LA28_: ;
								if (!T27_) goto LA29_;
								cnKind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152);
							}
							goto LA25_;
							LA29_: ;
							{
								cnKind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41);
							}
							LA25_: ;
							T32_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
							T32_ = arrayConstr__wDvUGprK4A7uVE8fdY6XSw(c, (*n).info);
							container = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(cnKind, (*n).info, T32_);
							T33_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T33_ = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), (*formal).typ, container, (&(*m)), c);
							setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), T33_);
						}
						goto LA21_;
						LA23_: ;
						{
							(*m).state = ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2);
							(*m).firstMismatch.kind = ((tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w) 5);
							unsureAsgnRef((void**) (&(*m).firstMismatch.formal), formal);
							goto LA9;
						}
						LA21_: ;
					}
					goto LA17_;
					LA19_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* defaultValue;
						{
							NimStringDesc* T40_;
							if (!((*(*formal).ast).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1))) goto LA38_;
							T40_ = (NimStringDesc*)0;
							T40_ = nsuFormatSingleElem(((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_79), (*(*formal).name).s);
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*(*m).call).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T40_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_80, NIM_FALSE);
						}
						LA38_: ;
						{
							if (!(((*(*formal).ast).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19))&31U)))!=0)) goto LA43_;
							(*(*m).call).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 19)) & 31);
						}
						LA43_: ;
						defaultValue = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*formal).ast);
						{
							if (!((*defaultValue).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA47_;
							defaultValue = implicitConv__ekWYb9baoe72jjRpfCUrNQQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58), (*formal).typ, defaultValue, (&(*m)), c);
						}
						LA47_: ;
						{
							tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* existing;
							tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* T53_;
							RootObj* T54_;
							if (!!(((100663296 & (*(*formal).typ).flags) == 0))) goto LA51_;
							T53_ = (tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA*)0;
							T53_ = &(*formal).typ->Sup;
							T54_ = (RootObj*)0;
							T54_ = idTableGet__K5M5T7J9c0H7M5ahfeRl8xw((*m).bindings, T53_);
							existing = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) (T54_));
							{
								NIM_BOOL T57_;
								T57_ = (NIM_BOOL)0;
								T57_ = (existing == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
								if (T57_) goto LA58_;
								T57_ = ((*existing).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
								LA58_: ;
								if (!T57_) goto LA59_;
								put__pK5c3oe09b3Wx3ch7A9cRLfAsigmatch(m, (*formal).typ, (*defaultValue).typ);
							}
							LA59_: ;
						}
						LA51_: ;
						(*defaultValue).flags |= ((NU32)1)<<((((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 18)) & 31);
						setSon__BZM7caO8KSYHHY8TNvb6UQ((*m).call, (NI)((*formal).position + ((NI) 1)), defaultValue);
					}
					LA17_: ;
				}
				LA15_: ;
				i += ((NI) 1);
			} LA11: ;
		}
	} LA9: ;
	{
		if (!((*m).state == ((tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg) 2))) goto LA63_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** t;
			NI i_2;
			NI L;
			NI T66_;
			t = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
			i_2 = ((NI) 0);
			T66_ = ((*m).inferredTypes ? (*m).inferredTypes->Sup.len : 0);
			L = T66_;
			{
				while (1) {
					if (!(i_2 < L)) goto LA68;
					t = &(*m).inferredTypes->data[i_2];
					{
						NI T71_;
						T71_ = (NI)0;
						T71_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*t));
						if (!(((NI) 1) < T71_)) goto LA72_;
						asgnRef((void**) (&(*(*t)).sons), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) setLengthSeqV2(&((*(*t)).sons)->Sup, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_), ((NI) 1)));
					}
					LA72_: ;
					i_2 += ((NI) 1);
				} LA68: ;
			}
		}
	}
	LA63_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ, cmpTypes__6LyhcPFOyQXLaZFXoqJM1w)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a) {
	tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	result = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, f, (&m));
	result = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&m), f, a, 0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestStmt__wb6KhAx6bZ5NV37kY4bXJw_4)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	suggestExpr__wb6KhAx6bZ5NV37kY4bXJw(c, n);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, instTypeBoundOp__Kdk4BCAjDmsFKO9cO4U4ccw)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dc, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg op, NI col) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA m;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* f;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	nimZeroMem((void*)(&m), sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA));
	newCandidate__rFFaxk6TYVlvnKNibvVmkg(c, (*dc).typ, (&m));
	{
		NI T3_;
		NimStringDesc* T6_;
		T3_ = (NI)0;
		T3_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*dc).typ);
		if (!(T3_ <= col)) goto LA4_;
		T6_ = (NimStringDesc*)0;
		T6_ = rawNewString(((*(*dc).name).s ? (*(*dc).name).s->Sup.len : 0) + 22);
appendString(T6_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_81));
appendString(T6_, (*(*dc).name).s);
appendString(T6_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_12));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T6_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_82, NIM_FALSE);
		result = ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL);
		goto BeforeRet_;
	}
	LA4_: ;
	f = (*(*dc).typ).sons->data[col];
	{
		if (!(op == ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))) goto LA9_;
		{
			if (!((6291456 &((NU64)1<<((NU)((*f).kind)&63U)))!=0)) goto LA13_;
			f = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
		}
		LA13_: ;
	}
	goto LA7_;
	LA9_: ;
	{
		{
			if (!((8388608 &((NU64)1<<((NU)((*f).kind)&63U)))!=0)) goto LA18_;
			f = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(f);
		}
		LA18_: ;
	}
	LA7_: ;
	{
		tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ T22_;
		NimStringDesc* T25_;
		T22_ = (tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ)0;
		T22_ = typeRel__3a3tkQB9aY8V2J9acM5cZ6nA((&m), f, t, 0);
		if (!(T22_ == ((tyEnum_TTypeRelation__1IMf5P083XuEtWGxYaIXyQ) 0))) goto LA23_;
		T25_ = (NimStringDesc*)0;
		T25_ = rawNewString(((*(*dc).name).s ? (*(*dc).name).s->Sup.len : 0) + 22);
appendString(T25_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_81));
appendString(T25_, (*(*dc).name).s);
appendString(T25_, ((NimStringDesc*) &TM__EV5hHJmjIY9cla9b9be7fSVJQ_12));
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T25_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__EV5hHJmjIY9cla9b9be7fSVJQ_83, NIM_FALSE);
	}
	goto LA20_;
	LA23_: ;
	{
		result = (*c).semGenerateInstance.ClE_0? (*c).semGenerateInstance.ClP_0(c, dc, m.bindings, info, (*c).semGenerateInstance.ClE_0):((TM__EV5hHJmjIY9cla9b9be7fSVJQ_84)((*c).semGenerateInstance.ClP_0))(c, dc, m.bindings, info);
		{
			if (!(op == ((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 5))) goto LA29_;
		}
		LA29_: ;
	}
	LA20_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestSentinel__9bcrXlTwB3ELAkoCqH9bihfA)(tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c) {
	tySequence__i7xpiUsxyv6cQ1xK3JbcGQ* outputs;
	NIM_BOOL isLocal;
	NI scopeN;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*(*c).graph).config).ideCmd == ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1)));
		if (T3_) goto LA4_;
		T3_ = !(((*(*c).module).position == ((NI) ((*(*(*c).graph).config).m.trackPos.fileIndex))));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		if (!(((NI) 0) < (*c).compilesContextId)) goto LA9_;
		goto BeforeRet_;
	}
	LA9_: ;
	(*c).compilesContextId += ((NI) 1);
	outputs = NIM_NIL;
	isLocal = NIM_TRUE;
	scopeN = ((NI) 0);
	{
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* scope;
		tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* current;
		scope = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)0;
		current = (*c).currentScope;
		{
			while (1) {
				if (!!((current == ((tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*) NIM_NIL)))) goto LA13;
				scope = current;
				{
					if (!(scope == (*c).topLevelScope)) goto LA16_;
					isLocal = NIM_FALSE;
				}
				LA16_: ;
				scopeN -= ((NI) 1);
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
					tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg it_2;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
					it = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
					nimZeroMem((void*)(&it_2), sizeof(tyObject_TTabIter__VYF5VQsIYEVaBL0fKZJkbg));
					s = initTabIter__Ag5U6LHpF7iSy3G6AzXM9cw((&it_2), (*scope).symbols);
					{
						while (1) {
							tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q pm;
							if (!!((s == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA20;
							it = s;
							pm = (tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q)0;
							{
								NIM_BOOL T23_;
								tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q T26_;
								tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* T27_;
								NI T28_;
								T23_ = (NIM_BOOL)0;
								T23_ = filterSymNoOpr__bcqYtfxSrIczthAmGccX0A_2sigmatch(it, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), (&pm));
								if (!T23_) goto LA24_;
								T26_ = newLineInfo__NPagzbOMpGo9aqJmfnDrITg((*(*(*c).graph).config).m.trackPos.fileIndex, ((NI) 0), ((NI) -1));
								T27_ = (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ*)0;
								T27_ = symToSuggest__vqIw3rWumn89bB7Y6J9bbSVw((*(*c).graph).config, it, isLocal, ((tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ) 1), T26_, ((NI) 0), ((tyEnum_PrefixMatch__Dkww2nY9cxJVLF9cfoQS5U6Q) 0), NIM_FALSE, scopeN, NIM_FALSE);
								outputs = (tySequence__i7xpiUsxyv6cQ1xK3JbcGQ*) incrSeqV3((TGenericSeq*)(outputs), (&NTI__i7xpiUsxyv6cQ1xK3JbcGQ_));
								T28_ = outputs->Sup.len++;
								asgnRef((void**) (&outputs->data[T28_]), T27_);
							}
							LA24_: ;
							s = nextIter__Ag5U6LHpF7iSy3G6AzXM9cw_2((&it_2), (*scope).symbols);
						} LA20: ;
					}
				}
				current = (*current).parent;
			} LA13: ;
		}
	}
	(*c).compilesContextId -= ((NI) 1);
	produceOutput__QAZcajHr1x9cYjb78UsSezg((&outputs), (*(*c).graph).config);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_sigmatchDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_4_2[2];
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[5];
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_22_2[2];
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[24];
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_53_3[3];
NI TM__EV5hHJmjIY9cla9b9be7fSVJQ_55;
static char* NIM_CONST TM__EV5hHJmjIY9cla9b9be7fSVJQ_54[3] = {
"csEmpty", 
"csMatch", 
"csNoMatch"};
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_56_3[3];
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_57_8[8];
NI TM__EV5hHJmjIY9cla9b9be7fSVJQ_59;
static char* NIM_CONST TM__EV5hHJmjIY9cla9b9be7fSVJQ_58[8] = {
"kUnknown", 
"kAlreadyGiven", 
"kUnknownNamedParam", 
"kTypeMismatch", 
"kVarNeeded", 
"kMissingParam", 
"kExtraArg", 
"kPositionalAlreadyGiven"};
static TNimNode* TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[4];
static TNimNode TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[59];

/* section: NIM_merge_TYPE_INIT3 */
NTI__OOiDxDXQlxWHlb9aU1AkbWQ_.size = sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ);
NTI__OOiDxDXQlxWHlb9aU1AkbWQ_.align = NIM_ALIGNOF(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ);
NTI__OOiDxDXQlxWHlb9aU1AkbWQ_.kind = 17;
NTI__OOiDxDXQlxWHlb9aU1AkbWQ_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_4_2[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[1];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[1].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[1].offset = offsetof(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ, colonstate_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[1].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[1].name = ":state";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_4_2[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[2];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[2].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[2].offset = offsetof(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ, line1);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[2].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[2].name = "line1";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[0].len = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[0].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[0].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_4_2[0];
NTI__OOiDxDXQlxWHlb9aU1AkbWQ_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[0];
NTI__AQEmz0epsPFaQWAZOZKqTA_.size = sizeof(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*);
NTI__AQEmz0epsPFaQWAZOZKqTA_.align = NIM_ALIGNOF(tyObject_Env_suggestdotnim_getTokenLenFromSource___OOiDxDXQlxWHlb9aU1AkbWQ*);
NTI__AQEmz0epsPFaQWAZOZKqTA_.kind = 22;
NTI__AQEmz0epsPFaQWAZOZKqTA_.base = (&NTI__OOiDxDXQlxWHlb9aU1AkbWQ_);
NTI__AQEmz0epsPFaQWAZOZKqTA_.marker = Marker_tyRef__AQEmz0epsPFaQWAZOZKqTA;
NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_.size = sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw);
NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_.align = NIM_ALIGNOF(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw);
NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_.kind = 17;
NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_.base = (&NTI__ytyiCJqK439aF9cIibuRVpAg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[4];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[4].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[4].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw, colonstate_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[4].typ = (&NTI__xHTZrq9aYs6boc9bCba0JbpQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[4].name = ":state";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[5];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[5].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[5].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw, errorPrefix1);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[5].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[5].name = "errorPrefix1";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[2] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[6];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[6].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[6].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw, typeClass2);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[6].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[6].name = "typeClass2";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[3] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[7];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[7].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[7].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw, oldWriteHook3);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[7].typ = (&NTI__k2HFjxisIgDALbEUFojxaQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[7].name = "oldWriteHook3";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[4] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[8];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[8].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[8].offset = offsetof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw, diagnostics4);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[8].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[8].name = "diagnostics4";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[3].len = 5; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[3].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[3].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_18_5[0];
NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[3];
NTI__T9cB3MofzwLcK9bH1dcRQNsg_.size = sizeof(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*);
NTI__T9cB3MofzwLcK9bH1dcRQNsg_.align = NIM_ALIGNOF(tyObject_Env_sigmatchdotnim_matchUserTypeClass___jDKUf9aGpXbb4hTUsm9a9aBsw*);
NTI__T9cB3MofzwLcK9bH1dcRQNsg_.kind = 22;
NTI__T9cB3MofzwLcK9bH1dcRQNsg_.base = (&NTI__jDKUf9aGpXbb4hTUsm9a9aBsw_);
NTI__T9cB3MofzwLcK9bH1dcRQNsg_.marker = Marker_tyRef__T9cB3MofzwLcK9bH1dcRQNsg;
NTI__gOsvkY4zLbqYcgABB1VEQg_.size = sizeof(tyTuple__gOsvkY4zLbqYcgABB1VEQg);
NTI__gOsvkY4zLbqYcgABB1VEQg_.align = NIM_ALIGNOF(tyTuple__gOsvkY4zLbqYcgABB1VEQg);
NTI__gOsvkY4zLbqYcgABB1VEQg_.kind = 18;
NTI__gOsvkY4zLbqYcgABB1VEQg_.base = 0;
NTI__gOsvkY4zLbqYcgABB1VEQg_.flags = 2;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_22_2[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[10];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[10].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[10].offset = offsetof(tyTuple__gOsvkY4zLbqYcgABB1VEQg, Field0);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[10].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[10].name = "Field0";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_22_2[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[11];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[11].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[11].offset = offsetof(tyTuple__gOsvkY4zLbqYcgABB1VEQg, Field1);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[11].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[11].name = "Field1";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[9].len = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[9].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[9].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_22_2[0];
NTI__gOsvkY4zLbqYcgABB1VEQg_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[9];
NTI__nl5fX6g5vxdA4inU5zASDQ_.size = sizeof(tySequence__nl5fX6g5vxdA4inU5zASDQ*);
NTI__nl5fX6g5vxdA4inU5zASDQ_.align = NIM_ALIGNOF(tySequence__nl5fX6g5vxdA4inU5zASDQ*);
NTI__nl5fX6g5vxdA4inU5zASDQ_.kind = 24;
NTI__nl5fX6g5vxdA4inU5zASDQ_.base = (&NTI__gOsvkY4zLbqYcgABB1VEQg_);
NTI__nl5fX6g5vxdA4inU5zASDQ_.flags = 2;
NTI__nl5fX6g5vxdA4inU5zASDQ_.marker = Marker_tySequence__nl5fX6g5vxdA4inU5zASDQ;
NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_.size = sizeof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA);
NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_.align = NIM_ALIGNOF(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA);
NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_.kind = 18;
NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_.base = 0;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[13];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[13].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[13].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, c);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[13].typ = (&NTI__EjEifkTC8tg9afiUW4StSSA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[13].name = "c";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[14];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[14].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[14].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, exactMatches);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[14].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[14].name = "exactMatches";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[2] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[15];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[15].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[15].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, genericMatches);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[15].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[15].name = "genericMatches";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[3] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[16];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[16].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[16].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, subtypeMatches);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[16].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[16].name = "subtypeMatches";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[4] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[17];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[17].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[17].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, intConvMatches);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[17].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[17].name = "intConvMatches";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[5] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[18];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[18].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[18].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, convMatches);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[18].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[18].name = "convMatches";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[6] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[19];
NTI__C8RXb59bvbxaTzDOqx49aVVg_.size = sizeof(tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg);
NTI__C8RXb59bvbxaTzDOqx49aVVg_.align = NIM_ALIGNOF(tyEnum_TCandidateState__C8RXb59bvbxaTzDOqx49aVVg);
NTI__C8RXb59bvbxaTzDOqx49aVVg_.kind = 14;
NTI__C8RXb59bvbxaTzDOqx49aVVg_.base = 0;
NTI__C8RXb59bvbxaTzDOqx49aVVg_.flags = 3;
for (TM__EV5hHJmjIY9cla9b9be7fSVJQ_55 = 0; TM__EV5hHJmjIY9cla9b9be7fSVJQ_55 < 3; TM__EV5hHJmjIY9cla9b9be7fSVJQ_55++) {
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55+20].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55+20].offset = TM__EV5hHJmjIY9cla9b9be7fSVJQ_55;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55+20].name = TM__EV5hHJmjIY9cla9b9be7fSVJQ_54[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_53_3[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_55+20];
}
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[23].len = 3; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[23].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[23].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_53_3[0];
NTI__C8RXb59bvbxaTzDOqx49aVVg_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[23];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[19].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[19].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, state);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[19].typ = (&NTI__C8RXb59bvbxaTzDOqx49aVVg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[19].name = "state";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[7] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[24];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[24].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[24].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, callee);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[24].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[24].name = "callee";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[8] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[25];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[25].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[25].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, calleeSym);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[25].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[25].name = "calleeSym";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[9] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[26];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[26].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[26].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, calleeScope);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[26].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[26].name = "calleeScope";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[10] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[27];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[27].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[27].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, call);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[27].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[27].name = "call";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[11] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[28];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[28].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[28].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, bindings);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[28].typ = (&NTI__9aiv9bp2t5icFNINcg9c4xi1Q_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[28].name = "bindings";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[12] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[29];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[29].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[29].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, magic);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[29].typ = (&NTI__shZhZOdbVC5nnFvcXQAImg_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[29].name = "magic";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[13] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[30];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[30].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[30].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, baseTypeMatch);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[30].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[30].name = "baseTypeMatch";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[14] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[31];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[31].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[31].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, fauxMatch);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[31].typ = (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[31].name = "fauxMatch";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[15] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[32];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[32].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[32].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, genericConverter);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[32].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[32].name = "genericConverter";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[16] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[33];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[33].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[33].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, coerceDistincts);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[33].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[33].name = "coerceDistincts";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[17] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[34];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[34].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[34].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, typedescMatched);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[34].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[34].name = "typedescMatched";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[18] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[35];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[35].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[35].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, isNoCall);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[35].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[35].name = "isNoCall";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[19] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[36];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[36].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[36].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, inferredTypes);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[36].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[36].name = "inferredTypes";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[20] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[37];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[37].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[37].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, diagnostics);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[37].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[37].name = "diagnostics";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[21] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[38];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[38].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[38].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, inheritancePenalty);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[38].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[38].name = "inheritancePenalty";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[22] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[39];
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.size = sizeof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ);
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.align = NIM_ALIGNOF(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ);
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.kind = 18;
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.base = 0;
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.flags = 2;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_56_3[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[41];
NTI__9a6KkG9auuBdYowCMkBNpD6w_.size = sizeof(tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w);
NTI__9a6KkG9auuBdYowCMkBNpD6w_.align = NIM_ALIGNOF(tyEnum_MismatchKind__9a6KkG9auuBdYowCMkBNpD6w);
NTI__9a6KkG9auuBdYowCMkBNpD6w_.kind = 14;
NTI__9a6KkG9auuBdYowCMkBNpD6w_.base = 0;
NTI__9a6KkG9auuBdYowCMkBNpD6w_.flags = 3;
for (TM__EV5hHJmjIY9cla9b9be7fSVJQ_59 = 0; TM__EV5hHJmjIY9cla9b9be7fSVJQ_59 < 8; TM__EV5hHJmjIY9cla9b9be7fSVJQ_59++) {
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59+42].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59+42].offset = TM__EV5hHJmjIY9cla9b9be7fSVJQ_59;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59+42].name = TM__EV5hHJmjIY9cla9b9be7fSVJQ_58[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_57_8[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[TM__EV5hHJmjIY9cla9b9be7fSVJQ_59+42];
}
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[50].len = 8; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[50].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[50].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_57_8[0];
NTI__9a6KkG9auuBdYowCMkBNpD6w_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[50];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[41].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[41].offset = offsetof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ, kind);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[41].typ = (&NTI__9a6KkG9auuBdYowCMkBNpD6w_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[41].name = "kind";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_56_3[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[51];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[51].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[51].offset = offsetof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ, arg);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[51].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[51].name = "arg";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_56_3[2] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[52];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[52].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[52].offset = offsetof(tyObject_MismatchInfo__Bde9a0sl26Y9b6iLNg1iH8LQ, formal);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[52].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[52].name = "formal";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[40].len = 3; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[40].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[40].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_56_3[0];
NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[40];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[39].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[39].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, firstMismatch);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[39].typ = (&NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[39].name = "firstMismatch";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[23] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[53];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[53].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[53].offset = offsetof(tyObject_TCandidate__B8Gf2sSWgQ79bLZ9bYWrLHaA, diagnosticsEnabled);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[53].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[53].name = "diagnosticsEnabled";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[12].len = 24; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[12].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[12].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_52_24[0];
NTI__B8Gf2sSWgQ79bLZ9bYWrLHaA_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[12];
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.size = sizeof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ);
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.align = NIM_ALIGNOF(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ);
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.kind = 18;
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.base = 0;
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.flags = 2;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[0] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[55];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[55].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[55].offset = offsetof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ, sym);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[55].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[55].name = "sym";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[1] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[56];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[56].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[56].offset = offsetof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ, firstMismatch);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[56].typ = (&NTI__Bde9a0sl26Y9b6iLNg1iH8LQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[56].name = "firstMismatch";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[2] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[57];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[57].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[57].offset = offsetof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ, diagnostics);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[57].typ = (&NTI__sM4lkSb7zS6F7OVMvW9cffQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[57].name = "diagnostics";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[3] = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[58];
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[58].kind = 1;
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[58].offset = offsetof(tyObject_CandidateError__5fLnqPfj0Ty9cmak1Q1pBFQ, enabled);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[58].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[58].name = "enabled";
TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[54].len = 4; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[54].kind = 2; TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[54].sons = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_75_4[0];
NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_.node = &TM__EV5hHJmjIY9cla9b9be7fSVJQ_0[54];
NTI__0dpGN6F4ocevqUQGsaf41w_.size = sizeof(tySequence__0dpGN6F4ocevqUQGsaf41w*);
NTI__0dpGN6F4ocevqUQGsaf41w_.align = NIM_ALIGNOF(tySequence__0dpGN6F4ocevqUQGsaf41w*);
NTI__0dpGN6F4ocevqUQGsaf41w_.kind = 24;
NTI__0dpGN6F4ocevqUQGsaf41w_.base = (&NTI__5fLnqPfj0Ty9cmak1Q1pBFQ_);
NTI__0dpGN6F4ocevqUQGsaf41w_.flags = 2;
NTI__0dpGN6F4ocevqUQGsaf41w_.marker = Marker_tySequence__0dpGN6F4ocevqUQGsaf41w;
}

