/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw;
typedef struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q;
typedef struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
typedef struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg;
typedef struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA tyObject_Int128__9a9axPfb75jdWY25AamJewkA;
typedef struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA;
typedef struct tySequence__K8W16aeLg4OWxniQxtguMw tySequence__K8W16aeLg4OWxniQxtguMw;
typedef struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A;
typedef struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q tySequence__vhmj4KkIKPinmRXny9c2Q6Q;
typedef struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;

/* section: NIM_merge_TYPES */
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* concreteTypes;
NI compilesId;
};
typedef NU8 tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ;
struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA {
tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ kind;
NIM_BOOL generated;
NIM_BOOL isOverriden;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* name;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* path;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g;
struct tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw {
NI depthLevel;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA symbols;
tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* parent;
};
struct tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q {
NI counter;
tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* data;
};
struct tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
RootObj* val;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA {
  RootObj Sup;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* left;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* right;
NI L;
NimStringDesc* data;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU32 tyArray__FleBT9cC2nxhgiXmSYYnEKA[4];
struct tyObject_Int128__9a9axPfb75jdWY25AamJewkA {
tyArray__FleBT9cC2nxhgiXmSYYnEKA udata;
};
struct tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA {
NI counter;
tySequence__K8W16aeLg4OWxniQxtguMw* data;
};
struct tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w {
tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA* key;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val;
};
typedef NimStringDesc* tyArray__JXkBzVsE9bvmcpuZvrueLVg[6];
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TNodeKind__D37bGuL0oC9aRhwdwBfWpFg;
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
typedef NU32 tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU8 tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg;
typedef NU8 tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw[21];
typedef NU8 tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg;
struct tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A {
NI counter;
tySequence__vhmj4KkIKPinmRXny9c2Q6Q* data;
};
struct tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg {
NI h;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* key;
NI val;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__Mh9agqM29bm9aP5AUL1x7dZGA {
  TGenericSeq Sup;
  tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg data[SEQ_DECL_SIZE];
};
struct tySequence__K8W16aeLg4OWxniQxtguMw {
  TGenericSeq Sup;
  tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w data[SEQ_DECL_SIZE];
};
struct tySequence__vhmj4KkIKPinmRXny9c2Q6Q {
  TGenericSeq Sup;
  tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__fKfcLzXYiz5jNu3NH3Tv8Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__MvZmat48bhe9b6x9aUD58D5Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__AgIT5feFR9a9aoVjv9cx2rOtg)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Ef05srmQTDulnBdXR4Ja6Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__Y32tFilzS9adEEksgrCsOzQ)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__DXS6mEo7PVUFJkirsQ9bNQA)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__EL9cZTJI9a9cmSIbGnseCuc9bg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__K9bspPztfoWajecnwjyHuYQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newSeq)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, getID__82csy2YSddf27azS9awAkVgidgen)(void);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, genericShallowAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
N_LIB_PRIVATE N_NIMCALL(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*, at___l5EwVkovx8Ofyb2pm635QA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** a, NI aLen_0);
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**, X5BX5D___RNblfFqyHCLnrLulG0Us9bQsystem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** s, NI sLen_0, NI i);
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**, X5BX5D___f6j2Rr9bpYzKO9bs9a65jNGYQsystem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s, NI sLen_0, NI i);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getnimblePkg__Dc0qjIQVl9aS9cfSt6IH2IOg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_NIMCALL(void, Marker_tyRef__N89ckikRqMir57209a3tEeqw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__Mh9agqM29bm9aP5AUL1x7dZGA)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(void, genericAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, mergeLoc__3y7Rn2QCRcBO28D5ulHx6w)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b);
N_LIB_PRIVATE N_NIMCALL(void, newSons__UKZtv7j9a9bCciLd0w3xIW1Q)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, NI length);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, assignType__RDstL9c8H9bSHUphDz0iB0hg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__TDVoY1DSlNtMNULcUFRJzA)(NU64 arg);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, toInt128__ZBiVpGjOydV7ZjeElrE9cFQ)(NI64 arg);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ)(NimStringDesc* msg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__aVxWxXLmf103vwE8uZ9cXRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
static N_INLINE(NIM_BOOL, isGCedMem__nPImuPGZIdcrAfCNyf4oxAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elem, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(void, copyStrTable__j9aaCGqD2f9bSLzpYxKfYCiA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* dest, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA src);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, copyType__4O4aYoscFPo2FRSh4rP9ayg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL keepId);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A)(NimStringDesc* msg);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_NIMCALL(void, Marker_tySequence__K8W16aeLg4OWxniQxtguMw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(NI64, castToInt64__1szweXXq3RBN50owrYu2Xw_2)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA arg);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStrImpl__FnrYV0vmnt9aYi4h7fMu7dQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind);
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStrImpl__QnY9aC6DAYwbdvoEdssXiLw)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__3PkUvehQ5keciM9cue9ayMTw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kinds);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewSeqOfCap)(TNimType* typ, NI cap);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTreeWithoutNode__aN5jlv83QmlsI1PY356I2w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* skippedNode);
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_NIMCALL(void, Marker_tySequence__vhmj4KkIKPinmRXny9c2Q6Q)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);

/* section: NIM_merge_DATA */
N_LIB_PRIVATE TNimType NTI__cNCW9acsSznmEccl1fgQwkw_;
N_LIB_PRIVATE TNimType NTI__K9ay6LWMat9bUiT9bIbMxpDHw_;
N_LIB_PRIVATE TNimType NTI__9a3YiReNVD0IJHWFKgXRe9ag_;
N_LIB_PRIVATE TNimType NTI__x2m5g1NpbmDig4wLT3Ylhw_;
N_LIB_PRIVATE TNimType NTI__G4E4Gxe7oI2Cm03rkiOzQw_;
N_LIB_PRIVATE TNimType NTI__jyh9acXHkhZANSSvPIY7ZLg_;
extern TNimType NTI__iIXPrEsiKHiioLj0HSkQhA_;
N_LIB_PRIVATE TNimType NTI__JpsEh5i1AcKChGYbg7aV4w_;
TNimNode* NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[27];
N_LIB_PRIVATE TNimType NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_;
N_LIB_PRIVATE TNimType NTI__yjAJ8w0h1PBaSwSGJ3P7IA_;
N_LIB_PRIVATE TNimType NTI__TUnU4oefCIvAMjkVjD9cuBA_;
N_LIB_PRIVATE TNimType NTI__bROa11lyF5vxEN9aYNbHmhw_;
extern TNimType NTI__WGx4rAexNXnczy1Avn646Q_;
N_LIB_PRIVATE TNimType NTI__Lj66phhshW0KaYhwBUJJ3Q_;
TNimNode* NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[162];
extern TNimType NTI__Aav8dQoMlCFnZRxA0IhTHQ_;
extern TNimType NTI__w9bl9a1ul9ctRJWiMl9cNnIMvg_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTI__B0xRsLi0eK4raPu9bd2tkcA_;
N_LIB_PRIVATE TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
N_LIB_PRIVATE TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
N_LIB_PRIVATE TNimType NTI__PsPyPA45AAjHu4uDGHNjTg_;
N_LIB_PRIVATE TNimType NTI__zwpS6d6iewrdlBSTNFoyVA_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__MvZmat48bhe9b6x9aUD58D5Q_;
extern TNimType NTI__kDPg4wXyR8DDyA0MeEjIsw_;
N_LIB_PRIVATE TNimType NTI__EtHNvCB0bgfu9bFjzx9cb6aA_;
N_LIB_PRIVATE TNimType NTI__O7PRFZKuiBBWbku09cayVBg_;
N_LIB_PRIVATE TNimType NTI__JK9cKMX3XnqHaUky9b6gkGEw_;
N_LIB_PRIVATE TNimType NTI__o2bqJgR4ceIupnUSpxiudA_;
N_LIB_PRIVATE TNimType NTI__yChkHmjOkttAUPxHrKvWAA_;
extern TNimType NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_;
N_LIB_PRIVATE TNimType NTI__AgIT5feFR9a9aoVjv9cx2rOtg_;
N_LIB_PRIVATE TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
N_LIB_PRIVATE TNimType NTI__5LqgVn6Tq9ainQRK7TQAQxA_;
N_LIB_PRIVATE TNimType NTI__Y32tFilzS9adEEksgrCsOzQ_;
N_LIB_PRIVATE TNimType NTI__DXS6mEo7PVUFJkirsQ9bNQA_;
N_LIB_PRIVATE TNimType NTI__f07aOS3dr28kGa5wcE29aFA_;
extern TNimType NTI__DfgJFJEYoj4YBAHLZPl5lQ_;
N_LIB_PRIVATE TNimType NTI__shZhZOdbVC5nnFvcXQAImg_;
N_LIB_PRIVATE TNimType NTI__h9a2sdtQFa6zibBX41u5eAQ_;
extern TNimType NTI__7MnKRybmCNh5j9bDRLMkxLw_;
N_LIB_PRIVATE TNimType NTI__NBMxlJ6g3utqUlplqTTHkA_;
N_LIB_PRIVATE TNimType NTI__9b8v60kso59bBaw9cp8B9a9apKQ_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_;
N_LIB_PRIVATE TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
N_LIB_PRIVATE TNimType NTI__1cQRXW6aAknk7ywAwjH3nw_;
N_LIB_PRIVATE TNimType NTI__N89ckikRqMir57209a3tEeqw_;
N_LIB_PRIVATE TNimType NTI__9aiv9bp2t5icFNINcg9c4xi1Q_;
N_LIB_PRIVATE TNimType NTI__AdFnD2YdADPeuJbG2YJ4vg_;
extern TNimType NTI__eH2Hxsu3PVPvJHXo2xTrZw_;
extern TNimType NTI__0vJvi4uHbxjbxlkkX7P1EA_;
N_LIB_PRIVATE TNimType NTI__Mh9agqM29bm9aP5AUL1x7dZGA_;
N_LIB_PRIVATE TNimType NTI__uyBDtVkS7CL1Bm1j1dvmcw_;
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_52, "<unspecified>", 13);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_53, "<unknown>", 9);
N_LIB_PRIVATE NIM_CONST tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg PersistentNodeFlags__CA9cjAPRNeyIu5iCykQHUHQ = 1763086;
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_54, "cannot extract number from invalid AST node", 43);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_55, "ast.nim(1297, 18) `false` ", 26);
N_LIB_PRIVATE TNimType NTI__UWAp0mDjKLG1NEwUafSRhA_;
N_LIB_PRIVATE TNimType NTI__fUuF71MXGqn0RZORg9clE3w_;
N_LIB_PRIVATE TNimType NTI__K8W16aeLg4OWxniQxtguMw_;
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_58, "=destroy", 8);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_59, "=copy", 5);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_60, "=sink", 5);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_61, "=trace", 6);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_62, "=dispose", 8);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_63, "=deepcopy", 9);
N_LIB_PRIVATE NIM_CONST tyArray__JXkBzVsE9bvmcpuZvrueLVg AttachedOpToStr__gGSR5Ulzx6g21lOISgt9aWA = {((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_58),
((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_59),
((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_60),
((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_61),
((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_62),
((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_63)}
;
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_64, "cannot extract string from invalid AST node", 43);
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_65, "as", 2);
N_LIB_PRIVATE NIM_CONST tySet_tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw OverloadableSyms__yJfP9bpZPSQn9bPO6KCo08fQ = 520256;
STRING_LITERAL(TM__EnH1I9cGkGYbf9a1NwhuXDPg_66, "runnableExamples", 16);
N_LIB_PRIVATE TNimType NTI__wN7B39cKxLpMkvKNm9bduZ0A_;
N_LIB_PRIVATE TNimType NTI__EZfI4tFqtDSTQys2UInNjg_;
N_LIB_PRIVATE TNimType NTI__vhmj4KkIKPinmRXny9c2Q6Q_;

/* section: NIM_merge_VARS */
N_LIB_PRIVATE tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw eqTypeFlags__9aJCM4BDGbCJ8tj1Vz9bDB7g = 1212546;
N_LIB_PRIVATE NIM_BOOL ggDebug__b0PqVRvVBKrlcFJqGWVTyQ;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;
extern NI gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ)(void* p, NI op) {
	tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* a;
	NI T1_;
	a = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__fKfcLzXYiz5jNu3NH3Tv8Q)(void* p, NI op) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
	a = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)p;
	nimGCvisit((void*)(*a).typ, op);
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	nimGCvisit((void*)(*a)._kind_3.strVal, op);
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	nimGCvisit((void*)(*a)._kind_4.sym, op);
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	nimGCvisit((void*)(*a)._kind_5.ident, op);
	break;
	default:
	nimGCvisit((void*)(*a)._kind_6.sons, op);
	break;
	} 
	nimGCvisit((void*)(*a).comment, op);
}
static N_NIMCALL(void, Marker_tySequence__MvZmat48bhe9b6x9aUD58D5Q)(void* p, NI op) {
	tySequence__MvZmat48bhe9b6x9aUD58D5Q* a;
	NI T1_;
	a = (tySequence__MvZmat48bhe9b6x9aUD58D5Q*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field1, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__AgIT5feFR9a9aoVjv9cx2rOtg)(void* p, NI op) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* a;
	NI T1_;
	a = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)p;
	nimGCvisit((void*)(*a).sons, op);
	nimGCvisit((void*)(*a).n, op);
	nimGCvisit((void*)(*a).owner, op);
	nimGCvisit((void*)(*a).sym, op);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 6; T1_++) {
	nimGCvisit((void*)(*a).attachedOps[T1_], op);
	}
	nimGCvisit((void*)(*a).methods, op);
	nimGCvisit((void*)(*a).loc.lode, op);
	nimGCvisit((void*)(*a).loc.r, op);
	nimGCvisit((void*)(*a).typeInst, op);
}
static N_NIMCALL(void, Marker_tySequence__Ef05srmQTDulnBdXR4Ja6Q)(void* p, NI op) {
	tySequence__Ef05srmQTDulnBdXR4Ja6Q* a;
	NI T1_;
	a = (tySequence__Ef05srmQTDulnBdXR4Ja6Q*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__Y32tFilzS9adEEksgrCsOzQ)(void* p, NI op) {
	tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* a;
	a = (tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA*)p;
	nimGCvisit((void*)(*a).sym, op);
	nimGCvisit((void*)(*a).concreteTypes, op);
}
static N_NIMCALL(void, Marker_tySequence__DXS6mEo7PVUFJkirsQ9bNQA)(void* p, NI op) {
	tySequence__DXS6mEo7PVUFJkirsQ9bNQA* a;
	NI T1_;
	a = (tySequence__DXS6mEo7PVUFJkirsQ9bNQA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
static N_NIMCALL(void, Marker_tyRef__EL9cZTJI9a9cmSIbGnseCuc9bg)(void* p, NI op) {
	tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* a;
	a = (tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*)p;
	nimGCvisit((void*)(*a).name, op);
	nimGCvisit((void*)(*a).path, op);
}
static N_NIMCALL(void, Marker_tyRef__K9bspPztfoWajecnwjyHuYQ)(void* p, NI op) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a;
	a = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)p;
	switch ((*a).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
	nimGCvisit((void*)(*a)._kind_1.typeInstCache, op);
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	nimGCvisit((void*)(*a)._kind_2.procInstCache, op);
	nimGCvisit((void*)(*a)._kind_2.gcUnsafetyReason, op);
	nimGCvisit((void*)(*a)._kind_2.transformedBody, op);
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 24):
	nimGCvisit((void*)(*a)._kind_3.usedGenerics, op);
	nimGCvisit((void*)(*a)._kind_3.tab.data, op);
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 21):
	nimGCvisit((void*)(*a)._kind_4.guard, op);
	break;
	default:
	break;
	} 
	nimGCvisit((void*)(*a).typ, op);
	nimGCvisit((void*)(*a).name, op);
	nimGCvisit((void*)(*a).owner, op);
	nimGCvisit((void*)(*a).ast, op);
	nimGCvisit((void*)(*a).loc.lode, op);
	nimGCvisit((void*)(*a).loc.r, op);
	nimGCvisit((void*)(*a).annex, op);
	nimGCvisit((void*)(*a).constraint, op);
}
N_LIB_PRIVATE N_NIMCALL(void, initStrTable__2n9b6ELeZfbbP5wqNYm7VyA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* x) {
	(*x).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*x).data), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) newSeq((&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) 8)));
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NI, getID__82csy2YSddf27azS9awAkVgidgen)(void) {
	NI result;
	result = (NI)0;
	result = gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng;
	gFrontEndId__gyRrMPnY7JyC6tAu9bCfGng += ((NI) 1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) newObj((&NTI__K9bspPztfoWajecnwjyHuYQ_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	(*T1_).Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	asgnRef((void**) (&(*T1_).name), name);
	(*T1_).kind = symKind;
	(*T1_).flags = 0;
	(*T1_).info = info;
	(*T1_).Sup.id = getID__82csy2YSddf27azS9awAkVgidgen();
	(*T1_).options = options;
	asgnRef((void**) (&(*T1_).owner), owner);
	(*T1_).offset = ((NI) -1);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) newObj((&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	(*T1_).kind = kind;
	(*T1_).info = unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) newObj((&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	(*T1_).kind = kind;
	(*T1_).info = info;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son) {
	NI T1_;
	asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*father)._kind_6.sons), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
	T1_ = (*father)._kind_6.sons->Sup.len++;
	asgnRef((void**) (&(*father)._kind_6.sons->data[T1_]), son);
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__uOUBEXn0RV9b64TOM9ajIDag)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__Dq0DNfMwTBUf7hLFKKDU7g kind) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw obj;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*n)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	T1_.kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) (kind));
	T1_.typ = obj.typ;
	T1_.info = obj.info;
	T1_.flags = obj.flags;
	T1_.comment = copyString(obj.comment);
	genericShallowAssign((void*)(&(*n)), (void*)(&T1_), (&NTI__bROa11lyF5vxEN9aYNbHmhw_));
	genericSeqAssign((&(*n)._kind_6.sons), obj._kind_6.sons, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_));
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newProcNode__g5PEkYP0A0RT03uHbJ6wKQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pattern, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptions) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(kind, info);
	if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
	(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), 7);
	asgnRef((void**) (&(*result)._kind_6.sons->data[0]), name);
	asgnRef((void**) (&(*result)._kind_6.sons->data[1]), pattern);
	asgnRef((void**) (&(*result)._kind_6.sons->data[2]), genericParams);
	asgnRef((void**) (&(*result)._kind_6.sons->data[3]), params);
	asgnRef((void**) (&(*result)._kind_6.sons->data[4]), pragmas);
	asgnRef((void**) (&(*result)._kind_6.sons->data[5]), exceptions);
	asgnRef((void**) (&(*result)._kind_6.sons->data[6]), body);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeI__L1Xluv2iZ8cHbWec9bBiiaw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(kind, info);
	{
		if (!(((NI) 0) < childrenLen_0)) goto LA3_;
		(*result).info = (*children[((NI) 0)]).info;
	}
	LA3_: ;
	asgnRef((void**) (&(*result)._kind_6.sons), at___l5EwVkovx8Ofyb2pm635QA(children, childrenLen_0));
	return result;
}
static N_INLINE(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**, X5BX5D___RNblfFqyHCLnrLulG0Us9bQsystem)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** s, NI sLen_0, NI i) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ** T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ**)0;
	T1_ = X5BX5D___RNblfFqyHCLnrLulG0Us9bQsystem((*n).sons->data, ((*n).sons ? (*n).sons->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
static N_INLINE(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**, X5BX5D___f6j2Rr9bpYzKO9bs9a65jNGYQsystem)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** s, NI sLen_0, NI i) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
	result = &s[(NI)(sLen_0 - i)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
	T1_ = X5BX5D___f6j2Rr9bpYzKO9bs9a65jNGYQsystem((*n)._kind_6.sons->data, ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0), ((NI) 1));
	result = (*T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getnimblePkg__Dc0qjIQVl9aS9cfSt6IH2IOg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = a;
	{
		while (1) {
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA2;
			switch ((*result).kind) {
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6):
			{
				result = (*result).owner;
			}
			break;
			case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 24):
			{
				{
					if (!((*result).owner == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA7_;
					goto LA1;
				}
				goto LA5_;
				LA7_: ;
				{
					result = (*result).owner;
				}
				LA5_: ;
			}
			break;
			default:
			{
			}
			break;
			}
		} LA2: ;
	} LA1: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getnimblePkgId__h22KSexh3g61XkIPdO8SNA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a) {
	NI result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b;
	result = (NI)0;
	b = getnimblePkg__Dc0qjIQVl9aS9cfSt6IH2IOg(a);
	{
		if (!(b == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA3_;
		result = ((NI) -1);
	}
	goto LA1_;
	LA3_: ;
	{
		result = (*b).Sup.id;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	T1_ = (NimStringDesc*)0;
	T1_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1(strVal);
	if (T1_) nimGCunrefNoCycle(T1_);
	return result;
}
static N_NIMCALL(void, Marker_tyRef__N89ckikRqMir57209a3tEeqw)(void* p, NI op) {
	tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw* a;
	a = (tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*)p;
	nimGCvisit((void*)(*a).symbols.data, op);
	nimGCvisit((void*)(*a).parent, op);
}
static N_NIMCALL(void, Marker_tySequence__Mh9agqM29bm9aP5AUL1x7dZGA)(void* p, NI op) {
	tySequence__Mh9agqM29bm9aP5AUL1x7dZGA* a;
	NI T1_;
	a = (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].key, op);
	nimGCvisit((void*)a->data[T1_].val, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___75vsOXLrqmx5LmVlMWaymw)(NI16 x) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	{
		if (!(x == ((NI) -1))) goto LA3_;
		result = copyString(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_52));
	}
	goto LA1_;
	LA3_: ;
	{
		if (!(x == ((NI) 1001))) goto LA6_;
		result = copyString(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_53));
	}
	goto LA1_;
	LA6_: ;
	{
		result = nimIntToStr(((NI) (x)));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = t;
	{
		while (1) {
			if (!((kinds &((NU64)1<<((NU)((*result).kind)&63U)))!=0)) goto LA2;
			result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x) {
	(*x).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*x).data), (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*) newSeq((&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_), ((NI) 8)));
}
N_LIB_PRIVATE N_NIMCALL(void, mergeLoc__3y7Rn2QCRcBO28D5ulHx6w)(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA* a, tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA b) {
	{
		if (!((*a).k == ((tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg) 0))) goto LA3_;
		(*a).k = b.k;
	}
	LA3_: ;
	{
		if (!((*a).storage == ((tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw) 0))) goto LA7_;
		(*a).storage = b.storage;
	}
	LA7_: ;
	(*a).flags = ((*a).flags | b.flags);
	{
		if (!((*a).lode == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA11_;
		unsureAsgnRef((void**) (&(*a).lode), b.lode);
	}
	LA11_: ;
	{
		if (!((*a).r == ((tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA*) NIM_NIL))) goto LA15_;
		unsureAsgnRef((void**) (&(*a).r), b.r);
	}
	LA15_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSons__UKZtv7j9a9bCciLd0w3xIW1Q)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, NI length) {
	asgnRef((void**) (&(*father).sons), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) setLengthSeqV2(&((*father).sons)->Sup, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_), ((NI) (length))));
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, assignType__RDstL9c8H9bSHUphDz0iB0hg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* dest, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* src) {
	NI T14_;
	(*dest).kind = (*src).kind;
	(*dest).flags = (*src).flags;
	(*dest).callConv = (*src).callConv;
	asgnRef((void**) (&(*dest).n), (*src).n);
	(*dest).size = (*src).size;
	(*dest).align = (*src).align;
	genericAssign((void*)(*dest).attachedOps, (void*)(*src).attachedOps, (&NTI__PsPyPA45AAjHu4uDGHNjTg_));
	(*dest).lockLevel = (*src).lockLevel;
	{
		if (!!(((*src).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		{
			if (!!(((*dest).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
			(*(*dest).sym).flags = ((*(*dest).sym).flags | ((*(*src).sym).flags & ~ 2));
			{
				if (!((*(*dest).sym).annex == ((tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*) NIM_NIL))) goto LA11_;
				asgnRef((void**) (&(*(*dest).sym).annex), (*(*src).sym).annex);
			}
			LA11_: ;
			mergeLoc__3y7Rn2QCRcBO28D5ulHx6w((&(*(*dest).sym).loc), (*(*src).sym).loc);
		}
		goto LA5_;
		LA7_: ;
		{
			asgnRef((void**) (&(*dest).sym), (*src).sym);
		}
		LA5_: ;
	}
	LA3_: ;
	T14_ = (NI)0;
	T14_ = len__5mJADrRYkP3r9auuiuDZN9cQast(src);
	newSons__UKZtv7j9a9bCciLd0w3xIW1Q(dest, T14_);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast(src);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA17;
				i = i_2;
				asgnRef((void**) (&(*dest).sons->data[i]), (*src).sons->data[i]);
				i_2 += ((NI) 1);
			} LA17: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	(*result).info = info;
	asgnRef((void**) (&(*result).typ), typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	NI id;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	id = getID__82csy2YSddf27azS9awAkVgidgen();
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) newObj((&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_), sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ));
	(*T1_).Sup.Sup.m_type = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
	(*T1_).kind = kind;
	asgnRef((void**) (&(*T1_).owner), owner);
	(*T1_).size = IL64(-1);
	(*T1_).align = ((NI16) -1);
	(*T1_).Sup.id = id;
	(*T1_).uniqueId = id;
	(*T1_).lockLevel = ((NI16) -1);
	result = T1_;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T5_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(src == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ((*src).kind);
	(*result).info = (*src).info;
	asgnRef((void**) (&(*result).typ), (*src).typ);
	(*result).flags = ((*src).flags & PersistentNodeFlags__CA9cjAPRNeyIu5iCykQHUHQ);
	T5_ = (NimStringDesc*)0;
	T5_ = (*result).comment; (*result).comment = copyStringRC1((*src).comment);
	if (T5_) nimGCunrefNoCycle(T5_);
	switch ((*src).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		(*result)._kind_1.intVal = (*src)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		(*result)._kind_2.floatVal = (*src)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		asgnRef((void**) (&(*result)._kind_4.sym), (*src)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		asgnRef((void**) (&(*result)._kind_5.ident), (*src)._kind_5.ident);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1((*src)._kind_3.strVal);
		if (T11_) nimGCunrefNoCycle(T11_);
	}
	break;
	default:
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = len__P89cqdlERShb9alU3iC0yj8wast(src);
		if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
		(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (T13_)));
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(src);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA16;
					i = i_2;
					asgnRef((void**) (&(*result)._kind_6.sons->data[i]), copyTree__Dsjo9bte8vGxzhtcSrsTyiQ((*src)._kind_6.sons->data[i]));
					i_2 += ((NI) 1);
				} LA16: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, copyType__4O4aYoscFPo2FRSh4rP9ayg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, NIM_BOOL keepId) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ((*t).kind, owner);
	assignType__RDstL9c8H9bSHUphDz0iB0hg(result, t);
	{
		if (!keepId) goto LA3_;
		(*result).Sup.id = (*t).Sup.id;
	}
	goto LA1_;
	LA3_: ;
	{
	}
	LA1_: ;
	asgnRef((void**) (&(*result).sym), (*t).sym);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, copyIdTable__kWmPoTDdSpeN1EEQ59bRmKA)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* dest, tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q src) {
	NI T1_;
	(*dest).counter = src.counter;
	T1_ = (src.data ? src.data->Sup.len : 0);
	unsureAsgnRef((void**) (&(*dest).data), (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*) newSeq((&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_), ((NI) (T1_))));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((src.data ? src.data->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				asgnRef((void**) (&(*dest).data->data[i].key), src.data->data[i].key);
				asgnRef((void**) (&(*dest).data->data[i].val), src.data->data[i].val);
				res += ((NI) 1);
			} LA5: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T5_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(src == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ((*src).kind);
	(*result).info = (*src).info;
	asgnRef((void**) (&(*result).typ), (*src).typ);
	(*result).flags = ((*src).flags & 1763086);
	T5_ = (NimStringDesc*)0;
	T5_ = (*result).comment; (*result).comment = copyStringRC1((*src).comment);
	if (T5_) nimGCunrefNoCycle(T5_);
	switch ((*src).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		(*result)._kind_1.intVal = (*src)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		(*result)._kind_2.floatVal = (*src)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		asgnRef((void**) (&(*result)._kind_4.sym), (*src)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		asgnRef((void**) (&(*result)._kind_5.ident), (*src)._kind_5.ident);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1((*src)._kind_3.strVal);
		if (T11_) nimGCunrefNoCycle(T11_);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__9a9axPfb75jdWY25AamJewkA, getInt__Ml9bTZ5dXYSLBfnGRkErokw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_Int128__9a9axPfb75jdWY25AamJewkA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_Int128__9a9axPfb75jdWY25AamJewkA));
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 11) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		result = toInt128__TDVoY1DSlNtMNULcUFRJzA(((NU64) ((*a)._kind_1.intVal)));
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 7) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
	{
		result = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ((*a)._kind_1.intVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6):
	{
		result = toInt128__ZBiVpGjOydV7ZjeElrE9cFQ((*a)._kind_1.intVal);
	}
	break;
	default:
	{
		raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_54));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__aVxWxXLmf103vwE8uZ9cXRw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T4_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 6) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 12) || (*t).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 51) && (*t).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 54) || (*t).kind >= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 56) && (*t).kind <= ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 59));
	if (T2_) goto LA3_;
	T4_ = (NIM_BOOL)0;
	T4_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
	if (!(T4_)) goto LA5_;
	T4_ = ((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	LA5_: ;
	T2_ = T4_;
	LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T1_ = (((*t).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21))&63U)))!=0);
	LA6_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isGCedMem__nPImuPGZIdcrAfCNyf4oxAast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22) || (*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
	LA4_: ;
	T1_ = T3_;
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elem, NIM_BOOL propagateHasAsgn) {
	tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw mask;
	(*owner).flags = ((*owner).flags | ((*elem).flags & IL64(8592031744)));
	{
		if (!(((*elem).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17))&63U)))!=0)) goto LA3_;
		{
			if (!((*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9))) goto LA7_;
			(*owner).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 17)) & 63);
		}
		LA7_: ;
	}
	LA3_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isMetaType__aVxWxXLmf103vwE8uZ9cXRw(elem);
		if (!T11_) goto LA12_;
		(*owner).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 21)) & 63);
	}
	LA12_: ;
	mask = ((*elem).flags & IL64(2147483664));
	{
		NIM_BOOL T16_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* o2;
		T16_ = (NIM_BOOL)0;
		T16_ = !((mask == 0));
		if (!(T16_)) goto LA17_;
		T16_ = propagateHasAsgn;
		LA17_: ;
		if (!T16_) goto LA18_;
		o2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(owner, IL64(70368744179728));
		{
			if (!((*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 13) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 27) || (*o2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 48))) goto LA22_;
			(*o2).flags = ((*o2).flags | mask);
			(*owner).flags = ((*owner).flags | mask);
		}
		LA22_: ;
	}
	LA18_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* elemB;
		if (!!(((*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 10) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 9) || (*owner).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21)))) goto LA26_;
		elemB = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(elem, IL64(70368744179728));
		{
			NIM_BOOL T30_;
			T30_ = (NIM_BOOL)0;
			T30_ = isGCedMem__nPImuPGZIdcrAfCNyf4oxAast(elemB);
			if (T30_) goto LA31_;
			T30_ = (((*elemB).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 22))&63U)))!=0);
			LA31_: ;
			if (!T30_) goto LA32_;
			(*owner).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 22)) & 63);
		}
		LA32_: ;
	}
	LA26_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn) {
	NI T1_;
	asgnRef((void**) (&(*father).sons), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*father).sons), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
	T1_ = (*father).sons->Sup.len++;
	asgnRef((void**) (&(*father).sons->data[T1_]), son);
	{
		if (!!((son == 0))) goto LA4_;
		propagateToOwner__SzeWf39bw6SALsrL5NDJWbQ(father, son, propagateHasAsgn);
	}
	LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, copyStrTable__j9aaCGqD2f9bSLzpYxKfYCiA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* dest, tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA src) {
	NI T1_;
	(*dest).counter = src.counter;
	T1_ = (src.data ? src.data->Sup.len : 0);
	unsureAsgnRef((void**) (&(*dest).data), (tySequence__DfgJFJEYoj4YBAHLZPl5lQ*) setLengthSeqV2(&((*dest).data)->Sup, (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_), ((NI) (T1_))));
	{
		NI i;
		NI colontmp_;
		NI T3_;
		NI res;
		i = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((src.data ? src.data->Sup.len : 0)-1);
		colontmp_ = T3_;
		res = ((NI) 0);
		{
			while (1) {
				if (!(res <= colontmp_)) goto LA5;
				i = res;
				asgnRef((void**) (&(*dest).data->data[i]), src.data->data[i]);
				res += ((NI) 1);
			} LA5: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, copySym__lIu8wX6Beq6dBJgESOFFjg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = newSym__IXbidcxhXTQGZY9abN63Cxg((*s).kind, (*s).name, (*s).owner, (*s).info, (*s).options);
	asgnRef((void**) (&(*result).typ), (*s).typ);
	(*result).flags = (*s).flags;
	(*result).magic = (*s).magic;
	{
		if (!((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6))) goto LA3_;
		copyStrTable__j9aaCGqD2f9bSLzpYxKfYCiA((&(*result)._kind_3.tab), (*s)._kind_3.tab);
	}
	LA3_: ;
	(*result).options = (*s).options;
	(*result).position = (*s).position;
	genericAssign((void*)(&(*result).loc), (void*)(&(*s).loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	asgnRef((void**) (&(*result).annex), (*s).annex);
	asgnRef((void**) (&(*result).constraint), (*s).constraint);
	{
		if (!((525056 &((NU32)1<<((NU)((*result).kind)&31U)))!=0)) goto LA7_;
		asgnRef((void**) (&(*result)._kind_4.guard), (*s)._kind_4.guard);
		(*result)._kind_4.bitsize = (*s)._kind_4.bitsize;
		(*result)._kind_4.alignment = (*s)._kind_4.alignment;
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	asgnRef((void**) (&(*result)._kind_4.sym), sym);
	asgnRef((void**) (&(*result).typ), (*sym).typ);
	(*result).info = (*sym).info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newSons__Bu9cqnssJjx4jfWBeiR9albg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI length) {
	asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*father)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (length))));
}
N_LIB_PRIVATE N_NIMCALL(void, add__9a8CdZqChTyqzq5bpSL3TzA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son) {
	NI T1_;
	asgnRef((void**) (&(*father).sons), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*father).sons), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
	T1_ = (*father).sons->Sup.len++;
	asgnRef((void**) (&(*father).sons->data[T1_]), son);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	(*result)._kind_1.intVal = intVal;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T5_)) goto LA6_;
		T5_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((*(*n).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = ((*(*n).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		LA8_: ;
		if (!T3_) goto LA9_;
		result = n;
		goto BeforeRet_;
	}
	LA9_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son;
		son = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
					if (!(i_2 < colontmp_)) goto LA14;
					i = i_2;
					son = (*n)._kind_6.sons->data[i];
					n_2 = findUnresolvedStatic__UPSW0jLTX5qJL51YMUAHgw_2(son);
					{
						if (!!((n_2 == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA17_;
						result = n_2;
						goto BeforeRet_;
					}
					LA17_: ;
					i_2 += ((NI) 1);
				} LA14: ;
			}
		}
	}
	result = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newStrTable__mHe4qdIbMriO4fD2l0WhLA)(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA* Result) {
	(*Result).counter = 0;
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	initStrTable__2n9b6ELeZfbbP5wqNYm7VyA(Result);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, exactReplica__wG9cFX0BL4VD1hNwr4zEuwQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = copyType__4O4aYoscFPo2FRSh4rP9ayg(t, (*t).owner, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionGenericParamToType__EEixHgS5VK63cVXrrMe6Tw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w obj;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	obj.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*s)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	T1_.kind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7);
	T1_.Sup.id = obj.Sup.id;
	T1_.magic = obj.magic;
	T1_.typ = obj.typ;
	T1_.name = obj.name;
	T1_.info = obj.info;
	T1_.owner = obj.owner;
	T1_.flags = obj.flags;
	T1_.ast = obj.ast;
	T1_.options = obj.options;
	T1_.position = obj.position;
	T1_.offset = obj.offset;
	genericAssign((void*)(&T1_.loc), (void*)(&obj.loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	T1_.annex = obj.annex;
	T1_.constraint = obj.constraint;
	genericShallowAssign((void*)(&(*s)), (void*)(&T1_), (&NTI__JpsEh5i1AcKChGYbg7aV4w_));
	genericSeqAssign((&(*s)._kind_1.typeInstCache), obj._kind_1.typeInstCache, (&NTI__Ef05srmQTDulnBdXR4Ja6Q_));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__AFd9c9cdRrILXl9anrr9aRvqig)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	asgnRef((void**) (&(*result)._kind_4.sym), sym);
	asgnRef((void**) (&(*result).typ), (*sym).typ);
	(*result).info = info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	{
		if (!(((NI) 0) < childrenLen_0)) goto LA3_;
		(*result).info = (*children[((NI) 0)]).info;
	}
	LA3_: ;
	asgnRef((void**) (&(*result)._kind_6.sons), at___l5EwVkovx8Ofyb2pm635QA(children, childrenLen_0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, originatingModule__lIu8wX6Beq6dBJgESOFFjg_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = (*s).owner;
	{
		while (1) {
			if (!!(((*result).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)))) goto LA2;
			result = (*result).owner;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((520192 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*(*s).owner).owner;
	}
	goto LA1_;
	LA5_: ;
	{
		result = (*s).owner;
	}
	LA1_: ;
	return result;
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, IL64(36134350144710928));
	kind = (*T1_).kind;
	switch (kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 32):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 7));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 33):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 8));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 34):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 9));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 11));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 41):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 12));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 42):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 13));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 43):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 14));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60):
	{
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6));
	}
	break;
	default:
	{
		{
			NimStringDesc* T20_;
			if (!NIM_TRUE) goto LA18_;
			T20_ = (NimStringDesc*)0;
			T20_ = rawNewString((reprEnum((NI)kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)) ? reprEnum((NI)kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_))->Sup.len : 0) + 26);
appendString(T20_, ((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_55));
appendString(T20_, reprEnum((NI)kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_)));
			failedAssertImpl__W9cjVocn1tjhW7p7xohJj6A(T20_);
		}
		LA18_: ;
	}
	break;
	}
	(*result)._kind_1.intVal = intVal;
	asgnRef((void**) (&(*result).typ), typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIdentNode__KZLyxk08RZ9cnzbQfphbJPQ)(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
	asgnRef((void**) (&(*result)._kind_5.ident), ident);
	(*result).info = info;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	switch ((*s).kind) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12) ... ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 18):
	{
		NIM_BOOL T2_;
		NIM_BOOL T4_;
		T2_ = (NIM_BOOL)0;
		T2_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2))&63U)))!=0);
		if (T2_) goto LA3_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = !(((*(*(*s).ast)._kind_6.sons->data[((NI) 2)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		LA5_: ;
		T2_ = T4_;
		LA3_: ;
		result = T2_;
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, requiredParams__knh7oe6js9clE7mbQBo9aJGA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NI result;
	NI T8_;
{	result = (NI)0;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!!(((*(*(*(*(*s).typ).n)._kind_6.sons->data[i])._kind_4.sym).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA6_;
					result = (NI)(i - ((NI) 1));
					goto BeforeRet_;
				}
				LA6_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	T8_ = (NI)0;
	T8_ = len__5mJADrRYkP3r9auuiuDZN9cQast((*s).typ);
	result = (NI)(T8_ - ((NI) 1));
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipColon__UPSW0jLTX5qJL51YMUAHgw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA3_;
		result = (*n)._kind_6.sons->data[((NI) 1)];
	}
	LA3_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__K8W16aeLg4OWxniQxtguMw)(void* p, NI op) {
	tySequence__K8W16aeLg4OWxniQxtguMw* a;
	NI T1_;
	a = (tySequence__K8W16aeLg4OWxniQxtguMw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].key, op);
	nimGCvisit((void*)a->data[T1_].val, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) newObj((&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	(*T1_).kind = kind;
	(*T1_).info = info;
	result = T1_;
	{
		if (!(((NI) 0) < children)) goto LA4_;
		if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
		(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (children)));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newProcType__9bgJAAoskVeu3l1AHMmz9adg)(tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25), owner);
	asgnRef((void**) (&(*result).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), info));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), NIM_TRUE);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), info);
	add__P8dDSotTW25BkfbyspojGg((*result).n, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addParam__MnxL8SpIj0v6dB7M1prhCw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* procType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param) {
	NI T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	T1_ = (NI)0;
	T1_ = len__5mJADrRYkP3r9auuiuDZN9cQast(procType);
	(*param).position = (NI)(T1_ - ((NI) 1));
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(param);
	add__P8dDSotTW25BkfbyspojGg((*procType).n, T2_);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(procType, (*param).typ, NIM_TRUE);
}
N_LIB_PRIVATE N_NIMCALL(void, initIdNodeTable__n26YHulDKiMl1PNSd3sg9cA)(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA* x) {
	(*x).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*x).data), (tySequence__K8W16aeLg4OWxniQxtguMw*) newSeq((&NTI__K8W16aeLg4OWxniQxtguMw_), ((NI) 8)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, shallowCopy__Dsjo9bte8vGxzhtcSrsTyiQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T5_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(src == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ((*src).kind);
	(*result).info = (*src).info;
	asgnRef((void**) (&(*result).typ), (*src).typ);
	(*result).flags = ((*src).flags & PersistentNodeFlags__CA9cjAPRNeyIu5iCykQHUHQ);
	T5_ = (NimStringDesc*)0;
	T5_ = (*result).comment; (*result).comment = copyStringRC1((*src).comment);
	if (T5_) nimGCunrefNoCycle(T5_);
	switch ((*src).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		(*result)._kind_1.intVal = (*src)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		(*result)._kind_2.floatVal = (*src)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		asgnRef((void**) (&(*result)._kind_4.sym), (*src)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		asgnRef((void**) (&(*result)._kind_5.ident), (*src)._kind_5.ident);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1((*src)._kind_3.strVal);
		if (T11_) nimGCunrefNoCycle(T11_);
	}
	break;
	default:
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = len__P89cqdlERShb9alU3iC0yj8wast(src);
		if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
		(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (T13_)));
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionToLet__EEixHgS5VK63cVXrrMe6Tw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w obj;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	obj.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*s)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	T1_.kind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9);
	T1_.Sup.id = obj.Sup.id;
	T1_.magic = obj.magic;
	T1_.typ = obj.typ;
	T1_.name = obj.name;
	T1_.info = obj.info;
	T1_.owner = obj.owner;
	T1_.flags = obj.flags;
	T1_.ast = obj.ast;
	T1_.options = obj.options;
	T1_.position = obj.position;
	T1_.offset = obj.offset;
	genericAssign((void*)(&T1_.loc), (void*)(&obj.loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	T1_.annex = obj.annex;
	T1_.constraint = obj.constraint;
	genericShallowAssign((void*)(&(*s)), (void*)(&T1_), (&NTI__JpsEh5i1AcKChGYbg7aV4w_));
	asgnRef((void**) (&(*s)._kind_4.guard), obj._kind_4.guard);
	(*s)._kind_4.bitsize = obj._kind_4.bitsize;
	(*s)._kind_4.alignment = obj._kind_4.alignment;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__dcaLKYQOoDL7JJDz3Djr8g)(tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NI64 T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NI64)0;
	T1_ = castToInt64__1szweXXq3RBN50owrYu2Xw_2(intVal);
	result = newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(T1_, typ);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNode__FUOXigLcQdNOaWKUo0hkTg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NF floatVal) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	(*result)._kind_2.floatVal = floatVal;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__dgNNhprrT2HlJglL2Nc3EA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	NF result;
	result = (NF)0;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		result = (*a)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 11) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 10):
	{
		result = ((NF) ((*a)._kind_1.intVal));
	}
	break;
	default:
	{
		raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_54));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStr__P2DOsHG6Jk4Siab3L2qwUg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		result = copyString((*a)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = ((NimStringDesc*) NIM_NIL);
	}
	break;
	default:
	{
		raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_64));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getStrOrChar__P2DOsHG6Jk4Siab3L2qwUg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	switch ((*a).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		result = copyString((*a)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		result = nimCharToStr(((NIM_CHAR) (((NI) (((NI) ((*a)._kind_1.intVal)))))));
	}
	break;
	default:
	{
		raiseRecoverableError__5jd5IdwI3N06CaI2zjEQsQ(((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_64));
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toVar__ltkZL9cdOU06qIwP1L9aFqcw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = typ;
	{
		if (!!(((*typ).kind == kind))) goto LA3_;
		result = newType__SNqpa06pdVCLFFBR28119aQ(kind, (*typ).owner);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, typ, NIM_TRUE);
	}
	LA3_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__CZaoTkWCFI9acor4BmYF3Yw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = eqStrings((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_65));
	LA4_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__dZW9czpRSiiVl9cyT6tyk84A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* base;
{	result = (NIM_BOOL)0;
	{
		if (!!(((*conf).exc == ((tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ) 2)))) goto LA3_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA3_: ;
	base = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, 2107408);
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = !(((*base).sym == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
		if (!(T7_)) goto LA8_;
		T7_ = !(((IL64(2147483712) & (*(*base).sym).flags) == 0));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = NIM_TRUE;
	}
	LA9_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toRef__IIQZtbSxQZOu2WmBJ9bnpCg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = typ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T3_;
		T3_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T3_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, 2064);
		if (!((*T3_).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17))) goto LA4_;
		result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), (*typ).owner);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, typ, NIM_TRUE);
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionIntKind__VaXqiHBsdA0MNhmXnesuRw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__D37bGuL0oC9aRhwdwBfWpFg kind) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw obj;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*n)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	T1_.kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) (kind));
	T1_.typ = obj.typ;
	T1_.info = obj.info;
	T1_.flags = obj.flags;
	T1_.comment = copyString(obj.comment);
	genericShallowAssign((void*)(&(*n)), (void*)(&T1_), (&NTI__bROa11lyF5vxEN9aYNbHmhw_));
	(*n)._kind_1.intVal = obj._kind_1.intVal;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypesOrNil__zsqmUNR5OZrTUna0Y9bdu9bg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = t;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((result == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = ((kinds &((NU64)1<<((NU)((*result).kind)&63U)))!=0);
			LA4_: ;
			if (!T3_) goto LA2;
			{
				NI T7_;
				T7_ = (NI)0;
				T7_ = len__5mJADrRYkP3r9auuiuDZN9cQast(result);
				if (!(T7_ == ((NI) 0))) goto LA8_;
				result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
				goto BeforeRet_;
			}
			LA8_: ;
			result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, astdef__PBkjYIaAGbtrZ8DiUArHcw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*s).ast).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*(*s).ast)._kind_6.sons->data[((NI) 2)];
	}
	goto LA1_;
	LA5_: ;
	{
		result = (*s).ast;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__C1MQfgDmfXqO1v69aAZbuYA)(NimStringDesc* strVal, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), info);
	T1_ = (NimStringDesc*)0;
	T1_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1(strVal);
	if (T1_) nimGCunrefNoCycle(T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, discardSons__CndA7u9cT5evGd9a583WPNqQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father) {
	if ((*father)._kind_6.sons) { nimGCunrefNoCycle((*father)._kind_6.sons); (*father)._kind_6.sons = NIM_NIL; }
}
N_LIB_PRIVATE N_NIMCALL(void, appendToModule__T4o9clzgbAgGY4ORbfP6LmQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	{
		if (!((*m).ast == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		asgnRef((void**) (&(*m).ast), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115)));
		if ((*(*m).ast)._kind_6.sons) { nimGCunrefNoCycle((*(*m).ast)._kind_6.sons); (*(*m).ast)._kind_6.sons = NIM_NIL; }
		(*(*m).ast)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), 1);
		asgnRef((void**) (&(*(*m).ast)._kind_6.sons->data[0]), n);
	}
	goto LA1_;
	LA3_: ;
	{
		NI T6_;
		asgnRef((void**) (&(*(*m).ast)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*(*m).ast)._kind_6.sons), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
		T6_ = (*(*m).ast)._kind_6.sons->Sup.len++;
		asgnRef((void**) (&(*(*m).ast)._kind_6.sons->data[T6_]), n);
	}
	LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, delSon__oU9bKATaboy8iUhv0r9bMBPw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, NI idx) {
	NI T10_;
{	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast(father);
		if (!(T3_ == ((NI) 0))) goto LA4_;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NI i;
		NI colontmp_;
		NI T7_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		T7_ = (NI)0;
		T7_ = len__P89cqdlERShb9alU3iC0yj8wast(father);
		colontmp_ = (NI)(T7_ - ((NI) 1));
		i_2 = idx;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i = i_2;
				asgnRef((void**) (&(*father)._kind_6.sons->data[i]), (*father)._kind_6.sons->data[(NI)(i + ((NI) 1))]);
				i_2 += ((NI) 1);
			} LA9: ;
		}
	}
	T10_ = (NI)0;
	T10_ = len__P89cqdlERShb9alU3iC0yj8wast(father);
	asgnRef((void**) (&(*father)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*father)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(T10_ - ((NI) 1))))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCallExpr__CZaoTkWCFI9acor4BmYF3Yw_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, resetIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ_2)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* x) {
	(*x).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*x).data), (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*) setLengthSeqV2(&((*x).data)->Sup, (&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_), ((NI) 0)));
	unsureAsgnRef((void**) (&(*x).data), (tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*) setLengthSeqV2(&((*x).data)->Sup, (&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_), ((NI) 8)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, linkTo__Lxy1G9c1I40y65cWkoPnssA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	asgnRef((void**) (&(*t).sym), s);
	asgnRef((void**) (&(*s).typ), t);
	result = s;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___ogYTOKbgqbjPfyC123US1gsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)((NI)((s ? s->Sup.len : 0) - x.b) - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStrImpl__FnrYV0vmnt9aYi4h7fMu7dQ)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	NimStringDesc* result;
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T1_;
	result = (NimStringDesc*)0;
	result = reprEnum((NI)kind, (&NTI__cNCW9acsSznmEccl1fgQwkw_));
	T1_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 2), ((NI) 1));
	result = X5BX5D___ogYTOKbgqbjPfyC123US1gsystem(result, T1_);
	result->data[((NI) 0)] = nsuToLowerAsciiChar(result->data[((NI) 0)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStr__QHyA5kxlk0TZf3p6IbMdtA)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = toHumanStrImpl__FnrYV0vmnt9aYi4h7fMu7dQ(kind);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStrImpl__QnY9aC6DAYwbdvoEdssXiLw)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	NimStringDesc* result;
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T1_;
	result = (NimStringDesc*)0;
	result = reprEnum((NI)kind, (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_));
	T1_ = dotdot___xNR8BVBMWzS9bXXNMikmyLgsystem(((NI) 2), ((NI) 1));
	result = X5BX5D___ogYTOKbgqbjPfyC123US1gsystem(result, T1_);
	result->data[((NI) 0)] = nsuToLowerAsciiChar(result->data[((NI) 0)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHumanStr__8clA3iQh1Lbc5cnapppbXQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = toHumanStrImpl__QnY9aC6DAYwbdvoEdssXiLw(kind);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg kind) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w obj;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	obj.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*s)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w));
	T1_.Sup.Sup.m_type = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
	T1_.kind = ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) (kind));
	T1_.Sup.id = obj.Sup.id;
	T1_.magic = obj.magic;
	T1_.typ = obj.typ;
	T1_.name = obj.name;
	T1_.info = obj.info;
	T1_.owner = obj.owner;
	T1_.flags = obj.flags;
	T1_.ast = obj.ast;
	T1_.options = obj.options;
	T1_.position = obj.position;
	T1_.offset = obj.offset;
	genericAssign((void*)(&T1_.loc), (void*)(&obj.loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	T1_.annex = obj.annex;
	T1_.constraint = obj.constraint;
	genericShallowAssign((void*)(&(*s)), (void*)(&T1_), (&NTI__JpsEh5i1AcKChGYbg7aV4w_));
	genericSeqAssign((&(*s)._kind_2.procInstCache), obj._kind_2.procInstCache, (&NTI__DXS6mEo7PVUFJkirsQ9bNQA_));
	asgnRef((void**) (&(*s)._kind_2.gcUnsafetyReason), obj._kind_2.gcUnsafetyReason);
	asgnRef((void**) (&(*s)._kind_2.transformedBody), obj._kind_2.transformedBody);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__3PkUvehQ5keciM9cue9ayMTw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tySet_tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kinds) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = ((kinds[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i = i_2;
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = ((kinds[(NU)((*n).kind)>>3] &(1U<<((NU)((*n).kind)&7U)))!=0);
						if (T12_) goto LA13_;
						T12_ = containsNode__3PkUvehQ5keciM9cue9ayMTw((*n)._kind_6.sons->data[i], kinds);
						LA13_: ;
						if (!T12_) goto LA14_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA14_: ;
					i_2 += ((NI) 1);
				} LA9: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__4YOyxaxo739b3eaIho5QEcA)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_Int128__9a9axPfb75jdWY25AamJewkA intVal) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(kind);
	(*result)._kind_1.intVal = castToInt64__1szweXXq3RBN50owrYu2Xw_2(intVal);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	{
		result = ((*n).kind == kind);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i = i_2;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = ((*(*n)._kind_6.sons->data[i]).kind == kind);
						if (T8_) goto LA9_;
						T8_ = hasSubnodeWith__SQs4BrslojahuO1o7NDT4Q((*n)._kind_6.sons->data[i], kind);
						LA9_: ;
						if (!T8_) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
					LA10_: ;
					i_2 += ((NI) 1);
				} LA5: ;
			}
		}
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasDisabledAsgn__aVxWxXLmf103vwE8uZ9cXRw_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 1))- 0] == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*t).attachedOps[(((tyEnum_TTypeAttachedOp__Rp5P9bWYldQTLkZ7DytmxOg) 1))- 0]).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 24))&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawAddSonNoPropagationOfTypeFlags__9a8CdZqChTyqzq5bpSL3TzA_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son) {
	NI T1_;
	asgnRef((void**) (&(*father).sons), (tySequence__Ef05srmQTDulnBdXR4Ja6Q*) incrSeqV3((TGenericSeq*)((*father).sons), (&NTI__Ef05srmQTDulnBdXR4Ja6Q_)));
	T1_ = (*father).sons->Sup.len++;
	asgnRef((void**) (&(*father).sons->data[T1_]), son);
}
N_LIB_PRIVATE N_NIMCALL(void, transitionNoneToSym__ZdMf7vswMpd0Pc5oB9aS4og)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw obj;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw T1_;
	nimZeroMem((void*)(&obj), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimCopyMem((void*)(&obj), (NIM_CONST void*)(&(*n)), sizeof(obj));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw));
	T1_.kind = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3);
	T1_.typ = obj.typ;
	T1_.info = obj.info;
	T1_.flags = obj.flags;
	T1_.comment = copyString(obj.comment);
	genericShallowAssign((void*)(&(*n)), (void*)(&T1_), (&NTI__bROa11lyF5vxEN9aYNbHmhw_));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__Jb9ck8uy9aKqJSHdNSzDJAJQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds, NI maxIters) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	NI i;
{	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = t;
	i = maxIters;
	{
		while (1) {
			if (!((kinds &((NU64)1<<((NU)((*result).kind)&63U)))!=0)) goto LA2;
			result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(result);
			i -= ((NI) 1);
			{
				if (!(i == ((NI) 0))) goto LA5_;
				result = ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL);
				goto BeforeRet_;
			}
			LA5_: ;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTreeWithoutNode__aN5jlv83QmlsI1PY356I2w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* skippedNode) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NimStringDesc* T5_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!(src == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ((*src).kind);
	(*result).info = (*src).info;
	asgnRef((void**) (&(*result).typ), (*src).typ);
	(*result).flags = ((*src).flags & PersistentNodeFlags__CA9cjAPRNeyIu5iCykQHUHQ);
	T5_ = (NimStringDesc*)0;
	T5_ = (*result).comment; (*result).comment = copyStringRC1((*src).comment);
	if (T5_) nimGCunrefNoCycle(T5_);
	switch ((*src).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 5) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 15):
	{
		(*result)._kind_1.intVal = (*src)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 19):
	{
		(*result)._kind_2.floatVal = (*src)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		asgnRef((void**) (&(*result)._kind_4.sym), (*src)._kind_4.sym);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	{
		asgnRef((void**) (&(*result)._kind_5.ident), (*src)._kind_5.ident);
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 22):
	{
		NimStringDesc* T11_;
		T11_ = (NimStringDesc*)0;
		T11_ = (*result)._kind_3.strVal; (*result)._kind_3.strVal = copyStringRC1((*src)._kind_3.strVal);
		if (T11_) nimGCunrefNoCycle(T11_);
	}
	break;
	default:
	{
		NI T13_;
		T13_ = (NI)0;
		T13_ = len__P89cqdlERShb9alU3iC0yj8wast(src);
		asgnRef((void**) (&(*result)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)nimNewSeqOfCap((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) (T13_))));
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** n;
			tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* colontmp_;
			NI i;
			NI L;
			NI T15_;
			n = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			colontmp_ = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*)0;
			colontmp_ = (*src)._kind_6.sons;
			i = ((NI) 0);
			T15_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T15_;
			{
				while (1) {
					if (!(i < L)) goto LA17;
					n = &colontmp_->data[i];
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
						NI T23_;
						if (!!(((*n) == skippedNode))) goto LA20_;
						T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T22_ = copyTreeWithoutNode__aN5jlv83QmlsI1PY356I2w((*n), skippedNode);
						asgnRef((void**) (&(*result)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) incrSeqV3((TGenericSeq*)((*result)._kind_6.sons), (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_)));
						T23_ = (*result)._kind_6.sons->Sup.len++;
						asgnRef((void**) (&(*result)._kind_6.sons->data[T23_]), T22_);
					}
					LA20_: ;
					i += ((NI) 1);
				} LA17: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newIdTable__Vn79aD3eLpwW0W0F5ymtWkw)(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q* Result) {
	(*Result).counter = 0;
	unsureAsgnRef((void**)&(*Result).data, NIM_NIL);
	initIdTable__Z7fF0Wc4DSB4kCiKZ8rGfQ(Result);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRunnableExamples__CZaoTkWCFI9acor4BmYF3Yw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*n)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 263));
	LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2));
	if (!(T5_)) goto LA6_;
	T5_ = eqStrings((*(*n)._kind_5.ident).s, ((NimStringDesc*) &TM__EnH1I9cGkGYbf9a1NwhuXDPg_66));
	LA6_: ;
	T1_ = T5_;
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTreeIT__iShdzoe9aISfAzry2HqGKqg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(kind, info, typ);
	{
		if (!(((NI) 0) < childrenLen_0)) goto LA3_;
		(*result).info = (*children[((NI) 0)]).info;
	}
	LA3_: ;
	asgnRef((void**) (&(*result)._kind_6.sons), at___l5EwVkovx8Ofyb2pm635QA(children, childrenLen_0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnresolvedStatic__aVxWxXLmf103vwE8uZ9cXRw_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 60));
	if (!(T1_)) goto LA2_;
	T1_ = ((*t).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, toObject__IIQZtbSxQZOu2WmBJ9bnpCg_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	t = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(typ, 2064);
	{
		if (!((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22))) goto LA3_;
		result = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
	}
	goto LA1_;
	LA3_: ;
	{
		result = typ;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createModuleAlias__ajb2UbRCmJqd8A4LzDHuFw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* newIdent, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	result = newSym__IXbidcxhXTQGZY9abN63Cxg((*s).kind, newIdent, (*s).owner, info, options);
	asgnRef((void**) (&(*result).ast), (*s).ast);
	(*result).Sup.id = (*s).Sup.id;
	(*result).flags = (*s).flags;
	(*result)._kind_3.tab.counter = (*s)._kind_3.tab.counter;
	asgnRef((void**) (&(*result)._kind_3.tab.data), (*s)._kind_3.tab.data);
	(*result).options = (*s).options;
	(*result).position = (*s).position;
	genericAssign((void*)(&(*result).loc), (void*)(&(*s).loc), (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_));
	asgnRef((void**) (&(*result).annex), (*s).annex);
	return result;
}
static N_NIMCALL(void, Marker_tySequence__vhmj4KkIKPinmRXny9c2Q6Q)(void* p, NI op) {
	tySequence__vhmj4KkIKPinmRXny9c2Q6Q* a;
	NI T1_;
	a = (tySequence__vhmj4KkIKPinmRXny9c2Q6Q*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].key, op);
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initNodeTable__RsAJjlvhLCgVyd9cZJtMRoQ)(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A* x) {
	(*x).counter = ((NI) 0);
	unsureAsgnRef((void**) (&(*x).data), (tySequence__vhmj4KkIKPinmRXny9c2Q6Q*) newSeq((&NTI__vhmj4KkIKPinmRXny9c2Q6Q_), ((NI) 8)));
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__qAerQ9bftuf70QDk42UIFXg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 22) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 23) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 25) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 26) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 20)));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA5_: ;
	{
		result = NIM_TRUE;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__qAerQ9bftuf70QDk42UIFXg_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 22) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 23) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 25) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 26) || (*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 20)));
		if (T6_) goto LA7_;
		T6_ = ((IL64(2147483712) & (*(*fn)._kind_4.sym).flags) == 64);
		LA7_: ;
		T5_ = T6_;
		if (T5_) goto LA8_;
		T5_ = (((*(*fn)._kind_4.sym).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 38))&63U)))!=0);
		LA8_: ;
		T3_ = T5_;
		LA4_: ;
		if (!T3_) goto LA9_;
		result = NIM_FALSE;
	}
	goto LA1_;
	LA9_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T12_)) goto LA13_;
		T12_ = ((*(*fn)._kind_4.sym).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 20));
		LA13_: ;
		if (!T12_) goto LA14_;
		result = NIM_TRUE;
	}
	goto LA1_;
	LA14_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T18_;
		NIM_BOOL T21_;
		NI T22_;
		NIM_BOOL T24_;
		NI T26_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NIM_BOOL)0;
		T18_ = !(((*fn).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T18_)) goto LA19_;
		T18_ = !(((*(*fn).typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		LA19_: ;
		T17_ = T18_;
		if (!(T17_)) goto LA20_;
		T21_ = (NIM_BOOL)0;
		T22_ = (NI)0;
		T22_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*(*fn).typ).n)._kind_6.sons->data[((NI) 0)]);
		T21_ = (T22_ < ((NI) 5));
		if (T21_) goto LA23_;
		T24_ = (NIM_BOOL)0;
		T24_ = !(((*(*(*(*fn).typ).n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)] == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T24_)) goto LA25_;
		T26_ = (NI)0;
		T26_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*(*(*(*fn).typ).n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 0)]);
		T24_ = (((NI) 0) < T26_);
		LA25_: ;
		T21_ = T24_;
		LA23_: ;
		T17_ = T21_;
		LA20_: ;
		result = T17_;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipStmtList__UPSW0jLTX5qJL51YMUAHgw_4)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA3_;
		{
			NI i;
			NI colontmp_;
			NI T6_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (NI)0;
			T6_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			colontmp_ = (NI)(T6_ - ((NI) 1));
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i = i_2;
					{
						if (!!(((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) || (*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125)))) goto LA11_;
						result = n;
						goto BeforeRet_;
					}
					LA11_: ;
					i_2 += ((NI) 1);
				} LA8: ;
			}
		}
		result = lastSon__UPSW0jLTX5qJL51YMUAHgw(n);
	}
	goto LA1_;
	LA3_: ;
	{
		result = n;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_astDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_2_26[26];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_4;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_3[26] = {
"skUnknown", 
"skConditional", 
"skDynLib", 
"skParam", 
"skGenericParam", 
"skTemp", 
"skModule", 
"skType", 
"skVar", 
"skLet", 
"skConst", 
"skResult", 
"skProc", 
"skFunc", 
"skMethod", 
"skIterator", 
"skConverter", 
"skMacro", 
"skTemplate", 
"skField", 
"skEnumField", 
"skForVar", 
"skLabel", 
"skStub", 
"skPackage", 
"skAlias"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_5_46[46];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_7;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_6[46] = {
"sfUsed", 
"sfExported", 
"sfFromGeneric", 
"sfGlobal", 
"sfForward", 
"sfWasForwarded", 
"sfImportc", 
"sfExportc", 
"sfMangleCpp", 
"sfVolatile", 
"sfRegister", 
"sfPure", 
"sfNoSideEffect", 
"sfSideEffect", 
"sfMainModule", 
"sfSystemModule", 
"sfNoReturn", 
"sfAddrTaken", 
"sfCompilerProc", 
"sfProcvar", 
"sfDiscriminant", 
"sfRequiresInit", 
"sfDeprecated", 
"sfExplain", 
"sfError", 
"sfShadowed", 
"sfThread", 
"sfCompileTime", 
"sfConstructor", 
"sfDispatcher", 
"sfBorrow", 
"sfInfixCall", 
"sfNamedParamCall", 
"sfDiscardable", 
"sfOverriden", 
"sfCallsite", 
"sfGenSym", 
"sfNonReloadable", 
"sfGeneratedOp", 
"sfTemplateParam", 
"sfCursor", 
"sfInjectDestructors", 
"sfNeverRaises", 
"sfUsedInFinallyOrExcept", 
"sfSingleUsedTemp", 
"sfNoalias"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_8_64[64];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_10;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_9[64] = {
"tyNone", 
"tyBool", 
"tyChar", 
"tyEmpty", 
"tyAlias", 
"tyNil", 
"tyUntyped", 
"tyTyped", 
"tyTypeDesc", 
"tyGenericInvocation", 
"tyGenericBody", 
"tyGenericInst", 
"tyGenericParam", 
"tyDistinct", 
"tyEnum", 
"tyOrdinal", 
"tyArray", 
"tyObject", 
"tyTuple", 
"tySet", 
"tyRange", 
"tyPtr", 
"tyRef", 
"tyVar", 
"tySequence", 
"tyProc", 
"tyPointer", 
"tyOpenArray", 
"tyString", 
"tyCString", 
"tyForward", 
"tyInt", 
"tyInt8", 
"tyInt16", 
"tyInt32", 
"tyInt64", 
"tyFloat", 
"tyFloat32", 
"tyFloat64", 
"tyFloat128", 
"tyUInt", 
"tyUInt8", 
"tyUInt16", 
"tyUInt32", 
"tyUInt64", 
"tyOwned", 
"tySink", 
"tyLent", 
"tyVarargs", 
"tyUncheckedArray", 
"tyProxy", 
"tyBuiltInTypeClass", 
"tyUserTypeClass", 
"tyUserTypeClassInst", 
"tyCompositeTypeClass", 
"tyInferred", 
"tyAnd", 
"tyOr", 
"tyNot", 
"tyAnything", 
"tyStatic", 
"tyFromExpr", 
"tyOptDeprecated", 
"tyVoid"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_11_43[43];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_13;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_12[43] = {
"tfVarargs", 
"tfNoSideEffect", 
"tfFinal", 
"tfInheritable", 
"tfHasOwned", 
"tfEnumHasHoles", 
"tfShallow", 
"tfThread", 
"tfFromGeneric", 
"tfUnresolved", 
"tfResolved", 
"tfRetType", 
"tfCapturesEnv", 
"tfByCopy", 
"tfByRef", 
"tfIterator", 
"tfPartial", 
"tfNotNil", 
"tfRequiresInit", 
"tfNeedsFullInit", 
"tfVarIsPtr", 
"tfHasMeta", 
"tfHasGCedMem", 
"tfPacked", 
"tfHasStatic", 
"tfGenericTypeParam", 
"tfImplicitTypeParam", 
"tfInferrableStatic", 
"tfConceptMatchedTypeSym", 
"tfExplicit", 
"tfWildcard", 
"tfHasAsgn", 
"tfBorrowDot", 
"tfTriggersCompileTime", 
"tfRefsAnonObj", 
"tfCovariant", 
"tfWeakCovariant", 
"tfContravariant", 
"tfCheckedForDestructor", 
"tfAcyclic", 
"tfIncompleteStruct", 
"tfCompleteStruct", 
"tfExplicitCallConv"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_14_161[161];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_16;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_15[161] = {
"nkNone", 
"nkEmpty", 
"nkIdent", 
"nkSym", 
"nkType", 
"nkCharLit", 
"nkIntLit", 
"nkInt8Lit", 
"nkInt16Lit", 
"nkInt32Lit", 
"nkInt64Lit", 
"nkUIntLit", 
"nkUInt8Lit", 
"nkUInt16Lit", 
"nkUInt32Lit", 
"nkUInt64Lit", 
"nkFloatLit", 
"nkFloat32Lit", 
"nkFloat64Lit", 
"nkFloat128Lit", 
"nkStrLit", 
"nkRStrLit", 
"nkTripleStrLit", 
"nkNilLit", 
"nkComesFrom", 
"nkDotCall", 
"nkCommand", 
"nkCall", 
"nkCallStrLit", 
"nkInfix", 
"nkPrefix", 
"nkPostfix", 
"nkHiddenCallConv", 
"nkExprEqExpr", 
"nkExprColonExpr", 
"nkIdentDefs", 
"nkVarTuple", 
"nkPar", 
"nkObjConstr", 
"nkCurly", 
"nkCurlyExpr", 
"nkBracket", 
"nkBracketExpr", 
"nkPragmaExpr", 
"nkRange", 
"nkDotExpr", 
"nkCheckedFieldExpr", 
"nkDerefExpr", 
"nkIfExpr", 
"nkElifExpr", 
"nkElseExpr", 
"nkLambda", 
"nkDo", 
"nkAccQuoted", 
"nkTableConstr", 
"nkBind", 
"nkClosedSymChoice", 
"nkOpenSymChoice", 
"nkHiddenStdConv", 
"nkHiddenSubConv", 
"nkConv", 
"nkCast", 
"nkStaticExpr", 
"nkAddr", 
"nkHiddenAddr", 
"nkHiddenDeref", 
"nkObjDownConv", 
"nkObjUpConv", 
"nkChckRangeF", 
"nkChckRange64", 
"nkChckRange", 
"nkStringToCString", 
"nkCStringToString", 
"nkAsgn", 
"nkFastAsgn", 
"nkGenericParams", 
"nkFormalParams", 
"nkOfInherit", 
"nkImportAs", 
"nkProcDef", 
"nkMethodDef", 
"nkConverterDef", 
"nkMacroDef", 
"nkTemplateDef", 
"nkIteratorDef", 
"nkOfBranch", 
"nkElifBranch", 
"nkExceptBranch", 
"nkElse", 
"nkAsmStmt", 
"nkPragma", 
"nkPragmaBlock", 
"nkIfStmt", 
"nkWhenStmt", 
"nkForStmt", 
"nkParForStmt", 
"nkWhileStmt", 
"nkCaseStmt", 
"nkTypeSection", 
"nkVarSection", 
"nkLetSection", 
"nkConstSection", 
"nkConstDef", 
"nkTypeDef", 
"nkYieldStmt", 
"nkDefer", 
"nkTryStmt", 
"nkFinally", 
"nkRaiseStmt", 
"nkReturnStmt", 
"nkBreakStmt", 
"nkContinueStmt", 
"nkBlockStmt", 
"nkStaticStmt", 
"nkDiscardStmt", 
"nkStmtList", 
"nkImportStmt", 
"nkImportExceptStmt", 
"nkExportStmt", 
"nkExportExceptStmt", 
"nkFromStmt", 
"nkIncludeStmt", 
"nkBindStmt", 
"nkMixinStmt", 
"nkUsingStmt", 
"nkCommentStmt", 
"nkStmtListExpr", 
"nkBlockExpr", 
"nkStmtListType", 
"nkBlockType", 
"nkWith", 
"nkWithout", 
"nkTypeOfExpr", 
"nkObjectTy", 
"nkTupleTy", 
"nkTupleClassTy", 
"nkTypeClassTy", 
"nkStaticTy", 
"nkRecList", 
"nkRecCase", 
"nkRecWhen", 
"nkRefTy", 
"nkPtrTy", 
"nkVarTy", 
"nkConstTy", 
"nkMutableTy", 
"nkDistinctTy", 
"nkProcTy", 
"nkIteratorTy", 
"nkSharedTy", 
"nkEnumTy", 
"nkEnumFieldDef", 
"nkArgList", 
"nkPattern", 
"nkHiddenTryStmt", 
"nkClosure", 
"nkGotoState", 
"nkState", 
"nkBreakState", 
"nkFuncDef", 
"nkTupleConstr"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_17_21[21];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_19;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_18[21] = {
"nfNone", 
"nfBase2", 
"nfBase8", 
"nfBase16", 
"nfAllConst", 
"nfTransf", 
"nfNoRewrite", 
"nfSem", 
"nfLL", 
"nfDotField", 
"nfDotSetter", 
"nfExplicitCall", 
"nfExprCall", 
"nfIsRef", 
"nfIsPtr", 
"nfPreventCg", 
"nfBlockArg", 
"nfFromTemplate", 
"nfDefaultParam", 
"nfDefaultRefsParam", 
"nfExecuteOnReload"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[14];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[16];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_22_11[11];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_24;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_23[11] = {
"nimcall", 
"stdcall", 
"cdecl", 
"safecall", 
"syscall", 
"inline", 
"noinline", 
"fastcall", 
"thiscall", 
"closure", 
"noconv"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[5];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_26_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[5];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_28_11[11];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_30;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_29[11] = {
"locNone", 
"locTemp", 
"locLocalVar", 
"locGlobalVar", 
"locParam", 
"locField", 
"locExpr", 
"locProc", 
"locData", 
"locCall", 
"locOther"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_31_4[4];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_33;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_32[4] = {
"OnUnknown", 
"OnStatic", 
"OnStack", 
"OnHeap"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_34_11[11];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_36;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_35[11] = {
"lfIndirect", 
"lfFullExternalName", 
"lfNoDeepCopy", 
"lfNoDecl", 
"lfDynamicLib", 
"lfExportLib", 
"lfHeader", 
"lfImportCompilerProc", 
"lfSingleUse", 
"lfEnforceDeref", 
"lfPrepareForMutation"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_37_3[3];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_38_3[3];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_39_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_40_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_41_3[3];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_42_271[271];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_44;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_43[271] = {
"mNone", 
"mDefined", 
"mDeclared", 
"mDeclaredInScope", 
"mCompiles", 
"mArrGet", 
"mArrPut", 
"mAsgn", 
"mLow", 
"mHigh", 
"mSizeOf", 
"mAlignOf", 
"mOffsetOf", 
"mTypeTrait", 
"mIs", 
"mOf", 
"mAddr", 
"mType", 
"mTypeOf", 
"mPlugin", 
"mEcho", 
"mShallowCopy", 
"mSlurp", 
"mStaticExec", 
"mStatic", 
"mParseExprToAst", 
"mParseStmtToAst", 
"mExpandToAst", 
"mQuoteAst", 
"mInc", 
"mDec", 
"mOrd", 
"mNew", 
"mNewFinalize", 
"mNewSeq", 
"mNewSeqOfCap", 
"mLengthOpenArray", 
"mLengthStr", 
"mLengthArray", 
"mLengthSeq", 
"mIncl", 
"mExcl", 
"mCard", 
"mChr", 
"mGCref", 
"mGCunref", 
"mAddI", 
"mSubI", 
"mMulI", 
"mDivI", 
"mModI", 
"mSucc", 
"mPred", 
"mAddF64", 
"mSubF64", 
"mMulF64", 
"mDivF64", 
"mShrI", 
"mShlI", 
"mAshrI", 
"mBitandI", 
"mBitorI", 
"mBitxorI", 
"mMinI", 
"mMaxI", 
"mAddU", 
"mSubU", 
"mMulU", 
"mDivU", 
"mModU", 
"mEqI", 
"mLeI", 
"mLtI", 
"mEqF64", 
"mLeF64", 
"mLtF64", 
"mLeU", 
"mLtU", 
"mEqEnum", 
"mLeEnum", 
"mLtEnum", 
"mEqCh", 
"mLeCh", 
"mLtCh", 
"mEqB", 
"mLeB", 
"mLtB", 
"mEqRef", 
"mLePtr", 
"mLtPtr", 
"mXor", 
"mEqCString", 
"mEqProc", 
"mUnaryMinusI", 
"mUnaryMinusI64", 
"mAbsI", 
"mNot", 
"mUnaryPlusI", 
"mBitnotI", 
"mUnaryPlusF64", 
"mUnaryMinusF64", 
"mCharToStr", 
"mBoolToStr", 
"mIntToStr", 
"mInt64ToStr", 
"mFloatToStr", 
"mCStrToStr", 
"mStrToStr", 
"mEnumToStr", 
"mAnd", 
"mOr", 
"mImplies", 
"mIff", 
"mExists", 
"mForall", 
"mOld", 
"mEqStr", 
"mLeStr", 
"mLtStr", 
"mEqSet", 
"mLeSet", 
"mLtSet", 
"mMulSet", 
"mPlusSet", 
"mMinusSet", 
"mConStrStr", 
"mSlice", 
"mDotDot", 
"mFields", 
"mFieldPairs", 
"mOmpParFor", 
"mAppendStrCh", 
"mAppendStrStr", 
"mAppendSeqElem", 
"mInSet", 
"mRepr", 
"mExit", 
"mSetLengthStr", 
"mSetLengthSeq", 
"mIsPartOf", 
"mAstToStr", 
"mParallel", 
"mSwap", 
"mIsNil", 
"mArrToSeq", 
"mNewString", 
"mNewStringOfCap", 
"mParseBiggestFloat", 
"mMove", 
"mWasMoved", 
"mDestroy", 
"mDefault", 
"mUnown", 
"mIsolate", 
"mAccessEnv", 
"mReset", 
"mArray", 
"mOpenArray", 
"mRange", 
"mSet", 
"mSeq", 
"mVarargs", 
"mRef", 
"mPtr", 
"mVar", 
"mDistinct", 
"mVoid", 
"mTuple", 
"mOrdinal", 
"mInt", 
"mInt8", 
"mInt16", 
"mInt32", 
"mInt64", 
"mUInt", 
"mUInt8", 
"mUInt16", 
"mUInt32", 
"mUInt64", 
"mFloat", 
"mFloat32", 
"mFloat64", 
"mFloat128", 
"mBool", 
"mChar", 
"mString", 
"mCstring", 
"mPointer", 
"mNil", 
"mExpr", 
"mStmt", 
"mTypeDesc", 
"mVoidType", 
"mPNimrodNode", 
"mSpawn", 
"mDeepCopy", 
"mIsMainModule", 
"mCompileDate", 
"mCompileTime", 
"mProcCall", 
"mCpuEndian", 
"mHostOS", 
"mHostCPU", 
"mBuildOS", 
"mBuildCPU", 
"mAppType", 
"mCompileOption", 
"mCompileOptionArg", 
"mNLen", 
"mNChild", 
"mNSetChild", 
"mNAdd", 
"mNAddMultiple", 
"mNDel", 
"mNKind", 
"mNSymKind", 
"mNccValue", 
"mNccInc", 
"mNcsAdd", 
"mNcsIncl", 
"mNcsLen", 
"mNcsAt", 
"mNctPut", 
"mNctLen", 
"mNctGet", 
"mNctHasNext", 
"mNctNext", 
"mNIntVal", 
"mNFloatVal", 
"mNSymbol", 
"mNIdent", 
"mNGetType", 
"mNStrVal", 
"mNSetIntVal", 
"mNSetFloatVal", 
"mNSetSymbol", 
"mNSetIdent", 
"mNSetType", 
"mNSetStrVal", 
"mNLineInfo", 
"mNNewNimNode", 
"mNCopyNimNode", 
"mNCopyNimTree", 
"mStrToIdent", 
"mNSigHash", 
"mNSizeOf", 
"mNBindSym", 
"mNCallSite", 
"mEqIdent", 
"mEqNimrodNode", 
"mSameNodeType", 
"mGetImpl", 
"mNGenSym", 
"mNHint", 
"mNWarning", 
"mNError", 
"mInstantiationInfo", 
"mGetTypeInfo", 
"mGetTypeInfoV2", 
"mNimvm", 
"mIntDefine", 
"mStrDefine", 
"mBoolDefine", 
"mRunnableExamples", 
"mException", 
"mBuiltinType", 
"mSymOwner", 
"mUncheckedArray", 
"mGetImplTransf", 
"mSymIsInstantiationOf", 
"mNodeId"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[5];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_46_2[2];
NI TM__EnH1I9cGkGYbf9a1NwhuXDPg_48;
static char* NIM_CONST TM__EnH1I9cGkGYbf9a1NwhuXDPg_47[2] = {
"libHeader", 
"libDynamic"};
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_49_3[3];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_50_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_51_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_56_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_57_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_67_2[2];
static TNimNode* TM__EnH1I9cGkGYbf9a1NwhuXDPg_68_3[3];
static TNimNode TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[789];

/* section: NIM_merge_TYPE_INIT3 */
NTI__cNCW9acsSznmEccl1fgQwkw_.size = sizeof(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw);
NTI__cNCW9acsSznmEccl1fgQwkw_.align = NIM_ALIGNOF(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw);
NTI__cNCW9acsSznmEccl1fgQwkw_.kind = 14;
NTI__cNCW9acsSznmEccl1fgQwkw_.base = 0;
NTI__cNCW9acsSznmEccl1fgQwkw_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_4 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_4 < 26; TM__EnH1I9cGkGYbf9a1NwhuXDPg_4++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4+0].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4+0].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_4;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4+0].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_3[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_2_26[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_4+0];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[26].len = 26; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[26].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[26].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_2_26[0];
NTI__cNCW9acsSznmEccl1fgQwkw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[26];
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.size = sizeof(tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw);
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.align = NIM_ALIGNOF(tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw);
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.kind = 14;
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.base = 0;
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_7 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_7 < 46; TM__EnH1I9cGkGYbf9a1NwhuXDPg_7++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7+27].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7+27].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_7;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7+27].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_6[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_5_46[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_7+27];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[73].len = 46; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[73].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[73].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_5_46[0];
NTI__K9ay6LWMat9bUiT9bIbMxpDHw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[73];
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.size = sizeof(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag);
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.align = NIM_ALIGNOF(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag);
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.kind = 14;
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.base = 0;
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_10 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_10 < 64; TM__EnH1I9cGkGYbf9a1NwhuXDPg_10++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10+74].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10+74].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_10;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10+74].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_9[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_8_64[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_10+74];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[138].len = 64; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[138].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[138].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_8_64[0];
NTI__9a3YiReNVD0IJHWFKgXRe9ag_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[138];
NTI__x2m5g1NpbmDig4wLT3Ylhw_.size = sizeof(tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw);
NTI__x2m5g1NpbmDig4wLT3Ylhw_.align = NIM_ALIGNOF(tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw);
NTI__x2m5g1NpbmDig4wLT3Ylhw_.kind = 14;
NTI__x2m5g1NpbmDig4wLT3Ylhw_.base = 0;
NTI__x2m5g1NpbmDig4wLT3Ylhw_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_13 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_13 < 43; TM__EnH1I9cGkGYbf9a1NwhuXDPg_13++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13+139].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13+139].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_13;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13+139].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_12[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_11_43[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_13+139];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[182].len = 43; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[182].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[182].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_11_43[0];
NTI__x2m5g1NpbmDig4wLT3Ylhw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[182];
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.size = sizeof(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw);
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.align = NIM_ALIGNOF(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw);
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.kind = 14;
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.base = 0;
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_16 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_16 < 161; TM__EnH1I9cGkGYbf9a1NwhuXDPg_16++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16+183].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16+183].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_16;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16+183].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_15[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_14_161[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_16+183];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[344].len = 161; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[344].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[344].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_14_161[0];
NTI__G4E4Gxe7oI2Cm03rkiOzQw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[344];
NTI__jyh9acXHkhZANSSvPIY7ZLg_.size = sizeof(tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg);
NTI__jyh9acXHkhZANSSvPIY7ZLg_.align = NIM_ALIGNOF(tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg);
NTI__jyh9acXHkhZANSSvPIY7ZLg_.kind = 14;
NTI__jyh9acXHkhZANSSvPIY7ZLg_.base = 0;
NTI__jyh9acXHkhZANSSvPIY7ZLg_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_19 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_19 < 21; TM__EnH1I9cGkGYbf9a1NwhuXDPg_19++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19+345].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19+345].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_19;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19+345].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_18[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_17_21[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_19+345];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[366].len = 21; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[366].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[366].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_17_21[0];
NTI__jyh9acXHkhZANSSvPIY7ZLg_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[366];
NTI__JpsEh5i1AcKChGYbg7aV4w_.size = sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w);
NTI__JpsEh5i1AcKChGYbg7aV4w_.align = NIM_ALIGNOF(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w);
NTI__JpsEh5i1AcKChGYbg7aV4w_.kind = 17;
NTI__JpsEh5i1AcKChGYbg7aV4w_.base = (&NTI__iIXPrEsiKHiioLj0HSkQhA_);
NTI__JpsEh5i1AcKChGYbg7aV4w_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].kind = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, kind);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].typ = (&NTI__cNCW9acsSznmEccl1fgQwkw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].name = "kind";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].sons = &NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[0];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[368].len = 26;
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.size = sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ);
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.align = NIM_ALIGNOF(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ);
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.kind = 17;
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.base = (&NTI__iIXPrEsiKHiioLj0HSkQhA_);
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[371];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[371].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[371].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, kind);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[371].typ = (&NTI__9a3YiReNVD0IJHWFKgXRe9ag_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[371].name = "kind";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[372];
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.size = sizeof(tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA);
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.align = NIM_ALIGNOF(tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA);
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.kind = 14;
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.base = 0;
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_24 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_24 < 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_24++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24+373].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24+373].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_24;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24+373].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_23[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_22_11[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_24+373];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[384].len = 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[384].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[384].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_22_11[0];
NTI__yjAJ8w0h1PBaSwSGJ3P7IA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[384];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[372].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[372].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, callConv);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[372].typ = (&NTI__yjAJ8w0h1PBaSwSGJ3P7IA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[372].name = "callConv";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[385];
NTI__TUnU4oefCIvAMjkVjD9cuBA_.size = sizeof(tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw);
NTI__TUnU4oefCIvAMjkVjD9cuBA_.align = NIM_ALIGNOF(tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw);
NTI__TUnU4oefCIvAMjkVjD9cuBA_.kind = 19;
NTI__TUnU4oefCIvAMjkVjD9cuBA_.base = (&NTI__x2m5g1NpbmDig4wLT3Ylhw_);
NTI__TUnU4oefCIvAMjkVjD9cuBA_.flags = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[386].len = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[386].kind = 0;
NTI__TUnU4oefCIvAMjkVjD9cuBA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[386];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[385].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[385].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, flags);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[385].typ = (&NTI__TUnU4oefCIvAMjkVjD9cuBA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[385].name = "flags";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[387];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[387].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[387].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, sons);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[387].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[387].name = "sons";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[388];
NTI__bROa11lyF5vxEN9aYNbHmhw_.size = sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw);
NTI__bROa11lyF5vxEN9aYNbHmhw_.align = NIM_ALIGNOF(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw);
NTI__bROa11lyF5vxEN9aYNbHmhw_.kind = 18;
NTI__bROa11lyF5vxEN9aYNbHmhw_.base = 0;
NTI__bROa11lyF5vxEN9aYNbHmhw_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[390];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[390].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[390].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, typ);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[390].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[390].name = "typ";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[391];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[391].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[391].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, info);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[391].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[391].name = "info";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[392];
NTI__Lj66phhshW0KaYhwBUJJ3Q_.size = sizeof(tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg);
NTI__Lj66phhshW0KaYhwBUJJ3Q_.align = NIM_ALIGNOF(tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg);
NTI__Lj66phhshW0KaYhwBUJJ3Q_.kind = 19;
NTI__Lj66phhshW0KaYhwBUJJ3Q_.base = (&NTI__jyh9acXHkhZANSSvPIY7ZLg_);
NTI__Lj66phhshW0KaYhwBUJJ3Q_.flags = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[393].len = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[393].kind = 0;
NTI__Lj66phhshW0KaYhwBUJJ3Q_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[393];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[392].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[392].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, flags);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[392].typ = (&NTI__Lj66phhshW0KaYhwBUJJ3Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[392].name = "flags";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].kind = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, kind);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].typ = (&NTI__G4E4Gxe7oI2Cm03rkiOzQw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].name = "kind";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].sons = &NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[0];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[394].len = 161;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_1.intVal);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395].typ = (&NTI__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395].name = "intVal";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[5] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[6] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[7] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[8] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[9] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[10] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[11] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[12] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[13] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[14] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[15] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[395];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_2.floatVal);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396].typ = (&NTI__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396].name = "floatVal";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[16] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[17] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[18] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[19] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[396];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_3.strVal);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397].name = "strVal";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[20] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[21] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397];
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[22] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[397];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[398].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[398].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_4.sym);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[398].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[398].name = "sym";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[398];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[399].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[399].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_5.ident);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[399].typ = (&NTI__B0xRsLi0eK4raPu9bd2tkcA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[399].name = "ident";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[399];
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.size = sizeof(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*);
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.align = NIM_ALIGNOF(tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*);
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.kind = 24;
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.base = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.flags = 2;
NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_.marker = Marker_tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[400].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[400].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, _kind_6.sons);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[400].typ = (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[400].name = "sons";
NimDT___bROa11lyF5vxEN9aYNbHmhw_kind[161] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[400];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[401];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[401].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[401].offset = offsetof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw, comment);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[401].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[401].name = "comment";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[389].len = 5; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[389].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[389].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_25_5[0];
NTI__bROa11lyF5vxEN9aYNbHmhw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[389];
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.size = sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*);
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.align = NIM_ALIGNOF(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*);
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.kind = 22;
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.base = (&NTI__bROa11lyF5vxEN9aYNbHmhw_);
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.flags = 2;
NTI__fKfcLzXYiz5jNu3NH3Tv8Q_.marker = Marker_tyRef__fKfcLzXYiz5jNu3NH3Tv8Q;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[388].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[388].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, n);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[388].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[388].name = "n";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[5] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[402];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[402].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[402].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, owner);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[402].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[402].name = "owner";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[6] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[403];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[403].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[403].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, sym);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[403].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[403].name = "sym";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[7] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[404];
NTI__PsPyPA45AAjHu4uDGHNjTg_.size = sizeof(tyArray__PsPyPA45AAjHu4uDGHNjTg);
NTI__PsPyPA45AAjHu4uDGHNjTg_.align = NIM_ALIGNOF(tyArray__PsPyPA45AAjHu4uDGHNjTg);
NTI__PsPyPA45AAjHu4uDGHNjTg_.kind = 16;
NTI__PsPyPA45AAjHu4uDGHNjTg_.base = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
NTI__PsPyPA45AAjHu4uDGHNjTg_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[404].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[404].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, attachedOps);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[404].typ = (&NTI__PsPyPA45AAjHu4uDGHNjTg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[404].name = "attachedOps";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[8] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[405];
NTI__zwpS6d6iewrdlBSTNFoyVA_.size = sizeof(tyTuple__zwpS6d6iewrdlBSTNFoyVA);
NTI__zwpS6d6iewrdlBSTNFoyVA_.align = NIM_ALIGNOF(tyTuple__zwpS6d6iewrdlBSTNFoyVA);
NTI__zwpS6d6iewrdlBSTNFoyVA_.kind = 18;
NTI__zwpS6d6iewrdlBSTNFoyVA_.base = 0;
NTI__zwpS6d6iewrdlBSTNFoyVA_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_26_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[407];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[407].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[407].offset = offsetof(tyTuple__zwpS6d6iewrdlBSTNFoyVA, Field0);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[407].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[407].name = "Field0";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_26_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[408];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[408].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[408].offset = offsetof(tyTuple__zwpS6d6iewrdlBSTNFoyVA, Field1);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[408].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[408].name = "Field1";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[406].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[406].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[406].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_26_2[0];
NTI__zwpS6d6iewrdlBSTNFoyVA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[406];
NTI__MvZmat48bhe9b6x9aUD58D5Q_.size = sizeof(tySequence__MvZmat48bhe9b6x9aUD58D5Q*);
NTI__MvZmat48bhe9b6x9aUD58D5Q_.align = NIM_ALIGNOF(tySequence__MvZmat48bhe9b6x9aUD58D5Q*);
NTI__MvZmat48bhe9b6x9aUD58D5Q_.kind = 24;
NTI__MvZmat48bhe9b6x9aUD58D5Q_.base = (&NTI__zwpS6d6iewrdlBSTNFoyVA_);
NTI__MvZmat48bhe9b6x9aUD58D5Q_.flags = 2;
NTI__MvZmat48bhe9b6x9aUD58D5Q_.marker = Marker_tySequence__MvZmat48bhe9b6x9aUD58D5Q;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[405].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[405].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, methods);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[405].typ = (&NTI__MvZmat48bhe9b6x9aUD58D5Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[405].name = "methods";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[9] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[409];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[409].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[409].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, size);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[409].typ = (&NTI__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[409].name = "size";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[10] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[410];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[410].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[410].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, align);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[410].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[410].name = "align";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[11] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[411];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[411].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[411].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, paddingAtEnd);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[411].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[411].name = "paddingAtEnd";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[12] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[412];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[412].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[412].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, lockLevel);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[412].typ = (&NTI__kDPg4wXyR8DDyA0MeEjIsw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[412].name = "lockLevel";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[13] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[413];
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.size = sizeof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA);
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.align = NIM_ALIGNOF(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA);
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.kind = 18;
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.base = 0;
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[415];
NTI__O7PRFZKuiBBWbku09cayVBg_.size = sizeof(tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg);
NTI__O7PRFZKuiBBWbku09cayVBg_.align = NIM_ALIGNOF(tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg);
NTI__O7PRFZKuiBBWbku09cayVBg_.kind = 14;
NTI__O7PRFZKuiBBWbku09cayVBg_.base = 0;
NTI__O7PRFZKuiBBWbku09cayVBg_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_30 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_30 < 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_30++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30+416].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30+416].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_30;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30+416].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_29[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_28_11[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_30+416];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[427].len = 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[427].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[427].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_28_11[0];
NTI__O7PRFZKuiBBWbku09cayVBg_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[427];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[415].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[415].offset = offsetof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA, k);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[415].typ = (&NTI__O7PRFZKuiBBWbku09cayVBg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[415].name = "k";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[428];
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.size = sizeof(tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw);
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.align = NIM_ALIGNOF(tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw);
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.kind = 14;
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.base = 0;
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_33 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_33 < 4; TM__EnH1I9cGkGYbf9a1NwhuXDPg_33++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33+429].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33+429].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_33;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33+429].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_32[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_31_4[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_33+429];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[433].len = 4; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[433].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[433].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_31_4[0];
NTI__JK9cKMX3XnqHaUky9b6gkGEw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[433];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[428].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[428].offset = offsetof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA, storage);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[428].typ = (&NTI__JK9cKMX3XnqHaUky9b6gkGEw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[428].name = "storage";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[434];
NTI__o2bqJgR4ceIupnUSpxiudA_.size = sizeof(tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA);
NTI__o2bqJgR4ceIupnUSpxiudA_.align = NIM_ALIGNOF(tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA);
NTI__o2bqJgR4ceIupnUSpxiudA_.kind = 14;
NTI__o2bqJgR4ceIupnUSpxiudA_.base = 0;
NTI__o2bqJgR4ceIupnUSpxiudA_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_36 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_36 < 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_36++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36+435].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36+435].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_36;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36+435].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_35[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_34_11[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_36+435];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[446].len = 11; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[446].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[446].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_34_11[0];
NTI__o2bqJgR4ceIupnUSpxiudA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[446];
NTI__yChkHmjOkttAUPxHrKvWAA_.size = sizeof(tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA);
NTI__yChkHmjOkttAUPxHrKvWAA_.align = NIM_ALIGNOF(tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA);
NTI__yChkHmjOkttAUPxHrKvWAA_.kind = 19;
NTI__yChkHmjOkttAUPxHrKvWAA_.base = (&NTI__o2bqJgR4ceIupnUSpxiudA_);
NTI__yChkHmjOkttAUPxHrKvWAA_.flags = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[447].len = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[447].kind = 0;
NTI__yChkHmjOkttAUPxHrKvWAA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[447];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[434].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[434].offset = offsetof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA, flags);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[434].typ = (&NTI__yChkHmjOkttAUPxHrKvWAA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[434].name = "flags";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[448];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[448].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[448].offset = offsetof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA, lode);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[448].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[448].name = "lode";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[449];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[449].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[449].offset = offsetof(tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA, r);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[449].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[449].name = "r";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[414].len = 5; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[414].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[414].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_27_5[0];
NTI__EtHNvCB0bgfu9bFjzx9cb6aA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[414];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[413].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[413].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, loc);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[413].typ = (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[413].name = "loc";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[14] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[450];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[450].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[450].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, typeInst);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[450].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[450].name = "typeInst";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[15] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[451];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[451].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[451].offset = offsetof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ, uniqueId);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[451].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[451].name = "uniqueId";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[370].len = 16; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[370].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[370].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_21_16[0];
NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[370];
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.size = sizeof(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*);
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.align = NIM_ALIGNOF(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*);
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.kind = 22;
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.base = (&NTI__v9ae2Dpu13OW2ZJ2U9bNMd9cQ_);
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.flags = 2;
NTI__AgIT5feFR9a9aoVjv9cx2rOtg_.marker = Marker_tyRef__AgIT5feFR9a9aoVjv9cx2rOtg;
NTI__Ef05srmQTDulnBdXR4Ja6Q_.size = sizeof(tySequence__Ef05srmQTDulnBdXR4Ja6Q*);
NTI__Ef05srmQTDulnBdXR4Ja6Q_.align = NIM_ALIGNOF(tySequence__Ef05srmQTDulnBdXR4Ja6Q*);
NTI__Ef05srmQTDulnBdXR4Ja6Q_.kind = 24;
NTI__Ef05srmQTDulnBdXR4Ja6Q_.base = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
NTI__Ef05srmQTDulnBdXR4Ja6Q_.flags = 2;
NTI__Ef05srmQTDulnBdXR4Ja6Q_.marker = Marker_tySequence__Ef05srmQTDulnBdXR4Ja6Q;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_1.typeInstCache);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369].name = "typeInstCache";
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[7] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[369];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_37_3[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[453];
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.size = sizeof(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA);
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.align = NIM_ALIGNOF(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA);
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.kind = 18;
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.base = 0;
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_38_3[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[455];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[455].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[455].offset = offsetof(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA, sym);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[455].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[455].name = "sym";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_38_3[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[456];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[456].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[456].offset = offsetof(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA, concreteTypes);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[456].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[456].name = "concreteTypes";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_38_3[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[457];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[457].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[457].offset = offsetof(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA, compilesId);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[457].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[457].name = "compilesId";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[454].len = 3; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[454].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[454].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_38_3[0];
NTI__5LqgVn6Tq9ainQRK7TQAQxA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[454];
NTI__Y32tFilzS9adEEksgrCsOzQ_.size = sizeof(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA*);
NTI__Y32tFilzS9adEEksgrCsOzQ_.align = NIM_ALIGNOF(tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA*);
NTI__Y32tFilzS9adEEksgrCsOzQ_.kind = 22;
NTI__Y32tFilzS9adEEksgrCsOzQ_.base = (&NTI__5LqgVn6Tq9ainQRK7TQAQxA_);
NTI__Y32tFilzS9adEEksgrCsOzQ_.flags = 2;
NTI__Y32tFilzS9adEEksgrCsOzQ_.marker = Marker_tyRef__Y32tFilzS9adEEksgrCsOzQ;
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.size = sizeof(tySequence__DXS6mEo7PVUFJkirsQ9bNQA*);
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.align = NIM_ALIGNOF(tySequence__DXS6mEo7PVUFJkirsQ9bNQA*);
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.kind = 24;
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.base = (&NTI__Y32tFilzS9adEEksgrCsOzQ_);
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.flags = 2;
NTI__DXS6mEo7PVUFJkirsQ9bNQA_.marker = Marker_tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[453].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[453].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_2.procInstCache);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[453].typ = (&NTI__DXS6mEo7PVUFJkirsQ9bNQA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[453].name = "procInstCache";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_37_3[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[458];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[458].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[458].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_2.gcUnsafetyReason);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[458].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[458].name = "gcUnsafetyReason";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_37_3[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[459];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[459].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[459].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_2.transformedBody);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[459].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[459].name = "transformedBody";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452].len = 3; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_37_3[0];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[12] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[13] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[14] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[15] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[16] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[17] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[18] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[452];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_39_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[461];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[461].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[461].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_3.usedGenerics);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[461].typ = (&NTI__DXS6mEo7PVUFJkirsQ9bNQA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[461].name = "usedGenerics";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_39_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[462];
NTI__f07aOS3dr28kGa5wcE29aFA_.size = sizeof(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA);
NTI__f07aOS3dr28kGa5wcE29aFA_.align = NIM_ALIGNOF(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA);
NTI__f07aOS3dr28kGa5wcE29aFA_.kind = 18;
NTI__f07aOS3dr28kGa5wcE29aFA_.base = 0;
NTI__f07aOS3dr28kGa5wcE29aFA_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_40_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[464];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[464].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[464].offset = offsetof(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA, counter);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[464].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[464].name = "counter";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_40_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[465];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[465].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[465].offset = offsetof(tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA, data);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[465].typ = (&NTI__DfgJFJEYoj4YBAHLZPl5lQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[465].name = "data";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[463].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[463].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[463].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_40_2[0];
NTI__f07aOS3dr28kGa5wcE29aFA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[463];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[462].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[462].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_3.tab);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[462].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[462].name = "tab";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[460].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[460].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[460].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_39_2[0];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[6] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[460];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[24] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[460];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_41_3[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[467];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[467].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[467].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_4.guard);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[467].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[467].name = "guard";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_41_3[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[468];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[468].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[468].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_4.bitsize);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[468].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[468].name = "bitsize";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_41_3[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[469];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[469].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[469].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, _kind_4.alignment);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[469].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[469].name = "alignment";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466].len = 3; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_41_3[0];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[9] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[8] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[19] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466];
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[21] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[466];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[470].len = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[470].kind = 2;
NimDT___JpsEh5i1AcKChGYbg7aV4w_kind[26] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[470];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[471];
NTI__shZhZOdbVC5nnFvcXQAImg_.size = sizeof(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg);
NTI__shZhZOdbVC5nnFvcXQAImg_.align = NIM_ALIGNOF(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg);
NTI__shZhZOdbVC5nnFvcXQAImg_.kind = 14;
NTI__shZhZOdbVC5nnFvcXQAImg_.base = 0;
NTI__shZhZOdbVC5nnFvcXQAImg_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_44 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_44 < 271; TM__EnH1I9cGkGYbf9a1NwhuXDPg_44++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44+472].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44+472].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_44;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44+472].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_43[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_42_271[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_44+472];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[743].len = 271; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[743].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[743].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_42_271[0];
NTI__shZhZOdbVC5nnFvcXQAImg_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[743];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[471].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[471].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, magic);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[471].typ = (&NTI__shZhZOdbVC5nnFvcXQAImg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[471].name = "magic";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[744];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[744].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[744].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, typ);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[744].typ = (&NTI__AgIT5feFR9a9aoVjv9cx2rOtg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[744].name = "typ";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[745];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[745].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[745].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, name);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[745].typ = (&NTI__B0xRsLi0eK4raPu9bd2tkcA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[745].name = "name";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[746];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[746].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[746].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, info);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[746].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[746].name = "info";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[5] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[747];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[747].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[747].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, owner);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[747].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[747].name = "owner";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[6] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[748];
NTI__h9a2sdtQFa6zibBX41u5eAQ_.size = sizeof(tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw);
NTI__h9a2sdtQFa6zibBX41u5eAQ_.align = NIM_ALIGNOF(tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw);
NTI__h9a2sdtQFa6zibBX41u5eAQ_.kind = 19;
NTI__h9a2sdtQFa6zibBX41u5eAQ_.base = (&NTI__K9ay6LWMat9bUiT9bIbMxpDHw_);
NTI__h9a2sdtQFa6zibBX41u5eAQ_.flags = 3;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[749].len = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[749].kind = 0;
NTI__h9a2sdtQFa6zibBX41u5eAQ_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[749];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[748].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[748].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, flags);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[748].typ = (&NTI__h9a2sdtQFa6zibBX41u5eAQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[748].name = "flags";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[7] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[750];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[750].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[750].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, ast);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[750].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[750].name = "ast";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[8] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[751];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[751].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[751].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, options);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[751].typ = (&NTI__7MnKRybmCNh5j9bDRLMkxLw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[751].name = "options";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[9] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[752];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[752].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[752].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, position);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[752].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[752].name = "position";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[10] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[753];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[753].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[753].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, offset);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[753].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[753].name = "offset";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[11] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[754];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[754].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[754].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, loc);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[754].typ = (&NTI__EtHNvCB0bgfu9bFjzx9cb6aA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[754].name = "loc";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[12] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[755];
NTI__NBMxlJ6g3utqUlplqTTHkA_.size = sizeof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA);
NTI__NBMxlJ6g3utqUlplqTTHkA_.align = NIM_ALIGNOF(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA);
NTI__NBMxlJ6g3utqUlplqTTHkA_.kind = 18;
NTI__NBMxlJ6g3utqUlplqTTHkA_.base = 0;
NTI__NBMxlJ6g3utqUlplqTTHkA_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[757];
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.size = sizeof(tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ);
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.align = NIM_ALIGNOF(tyEnum_TLibKind__9b8v60kso59bBaw9cp8B9a9apKQ);
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.kind = 14;
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.base = 0;
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.flags = 3;
for (TM__EnH1I9cGkGYbf9a1NwhuXDPg_48 = 0; TM__EnH1I9cGkGYbf9a1NwhuXDPg_48 < 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_48++) {
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48+758].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48+758].offset = TM__EnH1I9cGkGYbf9a1NwhuXDPg_48;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48+758].name = TM__EnH1I9cGkGYbf9a1NwhuXDPg_47[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_46_2[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[TM__EnH1I9cGkGYbf9a1NwhuXDPg_48+758];
}
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[760].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[760].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[760].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_46_2[0];
NTI__9b8v60kso59bBaw9cp8B9a9apKQ_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[760];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[757].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[757].offset = offsetof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA, kind);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[757].typ = (&NTI__9b8v60kso59bBaw9cp8B9a9apKQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[757].name = "kind";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[761];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[761].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[761].offset = offsetof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA, generated);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[761].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[761].name = "generated";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[762];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[762].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[762].offset = offsetof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA, isOverriden);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[762].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[762].name = "isOverriden";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[3] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[763];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[763].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[763].offset = offsetof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA, name);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[763].typ = (&NTI__4hi0XQqK9aLiPuWT9acsXm9aQ_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[763].name = "name";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[4] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[764];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[764].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[764].offset = offsetof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA, path);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[764].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[764].name = "path";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[756].len = 5; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[756].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[756].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_45_5[0];
NTI__NBMxlJ6g3utqUlplqTTHkA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[756];
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.size = sizeof(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*);
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.align = NIM_ALIGNOF(tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA*);
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.kind = 22;
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.base = (&NTI__NBMxlJ6g3utqUlplqTTHkA_);
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.flags = 2;
NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_.marker = Marker_tyRef__EL9cZTJI9a9cmSIbGnseCuc9bg;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[755].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[755].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, annex);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[755].typ = (&NTI__EL9cZTJI9a9cmSIbGnseCuc9bg_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[755].name = "annex";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[13] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[765];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[765].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[765].offset = offsetof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w, constraint);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[765].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[765].name = "constraint";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[367].len = 14; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[367].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[367].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_20_14[0];
NTI__JpsEh5i1AcKChGYbg7aV4w_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[367];
NTI__K9bspPztfoWajecnwjyHuYQ_.size = sizeof(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*);
NTI__K9bspPztfoWajecnwjyHuYQ_.align = NIM_ALIGNOF(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*);
NTI__K9bspPztfoWajecnwjyHuYQ_.kind = 22;
NTI__K9bspPztfoWajecnwjyHuYQ_.base = (&NTI__JpsEh5i1AcKChGYbg7aV4w_);
NTI__K9bspPztfoWajecnwjyHuYQ_.flags = 2;
NTI__K9bspPztfoWajecnwjyHuYQ_.marker = Marker_tyRef__K9bspPztfoWajecnwjyHuYQ;
NTI__1cQRXW6aAknk7ywAwjH3nw_.size = sizeof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw);
NTI__1cQRXW6aAknk7ywAwjH3nw_.align = NIM_ALIGNOF(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw);
NTI__1cQRXW6aAknk7ywAwjH3nw_.kind = 18;
NTI__1cQRXW6aAknk7ywAwjH3nw_.base = 0;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_49_3[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[767];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[767].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[767].offset = offsetof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw, depthLevel);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[767].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[767].name = "depthLevel";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_49_3[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[768];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[768].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[768].offset = offsetof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw, symbols);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[768].typ = (&NTI__f07aOS3dr28kGa5wcE29aFA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[768].name = "symbols";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_49_3[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[769];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[769].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[769].offset = offsetof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw, parent);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[769].typ = (&NTI__N89ckikRqMir57209a3tEeqw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[769].name = "parent";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[766].len = 3; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[766].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[766].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_49_3[0];
NTI__1cQRXW6aAknk7ywAwjH3nw_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[766];
NTI__N89ckikRqMir57209a3tEeqw_.size = sizeof(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*);
NTI__N89ckikRqMir57209a3tEeqw_.align = NIM_ALIGNOF(tyObject_TScope__1cQRXW6aAknk7ywAwjH3nw*);
NTI__N89ckikRqMir57209a3tEeqw_.kind = 22;
NTI__N89ckikRqMir57209a3tEeqw_.base = (&NTI__1cQRXW6aAknk7ywAwjH3nw_);
NTI__N89ckikRqMir57209a3tEeqw_.marker = Marker_tyRef__N89ckikRqMir57209a3tEeqw;
NTI__9aiv9bp2t5icFNINcg9c4xi1Q_.size = sizeof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q);
NTI__9aiv9bp2t5icFNINcg9c4xi1Q_.align = NIM_ALIGNOF(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q);
NTI__9aiv9bp2t5icFNINcg9c4xi1Q_.kind = 18;
NTI__9aiv9bp2t5icFNINcg9c4xi1Q_.base = 0;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_50_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[771];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[771].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[771].offset = offsetof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q, counter);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[771].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[771].name = "counter";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_50_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[772];
NTI__AdFnD2YdADPeuJbG2YJ4vg_.size = sizeof(tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg);
NTI__AdFnD2YdADPeuJbG2YJ4vg_.align = NIM_ALIGNOF(tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg);
NTI__AdFnD2YdADPeuJbG2YJ4vg_.kind = 18;
NTI__AdFnD2YdADPeuJbG2YJ4vg_.base = 0;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_51_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[774];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[774].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[774].offset = offsetof(tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg, key);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[774].typ = (&NTI__eH2Hxsu3PVPvJHXo2xTrZw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[774].name = "key";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_51_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[775];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[775].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[775].offset = offsetof(tyObject_TIdPair__AdFnD2YdADPeuJbG2YJ4vg, val);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[775].typ = (&NTI__0vJvi4uHbxjbxlkkX7P1EA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[775].name = "val";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[773].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[773].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[773].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_51_2[0];
NTI__AdFnD2YdADPeuJbG2YJ4vg_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[773];
NTI__Mh9agqM29bm9aP5AUL1x7dZGA_.size = sizeof(tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*);
NTI__Mh9agqM29bm9aP5AUL1x7dZGA_.align = NIM_ALIGNOF(tySequence__Mh9agqM29bm9aP5AUL1x7dZGA*);
NTI__Mh9agqM29bm9aP5AUL1x7dZGA_.kind = 24;
NTI__Mh9agqM29bm9aP5AUL1x7dZGA_.base = (&NTI__AdFnD2YdADPeuJbG2YJ4vg_);
NTI__Mh9agqM29bm9aP5AUL1x7dZGA_.marker = Marker_tySequence__Mh9agqM29bm9aP5AUL1x7dZGA;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[772].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[772].offset = offsetof(tyObject_TIdTable__9aiv9bp2t5icFNINcg9c4xi1Q, data);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[772].typ = (&NTI__Mh9agqM29bm9aP5AUL1x7dZGA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[772].name = "data";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[770].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[770].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[770].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_50_2[0];
NTI__9aiv9bp2t5icFNINcg9c4xi1Q_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[770];
NTI__uyBDtVkS7CL1Bm1j1dvmcw_.size = sizeof(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**);
NTI__uyBDtVkS7CL1Bm1j1dvmcw_.align = NIM_ALIGNOF(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**);
NTI__uyBDtVkS7CL1Bm1j1dvmcw_.kind = 21;
NTI__uyBDtVkS7CL1Bm1j1dvmcw_.base = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
NTI__uyBDtVkS7CL1Bm1j1dvmcw_.flags = 3;
NTI__UWAp0mDjKLG1NEwUafSRhA_.size = sizeof(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA);
NTI__UWAp0mDjKLG1NEwUafSRhA_.align = NIM_ALIGNOF(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA);
NTI__UWAp0mDjKLG1NEwUafSRhA_.kind = 18;
NTI__UWAp0mDjKLG1NEwUafSRhA_.base = 0;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_56_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[777];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[777].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[777].offset = offsetof(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA, counter);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[777].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[777].name = "counter";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_56_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[778];
NTI__fUuF71MXGqn0RZORg9clE3w_.size = sizeof(tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w);
NTI__fUuF71MXGqn0RZORg9clE3w_.align = NIM_ALIGNOF(tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w);
NTI__fUuF71MXGqn0RZORg9clE3w_.kind = 18;
NTI__fUuF71MXGqn0RZORg9clE3w_.base = 0;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_57_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[780];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[780].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[780].offset = offsetof(tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w, key);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[780].typ = (&NTI__eH2Hxsu3PVPvJHXo2xTrZw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[780].name = "key";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_57_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[781];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[781].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[781].offset = offsetof(tyObject_TIdNodePair__fUuF71MXGqn0RZORg9clE3w, val);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[781].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[781].name = "val";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[779].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[779].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[779].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_57_2[0];
NTI__fUuF71MXGqn0RZORg9clE3w_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[779];
NTI__K8W16aeLg4OWxniQxtguMw_.size = sizeof(tySequence__K8W16aeLg4OWxniQxtguMw*);
NTI__K8W16aeLg4OWxniQxtguMw_.align = NIM_ALIGNOF(tySequence__K8W16aeLg4OWxniQxtguMw*);
NTI__K8W16aeLg4OWxniQxtguMw_.kind = 24;
NTI__K8W16aeLg4OWxniQxtguMw_.base = (&NTI__fUuF71MXGqn0RZORg9clE3w_);
NTI__K8W16aeLg4OWxniQxtguMw_.marker = Marker_tySequence__K8W16aeLg4OWxniQxtguMw;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[778].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[778].offset = offsetof(tyObject_TIdNodeTable__UWAp0mDjKLG1NEwUafSRhA, data);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[778].typ = (&NTI__K8W16aeLg4OWxniQxtguMw_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[778].name = "data";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[776].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[776].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[776].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_56_2[0];
NTI__UWAp0mDjKLG1NEwUafSRhA_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[776];
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.size = sizeof(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A);
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.align = NIM_ALIGNOF(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A);
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.kind = 18;
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.base = 0;
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_67_2[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[783];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[783].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[783].offset = offsetof(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A, counter);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[783].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[783].name = "counter";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_67_2[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[784];
NTI__EZfI4tFqtDSTQys2UInNjg_.size = sizeof(tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg);
NTI__EZfI4tFqtDSTQys2UInNjg_.align = NIM_ALIGNOF(tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg);
NTI__EZfI4tFqtDSTQys2UInNjg_.kind = 18;
NTI__EZfI4tFqtDSTQys2UInNjg_.base = 0;
NTI__EZfI4tFqtDSTQys2UInNjg_.flags = 2;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_68_3[0] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[786];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[786].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[786].offset = offsetof(tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg, h);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[786].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[786].name = "h";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_68_3[1] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[787];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[787].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[787].offset = offsetof(tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg, key);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[787].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[787].name = "key";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_68_3[2] = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[788];
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[788].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[788].offset = offsetof(tyObject_TNodePair__EZfI4tFqtDSTQys2UInNjg, val);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[788].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[788].name = "val";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[785].len = 3; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[785].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[785].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_68_3[0];
NTI__EZfI4tFqtDSTQys2UInNjg_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[785];
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.size = sizeof(tySequence__vhmj4KkIKPinmRXny9c2Q6Q*);
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.align = NIM_ALIGNOF(tySequence__vhmj4KkIKPinmRXny9c2Q6Q*);
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.kind = 24;
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.base = (&NTI__EZfI4tFqtDSTQys2UInNjg_);
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.flags = 2;
NTI__vhmj4KkIKPinmRXny9c2Q6Q_.marker = Marker_tySequence__vhmj4KkIKPinmRXny9c2Q6Q;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[784].kind = 1;
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[784].offset = offsetof(tyObject_TNodeTable__wN7B39cKxLpMkvKNm9bduZ0A, data);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[784].typ = (&NTI__vhmj4KkIKPinmRXny9c2Q6Q_);
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[784].name = "data";
TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[782].len = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[782].kind = 2; TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[782].sons = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_67_2[0];
NTI__wN7B39cKxLpMkvKNm9bduZ0A_.node = &TM__EnH1I9cGkGYbf9a1NwhuXDPg_0[782];
}

